.skip-link {
	position: absolute;
	top: 40px;
	left: 10px;
	display: inline-block;
	padding: 5px 10px;
	background: #000;
	color: #fff;
	z-index: 9999;
	font-size: 14px;
}
.skip-link:hover {
	background: #333;
}
.skip-link + .skip-link {
	top: 80px;
}
body.pc-acc-u a {
	text-decoration: underline !important;
}
body.pc-acc-f input {
  outline: auto;
}
body.pc-acc-animate-off *:not(#sidebar-nav):not(.penci-menu-hbg) {
	animation: none !important;
	transition: none !important;
	transform: none !important;
}