.penci-bookmark-btn.loop {
    position: absolute;
    top: 10px;
    left: 10px;
    z-index: 10;
    width: 25px;
    height: 25px;
    line-height: 25px;
    border: 1px solid #fff;
    color: #fff;
    text-align: center;
    border-radius: 50%;
}
.penci-bookmark-btn.loop:hover {
    background-color: var(--pcaccent-cl);
    border-color: var(--pcaccent-cl);
    color: #fff;
    cursor: pointer;
}
.penci-bookmark-btn.single:hover {
    color: var(--pcaccent-cl);
    cursor: pointer;
}
.penci-bookmark-btn.single:hover:before {
    color: var(--pcmeta-cl);
}
.penci-bookmark-btn.single i {
    margin-right: 3px;
    display: inline-block;
}