@font-face {
	font-family: "eicons";
	src: url("../fonts/eicons.eot?42232160");
	src: url("../fonts/eicons.eot?42232160#iefix") format("embedded-opentype"),
		url("../fonts/eicons.woff?42232160") format("woff"),
		url("../fonts/eicons.ttf?42232160") format("truetype"),
		url("../fonts/eicons.svg?42232160#eicons") format("svg");
	font-weight: normal;
	font-style: normal;
}
.wp-full-overlay-sidebar-content,
#customize-controls .customize-info.is-in-view,
#customize-controls .customize-section-title.is-in-view {
	margin-top: 0 !important;
}
.header-builder {
	position: absolute;
	right: 0;
	left: 0;
	bottom: 0;
	background: #fff;
	-webkit-transform: translateY(100%);
	-ms-transform: translateY(100%);
	transform: translateY(100%);
	-webkit-transition: all 0.2s ease-in-out;
	-o-transition: all 0.2s ease-in-out;
	transition: all 0.2s ease-in-out;
}
.header-builder-open .header-builder {
	-webkit-transform: translateY(0);
	-ms-transform: translateY(0);
	transform: translateY(0);
}
.flex-row {
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-flex-flow: row nowrap;
	flex-flow: row nowrap;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-justify-content: space-between;
	-ms-flex-pack: justify;
	justify-content: space-between;
	width: 100%;
}
body.rtl .flex-row {
	flex-flow: row-reverse nowrap;
}
.flex-col {
	max-height: 100%;
}
.flex-grow {
	-webkit-flex: 1;
	-ms-flex: 1;
	flex: 1;
	-ms-flex-negative: 1;
	-ms-flex-preferred-size: auto !important;
}
.flex-right {
	margin-left: auto;
}
.flex-left {
	margin-right: auto;
}
.notice-edit {
	margin-right: 30px;
}
.nav {
	width: 100%;
	position: relative;
	display: inline-block;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-flex-flow: row wrap;
	-ms-flex-flow: row wrap;
	flex-flow: row wrap;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
}
.nav-right {
	-webkit-justify-content: flex-end;
	-ms-flex-pack: end;
	justify-content: flex-end;
}
.cursor-pointer {
	cursor: pointer;
}
.header-builder-top-header {
	background: #333;
	padding: 10px 20px;
	box-sizing: border-box;
}
.header-builder-top-menu {
	-webkit-justify-content: flex-end;
	-ms-flex-pack: end;
	justify-content: flex-end;
}
.header-builder-desktop,
.header-builder-desktop-sticky,
.header-builder-mobile,
.header-builder-mobile-drawer {
	padding: 10px 10px;
	box-sizing: border-box;
	display: none;
}
.preview-desktop .header-builder-desktop,
.preview-desktop.sticky .header-builder-desktop-sticky,
.preview-mobile .header-builder-mobile,
.preview-mobile.drawer .header-builder-mobile-drawer,
.preview-mobile.mobile_menu .header-builder-mobile,
.preview-tablet .header-builder-mobile,
.preview-tablet.drawer .header-builder-mobile-drawer,
.preview-tablet.mobile_menu .header-builder-mobile {
	display: block;
}
.preview-desktop.sticky .header-builder-desktop,
.preview-mobile.drawer .header-builder-mobile,
.preview-tablet.drawer .header-builder-mobile {
	display: none;
}
.header-builder-wrapper > div {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	padding: 5px 0;
	position: relative;
	border: 1px solid transparent;
	background: #fff;
}
.header-builder-wrapper > div:hover {
	border: 1px solid var(--wp-admin-theme-color);
	box-sizing: border-box;
}
.header-builder-column {
	min-height: 25px;
	border: 1px solid #aaa;
	padding: 4px 25px 0 3px;
	position: relative;
	min-width: 50px;
	-webkit-flex: 1 auto;
	-ms-flex: 1 auto;
	flex: 1 auto;
	margin: 0 5px;
	background: #ececec;
	-webkit-transition: all 0.1s ease-in-out;
	-o-transition: all 0.1s ease-in-out;
	transition: all 0.1s ease-in-out;
}
.header-builder-left.header-builder-column,
.header-builder-left.normal ~ .header-builder-center.normal {
	padding: 4px 3px 0 4px;
}
.header-builder-column.active {
	background: #c5c5c5;
}
.header-builder-column.left {
	text-align: left;
}
.header-builder-column.center {
	text-align: center;
}
.header-builder-column.right {
	text-align: right;
}
.header-builder-column.grow {
	-webkit-flex: 1;
	-ms-flex: 1;
	flex: 1;
}
.header-builder-column.normal {
	-webkit-flex: 0 auto;
	-ms-flex: 0 auto;
	flex: 0 auto;
}
.header-builder-column:hover {
	background: #c5c5c5;
}
.header-builder-row-drag-handle,
.header-builder-row-option {
	position: absolute;
	z-index: 5;
	left: 45px;
	background: var(--wp-admin-theme-color);
	padding: 4px 15px;
	bottom: 100%;
	cursor: pointer;
	opacity: 0;
	visibility: hidden;
	font-size: 13px;
	margin-left: -1px;
	-webkit-transition: all 0.1s ease-in-out;
	-o-transition: all 0.1s ease-in-out;
	transition: all 0.1s ease-in-out;
	color: #fff;
}
.header-builder-row-drag-handle {
	left: 0;
	font-size: 10px;
}
.header-builder-wrapper > div:hover .header-builder-row-drag-handle,
.header-builder-wrapper > div:hover .header-builder-row-option {
	visibility: visible;
	opacity: 1;
}
.header-builder-top .header-builder-row-drag-handle {
	display: none;
}
.header-builder-mobile .header-builder-row-option,
.header-builder-mobile-drawer .header-builder-row-option,
.header-builder-sticky .header-builder-row-option,
.header-builder-top .header-builder-row-option {
	left: 0;
}
.device-mode > div,
.top-menu {
	display: inline-block;
	padding: 4px 20px;
	text-transform: uppercase;
	font-size: 12px;
	background: var(--wp-admin-theme-color);
	cursor: pointer;
	margin-right: 3px;
	border-radius: 2px;
	color: #fff;
	position: relative;
}
.preview-desktop .device-mode div.device-mode-desktop,
.preview-mobile .device-mode div.device-mode-mobile,
.preview-tablet .device-mode div.device-mode-mobile {
	background: #fff;
	color: #333;
	border-radius: 2px;
}
.top-menu.close {
	padding: 4px 10px;
}
.flex-clear {
	display: table;
	clear: both;
	content: "";
	padding: 0 !important;
	margin: 0 !important;
}
.header-builder-list {
	background: #f2f2f2;
	margin: 20px -10px -10px;
	padding: 15px 15px 5px;
	min-height: 85px;
	border-top: 1px solid silver;
	position: relative;
}
.header-builder-list:after {
	content: "";
	clear: both;
	display: table;
}
.header-builder-list .header-element:before {
	font-family: "eicons";
	content: "\e8b0";
	display: block;
	font-size: 24px;
	margin: 10px 0;
}
.header-builder-list .header-element.pb_bookmark:before {
	content: "\e91f";
}
/*.header-builder-list .header-element.ui-sortable-helper:before {
	display: none;
	min-height: auto;
}*/
.header-builder-list .header-element.pb_block:before,
.header-builder-list .header-element.pb_block_2:before {
	content: "\e841";
}
.header-builder-list .header-element.pb_button:before,
.header-builder-list .header-element.pb_button_mobile:before,
.header-builder-list .header-element.pb_button_mobile_2:before,
.header-builder-list .header-element.pb_button_2:before,
.header-builder-list .header-element.pb_button_3:before {
	content: "\e989";
}
.header-builder-list .header-element.pb_cart_icon:before {
	content: "\e8d2";
}
.header-builder-list .header-element.pb_compare_icon:before {
	content: "\e84c";
}
.header-builder-list .header-element.pb_date_time:before {
	content: "\e826";
}
.header-builder-list .header-element.pb_hamburger_menu:before {
	content: "\e86d";
}
.header-builder-list .header-element.pb_mobile_menu:before {
	content: "\e854";
}
.header-builder-list .header-element.pb_dropdown_menu:before {
	content: "\e83f";
}
.header-builder-list .header-element.pb_search_form:before {
	content: "\e8ca";
}
.header-builder-list .header-element.pb_html_ad:before,
.header-builder-list .header-element.pb_html_ad_2:before,
.header-builder-list .header-element.pb_html_ad_mobile:before,
.header-builder-list .header-element.pb_html_ad_mobile_2:before,
.header-builder-list .header-element.pb_html_ad_3:before {
	content: "\e870";
}
.header-builder-list .header-element.pb_second_menu:before,
.header-builder-list .header-element.pb_third_menu:before,
.header-builder-list .header-element.pb_main_menu:before {
	content: "\e83e";
}
.header-builder-list .header-element.pb_news_ticker:before {
	content: "\e84b";
}
.header-builder-list .header-element.pb_search_icon:before {
	content: "\e8ca";
}
.header-builder-list .header-element.pb_shortcode:before,
.header-builder-list .header-element.pb_shortcode_2:before,
.header-builder-list .header-element.pb_shortcode_mobile:before,
.header-builder-list .header-element.pb_shortcode_3:before {
	content: "\e883";
}
.header-builder-list .header-element.pb_social_icon:before,
.header-builder-list .header-element.pb_social_icon_mobile:before {
	content: "\e85e";
}
.header-builder-list .header-element.pb_vertical_line_mobile_1:before,
.header-builder-list .header-element.pb_vertical_line_mobile_2:before,
.header-builder-list .header-element.pb_vertical_line_1:before,
.header-builder-list .header-element.pb_vertical_line_2:before,
.header-builder-list .header-element.pb_vertical_line_3:before,
.header-builder-list .header-element.pb_vertical_line_4:before,
.header-builder-list .header-element.pb_vertical_line_5:before {
	content: "|";
}
.header-builder-list .header-element.pb_wishlist_icon:before {
	content: "\e923";
}
.header-builder-list .header-element.pb_login_register:before {
	content: "\e895";
}
.header-builder-list .header-element.pb_darkmode:before {
	content: "\e8fd";
}
.header-element {
	background: #fff;
	color: #3f3f3f;
	line-height: 18px;
	padding: 4px 8px;
	margin-bottom: 10px;
	font-size: 13px;
	cursor: pointer;
	display: inline-block;
	margin-right: 5px;
	border: 1px solid #868383;
	border-radius: 2px;
	transition: 0.15s all ease-in-out;
	text-align: center;
}
.header-element:hover {
	border-color: var(--wp-admin-theme-color);
	background-color: var(--wp-admin-theme-color);
	color: #fff;
}
.header-builder-column .header-element {
	margin: 2px 3px;
}
.header-builder-column {
	padding-right: 23px;
}
.header-builder-column.left {
	padding-left: 23px;
	padding-right: 0;
}
.header-builder-column .header-element:hover {
	background: #888;
	border: 1px solid #605e5e;
	color: #fff;
}
.header-builder-column .header-builder-drop-zone {
	width: 100%;
	min-height: 36px;
}
.ui-sortable-placeholder {
	background-color: var(--wp-admin-theme-color) !important;
	visibility: visible !important;
	vertical-align: top;
}
.header-element span {
	float: left;
}
.header-builder-column .header-element-close {
	display: block;
}
.header-element-close {
	display: none;
	margin: 0 0 0 4px;
}
.header-element-close:before {
	font-family: dashicons;
	content: "\f335";
	line-height: 14px;
	vertical-align: middle;
	color: #000;
	font-size: 16px;
	width: 14px;
	height: 14px;
	text-align: center;
	position: relative;
	top: -1px;
}
.header-tab {
	background: #f2f2f2;
	color: #000;
	left: 100%;
	border-bottom: 1px solid #aaa;
	text-transform: capitalize;
	padding: 10px 10px 0;
}
.header-tab i {
	margin-right: 5px;
}
.device-mode-desktop:hover .desktop-mode {
	opacity: 1;
	visibility: visible;
}
.header-tab:after {
	content: "";
	position: absolute;
	width: 0;
	height: 0;
	border-style: solid;
	right: 0;
	border-width: 8px 8px 8px 0;
	border-color: transparent var(--wp-admin-theme-color) transparent
		transparent;
	left: -8px;
	top: 9px;
	z-index: 100;
}
.header-tab ul {
	margin: 0;
	padding: 0;
}
.header-tab li,
.preview-desktop.sticky .desktop-mode .normal,
.preview-mobile.drawer .mobile-mode .menu,
.preview-tablet.drawer .mobile-mode .menu {
	display: inline-block;
	line-height: 10px;
	border: 1px solid var(--wp-admin-theme-color-darker-20);
	padding: 8px 12px 10px;
	margin-bottom: 0;
	background: var(--wp-admin-theme-color);
	color: #fff;
	text-align: center;
	border-bottom: 0;
	cursor: pointer;
	position: relative;
	top: 1px;
	height: 10px;
	-webkit-border-top-left-radius: 2px;
	-webkit-border-top-right-radius: 2px;
	-moz-border-radius-topleft: 2px;
	-moz-border-radius-topright: 2px;
	border-top-left-radius: 2px;
	border-top-right-radius: 2px;
}
.preview-desktop .desktop-mode .normal,
.preview-desktop.normal .desktop-mode .normal,
.preview-desktop.sticky .desktop-mode .sticky,
.preview-mobile .mobile-mode .menu,
.preview-mobile.drawer .mobile-mode .drawer,
.preview-mobile.mobile_menu .mobile-mode .menu,
.preview-tablet .mobile-mode .menu,
.preview-tablet.drawer .mobile-mode .drawer,
.preview-tablet.mobile_menu .mobile-mode .menu {
	background: #fff;
	color: #333;
	border: 1px solid #aaa;
	border-bottom: 0;
	-webkit-border-top-left-radius: 2px;
	-webkit-border-top-right-radius: 2px;
	-moz-border-radius-topleft: 2px;
	-moz-border-radius-topright: 2px;
	border-top-left-radius: 2px;
	border-top-right-radius: 2px;
}
.header-tab {
	display: none;
}
.preview-desktop .desktop-mode {
	display: block;
}
.preview-mobile .mobile-mode,
.preview-tablet .mobile-mode {
	display: block;
}
#accordion-section-penci_header_builder_block_section,
#customize-control-penci_hb_preset {
	display: none !important;
}
.header-builder-mobile-drawer .header-builder-column {
	padding: 4px 3px 10px;
}
.header-builder-mobile-drawer .header-builder-column .header-builder-drop-zone {
	height: 160px;
}
.header-builder-mobile-drawer .header-builder-row {
	width: 50%;
	display: inline-block;
}
.header-builder-mobile-drawer .header-builder-column .header-element {
	display: block;
}
.header-builder-mobile-drawer .header-builder-column .header-element:after {
	clear: both;
	content: "";
	display: table;
}
.header-builder-mobile-drawer .header-builder-column .header-element-close {
	float: right;
}
.preview-mobile .wp-full-overlay-main,
.preview-tablet .wp-full-overlay-main {
	margin-top: 10px !important;
}
.penci-btn-header-builder {
	display: inline-block;
	cursor: pointer;
	position: absolute;
	right: 0;
	top: 0;
	bottom: 0;
	width: 45px;
	text-align: center;
	border-left: 1px solid rgb(220, 220, 222);
}
.penci-btn-header-builder i:before {
	content: "\f0c9";
}
.header-builder-open .penci-btn-header-builder i:before {
	content: "\f00d";
}
.penci_builder_save_settings {
	padding: 5px 10px;
	border: 0;
	background-color: var(--wp-admin-theme-color);
	color: #fff;
	border-radius: 2px;
	line-height: 2.15384615;
	cursor: pointer;
	position: relative;
}
.penci_builder_save_settings.loading:before {
	font-family: inherit !important;
	line-height: 0;
	display: inline-block;
	width: 14px;
	height: 14px;
	margin: 0 10px 0 0;
	content: " " !important;
	animation: lds-dual-ring 0.4s linear infinite;
	vertical-align: middle;
	opacity: 1;
	border: 1px solid rgba(255, 255, 255, 0.5);
	border-left-color: #fff;
	border-top-color: #fff;
	border-radius: 50%;
}
.wrap div.penci-saved-message {
	margin-top: 15px;
}
.penci-saved-message.error {
	color: red;
}
.header-builder .top-edit-screen {
	color: #fff;
}
#penci_save_header {
	float: right;
	margin-left: 10px;
	margin-top: 10px;
	margin-right: 70px !important;
}
a.preview-header {
	padding: 4px 10px;
	display: inline-block;
	background: var(--wp-admin-theme-color);
	color: #fff;
	border-radius: 2px;
	margin: 0 0 0 10px;
	text-transform: uppercase;
	font-size: 12px;
}
.header-setting {
	position: absolute;
	right: 0;
	top: 0;
	background: #fff;
	color: #0e0e0e;
	line-height: 40px;
	width: 20px;
	text-align: center;
	border-left: 1px solid #8a8a8a;
	font-size: 12px;
	cursor: pointer;
}
.header-column-option-tooltip {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	position: absolute;
	background: #fff;
	color: #000;
	left: auto;
	right: -7px;
	font-size: 12px;
	bottom: auto;
	top: 100%;
	opacity: 0;
	visibility: hidden;
	margin-bottom: -10px;
	text-align: center;
	width: 330px;
	border: 1px solid var(--wp-admin-theme-color);
	margin-top: 6px;
	z-index: 100;
	-webkit-transition: all 0.1s ease-in-out;
	-o-transition: all 0.1s ease-in-out;
	transition: all 0.1s ease-in-out;
}

.header-builder-left .header-column-option-tooltip,
.header-builder-left.normal
	~ .header-builder-center.normal
	.header-column-option-tooltip {
	left: -7px;
	right: auto;
}

.header-column-option-tooltip > div {
	width: calc(100% / 2);
}

.header-builder-mobile .header-builder-top .header-column-option-tooltip {
	width: 150px;
}

.header-builder-mobile .header-builder-top .header-column-option-tooltip > div {
	width: 100%;
}

.header-column-option-tooltip > div h3 {
	background: var(--wp-admin-theme-color);
	margin: 0;
	color: #fff;
	padding: 6px 0;
	font-size: 13px;
}

.header-builder-column.active .header-column-option-tooltip {
	opacity: 1;
	visibility: visible;
	margin-bottom: 6px;
}

.header-column-option-tooltip ul {
	padding: 7px 5px;
	margin: 0;
}

.header-column-option-tooltip li {
	display: inline-block;
	margin: 0;
	padding: 2px 8px;
	cursor: pointer;
	background: #fff;
	color: #000;
	border: 1px solid transparent;
}

.header-column-option-tooltip li.active {
	border-color: #adadad;
}

.header-column-option-tooltip::after {
	content: "";
	position: absolute;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 0 8px 8px 8px;
	border-color: transparent transparent var(--wp-admin-theme-color);
	right: 8px;
	top: -7px;
	z-index: 100;
}

.header-builder-left .header-column-option-tooltip:after,
.header-builder-left.normal
	~ .header-builder-center.normal
	.header-column-option-tooltip:after {
	left: 8px;
	right: auto;
}