<?php
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/custom_css.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/featured_slider.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/featured_video.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/footer.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/general.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/homepage.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/logo_header.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/pages_options.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/popup.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/exit_popup.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/ad_blocker.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/helpful_articles.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/push_notification.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/post_layouts.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/sidebar.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/single_post.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/toc.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/social_media.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/speed_optimization.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/text_translation.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/topbar.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/verticalnav-hamburger.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/woo_translation.php';
require_once PENCI_SOLEDAD_DIR . '/inc/customizer/config/options/woocommerce.php';