<?php
namespace PenciSoledadElementor\Modules\PenciCircleInfo;

use PenciSoledadElementor\Base\Module_Base;

class Module extends Module_Base {

	public function get_name() {
		return 'penci-circle-info';
	}

	public function get_widgets() {

		return array( 'PenciCircleInfo' );
	}

}
