.penci-socialCT-wrap .penci-socialCT-item.penci-social-member a {
  background-color: #e2725c;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-foursquare a {
  background-color: #0d9ed1;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-px500 a {
  background-color: #00aeef;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-mixcloud a {
  background-color: #589fc3;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-goodreads a {
  background-color: #a06e0a;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-posts a {
  background-color: #1abc9c;
}
.penci-socialCT-wrap .penci-socialCT-item.penci-social-comments a {
  background-color: #9b59b6;
}
.penci-socialCT-wrap:not(.columns-1) {
  display: flex;
  flex-wrap: wrap;
  margin-left: -5px;
  margin-right: -5px;
}
.penci-socialCT-wrap:not(.columns-1) .penci-socialCT-item {
  flex: 0 0 auto;
  padding-left: 5px;
  padding-right: 5px;
}
.penci-socialCT-wrap.columns-2 .penci-socialCT-item {
  width: 50%;
}
.penci-socialCT-wrap.columns-3 .penci-socialCT-item {
  width: 33.3333333333%;
}
.penci-socialCT-wrap.columns-4 .penci-socialCT-item {
  width: 25%;
}
.penci-socialCT-wrap.columns-5 .penci-socialCT-item {
  width: 20%;
}
.penci-socialCT-wrap.columns-6 .penci-socialCT-item {
  width: 16.6666666667%;
}
.penci-socialCT-wrap.penci-socialCT-s7 .penci-socialCT-item {
  overflow: visible;
}
.penci-socialCT-wrap.penci-socialCT-s7 .penci-socialCT-item a {
  background: transparent !important;
  border: 1px solid var(--pcborder-cl);
  color: var(--pcheading-cl);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.08);
}
.penci-socialCT-wrap.penci-socialCT-s7 .penci-socialCT-item a:hover {
  background: rgba(55, 55, 55, 0.05) !important;
}
.penci-socialCT-wrap.penci-socialCT-s7 .penci-social-number {
  margin-right: 5px;
  font-weight: bold;
}
.penci-socialCT-wrap.penci-socialCT-s7 .penci-social-info-text {
  color: var(--pctext-cl);
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item span, .penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item span {
  display: block;
  text-align: center;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item span i, .penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item span i {
  display: block;
  margin-right: 0;
  font-size: 28px;
  line-height: 1.2;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item .penci-social-number, .penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item .penci-social-number {
  font-weight: bold;
  font-size: 18px;
  margin-top: 5px;
  margin-bottom: 5px;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item .penci-social-info-text, .penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item .penci-social-info-text {
  font-size: 11px;
  opacity: 0.5;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item a, .penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item a {
  justify-content: center;
  text-decoration: none;
  padding-top: 10px;
  padding-bottom: 10px;
}
.penci-socialCT-wrap.penci-socialCT-s8 {
  margin-left: 0;
  margin-right: 0;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item {
  padding-left: 0;
  padding-right: 0;
  margin-bottom: -1px;
  margin-right: -1px;
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item .penci-social-info-text {
  color: var(--pctext-cl);
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item a {
  background: transparent !important;
  border: 1px solid var(--pcborder-cl);
  color: var(--pcheading-cl);
}
.penci-socialCT-wrap.penci-socialCT-s8 .penci-socialCT-item a:hover {
  background-color: rgba(55, 55, 55, 0.05) !important;
}
.penci-socialCT-wrap.penci-socialCT-s9 {
  margin-left: -2px;
  margin-right: -2px;
}
.penci-socialCT-wrap.penci-socialCT-s9 .penci-socialCT-item {
  padding-left: 2px;
  padding-right: 2px;
  margin-bottom: 4px;
}

.penci-social-textcolored .penci-social-member i {
  color: #e2725c;
}
.penci-social-textcolored .penci-social-foursquare i {
  color: #0d9ed1;
}
.penci-social-textcolored .penci-social-px500 i {
  color: #00aeef;
}
.penci-social-textcolored .penci-social-mixcloud i {
  color: #589fc3;
}
.penci-social-textcolored .penci-social-goodreads i {
  color: #a06e0a;
}
.penci-social-textcolored .penci-social-posts i {
  color: #1abc9c;
}
.penci-social-textcolored .penci-social-comments i {
  color: #9b59b6;
}
