<?php defined( 'ABSPATH' ) || die ?>

<div class="postbox">
	<h3 class="hndle">
		<span><?php esc_html_e( 'Our WordPress Products', 'meta-box' ) ?></span>
	</h3>
	<div class="inside">
		<p><?php esc_html_e( 'Like this plugin? Check out our other WordPress products:', 'meta-box' ) ?></p>
		<p><a href="https://wpslimseo.com?utm_source=WordPress&utm_medium=link&utm_campaign=meta-box" target="_blank" rel="noopenner noreferrer">Slim SEO</a> - <?php esc_html_e( 'Automated & fast SEO plugin for WordPress', 'meta-box' ) ?></p>
		<p><a href="https://wpslimseo.com/slim-seo-schema/?utm_source=WordPress&utm_medium=link&utm_campaign=meta-box" target="_blank" rel="noopenner noreferrer">Slim SEO Schema</a> - <?php esc_html_e( 'The best schema plugin for WordPress', 'meta-box' ) ?></p>
		<p><a href="https://gretathemes.com?utm_source=WordPress&utm_medium=link&utm_campaign=meta-box" target="_blank" rel="noopenner noreferrer">GretaThemes</a> - <?php esc_html_e( 'Simple, elegant and clean WordPress themes', 'meta-box' ) ?></p>
	</div>
</div>
