.rwmb-video-item {
	position: relative;
	float: left;
	margin: 0 12px 12px 0;
	list-style: none;
	width: 300px;
	box-sizing: border-box;
}

.rwmb-video-item video {
	width: auto;
	height: 100%;
}

.rwmb-video-item .rwmb-media-info {
	margin-top: 12px;
}
