#customize-preview.is-soledad-fw-editor-open {
	height: calc(100% - 301px);
}
.customize-control-soledad .description {
	font-style: normal;
	font-weight: 300;
	font-size: .9em;
}
h2.customize-control-title:focus {
	background: #0f69ff;
	animation-name: title-focus;
	animation-duration: 1s;
	margin-left: -20px;
	margin-right: -20px;
	padding-left: 20px;
	padding-right: 20px;
}
@keyframes title-focus {
	from {
		background-color: #03087d;
	}
	to {
		background-color: #0f69ff;
	}
}
.customize-control input[type="tel"],
.customize-control input[type="url"],
.customize-control input[type="text"],
.customize-control input[type="password"],
.customize-control input[type="email"],
.customize-control input[type="number"],
.customize-control input[type="search"] {
	border: 1px solid #d4d4d4;
	background-image: none;
	background-position: 0% 0%;
	background-repeat: repeat;
	padding: 6px 12px;
	line-height: 18px;
	box-shadow: none;
}
.wp-full-overlay.expanded #customize-footer-actions .soledad-fw-footer-thanks {
	position: fixed;
	bottom: 8px;
	left: 150px;
	padding: 0;
	width: 90px;
	height: 25px;
	background-image: url("../images/soledad-fw-bottom.png");
	background-repeat: no-repeat;
	background-position: center center;
}
.soledad-fw-reset-section {
	position: absolute;
	top: 10px;
	right: 10px;
	background: #BDBDBD;
	opacity: .5;
	color: #fff;
	font-size: .8rem;
	border-radius: 3px;
	padding: 0 5px;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	-ms-transition: all .2s ease-in-out;
	-o-transition: all .2s ease-in-out;
	transition: all .2s ease-in-out;
	font-weight: bold;
}
.soledad-fw-reset-section .dashicons {
	font-size: .8rem;
	width: .8rem;
	height: .8rem;
	line-height: .8rem;
	vertical-align: baseline;
}
.soledad-fw-reset-section:hover,
.soledad-fw-reset-section:active {
	background: #F44336;
	color: #fff;
	font-weight: bold;
	opacity: 1;
}
.soledad-fw-reset-section:focus {
	opacity: 1;
	-webkit-box-shadow: 0 0 0 1px #F44336, 0 0 2px 1px rgba(200, 50, 30, 0.8);
	box-shadow: 0 0 0 1px #F44336, 0 0 2px 1px rgba(200, 50, 30, 0.8);
}
#customize-theme-controls .control-panel.control-panel-soledad-fw-expanded > ul.control-panel-content {
	position: relative;
	left: 0;
	display: block !important;
	margin-top: 0 !important;
}
#customize-theme-controls .control-panel.control-panel-soledad-fw-expanded > ul.control-panel-content .accordion-section-title {
	margin-left: 0;
}
#customize-theme-controls .control-panel.control-panel-soledad-fw-expanded > ul.control-panel-content > li.customize-info {
	margin-bottom: 0;
	border-top: none;
}
#customize-theme-controls .control-panel.control-panel-soledad-fw-expanded > ul.control-panel-content > li.customize-info .accordion-section-title {
	border-bottom: none !important;
}
#customize-theme-controls .control-section.control-section-soledad-fw-expanded > ul.accordion-section-content {
	position: relative;
	left: 0;
	display: block;
	margin-top: 0 !important;
}
#customize-theme-controls .control-section.control-section-soledad-fw-hover:hover:not(.open) > ul.accordion-section-content,
#customize-theme-controls .control-section.control-section-soledad-fw-hover:focus:not(.open) > ul.accordion-section-content,
#customize-theme-controls .control-section.control-section-soledad-fw-hover:active:not(.open) > ul.accordion-section-content {
	position: fixed;
	left: 300px;
	width: 300px;
	background: #eee;
	display: block;
	height: 100%;
	max-height: 100vh;
	overflow-y: scroll;
}
#customize-theme-controls .control-section.control-section-soledad-fw-hover:hover:not(.open) .customize-section-title,
#customize-theme-controls .control-section.control-section-soledad-fw-hover:focus:not(.open) .customize-section-title,
#customize-theme-controls .control-section.control-section-soledad-fw-hover:active:not(.open) .customize-section-title {
	display: none;
}
.customize-control-soledad-fw-checkbox input[type="checkbox"],
.customize-control-soledad-fw-multicheck input[type="checkbox"],
.customize-control-soledad-fw-repeater input[type="checkbox"] {
	position: relative;
	margin: 0 1rem 0 0;
	cursor: pointer;
	margin-bottom: 5px;
	width: 22px;
	height: 22px;
	border-radius: 3px;
	-webkit-border-radius: 3px;
}
.customize-control-soledad-fw-checkbox input[type="checkbox"]:before,
.customize-control-soledad-fw-multicheck input[type="checkbox"]:before,
.customize-control-soledad-fw-repeater input[type="checkbox"]:before {
	content: "";
	position: absolute;
	left: 0;
	z-index: 1;
	width: 100%;
	height: 100%;
	border: none;
}
.customize-control-soledad-fw-checkbox input[type="checkbox"]:after,
.customize-control-soledad-fw-multicheck input[type="checkbox"]:after,
.customize-control-soledad-fw-repeater input[type="checkbox"]:after {
	content: "";
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	background: #f2f2f2;
	cursor: pointer;
	border-radius: 3px;
	-webkit-border-radius: 3px;
}
.customize-control-soledad-fw-checkbox input[type="checkbox"]:checked:before,
.customize-control-soledad-fw-multicheck input[type="checkbox"]:checked:before,
.customize-control-soledad-fw-repeater input[type="checkbox"]:checked:before {
	content: "\f147";
	font-family: dashicons;
	font-size: 25px;
	left: 0;
	top: 2px;
}
.customize-control-soledad-fw-checkbox input[type="checkbox"]:checked:after,
.customize-control-soledad-fw-multicheck input[type="checkbox"]:checked:after,
.customize-control-soledad-fw-repeater input[type="checkbox"]:checked:after {
	background: #fff;
}
.wp-color-result {
	border-radius: 0;
	margin-right: 0;
	-webkit-box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.15);
	box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.15);
}
.wp-picker-container, .wp-picker-container:active {
	display: block;
}
.customize-control .wp-picker-open + .wp-picker-input-wrap {
	display: flex;
	justify-content: space-between;
}
.customize-control .wp-picker-container input[type=text].wp-color-picker {
	padding: 3px 5px;
	width: 100%;
}
.customize-control .wp-picker-container .wp-color-result {
	width: 100%;
}
.customize-control .wp-picker-container .button,
.customize-control .wp-color-result-text {
	transform: none !important;
	box-shadow: none;
	border-radius: 0;
}
.customize-control-soledad-fw-color .wp-picker-container .wp-color-result.button {
	padding-left: 40px;
}
.customize-control-soledad-fw-color .wp-picker-input-wrap label {
	width: 60%;
}
.customize-control-soledad-fw-color .wp-picker-input-wrap .button,
.customize-control-soledad-fw-color .wp-customizer .wp-picker-input-wrap .button {
	width: calc(40% - 6px);
}
.customize-control-soledad-fw-color .wp-picker-container a.wp-color-result {
	width: auto;
	display: block;
	border: none;
	padding-left: 40px;
}
.customize-control-soledad-fw-color .wp-picker-container .color-alpha {
	width: 40px !important;
	top: 0 !important;
}
.customize-control-soledad-fw-color .wp-picker-container a.wp-color-result:after {
	background: rgba(0, 0, 0, 0.25);
	color: #fff;
	border: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}
.customize-control-soledad-fw-color .wp-picker-container a.wp-color-result:focus:after,
.customize-control-soledad-fw-color .wp-picker-container a.wp-color-result:hover:after {
	color: #fff;
}
#soledad_fw_editor_pane {
	background: #fff;
	z-index: 1;
	padding-top: 5px;
	border-top: 1px solid #dedede;
	position: absolute;
	bottom: 0;
	width: 100%;
	-webkit-transition: bottom .2s;
	-moz-transition: bottom .2s;
	-ms-transition: bottom .2s;
	-o-transition: bottom .2s;
	transition: bottom .2s;
}
#soledad_fw_editor_pane.hide {
	bottom: -301px;
	z-index: -999;
}
.mce-container.mce-panel.mce-floatpanel.mce-window.mce-in {
	z-index: 99999999 !important;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper {
	display: flex;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .multicolor-single-color-wrapper {
	width: 100%;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .multicolor-single-color-wrapper label {
	display: block;
	text-align: center;
	padding: 3px;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .wp-picker-container {
	width: 100%;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .wp-picker-container a.wp-color-result {
	width: 100%;
	height: 30px;
	padding-left: 0;
	border-radius: 0;
	border: none;
	margin-right: 0;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .wp-picker-container a.wp-color-result > span {
	border-top-left-radius: 0 !important;
	border-bottom-left-radius: 0 !important;
	border-top-right-radius: 0 !important;
	border-bottom-right-radius: 0 !important;
}
.customize-control-soledad-fw-multicolor .multicolor-group-wrapper .wp-picker-container a.wp-color-result:after {
	display: none;
}
.customize-control-soledad-fw-color-palette label {
	position: relative;
	display: inline-block;
	padding: 2px 0;
}
.customize-control-soledad-fw-color-palette .color-palette-color {
	color: transparent;
	display: block;
	width: 42px;
	height: 42px;
	overflow: hidden;
	border-radius: 50%;
	-webkit-box-shadow: inset 3px 3px 13px 2px rgba(0, 0, 0, 0.22);
	box-shadow: inset 3px 3px 13px 2px rgba(0, 0, 0, 0.22);
	border: 1px solid rgba(0, 0, 0, 0.2);
}
.customize-control-soledad-fw-color-palette .colors-wrapper {
	max-height: 300px;
	overflow-y: auto;
	padding: 10px;
}
.customize-control-soledad-fw-color-palette .colors-wrapper input {
	display: none;
}
.customize-control-soledad-fw-color-palette .colors-wrapper input:checked + label .color-palette-color {
	-webkit-box-shadow: 1px 1px 10px 1px #333333;
	box-shadow: 1px 1px 10px 1px #333333;
	border: 1px solid rgba(0, 0, 0, 0.3);
}
.wp-customizer div.ui-datepicker {
	z-index: 500001 !important;
	width: 255px;
	background: #fff;
	border: 1px solid #dedede;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header {
	padding: 10px;
	background: #e5e5e5;
	border-bottom: 1px solid #fff;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev {
	display: block;
	position: absolute;
	width: 1em;
	overflow: hidden;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next:after,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next:before,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev:after,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev:before {
	font-family: dashicons;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next:after:hover,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next:before:hover,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev:after:hover,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev:before:hover {
	cursor: pointer;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next .ui-icon,
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev .ui-icon {
	display: none;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev {
	left: 10px;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-prev:before {
	content: "\f341";
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next {
	right: 10px;
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-next:after {
	content: "\f345";
}
.wp-customizer div.ui-datepicker .ui-datepicker-header .ui-datepicker-title {
	text-align: center;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar {
	border-collapse: collapse;
	width: 100%;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar thead {
	background: #e5e5e5;
	padding: 5px;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td {
	text-align: center;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td a {
	display: block;
	padding: 5px;
	color: #333;
	text-decoration: none;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td a.ui-state-active,
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td a:hover {
	color: #fff;
	background-color: #0073aa;
}
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td.ui-state-disabled a,
.wp-customizer div.ui-datepicker .ui-datepicker-calendar tr td.ui-state-disabled .ui-state-default a {
	color: #999;
}
.customize-control-soledad-fw-dashicons label {
	position: relative;
	display: inline-block;
}
.customize-control-soledad-fw-dashicons .icons-wrapper {
	max-height: 300px;
	overflow-y: scroll;
}
.customize-control-soledad-fw-dashicons .icons-wrapper h4 {
	font-weight: 300;
	margin: 0.7em 0;
}
.customize-control-soledad-fw-dashicons .icons-wrapper .dashicons {
	padding: 3px;
	font-size: 25px;
	width: 25px;
	height: 25px;
	border: 1px solid transparent;
}
.customize-control-soledad-fw-dashicons .icons-wrapper input {
	display: none;
}
.customize-control-soledad-fw-dashicons .icons-wrapper input:checked + label .dashicons {
	border: 1px solid #3498DB;
	color: #000;
}
.customize-control-soledad-fw-dimension .input-wrapper .invalid-value {
	display: none;
	background: #D32F2F;
	font-size: 0.85em;
	color: #fff;
	float: left;
	padding: 2px 0;
	border-radius: 3px;
}
.customize-control-soledad-fw-dimension .input-wrapper.invalid .invalid-value {
	display: block;
	width: 98%;
	text-align: center;
}
.customize-control-soledad-fw-dimension .input-wrapper.invalid input[type="text"]:focus {
	border-color: #D32F2F;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content {
	position: relative;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button {
	position: absolute;
	right: 0;
	color: #aaa;
	border: none;
	padding: 0 5px;
	width: 20px;
	height: calc(50% + 0.5em);
	border-radius: 0;
	-webkit-border-radius: 0;
	box-shadow: none;
	-webkit-box-shadow: none;
	margin: 0;
	text-align: center;
	border-left: 1px solid #e0e0e0;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button .ui-button-text {
	display: none;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-down:before,
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-up:before {
	font-family: dashicons;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-up {
	top: -50%;
	border-bottom: 1px solid #e0e0e0;
	padding-bottom: 1px;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-up:before {
	content: "\f343";
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-down {
	top: 50%;
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button.ui-spinner-down:before {
	content: "\f347";
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button:hover {
	color: inherit;
}
.customize-control-soledad-fw-palette input[type="radio"] {
	display: none;
}
.customize-control-soledad-fw-palette input[type="radio"]:checked + label {
	border: 3px solid rgba(0, 0, 0, 0.4);
}
.customize-control-soledad-fw-palette label {
	background: none;
	padding: 0;
	border-top: 3px solid transparent;
	border-bottom: 3px solid transparent;
	margin-bottom: 5px;
	display: flex;
}
.customize-control-soledad-fw-palette label span {
	padding: 10px 0;
	flex-grow: 1;
	font-size: 0;
	line-height: 10px;
	color: transparent;
	-webkit-transition: all 200ms ease-in-out;
	-moz-transition: all 200ms ease-in-out;
	-ms-transition: all 200ms ease-in-out;
	-o-transition: all 200ms ease-in-out;
	transition: all 200ms ease-in-out;
	border-top: 1px solid rgba(0, 0, 0, 0.1);
	border-bottom: 1px solid rgba(0, 0, 0, 0.1);
}
.customize-control-soledad-fw-palette label span:first-child {
	border-left: 1px solid rgba(0, 0, 0, 0.1);
}
.customize-control-soledad-fw-palette label span:last-child {
	border-right: 1px solid rgba(0, 0, 0, 0.1);
}
.customize-control-soledad-fw-palette label span:hover {
	padding: 10px;
	flex-grow: 3;
	min-width: 60px;
	font-size: 10px;
	line-height: 10px;
	color: #000;
}
.customize-control-soledad-fw-radio input[type=radio] {
	width: 18px;
	height: 18px;
}
.customize-control-soledad-fw-radio input[type=radio]:checked:before {
	width: 10px;
	height: 10px;
	margin: 3px;
}
.customize-control-soledad-fw-radio label {
	display: list-item;
	margin-bottom: 7px;
}
.customize-control-soledad-fw-radio .customize-inside-control-row label {
	display: inline;
	vertical-align: top;
}
.customize-control-soledad-fw-radio label .option-description {
	display: block;
	color: rgba(0, 0, 0, 0.35);
	font-size: 0.9em;
	padding-left: 25px;
}
.customize-control-soledad-fw-radio-buttonset .buttonset {
	margin-top: 15px;
}
.customize-control-soledad-fw-radio-buttonset .buttonset .switch-label {
	background: #ebebeb;
	color: #666;
	border: 1px solid rgba(0, 0, 0, 0.1);
	padding: 6px 12px;
	margin: 0;
	font-size: 12px;
	margin-right: 4px;
	border-radius: 2px;
	text-shadow: 0 1px 0 #fff;
	display: inline-block;
}
.customize-control-soledad-fw-radio-buttonset .buttonset .switch-label:last-child {
	margin-right: 0;
}
.customize-control-soledad-fw-radio-buttonset .buttonset .switch-input {
	display: none;
}
.customize-control-soledad-fw-radio-buttonset .buttonset .switch-input:checked + .switch-label {
	background-color: #0f69ff;
	color: #fff;
	text-shadow: 0 1px 1px #3d6fc3;
}
.customize-control-soledad-fw-radio-image label {
	position: relative;
	display: inline-block;
}
.customize-control-soledad-fw-radio-image .image label {
	padding: 3px;
	margin: 4px 2px;
	box-sizing: border-box;
	border: 3px solid #ddd;
}
.customize-control-soledad-fw-radio-image input:checked + label {
	-webkit-box-shadow: 0 0 5px 2px rgba(0, 0, 0, 0.25);
	box-shadow: 0 0 5px 2px rgba(0, 0, 0, 0.25);
	border-color: #3498DB;
}
.customize-control-soledad-fw-radio-image input {
	display: none;
}
.customize-control-soledad-fw-radio-image input img {
	border: 1px solid transparent;
}
.customize-control-soledad-fw-radio-image input + label img {
	display: block;
}
.customize-control-soledad-fw-radio-image input + label .image-clickable {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	width: 100%;
	height: 100%;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row {
	border: 1px solid #ddd;
	margin-top: 0.5rem;
	position: relative;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row.minimized {
	background: #f5f5f5;
	padding: 0;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row.minimized:hover {
	background: #fbfbfb;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row.minimized .repeater-row-content {
	display: none;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row label {
	margin-bottom: 12px;
	clear: both;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row .repeater-field.repeater-field- {
	display: none;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row .repeater-field.repeater-field-radio-image input {
	display: none;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row .repeater-field.repeater-field-radio-image input img {
	border: 1px solid transparent;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row .repeater-field.repeater-field-radio-image input:checked + label img {
	-webkit-box-shadow: 0 0 5px 2px rgba(0, 0, 0, 0.25);
	box-shadow: 0 0 5px 2px rgba(0, 0, 0, 0.25);
	border: 1px solid #3498DB;
}
.customize-control-soledad-fw-repeater .repeater-fields .repeater-row .repeater-field:last-child {
	border-bottom: none;
	padding-bottom: 0;
}
.customize-control-soledad-fw-repeater .repeater-add-wrapper {
	padding: 8px;
	margin-top: 10px;
	text-align: center;
	border: 1px dashed #e0e0e0;
}
.customize-control-soledad-fw-repeater .repeater-add-wrapper .repeater-add {
	width: 100px;
}
.customize-control-soledad-fw-repeater .repeater-row-content {
	padding: 12px 15px;
}
.customize-control-soledad-fw-repeater .repeater-field {
	margin-bottom: 12px;
	width: 100%;
	clear: both;
}
.customize-control-soledad-fw-repeater .repeater-field .customize-control-title {
	font-size: 13px;
	line-height: initial;
	margin-bottom: 0.5em;
}
.customize-control-soledad-fw-repeater .repeater-field .customize-control-description {
	font-size: 13px;
	line-height: initial;
}
.customize-control-soledad-fw-repeater .repeater-field.repeater-field-hidden {
	margin: 0;
	padding: 0;
	border: 0;
}
.customize-control-soledad-fw-repeater .repeater-field-checkbox label {
	line-height: 28px;
}
.customize-control-soledad-fw-repeater .repeater-field-checkbox input {
	line-height: 28px;
	margin-right: 5px;
}
.customize-control-soledad-fw-repeater .repeater-field-textarea textarea {
	width: 100%;
	resize: vertical;
}
.customize-control-soledad-fw-repeater .repeater-row-header {
	border-bottom: 1px solid #e0e0e0;
	position: relative;
	padding: 10px 15px 10px 35px;
	height: auto;
	min-height: 20px;
	line-height: 30px;
	overflow: hidden;
	word-wrap: break-word;
}
.customize-control-soledad-fw-repeater .repeater-row-header:hover {
	cursor: move;
}
.customize-control-soledad-fw-repeater .repeater-row-header .dashicons {
	font-size: 18px;
	position: absolute;
	right: 12px;
	top: 2px;
	color: #a0a5aa;
}
.customize-control-soledad-fw-repeater .repeater-row-label {
	font-size: 13px;
	font-weight: 600;
	line-height: 20px;
	display: block;
	text-transform: capitalize;
	width: 90%;
	overflow: hidden;
	height: 18px;
}
.customize-control-soledad-fw-repeater .repeater-row-remove {
	color: #a00;
}
.customize-control-soledad-fw-repeater .repeater-row-remove:hover {
	color: #f00;
}
.customize-control-soledad-fw-repeater .repeater-minimize {
	line-height: 36px;
}
.customize-control-soledad-fw-repeater .remove-button,
.customize-control-soledad-fw-repeater .upload-button {
	width: 48%;
}
.soledad-fw-image-attachment {
	margin: 0;
	text-align: center;
	margin-bottom: 10px;
}
.soledad-fw-image-attachment img {
	display: inline-block;
}
.soledad-fw-file-attachment {
	margin: 0;
	text-align: center;
	margin-bottom: 10px;
}
.soledad-fw-file-attachment .file {
	display: block;
	padding: 10px 5px;
	border: 1px dotted #c3c3c3;
	background: #f9f9f9;
}
.limit {
	padding: 3px;
	border-radius: 3px;
}
.limit.highlight {
	background: #D32F2F;
	color: #fff;
}
.selectize-control {
	position: relative;
}
.selectize-input {
	border-color: #d4d4d4;
	border-radius: 0;
	padding: 6px 12px;
	box-shadow: none;
}
.selectize-input.focus {
	box-shadow: none;
	border-color: #d4d4d4;
}
.selectize-control.single .selectize-input, .selectize-dropdown, .selectize-dropdown.single {
	border-color: #d4d4d4;
	border-radius: 0;
}
.customize-control .selectize-control.single .selectize-input {
	border-color: #d4d4d4;
	background: #fff;
	box-shadow: none;
	padding-right: 30px;
}
.selectize-control.single .selectize-input:after {
	font-family: dashicons;
	content: "\f347";
	color: #aaa;
	display: block;
	position: absolute;
	top: 0;
	right: 0;
	margin-top: 0;
	width: 30px;
	height: 36px;
	line-height: 36px;
	text-align: center;
	padding: 0;
	border: 0;
	border-left: 1px solid #e0e0e0;
}
.selectize-control.single .selectize-input.dropdown-active:after {
	content: "\f343";
	margin-top: -1px;
	border: 0;
	border-left: 1px solid #e0e0e0;
}
.selectize-dropdown {
	position: relative;
	top: -3px !important;
}
.selectize-dropdown .active {
	background: #e5efff !important;
}
.selectize-dropdown-content .selected {
	background: #f5f5f5 !important;
	color: #aaa !important;
}
.selectize-control.multi .selectize-input.has-items {
	padding: 1px 4px 4px;
}
.selectize-control.multi .selectize-input [data-value] {
	font-size: 12px;
	line-height: 16px;
	background: #0f69ff !important;
	border-radius: 2px;
	border: 1px solid rgba(0, 0, 0, 0.1);
	box-shadow: none !important;
	margin: 4px 4px 0 0;
}
.selectize-control.plugin-remove_button [data-value] .remove {
	background: rgba(0, 0, 0, 0.1);
	border-left: 0 !important;
}
/* fix dropdown overlap */
#customize-theme-controls .customize-pane-child.accordion-section-content {
	min-height: 100%;
}
.customize-control select {
	width: 100%;
	font-family: inherit;
	font-size: 13px;
	border-color: #d4d4d4;
	padding: 0 12px;
	height: 32px;
	margin: 0;
	-webkit-appearance: none;
	background: url(data:image/svg+xml;utf8;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iaXNvLTg4NTktMSI/Pgo8IS0tIEdlbmVyYXRvcjogQWRvYmUgSWxsdXN0cmF0b3IgMTYuMC4wLCBTVkcgRXhwb3J0IFBsdWctSW4gLiBTVkcgVmVyc2lvbjogNi4wMCBCdWlsZCAwKSAgLS0+CjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+CjxzdmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiB4bWxuczp4bGluaz0iaHR0cDovL3d3dy53My5vcmcvMTk5OS94bGluayIgdmVyc2lvbj0iMS4xIiBpZD0iQ2FwYV8xIiB4PSIwcHgiIHk9IjBweCIgd2lkdGg9IjE2cHgiIGhlaWdodD0iMTZweCIgdmlld0JveD0iMCAwIDMwNiAzMDYiIHN0eWxlPSJlbmFibGUtYmFja2dyb3VuZDpuZXcgMCAwIDMwNiAzMDY7IiB4bWw6c3BhY2U9InByZXNlcnZlIj4KPGc+Cgk8ZyBpZD0iZXhwYW5kLW1vcmUiPgoJCTxwb2x5Z29uIHBvaW50cz0iMjcwLjMsNTguNjUgMTUzLDE3NS45NSAzNS43LDU4LjY1IDAsOTQuMzUgMTUzLDI0Ny4zNSAzMDYsOTQuMzUgICAiIGZpbGw9IiNhYWFhYWEiLz4KCTwvZz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8Zz4KPC9nPgo8L3N2Zz4K) no-repeat 96% 50%;
	background-size: 10px;
	box-shadow: none;
}
.customize-control-soledad-fw-gradient input[type=range],
.customize-control-soledad-fw-slider input[type=range] {
	-webkit-appearance: none;
	-webkit-transition: background 0.3s;
	-moz-transition: background 0.3s;
	transition: background 0.3s;
	background-color: rgba(0, 0, 0, 0.1);
	height: 5px;
	width: calc(100% - 100px);
	padding: 0;
}
.customize-control-soledad-fw-gradient input[type=range]:focus,
.customize-control-soledad-fw-slider input[type=range]:focus {
	box-shadow: none;
	outline: none;
}
.customize-control-soledad-fw-gradient input[type=range]:focus,
.customize-control-soledad-fw-slider input[type=range]:hover {
	background-color: rgba(0, 0, 0, 0.25);
}
.customize-control-soledad-fw-gradient input[type=range]::-webkit-slider-thumb,
.customize-control-soledad-fw-slider input[type=range]::-webkit-slider-thumb {
	-webkit-appearance: none;
	width: 15px;
	height: 15px;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	background-color: #3498D9;
}
.customize-control-soledad-fw-gradient input[type=range]::-webkit-slider-thumb,
.customize-control-soledad-fw-slider input[type=range]::-webkit-slider-thumb {
	-webkit-appearance: none;
	width: 15px;
	height: 15px;
	border: none;
	border-radius: 50%;
	background-color: #3498D9;
}
.customize-control-soledad-fw-gradient input[type=range]::-moz-range-thumb,
.customize-control-soledad-fw-slider input[type=range]::-moz-range-thumb {
	width: 15px;
	height: 15px;
	border: none;
	border-radius: 50%;
	background-color: #3498D9;
}
.customize-control-soledad-fw-gradient input[type=range]::-ms-thumb,
.customize-control-soledad-fw-slider input[type=range]::-ms-thumb {
	width: 15px;
	height: 15px;
	border-radius: 50%;
	border: 0;
	background-color: #3498D9;
}
.customize-control-soledad-fw-gradient input[type=range]::-moz-range-track,
.customize-control-soledad-fw-slider input[type=range]::-moz-range-track {
	border: inherit;
	background: transparent;
}
.customize-control-soledad-fw-gradient input[type=range]::-ms-track,
.customize-control-soledad-fw-slider input[type=range]::-ms-track {
	border: inherit;
	color: transparent;
	background: transparent;
}
.customize-control-soledad-fw-gradient input[type=range]::-ms-fill-lower,
.customize-control-soledad-fw-gradient input[type=range]::-ms-fill-upper,
.customize-control-soledad-fw-slider input[type=range]::-ms-fill-lower,
.customize-control-soledad-fw-slider input[type=range]::-ms-fill-upper {
	background: transparent;
}
.customize-control-soledad-fw-gradient input[type=range]::-ms-tooltip,
.customize-control-soledad-fw-slider input[type=range]::-ms-tooltip {
	display: none;
}
.customize-control-soledad-fw-gradient .soledad_fw_range_value,
.customize-control-soledad-fw-slider .soledad_fw_range_value {
	display: inline-block;
	font-size: 14px;
	padding: 0 5px;
	font-weight: 400;
	position: relative;
	top: 2px;
}
.customize-control-soledad-fw-gradient .soledad-fw-slider-reset,
.customize-control-soledad-fw-slider .soledad-fw-slider-reset {
	color: rgba(0, 0, 0, 0.2);
	float: right;
	-webkit-transition: color 0.5s ease-in;
	-moz-transition: color 0.5s ease-in;
	-ms-transition: color 0.5s ease-in;
	-o-transition: color 0.5s ease-in;
	transition: color 0.5s ease-in;
}
.customize-control-soledad-fw-gradient .soledad-fw-slider-reset span,
.customize-control-soledad-fw-slider .soledad-fw-slider-reset span {
	font-size: 16px;
	line-height: 30px;
}
.customize-control-soledad-fw-gradient .soledad-fw-slider-reset:hover,
.customize-control-soledad-fw-slider .soledad-fw-slider-reset:hover {
	color: red;
}
.customize-control-soledad-fw-sortable ul.ui-sortable li {
	padding: 5px 10px;
	border: 1px solid #333;
	background: #fff;
}
.customize-control-soledad-fw-sortable ul.ui-sortable li .dashicons.dashicons-menu {
	float: right;
}
.customize-control-soledad-fw-sortable ul.ui-sortable li .dashicons.visibility {
	margin-right: 10px;
}
.customize-control-soledad-fw-sortable ul.ui-sortable li.invisible {
	color: #aaa;
	border: 1px dashed #aaa;
}
.customize-control-soledad-fw-sortable ul.ui-sortable li.invisible .dashicons.visibility {
	color: #aaa;
}
.customize-control-soledad-fw-spacing .wrapper {
	margin-top: 10px;
	padding: 14px;
	border: 1px solid #ddd;
}
.customize-control-soledad-fw-spacing .wrapper .control {
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
}
.customize-control-soledad-fw-spacing .wrapper .control > div {
	width: 47%;
}
.customize-control-soledad-fw-spacing .control > .top, .customize-control-soledad-fw-spacing .control > .bottom {
	margin-bottom: 10px;
}
.customize-control-soledad-fw-spacing .wrapper .control > div h5 {
	margin: 0 0 5px;
}
.customize-control-soledad-fw-spacing .wrapper .control > div .inner {
	display: flex;
}
.customize-control-soledad-fw-spacing .wrapper .control > div .inner input[type="number"] {
	width: 50%;
	height: 36px;
}
.customize-control-soledad-fw-spacing .wrapper .control > div .inner .selectize-control.single {
	width: 50%;
}
.customize-control-soledad-fw-spacing .wrapper .control > div .inner .selectize-control.single > .selectize-input {
	height: 36px;
}
.customize-control-soledad-fw-spacing .wrapper .input-wrapper .invalid-value {
	display: none;
	background: #D32F2F;
	font-size: 0.85em;
	color: #fff;
	float: left;
	padding: 2px 0;
	border-radius: 3px;
}
.customize-control-soledad-fw-spacing .wrapper .input-wrapper.invalid .invalid-value {
	display: block;
	width: 98%;
	text-align: center;
}
.customize-control-soledad-fw-spacing .wrapper .input-wrapper.invalid input[type="text"]:focus {
	border-color: #D32F2F;
}
.customize-control-soledad-fw-switch input[type="checkbox"] {
	display: none;
}
.customize-control-soledad-fw-switch .switch {
	border: none;
	margin-bottom: 1.5rem;
	outline: 0;
	padding: 0;
	position: relative;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}
.customize-control-soledad-fw-switch .switch label {
	background: rgba(0, 0, 0, 0.2);
	color: transparent;
	cursor: pointer;
	display: block;
	margin-bottom: 1rem;
	position: relative;
	transition: left 0.15s ease-out;
	height: 2rem;
	width: 4rem;
	font-family: Monaco, "Lucida Sans Typewriter", "Lucida Typewriter", "Courier New", Courier, monospace;
}
.customize-control-soledad-fw-switch .switch label:after {
	background: #FFFFFF;
	content: "";
	display: block;
	height: 1.5rem;
	left: 0.25rem;
	position: absolute;
	top: 0.25rem;
	width: 1.5rem;
	-webkit-transition: all 0.25s ease-in-out;
	-moz-transition: all 0.25s ease-in-out;
	-ms-transition: all 0.25s ease-in-out;
	-o-transition: all 0.25s ease-in-out;
	transition: all 0.25s ease-in-out;
}
.customize-control-soledad-fw-switch .switch input {
	left: 10px;
	opacity: 0;
	padding: 0;
	position: absolute;
	top: 9px;
}
.customize-control-soledad-fw-switch .switch input + label {
	margin-left: 0;
	margin-right: 0;
}
.customize-control-soledad-fw-switch .switch input:checked + label {
	background: #3498DB;
}
.customize-control-soledad-fw-switch .switch input:checked + label:after {
	left: 2.25rem;
	background: #ffffff;
}
.customize-control-soledad-fw-switch .switch.round {
	border-radius: 1000px;
}
.customize-control-soledad-fw-switch .switch.round label {
	border-radius: 2rem;
}
.customize-control-soledad-fw-switch .switch.round label:after {
	border-radius: 2rem;
}
.customize-control-soledad-fw-switch .switch-off,
.customize-control-soledad-fw-switch .switch-on {
	line-height: 32px;
	font-weight: bold;
	padding: 0 10px;
}
.customize-control-soledad-fw-switch .switch-on {
	color: #fff;
	padding-right: 5px;
}
.customize-control-soledad-fw-switch .switch-off {
	color: #777;
	padding-left: 5px;
}
.customize-control-soledad-fw-generic textarea {
	width: 100%;
	border: 1px solid rgba(0, 0, 0, 0.1);
	-webkit-box-shadow: none;
	box-shadow: none;
}
.customize-control-soledad-fw-toggle label {
	display: flex;
	flex-wrap: wrap;
}
.customize-control-soledad-fw-toggle label .customize-control-title {
	width: calc(100% - 55px);
	padding-right: 10px;
}
.customize-control-soledad-fw-toggle label .description {
	order: 99;
}
.customize-control-soledad-fw-toggle input[type="checkbox"] {
	display: none;
}
.customize-control-soledad-fw-toggle .switch {
	border: 1px solid rgba(0, 0, 0, 0.1);
	margin-top: 8px;
	display: inline-block;
	width: 35px;
	height: 10px;
	border-radius: 8px;
	background: #ebebeb;
	vertical-align: middle;
	position: relative;
	cursor: pointer;
	user-select: none;
	transition: background 350ms ease;
}
.customize-control-soledad-fw-toggle .switch:after {
	content: "";
	display: block;
	width: 16px;
	height: 16px;
	border-radius: 50%;
	position: absolute;
	top: 50%;
	left: -1px;
	transition: all 350ms cubic-bezier(0, 0.95, 0.38, 0.98), background 150ms ease;
}
.customize-control-soledad-fw-toggle .switch:after {
	background: #ccc;
	border: 1px solid rgba(0, 0, 0, 0.1);
	transform: translate3d(0, -50%, 0);
}
.customize-control-soledad-fw-toggle input:checked + .switch {
	background: #d4e4ff;
}
.customize-control-soledad-fw-toggle input:checked + .switch:after {
	background: #0f69ff;
	transform: translate3d(100%, -50%, 0);
}
.customize-control-soledad-fw-typography .wrapper,
.customize-control-soledad-fw-gradient .wrapper {
	margin-top: 10px;
	padding: 14px;
	border: 1px solid #ddd;
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
}
.customize-control-soledad-fw-typography .wrapper .color,
.customize-control-soledad-fw-typography .wrapper .font-family,
.customize-control-soledad-fw-typography .wrapper .font-size,
.customize-control-soledad-fw-typography .wrapper .letter-spacing,
.customize-control-soledad-fw-typography .wrapper .line-height,
.customize-control-soledad-fw-typography .wrapper .subsets,
.customize-control-soledad-fw-typography .wrapper .text-transform,
.customize-control-soledad-fw-typography .wrapper .variant,
.customize-control-soledad-fw-gradient .wrapper .color,
.customize-control-soledad-fw-gradient .wrapper .range {
	width: 100%;
	float: none;
	clear: both;
}
.customize-control-soledad-fw-typography .wrapper .font-family h5 {
	margin: 0 0 5px;
}
.customize-control-soledad-fw-typography .wrapper .color h5,
.customize-control-soledad-fw-typography .wrapper .font-size h5,
.customize-control-soledad-fw-typography .wrapper .letter-spacing h5,
.customize-control-soledad-fw-typography .wrapper .line-height h5,
.customize-control-soledad-fw-typography .wrapper .subsets h5,
.customize-control-soledad-fw-typography .wrapper .text-transform h5,
.customize-control-soledad-fw-typography .wrapper .variant h5,
.customize-control-soledad-fw-gradient .wrapper h5 {
	margin: 10px 0 5px;
}
.customize-control-soledad-fw-typography .wrapper .font-size,
.customize-control-soledad-fw-typography .wrapper .letter-spacing,
.customize-control-soledad-fw-typography .wrapper .line-height {
	width: 47%;
}
.customize-control-soledad-fw-typography .wrapper .text-align {
	width: 100%;
}
.customize-control-soledad-fw-typography .wrapper .text-align .dashicons {
	padding: 3px;
	font-size: 25px;
	width: 25px;
	height: 25px;
	border: 1px solid transparent;
}
.customize-control-soledad-fw-typography .wrapper .text-align input {
	display: none;
}
.customize-control-soledad-fw-typography .wrapper .text-align input:checked + label .dashicons {
	border: 1px solid #3498DB;
	color: #000;
}
.customize-control-soledad-fw-typography .wrapper .text-transform {
	padding-top: 10px;
}
.customize-control-soledad-fw-typography .wrapper .color {
	width: 100%;
}
.hint,
[data-hint] {
	position: relative;
	display: inline-block;
}
.hint:before,
.hint:after,
[data-hint]:before,
[data-hint]:after {
	position: absolute;
	-webkit-transform: translate3d(0, 0, 0);
	-moz-transform: translate3d(0, 0, 0);
	transform: translate3d(0, 0, 0);
	visibility: hidden;
	opacity: 0;
	z-index: 998;
	pointer-events: none;
	transition: 0.3s ease;
	transition-delay: 250ms;
}
.hint:hover:before,
.hint:hover:after,
.hint:focus:before,
.hint:focus:after,
[data-hint]:hover:before,
[data-hint]:hover:after,
[data-hint]:focus:before,
[data-hint]:focus:after {
	visibility: visible;
	opacity: 1;
}
.hint:hover:before,
.hint:hover:after,
[data-hint]:hover:before,
[data-hint]:hover:after {
	transition-delay: 0;
}
.hint:before,
[data-hint]:before {
	content: '';
	position: absolute;
	background: transparent;
	border: none;
	z-index: 999;
	width: 0;
	height: 0;
	border-top: 5px solid transparent;
	border-bottom: 5px solid transparent;
	border-left: 5px solid #333;
	left: -5px;
	top: 5px;
}
.hint:after,
[data-hint]:after {
	content: attr(data-hint);
	background: #333;
	color: white;
	padding: 5px 10px;
	font-size: 12px;
	line-height: 14px;
	height: auto;
	margin-bottom: -14px;
	width: 170px;
	max-width: 170px;
	display: block;
	white-space: normal;
	text-align: right;
	position: relative;
	top: -22px;
	left: -195px;
}
li.customize-control {
	position: relative;
}
li.customize-control a.tooltip.hint--left {
	display: block;
	position: absolute;
	top: 5px;
	right: -10px;
	border-radius: 50%;
	color: #999;
	border: none;
	line-height: 8px;
	width: 20px;
	height: 20px;
	z-index: 10;
}
.rtl li.customize-control a.tooltip.hint--left {
	right: auto;
	left: 0;
}
.rtl .hint:before,
.rtl [data-hint]:before {
	left: 20px;
	border-left: none;
	border-right: 5px solid #333;
}
.rtl .hint:after,
.rtl [data-hint]:after {
	left: 195px;
}
.customize-control-soledad-fw-select .select2-container {
	display: block;
}
.wp-customizer .select2-dropdown {
	z-index: 99999999;
}
.wp-customizer .select2-container--default .select2-selection--multiple {
	border-radius: 0;
}
.wp-customizer .select2-container--default .select2-selection--multiple .select2-selection__choice {
	padding: 0 5px;
	border-radius: 0;
	background-color: #3498DB;
	border: 1px solid #006f8d;
	color: #fff;
}
.wp-customizer .select2-container--default .select2-selection--multiple .select2-selection__choice__remove {
	color: #fff;
}
.wp-customizer .select2-container--default.select2-container--focus .select2-selection--multiple {
	border: solid 1px #006f8d;
	outline: 0;
}
.wp-customizer .select2-results__option {
	margin-bottom: 0;
}
.wp-customizer .select2-container--default .select2-selection--single {
	border-radius: 0;
}
.control-section-lazy .customize-control,
.control-section-default .customize-control,
.control-panel-default .customize-control {
	width: 100%;
	float: left;
	clear: both;
	margin-bottom: 0;
	margin-left: -15px;
	margin-right: -15px;
	padding: 10px 15px 20px 15px;
	background: #fff;
	border-bottom: 1px solid #ddd;
}
.customize-control.customize-control-soledad-fw-alert {
	padding: 0;
	margin: 0;
	background: transparent;
}
.customize-control .thumbnail-image {
	text-align: center;
}
#customize-controls img {
	max-width: 100%;
	width: auto;
}
.customize-lazy-section-loading {
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	left: 0;
	background: #eee;
	z-index: 5;
}
/** customize link section **/
.control-section-link .accordion-section-title {
	background-color: #3498DB !important;
	border-left-color: #006f8d;
	color: #fff !important;
	padding: 0
}
.control-section-link .accordion-section-title a {
	color: #fff;
	display: block;
	padding: 10px 10px 11px 14px;
	text-decoration: none
}
.control-section-link .accordion-section-title a:hover {
	background-color: #3498DB !important
}
.control-section-link .accordion-section-title:after {
	color: #fff !important
}
.control-section-link h3 a:after {
	color: #fff
}
/** customizer search **/
#customize-header-actions {
	position: relative;
}
.customizer-search-wrapper {
	background: #eee;
	z-index: 9;
	position: relative;
	padding: 15px;
	z-index: 9;
}
.customizer-search-wrapper .customizer-search-toggle {
	text-decoration: none;
	line-height: 30px;
	width: 45px;
	text-align: center;
	position: absolute;
	z-index: 10;
	outline: none;
	right: 10px;
	display: none;
}
.customizer-search-wrapper.active .customizer-search-toggle {
	display: block;
}
.customizer-search-result-wrapper .search-no-result {
	padding: 30px;
	text-align: center;
	font-size: 17px;
}
.customizer-search-result-wrapper .search-no-result p {
	font-size: inherit;
	line-height: 1.2;
}
.pccsz-help-buttons {
	display: flex;
	flex-direction: column;
	row-gap: 10px;
	margin-top: 60px;
	letter-spacing: -0.025rem;
}
.pccsz-help-buttons a {
	font-size: 13px;
	padding: 10px;
	background: #2e81ec;
	color: #fff;
	border-radius: 5px;
	font-weight: bold;
}
.pccsz-help-buttons a:last-child {
	background: #ff331e;
}
.customizer-search-wrapper .customizer-search-toggle:focus {
	box-shadow: none;
}
.customizer-search-wrapper .customizer-form-search input {
	width: 100%;
}
.customizer-search-result {
	position: absolute;
	top: 105px;
	width: 100%;
	left: 0;
	background: #fff;
	display: none;
	overflow: auto;
	z-index: 9;
}
.customizer-search-result ul {
	padding: 0;
	margin: 0;
}
.customizer-search-result li {
	padding: 15px 20px 15px;
	border-bottom: 1px solid #d8d8d8;
	margin: 0;
	line-height: normal;
	cursor: pointer;
}
.customizer-search-result li:hover {
	background: #eaeaea;
}
.customizer-search-result h3 {
	margin: 0;
	padding: 0;
	line-height: 1.5em;
}
.customizer-search-result span {
	font-size: 11px;
	display: block;
	margin-bottom: 2px;
}
.customizer-search-result em {
	margin-top: 1px;
	display: block;
	clear: both;
	font-size: 12px;
	font-style: normal;
}
.customizer-search-overlay {
	position: absolute;
	background: rgba(255, 255, 255, 0.8);
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 5;
	display: none;
}
.customizer-search-wrapper.active .customizer-form-search,
.customizer-search-result.active,
.customizer-search-overlay.active {
	display: block;
}
li.customize-control.customize-control-soledad-fw-header {
	background: #0f69ff;
	padding: 0 12px;
	margin: 15px -12px 0;
}
li.customize-control.customize-control-soledad-fw-header:nth-child(2) {
	margin-top: 0
}
h2.customize-control-title {
	font-size: 15px;
	color: #fff;
	font-weight: 400;
	margin: 0;
	padding: 8px 0;
}
#customize-controls .customize-control-soledad-fw-header .description {
	width: calc(100% - 32px);
	color: #eee;
}
#customize-controls .customize-control-soledad-fw-header .description a {
	color: #fff;
}
.customize-alert {
	width: 100%;
	float: left;
	clear: both;
	color: #5b5b5b;
	background-color: #ffffe8;
	border: 0;
	border-radius: 0;
	padding: 6px 12px;
	box-sizing: border-box;
	margin: 0 0 15px;
	font-size: 13px;
}
.customize-alert strong {
	font-size: 13px;
	font-weight: normal;
	line-height: 1.5;
}
.customize-alert.customize-alert-warning {
	color: #8a6d3b;
	background-color: #fcf8e3;
	border-color: #faebcc;
}
.customize-alert.customize-alert-success {
	color: #3c763d;
	background-color: #dff0d8;
	border-color: #d6e9c6;
}
.customize-alert.customize-alert-info {
	color: #31708f;
	background-color: #d9edf7;
	border-color: #bce8f1;
	margin-top: 15px;
}
.customize-alert.customize-alert-danger {
	color: #d21616;
	background-color: #ffe7e7;
	border-color: #d21616;
}
.customize-control-title {
	font-weight: 600;
}
.customize-control-soledad-fw-header:after {
	font-family: dashicons;
	content: "\f460";
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	font-size: 14px;
	width: 40px;
	cursor: pointer;
	vertical-align: middle;
	font-weight: normal;
	text-align: center;
	color: #fff;
	border-radius: 1px;
	padding: 0;
	background: rgba(255, 255, 255, 0.1);
	display: -moz-flex;
	display: -ms-flex;
	display: flex;
	align-items: center;
	justify-content: center;
}
.customize-control-soledad-fw-header {
	cursor: pointer;
}
.customize-control-soledad-fw-header.collapsed:after {
	content: "\f132";
}
.customizer-collapsed {
	display: none !important;
}
#customize-controls .description {
	color: #777;
	font-style: normal;
	font-size: 13px;
	font-weight: 400;
	word-wrap: break-word;
	line-height: 1.7em;
	margin-bottom: 10px;
}
.customize-control.first_child,
#customize-control-soledad_fw_single_post_date_format_custom {
	width: calc(100% - 18px);
	border-left: 20px solid rgba(0, 0, 0, 0.11);
	padding-left: 10px;
}
.customize-control-description ul {
}
.customize-control-description ul li {
	list-style-type: initial;
	margin-left: 20px;
}
.panel-customize-alert {
	display: block !important;
	float: none;
	margin: 20px;
	width: auto;
}
.panel-customize-alert.customize-alert .customize-control-title {
	font-size: 15px;
	margin-bottom: 10px;
	font-weight: bold;
}
#customize-controls .panel-customize-alert .description {
	color: #6e6161;
	font-style: normal;
	font-size: 13px;
	font-weight: 400;
	word-wrap: break-word;
}
.span-center {
	text-align: right;
	width: 100%;
	display: block;
	margin-top: 20px;
}
.customize-control .attachment-media-view {
	background: transparent;
}
/* Custom style */
#input_soledad_fw_single_blog_template img,
#input_soledad_fw_single_blog_layout img {
	width: 110px;
}
#accordion-panel-soledad_fw_disable_panel {
	display: block !important;
}
.soledad-fw-customizer-disable {
	position: relative;
	z-index: 999999;
	display: none;
}
.soledad-fw-customizer-overlay {
	-webkit-backface-visibility: hidden;
	position: fixed;
	background: rgba(0, 0, 0, 0.8);
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
}
.soledad-fw-customizer-disable-content {
	position: fixed;
	width: 400px;
	background: rgba(255, 255, 255, 0.2);
	left: 50%;
	margin-left: -205px;
	top: 50%;
	border-radius: 3px;
	padding: 10px;
	margin-top: -200px;
}
.soledad-fw-customizer-disable-content h2 {
	background: #fff;
	margin: 0;
	padding: 14px 12px;
	border-radius: 4px;
}
.soledad-fw-customizer-disable-content .soledad-fw-customizer-container {
	border-radius: 4px;
	background: #fff;
	margin-top: 10px;
	padding: 10px;
}
.soledad-fw-customizer-disable-content .soledad-fw-customizer-button {
	border: none;
	background: #f70d28;
	color: #fff;
	padding: 0 20px;
	line-height: 40px;
	height: 40px;
	display: inline-block;
	cursor: pointer;
	text-transform: uppercase;
	font-size: 12px;
	font-weight: bold;
	letter-spacing: 1px;
	outline: 0;
	-webkit-appearance: none;
	-webkit-transition: .3s ease;
	transition: .3s ease;
	width: 194px;
	margin-top: 10px;
	border-radius: 3px;
	float: left;
}
.soledad-fw-customizer-disable-content .soledad-fw-customizer-button.soledad-fw-customizer-cancel {
	margin-left: 8px;
	background: #fff;
	color: #000;
}
.soledad-fw-customizer-content-overlay {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: rgba(0, 0, 0, 0.6);
	display: none;
}
.soledad-fw-customizer-content-overlay i {
	left: 50%;
	position: relative;
	margin-left: -30px;
	z-index: 2;
	color: #fff;
	top: 50%;
	margin-top: -30px;
}
.customize-control-soledad-fw-textarea textarea {
	width: 100%;
}
/*attachable customizer*/
.soledad-fw-btn-header-builder,
.soledad-fw-btn-attach {
	position: absolute;
	top: 0;
	right: 45px;
	width: 45px;
	height: 45px;
	padding: 0 2px 0 0;
	background: #eee;
	border: none;
	border-left: 1px solid #ddd;
	cursor: pointer;
	-webkit-transition: color .1s ease-in-out, background .1s ease-in-out;
	transition: color .1s ease-in-out, background .1s ease-in-out;
	-webkit-box-sizing: content-box;
	-moz-box-sizing: content-box;
	box-sizing: content-box;
	text-align: center;
}
.soledad-fw-btn-header-builder i,
.soledad-fw-btn-attach i {
	font-size: 16px;
}
.wp-full-overlay.attached {
	margin-left: 0 !important;
}
.attached .wp-full-overlay-footer,
.wp-core-ui .wp-full-overlay.attached .collapse-sidebar {
	position: absolute;
}
.attached #customize-controls {
	border: none;
	box-shadow: -1px 2px 10px 0px rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.05);
	-webkit-box-shadow: -1px 2px 10px 0px rgba(0, 0, 0, 0.15), 0 0 0 1px rgba(0, 0, 0, 0.05);
}
.attached .collapse-sidebar {
	display: none;
	visibility: hidden;
}
#customize-header-actions {
	padding-left: 0;
}
.attached .ui-resizable-s {
	cursor: ns-resize;
	height: 30px;
	width: 100%;
	bottom: -20px;
	left: 0;
}
.attached .ui-resizable-handle {
	position: absolute;
	font-size: 0.1px;
	display: block;
	-ms-touch-action: none;
	touch-action: none;
}
.soledad-fw-btn-attach,
.customizer-search-wrapper .customizer-search-toggle {
	color: #444;
	-webkit-transition: .15s ease-in-out;
	-moz-transition: .15s ease-in-out;
	-o-transition: .15s ease-in-out;
	transition: .15s ease-in-out;
	font-size: 14px;
}
.soledad-fw-btn-attach:hover,
.customizer-search-wrapper .customizer-search-toggle:hover {
	color: #0085ba;
}
.wp-full-overlay.attached,
.wp-full-overlay.attached .collapse-sidebar,
.wp-full-overlay.attached .wp-full-overlay-main,
.wp-full-overlay.attached .wp-full-overlay-sidebar {
	-webkit-transition: none !important;
	-moz-transition: none !important;
	-o-transition: none !important;
	transition: none !important;
}
.customize-section-description-container + #customize-control-custom_css:last-child {
	width: 100%;
}
/* #customize-controls .customize-info.is-sticky,
#customize-controls .customize-section-title.is-sticky {
  position: relative;
  top: auto;
}

#customize-controls .customize-section-title.is-in-view {
    top: 0 !important;
} */
/* repeater style */
.soledad-fw-repeater-wrapper {
	padding: 15px;
	border: 1px solid #e0e0e0;
}
.soledad-fw-repeater-wrapper .repeater-fields {
	margin: 0;
}
.soledad-fw-repeater-wrapper .repeater-row {
	border: 1px solid #e0e0e0;
	margin-bottom: 10px;
	position: relative;
}
.soledad-fw-repeater-wrapper .repeater-row.minimized {
	background: #f5f5f5;
	padding: 0;
}
.soledad-fw-repeater-wrapper .repeater-row-header {
	border-bottom: 1px solid #e0e0e0;
	position: relative;
	padding: 10px 15px 10px 35px;
	height: auto;
	min-height: 20px;
	line-height: 30px;
	overflow: hidden;
	word-wrap: break-word;
}
.soledad-fw-repeater-wrapper .repeater-row-label {
	font-size: 13px;
	font-weight: 600;
	line-height: 20px;
	display: block;
	text-transform: capitalize;
	width: 90%;
	overflow: hidden;
	height: 18px;
}
.repeater-row-label:before {
	content: "\f047";
	font-family: 'FontAwesome', Helvetica, Arial, sans-serif;
	position: absolute;
	left: 0;
	width: 40px;
	text-align: center;
	font-weight: normal;
	margin-right: 0.5em;
	color: #aaa;
	font-size: 14px;
	text-rendering: optimizeLegibility;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.soledad-fw-repeater-wrapper .repeater-row-header .dashicons {
	font-size: 18px;
	position: absolute;
	right: 12px;
	top: 2px;
	color: #a0a5aa;
}
.soledad-fw-repeater-wrapper .repeater-minimize {
	line-height: 36px;
}
.soledad-fw-repeater-wrapper .repeater-row-content {
	padding: 12px 15px;
	display: none;
}
.soledad-fw-repeater-wrapper .repeater-field {
	padding: 8px 0;
	width: 100%;
	clear: both;
}
.soledad-fw-repeater-wrapper .repeater-fields .repeater-row .repeater-field.repeater-field- {
	display: none;
}
.soledad-fw-repeater-wrapper .repeater-fields .repeater-row label {
	margin-bottom: 12px;
	clear: both;
}
.soledad-fw-repeater-wrapper .repeater-field .customize-control-title {
	font-weight: 500;
	padding-bottom: 6px;
	display: block;
}
.soledad-fw-repeater-wrapper .repeater-field .customize-control-description {
	margin-top: 5px;
	clear: both;
	display: block;
	line-height: 20px;
	color: #888;
	font-style: normal;
	font-size: 12px;
	padding: 0;
}
.soledad-fw-repeater-wrapper input[type=text],
.soledad-fw-repeater-wrapper select {
	width: 100%;
}
.soledad-fw-repeater-wrapper .repeater-row-remove {
	color: #a00;
}
.soledad-fw-repeater-wrapper .repeater-add-wrapper {
	padding: 8px;
	text-align: center;
	border: 1px dashed #e0e0e0;
}
.soledad-fw-repeater-wrapper .repeater-add-wrapper .repeater-add {
	width: 100px;
}
@media only screen and (max-width: 640px) {
	.soledad-fw-btn-attach, .customizer-search-wrapper .customizer-search-toggle {
		display: none;
	}
	#customize-header-actions {
		padding-right: 0;
	}
	#customize-header-actions .button-primary {
		margin-right: 5px;
	}
}
.customize-control- eg-button .button.customize-control-title {
	display: block;
	text-align: center;
	margin: 11px 0;
}
.search-loader {
	background: #eee;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	position: absolute;
}
.search-loader .loader,
.control-section-lazy .loader {
	position: absolute;
	top: 50%;
	right: 50%;
	overflow: hidden;
	margin-right: -27px;
	margin-top: -27px;
}
.loader,
.loader:after {
	border-radius: 50%;
	width: 10em;
	height: 10em;
}
.loader {
	font-size: 5px;
	position: relative;
	text-indent: -9999em;
	border-top: 5px solid rgba(0, 0, 0, 0.15);
	border-right: 5px solid rgba(2, 2, 2, 0.15);
	border-bottom: 5px solid rgba(0, 0, 0, 0.15);
	border-left: 5px solid #000;
	-webkit-transform: translateZ(0);
	-ms-transform: translateZ(0);
	transform: translateZ(0);
	-webkit-animation: ifiniteload 0.7s infinite linear;
	animation: ifiniteload 0.7s infinite linear;
}
@-webkit-keyframes ifiniteload {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg);
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg);
	}
}
@keyframes ifiniteload {
	0% {
		-webkit-transform: rotate(0deg);
		transform: rotate(0deg);
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg);
	}
}
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button span.ui-icon.ui-icon-triangle-1-s,
.customize-control-soledad-fw-number .ui-spinner.ui-widget-content .ui-spinner-button span.ui-icon.ui-icon-triangle-1-n {
	display: none;
}
.customize-control .box-model-wrapper span {
	display: block;
	margin: 0 0 10px;
}
.customize-control .box-model-wrapper .box-spacing-item,
.penci-pm-control .button-group {
	width: 23%;
	margin-right: 1%;
	display: inline-block;
}
.customize-control .box-model-wrapper .box-model + .box-model {
	margin-top: 15px;
}
.customize-control .box-model-wrapper .box-spacing-item:last-child {
	margin-right: 0;
}
.customize-control .box-model-wrapper .box-head {
	padding: 5px 10px;
	background: #444;
	color: #fff;
}
.penci-pm-control .button-group .label {
	font-size: 11px;
	display: block;
}
.customize-control-soledad-fw-size .penci-range-lable{
	font-size: 13px;
	font-weight: 600;
	color: #555d66;
	margin-bottom: 0;
	margin-top: 16px;
}
.customize-control-soledad-fw-size .pencidesign-range-slider {
	position: relative;
	width: calc(100% - 60px);
	height: 6px;
	background-color: rgba(0,0,0,.10);
	cursor: pointer;
	transition: background .5s;
}
.customize-control-soledad-fw-size .has-unit .pencidesign-range-slider {
	width: calc(100% - 90px);
}
.customize-control-soledad-fw-size .penci_range_value.hide-value {
	display: none;
}
.customize-control-soledad-fw-size .penci_range_value.hide-value + .pencidesign-range-slider {
	width: 100%;
}
.customize-control-soledad-fw-size .pencidesign-range-slider .ui-slider-handle {
	height: 16px;
	width: 16px;
	background-color: #2d9de6;
	display: inline-block;
	position: absolute;
	top: 50%;
	transform: translateY(-50%) translateX(-4px);
	border-radius: 50%;
	cursor: pointer;
}
.customize-control-soledad-fw-size .wrapper {
	display: flex;
	justify-content: space-between;
	align-items: center;
}
.customize-control-soledad-fw-size .penci_range_value {
	font-size: 14px;
	padding: 0;
	font-weight: 400;
	width: 52px;
	display: flex;
}
.customize-control-soledad-fw-size .has-unit .penci_range_value {
	width: 80px;
}
.customize-control-soledad-fw-size .penci_range_value span.value {
	font-size: 12px;
	width: calc(100% - 2px);
	text-align: center;
	min-height: 30px;
	background: #FFF;
	line-height: 30px;
	border: 1px solid #DDD;
}
.customize-control-soledad-fw-size .has-unit .penci_range_value span.value {
	width: calc(100% - 32px);
	display: block;
}
.customize-control-soledad-fw-size .penci_range_value .unit {
	width: 29px;
	text-align: center;
	font-size: 12px;
	line-height: 22px;
	background: #fff;
	border: 1px solid #ddd;
	margin-left: 1px;
	height: 24px;
}
.customize-control-soledad-fw-size .pencidesign-range-slider-reset span {
	font-size: 16px;
	line-height: 22px;
}
.customize-control-soledad-fw-size .penci_range_value input {
	font-size: 12px;
	padding: 0px;
	text-align: center;
	min-height: 24px;
	height: auto;
	border-radius: 0;
	border-color: #ddd;
}
.customize-control-soledad-fw-size .has-unit .penci_range_value input {
	width: calc(100% - 30px);
}
.customize-control-soledad-fw-size .penci-range-title-area .dashicons {
	cursor: pointer;
	font-size: 11px;
	width: 20px;
	height: 18px;
	line-height: 20px;
	color: #222;
	text-align: center;
	position: relative;
	top: 2px;
}
.customize-control-soledad-fw-size .penci-range-title-area .dashicons:hover {
	background: #fafafa;
}
.customize-control-soledad-fw-size .penci-range-title-area .dashicons.selected {
	background: #f1f1f1;
	color: #222;
}
.penci-range-title-area {
	display: flex;
}
.penci-range-slider-controls {
	margin-left: auto;
	margin-bottom: 4px;
}
.customize-control-soledad-fw-size .penci-device-controls > span:first-child:last-child {
	display: none;
}
.customize-control-soledad-fw-size .sub-description {
	display: block;
	font-style: italic;
	line-height: 1.4;
	margin: 2px 0 2px;
}
.customize-control-soledad-fw-size .pencidesign-range-inner{
	display: flex;
	align-items: center;
}
.customize-control-soledad-fw-size .penci-control-process{
	width: 80px;
	float: right;
}
.customize-control-soledad-fw-size .penci-range-lableparent{
	width: calc(100% - 82px);
	padding-right: 5px;
}
.customize-control-soledad-fw-size .penci-wider-width .penci-control-process{
	width: 53px;
	float: right;
}
.customize-control-soledad-fw-size .penci-wider-width .penci-range-lableparent{
	width: calc(100% - 55px);
	padding-right: 5px;
}
.customize-control-soledad-fw-hidden {
	display: none !important;
}
.customize-control-soledad-fw-radio.customize-control .customize-inside-control-row {
	margin-left: 0;
}
#customize-controls .customize-pane-child .customize-info .customize-panel-description {
	display: block;
	color: #444;
	margin-bottom: 0;
}
#customize-controls .customize-pane-child .customize-info .customize-panel-description a {
	text-decoration: underline;
}
button[data-type="penci_speed_delete_cache"]:before,
button[data-type="render_separate_css"]:before {
	font: normal 20px/.5 dashicons;
	speak: none;
	display: inline-block;
	padding: 0;
	top: 9px;
	left: -4px;
	position: relative;
	vertical-align: top;
	content: "\f463";
}
button[data-type="render_separate_css"].loading:before,
button[data-type="penci_speed_delete_cache"].loading:before {
	animation: rotation 1s infinite linear;
}
button[data-type="render_separate_css"].success:before,
button[data-type="penci_speed_delete_cache"].success:before {
	content: "\f147";
	color: #46b450;
}
