.vc_edit_form_elements .penci-number-input {
  width: 5em;
  margin-right: 5px;
}
.vc_edit_form_elements .penci-number-suffix {
  width: 5em;
  height: 28px;
  padding: 0 6px;
  vertical-align: top;
}
