.compose-mode .vc_penci_container {
	padding-top: 32px;
	margin-top: 0 !important;
}

.compose-mode .vc_penci_container .penci-vc-column {
	padding: 0 !important;
	width: 100% !important;
	float: none;
}
.penci-pb-row .vc_empty-element {
	min-height: 100px;
}
.compose-mode .vc_element.vc_hold-hover > .penci-vc-container >  .penci-vc-row >  .penci-vc-row > .vc_element:before,
.compose-mode .vc_element.vc_hover > .penci-vc-container >  .penci-vc-row >  .penci-vc-row > .vc_element:before,
.compose-mode .vc_element:hover > .penci-vc-container >  .penci-vc-row > .vc_element:before,
.view-mode .vc_element.vc_hold-hover > .penci-vc-container >  .penci-vc-row > .vc_element:before,
.view-mode .vc_element.vc_hover > .penci-vc-container >  .penci-vc-row > .vc_element:before,
.view-mode .vc_element:hover > .penci-vc-container >  .penci-vc-row > .vc_element:before {
	content: '';
	margin: 0;
	padding: 0;
	position: absolute;
	z-index: 0;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	outline: #EBEBEB dashed 1px;
	outline: rgba(125, 125, 125, .4) dashed 1px;
}

.compose-mode .vc_element.vc_hold-hover>.wpb_row>.vc_element:before,
.compose-mode .vc_element.vc_hover>.wpb_row>.vc_element:before,
.compose-mode .vc_element:hover>.wpb_row>.vc_element:before,
.view-mode .vc_element.vc_hold-hover>.wpb_row>.vc_element:before,
.view-mode .vc_element.vc_hover>.wpb_row>.vc_element:before,
.view-mode .vc_element:hover>.wpb_row>.vc_element:before {

}