.rwmb-slider-inner {
	display: flex;
	align-items: center;
	justify-content: space-between;
}
.rwmb-slider-ui {
	flex: 1;
}
.rwmb-slider-label {
	margin-left: 8px;
}

/* Fix slider handle being visible through jQuery panel */
.ui-slider .ui-slider-handle {
	z-index: 1;
}
