<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit6d8949d71f8642fa71b1f18c16efe1b8
{
    public static $prefixLengthsPsr4 = array (
        'M' => 
        array (
            'MBSP\\' => 5,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'MBSP\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
    );

    public static $classMap = array (
        'RWMB_Backup_Field' => __DIR__ . '/../..' . '/src/BackupField.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit6d8949d71f8642fa71b1f18c16efe1b8::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit6d8949d71f8642fa71b1f18c16efe1b8::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit6d8949d71f8642fa71b1f18c16efe1b8::$classMap;

        }, null, ClassLoader::class);
    }
}
