body {
	direction: rtl;
	unicode-bidi: embed;
}
select {
	padding: 8px 15px 8px 28px;
	background-position: left 10px top 50%;
}
.container.has-banner .header-banner {
	text-align: left;
}
#navigation .menu ul ul.sub-menu a,
#navigation ul.menu ul.sub-menu a,
#penci-login-popup,
.container.has-banner #logo,
.navigation .menu ul ul.sub-menu a,
.navigation ul.menu ul.sub-menu a,
.penci-grid.penci-fea-cat-style-13 > li.grid-style {
	text-align: right;
}
#navigation.header-4 .pcheader-icon.shoping-cart-icon,
#navigation.header-5 .pcheader-icon.shoping-cart-icon,
.pcheader-icon.shoping-cart-icon.clear-right {
	margin-left: 0;
	margin-right: 40px;
}
#navigation .menu,
.navigation .menu {
	float: right;
}
.pcheader-icon {
	float: left;
}
.pcheader-icon.shoping-cart-icon {
	margin-left: 15px;
	margin-right: 0;
}
#navigation .menu > ul > li,
#navigation ul.menu > li,
.navigation .menu > ul > li,
.navigation ul.menu > li {
	float: right;
	margin-left: 44px;
	margin-right: 0;
}
.pc-builder-element.pc-main-menu .navigation .menu > ul > li,
.pc-builder-element.pc-main-menu .navigation ul.menu > li {
	margin-left: var(--pchb-main-menu-mg);
	margin-right: 0 !important;
}
.pc-builder-element.pc-second-menu .navigation .menu > ul > li,
.pc-builder-element.pc-second-menu .navigation ul.menu > li {
	margin-left: var(--pchb-second-menu-mg);
	margin-right: 0;
}
.pc-builder-element.pc-third-menu .navigation .menu > ul > li,
.pc-builder-element.pc-third-menu
	.navigation:not(.menu-item-padding)
	ul.menu
	> li {
	margin-left: var(--pchb-third-menu-mg);
	margin-right: 0;
}
#navigation .menu .children,
#navigation .menu .sub-menu,
#navigation ul.menu > li.megamenu > ul.sub-menu,
.home-featured-cat-content.style-7 .grid-header-box:after,
.navigation .menu .children,
.navigation .menu .sub-menu,
.navigation ul.menu > li.megamenu > ul.sub-menu {
	right: 0;
	left: auto;
}
.pc-builder-element.pc-main-menu .navigation .menu > ul > li > .sub-menu,
.pc-builder-element.pc-main-menu .navigation ul.menu > li > .sub-menu {
	top: var(--pchb-main-menu-lh);
}
.pc-builder-element.pc-third-menu .navigation .menu > ul > li > .sub-menu,
.pc-builder-element.pc-third-menu .navigation ul.menu > li > .sub-menu {
	top: var(--pchb-third-menu-lh);
}
.pc-builder-element.pc-second-menu .navigation .menu > ul > li > .sub-menu,
.pc-builder-element.pc-second-menu .navigation ul.menu > li > .sub-menu {
	top: var(--pchb-second-menu-lh);
}
#navigation .menu > ul > li > .sub-menu,
#navigation ul.menu > li > .sub-menu {
	top: 59px;
}
#navigation.header-11 .menu > ul > li > .sub-menu,
#navigation.header-11 ul.menu > li > .sub-menu {
	top: 58px;
}
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-10
	.menu
	> ul
	> li
	> .sub-menu,
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-10
	ul.menu
	> li
	> .sub-menu,
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-11
	.menu
	> ul
	> li
	> .sub-menu,
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-11
	ul.menu
	> li
	> .sub-menu,
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-6
	.menu
	> ul
	> li
	> .sub-menu,
#navigation-sticky-wrapper:not(.is-sticky)
	#navigation.header-6
	ul.menu
	> li
	> .sub-menu {
	top: 81px;
}
#navigation .menu .children ul,
#navigation .menu .sub-menu ul,
.navigation .menu .children ul,
.navigation .menu .sub-menu ul,
.post-entry blockquote .author span:after,
div.penci-topbar-menu > ul li:hover ul.sub-menu ul.sub-menu,
ul.penci-topbar-menu li:hover ul.sub-menu ul.sub-menu {
	right: 100%;
	left: auto;
}
#navigation .menu > ul > li.menu-item-has-children > a:after,
#navigation .menu > ul > li.penci-mega-menu > a:after,
#navigation ul.menu > li.menu-item-has-children > a:after,
#navigation ul.menu > li.penci-mega-menu > a:after,
.navigation .menu > ul > li.menu-item-has-children > a:after,
.navigation .menu > ul > li.penci-mega-menu > a:after,
.navigation ul.menu > li.menu-item-has-children > a:after,
.navigation ul.menu > li.penci-mega-menu > a:after {
	float: left;
	margin: 0 5px 0 0;
}
.penci-menuhbg-wapper {
	float: left;
	margin-right: 0;
	margin-left: 12px;
}
.penci-headline-posts .slick-prev,
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev {
	left: auto;
	right: -32px;
}
.penci-headline-posts .slick-next,
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next {
	left: auto;
	right: -54px;
}
.featured-area.featured-style-14 .wrapper-item-classess,
.featured-area.featured-style-20 .wrapper-item-classess,
.featured-area.featured-style-21 .wrapper-item-classess,
.featured-area.featured-style-22 .wrapper-item-classess,
.featured-area.featured-style-23 .wrapper-item-classess,
.featured-area.featured-style-25 .wrapper-item-classess,
.featured-area.featured-style-26 .wrapper-item-classess,
.featured-area.featured-style-27 .wrapper-item-classess {
	margin-left: 0;
	margin-right: -2px;
}
.featured-style-13 .wrapper-item .penci-item-mag,
.featured-style-14 .wrapper-item .penci-item-mag,
.featured-style-15 .wrapper-item .penci-item-mag,
.featured-style-16 .wrapper-item .penci-item-mag,
.featured-style-17 .wrapper-item .penci-slider17-mag-item,
.featured-style-18 .wrapper-item .penci-slider17-mag-item,
.featured-style-19 .wrapper-item .penci-item-mag,
.featured-style-20 .wrapper-item .penci-item-mag,
.featured-style-21 .wrapper-item .penci-item-mag,
.featured-style-22 .wrapper-item .penci-item-mag,
.featured-style-23 .wrapper-item .penci-item-mag,
.featured-style-24 .wrapper-item .penci-item-mag,
.featured-style-25 .wrapper-item .penci-item-mag,
.featured-style-26 .wrapper-item .penci-item-mag,
.featured-style-27 .wrapper-item .penci-item-mag,
.featured-style-37 .penci-featured-items-left,
.featured-style-37 .penci-featured-items-right,
.featured-style-6 .wrapper-item .penci-item-mag {
	float: right;
}
@media only screen and (min-width: 961px) {
	.featured-style-37 .penci-featured-items-left,
	.featured-style-6 .wrapper-item .penci-item-1 {
		border-right: none;
		border-left: 10px solid transparent;
	}
}
@media only screen and (max-width: 961px) {
	.featured-style-6 .wrapper-item .penci-item-0 {
		border-right: 2px solid transparent;
		border-left: none;
	}
	.featured-style-6 .wrapper-item .penci-item-2 {
		border-left: 2px solid transparent;
		border-right: none;
	}
}
@media only screen and (min-width: 768px) {
	.featured-style-19 .wrapper-item .penci-item-0,
	.featured-style-19 .wrapper-item .penci-item-2 {
		border-left: none;
		border-right: 4px solid transparent;
	}
}
@media only screen and (max-width: 767px) {
	.featured-style-19 .wrapper-item .penci-item-1,
	.featured-style-19 .wrapper-item .penci-item-3 {
		border-right: none;
		border-left: 2px solid transparent;
	}
	.featured-style-19 .wrapper-item .penci-item-0,
	.featured-style-19 .wrapper-item .penci-item-2 {
		border-right: 2px solid transparent;
		border-left: none;
	}
}
.featured-style-35 .featured-content-excerpt .feat-meta span,
.grid-post-box-meta span,
.penci-featured-content .feat-text .feat-meta span,
.penci-mag-featured-content .feat-meta span {
	display: inline-block;
}
.main-nav-social {
	float: left;
	text-align: left;
	margin: 0 0 0 13px;
}
.penci-vernav-poright .penci-vernav-toggle:before {
	border-right: none;
	border-left: 50px solid transparent;
}
#navigation.header-4 .main-nav-social,
#navigation.header-5 .main-nav-social,
#navigation.header-6 .main-nav-social {
	margin: 0 30px 0 0;
}
#navigation.header-10 .penci-header-extra,
#navigation.header-11 .penci-header-extra {
	margin-left: 0;
	margin-right: 15px;
}
.penci-header-signup-form .mc4wp-form input[type="email"],
.penci-header-signup-form .mc4wp-form input[type="text"] {
	margin-left: 20px;
	margin-right: 0;
}
.penci-header-signup-form .mc4wp-form-fields > p,
.penci-header-signup-form form > p {
	padding-right: 0;
	padding-left: 20px;
	text-align: right;
}
form.pc-searchform.penci-hbg-search-form i {
	right: auto;
	left: 18px;
}
@media only screen and (max-width: 1169px) {
	.penci-header-signup-form .mc4wp-form input[type="email"],
	.penci-header-signup-form .mc4wp-form input[type="text"] {
		margin: 20px auto 0;
	}
	.penci-header-signup-form .mc4wp-form-fields > p,
	.penci-header-signup-form form > p {
		padding-left: 0;
		text-align: center;
	}
}
.penci-header-signup-form .mc4wp-form-fields > p:last-of-type,
.penci-header-signup-form form > p:last-of-type {
	padding-right: 0;
	padding-left: 0;
}
.show-search a.close-search {
	left: 0;
	right: auto;
}
.show-search form.pc-searchform input.search-input {
	padding: 15px 0 15px 35px;
	right: 0;
	left: auto;
}
.headline-title,
.penci-headline .pctopbar-item {
	float: right;
}
.headline-title.nticker-style-2 {
	margin-left: 8px;
	margin-right: 0;
}
.headline-title.nticker-style-2:after {
	border-left: none;
	border-right: 9px solid var(--pcaccent-cl);
	left: -8px;
	right: auto;
}
.headline-title.nticker-style-3 {
	padding-left: 25px;
	padding-right: 15px;
}
.headline-title.nticker-style-3:after {
	border-right: none;
	border-left: 11px solid #313131;
	right: auto;
	left: 0;
}
.headline-title.nticker-style-4 {
	margin-right: 0;
	margin-left: 9px;
}
.headline-title.nticker-style-4:after {
	border-left: 9px solid transparent;
	border-left-color: transparent !important;
	border-right: none;
	right: auto;
	left: -9px;
}
.penci-topbar-social {
	float: left;
}
body.rtl .penci-headline .slick-slider {
	direction: rtl;
}
.penci-topbar-social a {
	float: right;
	margin-right: 13px;
	margin-left: 0;
}
.penci-topbar-social a:first-child {
	margin-right: 0;
}
.pclg-2col > div,
.penci-topbar-trending .penci-trending-nav,
a.penci-topbar-post-title {
	float: right;
}
.penci-owl-carousel:not(.penci-owl-loaded) a.penci-topbar-post-title {
	float: none;
	vertical-align: top;
}
.penci-trending-nav a.penci-slider-prev {
	float: left;
}
@media only screen and (min-width: 1170px) {
	.penci-headline .pctopbar-item:last-child:not(:first-child) {
		float: left;
	}
}
.penci-headline .pctopbar-item:first-child {
	margin-left: 15px;
	margin-right: 0;
}
.penci-headline .pctopbar-item:last-child {
	margin-left: 0;
	margin-right: 15px;
}
.penci-topbar-social .pclogin-item {
	margin-left: 13px;
	margin-right: 0;
}
.penci-topbar-social.penci-lgdisplay-right .pclogin-item {
	margin-left: 0;
	margin-right: 13px;
}
.pctopbar-login-btn .pclogin-sub {
	left: auto;
	right: 0;
}
.pclogin-item.login-popup span {
	margin-right: 4px;
	margin-left: 0;
}
.pctopbar-login-btn .pclogin-sub li a i {
	margin-left: 5px;
	margin-right: 0;
}
#penci-login-popup .mfp-close {
	right: auto;
	left: 0;
}
.pclg-2col > div:last-child {
	margin-right: 5%;
}
.pclg-2col > div:first-child {
	margin-right: 0;
}
.widget_block.widget_search button[type="submit"] {
	margin-left: 0;
	margin-right: 0.625em;
}
.widget_block.widget_search .wp-block-search__no-button input[type="search"],
form.pc-searchform input.search-input {
	background-position: 6% 15px;
	padding: 12px 20px 12px 40px;
}
.widget_block.widget_search
	.wp-block-search__no-button
	.wp-block-search__inside-wrapper:before,
form.pc-searchform i {
	right: auto;
	left: 20px;
}
.featured-style-4 .penci-owl-carousel .penci-image-holder,
.featured-style-5 .penci-owl-carousel .penci-image-holder {
	float: left;
}
.penci-homepage-title.penci-magazine-title:before {
	right: 30px;
	left: auto;
}
.penci-border-arrow:before {
	right: 50%;
	left: auto;
}
.home-featured-cat-content .mag-post-box .magcat-thumb {
	float: right;
	margin-left: 20px;
	margin-right: 0;
}
.home-featured-cat-content .cat-left,
.home-featured-cat-content .cat-right,
.home-featured-cat-content .mag-photo,
.widget.widget_archive ul li a {
	float: right;
}
.home-featured-cat-content .first-post .magcat-detail .mag-header:after,
.list-post .header-list-style:after {
	right: 0;
	left: auto;
}
.grid-post-box-meta span:after {
	margin: 0 10px 0 8px;
}
.container .penci-grid li.magazine-layout,
.penci-featured-infor .item-content,
.penci-grid-excerpt-left .penci-grid li .item .item-content,
.penci-grid-excerpt-left .penci-masonry .item-masonry .item-content,
.penci-std-continue-left .penci-more-link,
.penci-std-excerpt-left .penci-grid .mixed-detail .item-content,
.penci-std-excerpt-left .standard-main-content,
.widget.widget_archive ul li {
	text-align: right;
}
.pc-widget-advanced-tax.tax-style-1 ul li a:before,
.widget.widget_archive ul li a:before,
.widget.widget_categories ul li a:before {
	content: "";
	margin-left: 10px;
	margin-right: 0;
}
.cat > a.penci-cat-name:after {
	margin-left: 0;
	margin-right: 11px;
}
.cat > a.penci-cat-name {
	margin: 0 0 0 15px;
	padding-left: 10px;
	padding-right: 0;
}
.cat > a.penci-cat-name:first-child {
	margin-right: 0;
	margin-left: 18px;
}
.cat > a.penci-cat-name:last-child {
	margin-left: 0;
	padding-left: 0;
}
.list-post.list-boxed-post .header-list-style:after {
	right: 50%;
	margin-left: 0;
	margin-right: -30px;
}
.penci-grid li.list-post .item > .thumbnail,
.penci-grid li.list-post.penci-slistp .item > .thumbnail {
	float: right;
}
.penci-grid li.list-post.penci-slistp .item > .thumbnail {
	margin-left: 16px;
	margin-right: 0;
}
.penci-featured-cat-sc .penci-grid li.list-post .item .content-list-right,
.penci-latest-posts-sc .penci-grid li.list-post .item .content-list-right {
	padding-right: 30px;
}
.container.two-sidebar .penci-grid li.pclist-layout .item .content-list-right {
	padding-left: 0;
	padding-right: 30px;
}
.home-featured-cat-content.style-14 .magcat-padding {
	padding-left: 0;
	padding-right: 17px;
	position: relative;
}
.home-featured-cat-content.style-14 .magcat-padding:before {
	left: auto;
	right: 0;
}
.home-featured-cat-content.style-7 .grid-header-box {
	text-align: right;
}
.grid-featured .penci-featured-share-box .penci-shareso a:last-child {
	margin-right: 10px;
}
.grid-featured .penci-featured-share-box .penci-shareso a:first-child {
	margin-right: 0;
}
.penci-featured-share-box .penci-shareso {
	transform: translateX(-40px);
	-webkit-transform: translateX(-40px);
}
#navigation ul.menu > li.megamenu > ul.sub-menu > li:before,
#sidebar-nav,
.navigation ul.menu > li.megamenu > ul.sub-menu > li:before,
.penci-featured-share-box .penci-shareic,
.penci-featured-share-box .penci-shareso {
	left: auto;
	right: 0;
}
.grid-featured .thumbnail:hover .penci-shareic {
	transform: translateX(40px);
	-webkit-transform: translateX(40px);
}
.footer-subscribe .mc4wp-form .mdes {
	margin-left: 0;
	margin-right: -100px;
}
@media only screen and (max-width: 960px) {
	.footer-subscribe .mc4wp-form .mdes {
		margin-right: 0;
	}
}
#respond p.comment-form-author,
#respond p.comment-form-email,
#respond p.comment-form-url,
.footer-subscribe .mc4wp-form .memail,
.wpcf7 p.email,
.wpcf7 p.name,
.wpcf7 p.subject {
	float: right;
}
.footer-subscribe .mc4wp-form .msubmit {
	margin-right: 10px;
	margin-left: 0;
}
ul.footer-socials li {
	margin-left: 36px;
	margin-right: 0;
}
ul.footer-socials li a span {
	margin-right: 14px;
	margin-left: 0;
}
.container.penci-breadcrumb i {
	margin: 0 19px 0 15px;
}
.penci-breadcrumb .fa-angle-right:before {
	content: "";
}
.inner-post-entry .alignnone {
	margin: 5px 0 20px 20px;
}
.post-entry ol,
.post-entry ul {
	padding-right: 36px;
	padding-left: 0;
}
.post-entry ol ol,
.post-entry ol ul,
.post-entry ul ol,
.post-entry ul ul {
	margin: 2px 0;
	padding-right: 22px;
	padding-left: 0;
}
.wp-block-yoast-how-to-block ol.schema-how-to-steps {
	padding: 15px 32px 20px 20px;
}
#respond p.comment-form-author {
	margin-left: 2%;
}
#respond p.comment-form-url {
	margin-left: 0;
}
#respond .comment-form-cookies-consent input[type="checkbox"] {
	margin: 0 0 0 5px;
}
div.wpcf7 {
	direction: rtl;
}
.tags-share-box .single-comment-o i,
.tags-share-box.hide-tags.page-share .share-title {
	margin-left: 5px;
	margin-right: 0;
}
.post-share a {
	margin: 0 10px 0 0;
}
.post-entry blockquote .author span {
	padding: 0 0 0 10px;
}
#navigation .button-menu-mobile,
.penci-portfolio-filter ul li,
.post-entry .penci-portfolio-filter ul li,
ul.homepage-featured-boxes li {
	float: right;
}
.penci-countdown {
	direction: ltr;
}
.penci-column {
	margin-left: 4%;
	margin-right: 0;
	float: right;
}
.column-last {
	margin-left: 0 !important;
}
#sidebar-nav {
	transform: translateX(270px);
	-webkit-transform: translateX(270px);
	-moz-transform: translateX(270px);
}
.open-sidebar-nav #sidebar-nav {
	right: 270px;
	left: auto;
}
#close-sidebar-nav {
	left: 0;
	right: 0;
}
.open-sidebar-nav #close-sidebar-nav {
	right: 270px;
	left: 0;
}
.container.penci-breadcrumb span,
.container.penci-breadcrumb span a {
	display: inline-block;
}
.post-share a.penci-post-like:after {
	margin: 4px 20px 0 6px;
}
.tags-share-box .single-comment-o:after {
	margin: 4px 20px 0;
}
@media (min-width: 600px) {
	.wp-block-latest-posts.is-grid li {
		padding-right: 0;
		padding-left: 8px;
	}
}
.post-share,
.thecomment .comment-text span.reply {
	left: 0;
	right: auto;
}
.penci-featured-cat-seemore i,
.penci-readmore-btn i,
.post-share a.penci-post-like,
.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove {
	margin-right: 5px;
	margin-left: 0;
}
.author-img {
	float: right;
	margin-left: 20px;
	margin-right: 0;
}
.post-author .author-content {
	margin-right: 120px;
	margin-left: 0;
}
.post-author.abio-style-3 .author-content,
.post-author.abio-style-4 .author-content {
	margin-left: 0;
	margin-right: 0;
}
.author-content .author-social,
.penci-post-box-meta .penci-box-meta i.fa,
.thecomment .comment-text span.date i {
	margin-left: 10px;
	margin-right: 0;
}
.thecomment .author-img {
	float: right;
	margin-left: 20px;
	margin-right: 0;
}
.thecomment .comment-text {
	margin-right: 80px;
	margin-left: 0;
}
.post-comments span.reply a {
	margin-right: 18px;
	margin-left: 0;
}
.comments .children,
.comments > .comment > .comment,
.comments > .comment > .comment > .comment,
.comments > .comment > .comment > .comment > .comment,
.comments > .comment > .comment > .comment > .comment > .comment {
	margin: 0 60px 0 0;
}
.post-pagination .prev-post,
.woocommerce #content table.cart td.actions,
.woocommerce table.cart td.actions,
.woocommerce-page #content table.cart td.actions,
.woocommerce-page table.cart td.actions {
	text-align: left;
}
.post-tags.penci-post-sources > span,
.container-single .post-entry .post-tags a {
	margin-left: 8px;
	margin-right: 0;
}
.standard-main-content {
	text-align: right;
}
.penci-post-box-meta .penci-post-share-box {
	float: left;
}
.penci-post-box-meta .penci-post-share-box a {
	margin-right: 10px;
	margin-left: 0;
}
.penci-post-box-meta .penci-post-share-box a:first-child {
	margin-right: 0;
}
.penci-post-box-meta .penci-box-meta span:after {
	margin: 0 20px 0 16px;
}
.penci-viewport {
	direction: ltr;
}
.penci-viewport * {
	direction: rtl;
}
.header-social a {
	float: right;
	margin-left: 13px;
	margin-right: 0;
}
.header-social a:last-child {
	margin-left: 0;
}
.penci-layout-boxed-1 .list-boxed-post .header-list-style:after,
.penci-layout-classic-boxed-1 .list-boxed-post .header-list-style:after,
.penci-layout-standard-boxed-1 .list-boxed-post .header-list-style:after {
	right: 50%;
	left: auto;
	margin-right: -30px;
	margin-left: 0;
}
.penci-pagination .newer .disable-url i,
.penci-pagination .newer a i {
	margin: 0 0 0 8px;
}
.penci-pagination .disable-url i,
.penci-pagination a i {
	margin-right: 8px;
	margin-left: 0;
}
.penci-pagination .newer .fa-angle-left:before {
	content: "";
}
.penci-pagination .older .fa-angle-right:before {
	content: "";
}
.mfp-title {
	text-align: right;
	padding-left: 36px;
	padding-right: 0;
}
.mfp-counter {
	left: 0;
	right: auto;
	direction: ltr;
}
.format-post-box .post-format-icon {
	margin-right: -36px;
	margin-left: 0;
}
.grid-mixed .thumbnail .icon-post-format,
.penci-grid li .item > .thumbnail .icon-post-format,
.penci-masonry .item-masonry > .thumbnail .icon-post-format {
	right: 50%;
	left: auto;
	margin: -25px -25px 0 0;
}
#add_payment_method #payment ul.payment_methods,
#add_payment_method #payment ul.payment_methods li,
#navigation ul.menu ul.sub-menu li a,
.navigation ul.menu ul.sub-menu li a,
.penci-featured-cat-seemore,
.penci-grid .mixed-detail .item-content,
.penci-grid li .item .item-content,
.penci-masonry .item-masonry .item-content,
.penci-readmore-btn,
.wishlist_table tr td.product-name,
.wishlist_table tr td.product-thumbnail,
.wishlist_table tr td.wishlist-name,
.wishlist_table tr td.wishlist-privacy,
.woocommerce #review_form #respond p.form-submit,
.woocommerce .page-title,
.woocommerce form.checkout_coupon,
.woocommerce form.login,
.woocommerce form.register,
.woocommerce table.shop_table,
.woocommerce table.wishlist_table tfoot td,
.woocommerce-cart #payment ul.payment_methods,
.woocommerce-cart #payment ul.payment_methods li,
.woocommerce-checkout #payment ul.payment_methods,
.woocommerce-checkout #payment ul.payment_methods li,
caption,
div.penci-topbar-menu > ul ul.sub-menu li a,
th,
ul.penci-topbar-menu ul.sub-menu li a {
	text-align: right;
}
.grid-mixed .grid-header-box:after,
.penci-post-box-meta.penci-post-box-grid:before,
.woocommerce .page-title:after,
.woocommerce .page-title:before,
.woocommerce div.product .entry-summary div[itemprop="description"]:before,
div.penci-topbar-menu > ul ul.sub-menu,
ul.penci-topbar-menu ul.sub-menu {
	right: 0;
	left: auto;
}
.grid-header-box:after {
	margin-right: -30px;
	margin-left: 0;
	right: 50%;
	left: auto;
}
.woocommerce-error,
.woocommerce-info,
.woocommerce-message {
	padding: 1em 3.5em 1em 2em !important;
}
.woocommerce-error:before,
.woocommerce-info:before,
.woocommerce-message:before {
	right: 1.5em;
	left: auto;
}
.penci-review-score {
	float: left;
}
.container .penci-grid li.magazine-layout .grid-header-box:after {
	right: 0;
	left: auto;
	margin-right: 0;
}
#sidebar-nav .menu li.menu-item-has-children a {
	padding-left: 17px;
	padding-right: 0;
}
#sidebar-nav .menu li a .indicator {
	left: 0;
	right: auto;
	text-align: left;
	padding: 11px 5px 11px 0;
}
#sidebar-nav ul.sub-menu {
	padding: 10px 12px 10px 0;
}
#sidebar-nav .menu .sub-menu li a .indicator {
	padding: 8px 5px 8px 0;
}
.penci-rlt-popup .rtlpopup-heading {
	text-align: right;
	padding: 8px 20px 8px 32px;
}
.penci-rlt-popup .penci-close-rltpopup {
	right: auto;
	left: 9px;
}
.overlay-post-box-meta .overlay-share i,
.woocommerce div.product p.price del,
.woocommerce div.product span.price del {
	margin-left: 10px;
	margin-right: 0;
}
.woocommerce-account .woocommerce-MyAccount-navigation {
	float: right;
}
.woocommerce-account .woocommerce-MyAccount-content {
	float: left;
}
.yith-wcwl-share ul {
	margin: 5px 0;
	padding: 0;
}
.woocommerce .woocommerce-result-count,
.woocommerce-page .woocommerce-result-count {
	float: right;
}
.woocommerce #content div.product #reviews .comment img,
.woocommerce .star-rating,
.woocommerce .woocommerce-ordering,
.woocommerce div.product #reviews .comment img,
.woocommerce-error .button,
.woocommerce-info .button,
.woocommerce-message .button,
.woocommerce-page #content div.product #reviews .comment img,
.woocommerce-page .woocommerce-ordering,
.woocommerce-page div.product #reviews .comment img {
	float: left;
}
.woocommerce ul.products li.product,
.woocommerce-page ul.products li.product {
	float: right;
	margin: 0 0 60px 2.565%;
}
.woocommerce .penci_sidebar ul.products li.product,
.woocommerce-page .penci_sidebar ul.products li.product {
	margin-left: 3.8465%;
	margin-right: 0;
}
.woocommerce .penci_sidebar ul.products > li.product:nth-child(4n + 4),
.woocommerce-page .penci_sidebar ul.products > li.product:nth-child(4n + 4) {
	margin-left: 3.8465%;
	margin-right: 0;
}
.woocommerce ul.products li.product .onsale {
	left: 10px;
	right: auto;
}
.woocommerce .penci_sidebar ul.products > li.product:nth-child(3n + 3),
.woocommerce ul.products > li.product:nth-child(4n + 4),
.woocommerce-page .penci_sidebar ul.products > li.product:nth-child(3n + 3),
.woocommerce-page ul.products > li.product:nth-child(4n + 4) {
	margin-left: 0;
}
.penci-recipe-heading .penci-recipe-meta span.servings,
.woocommerce ul.products li.last,
.woocommerce-page ul.products li.last {
	margin-left: 0;
}
.woocommerce .products .star-rating {
	right: 10px;
	left: auto;
}
.woocommerce .woocommerce-product-rating .star-rating {
	margin: 0.5em 0 0 4px;
	float: right;
}
.woocommerce div.product form.cart div.quantity {
	float: right;
	margin: 0 0 0 20px;
}
#add_payment_method .checkout .col-2 h3#ship-to-different-address,
.post-entry .penci-recipe-heading h2,
.woocommerce #content div.product div.thumbnails a,
.woocommerce #content table.cart td.actions .coupon,
.woocommerce #payment #place_order,
.woocommerce div.product div.thumbnails a,
.woocommerce div.product form.cart .button,
.woocommerce table.cart td.actions .coupon,
.woocommerce-account .addresses .title h3,
.woocommerce-cart .checkout .col-2 h3#ship-to-different-address,
.woocommerce-checkout .checkout .col-2 h3#ship-to-different-address,
.woocommerce-page #content div.product div.thumbnails a,
.woocommerce-page #content table.cart td.actions .coupon,
.woocommerce-page #payment #place_order,
.woocommerce-page div.product div.thumbnails a,
.woocommerce-page table.cart td.actions .coupon {
	float: right;
}
.woocommerce #content div.product div.thumbnails a,
.woocommerce #content div.product div.thumbnails a.last,
.woocommerce div.product div.thumbnails a,
.woocommerce div.product div.thumbnails a.last,
.woocommerce-page #content div.product div.thumbnails a,
.woocommerce-page #content div.product div.thumbnails a.last,
.woocommerce-page div.product div.thumbnails a,
.woocommerce-page div.product div.thumbnails a.last {
	margin-left: 5.25%;
	margin-right: 0;
}
.woocommerce #content div.product div.thumbnails a:nth-child(4n + 4),
.woocommerce div.product div.thumbnails a:nth-child(4n + 4),
.woocommerce-page #content div.product div.thumbnails a:nth-child(4n + 4),
.woocommerce-page div.product div.thumbnails a:nth-child(4n + 4) {
	margin-left: 0;
}
.woocommerce
	div.product
	.woocommerce-tabs
	.panel
	#respond
	h3.comment-reply-title,
.woocommerce div.product .woocommerce-tabs .panel #reviews #comments h2,
.woocommerce div.product .woocommerce-tabs .panel > h2:first-child {
	text-align: right;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
	float: right;
	right: 0;
	left: auto;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text {
	margin: 0 80px 0 0;
}
.woocommerce #respond input#submit.added:after,
.woocommerce a.button.added:after,
.woocommerce button.button.added:after,
.woocommerce input.button.added:after {
	margin-right: 0.53em;
	margin-left: 0;
}
.woocommerce #respond input#submit.loading:after,
.woocommerce a.button.loading:after,
.woocommerce button.button.loading:after,
.woocommerce input.button.loading:after {
	margin-left: 0;
	margin-right: 5px;
}
#add_payment_method table.cart td.actions .coupon .input-text,
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text {
	float: right;
	margin: 0 0 0 4px;
}
.woocommerce form.login .form-row input[type="submit"],
.woocommerce-cart table.cart td.actions .coupon .input-text {
	margin-left: 20px;
	margin-right: 0;
}
#add_payment_method #payment ul.payment_methods li input,
.woocommerce-cart #payment ul.payment_methods li input,
.woocommerce-checkout #payment ul.payment_methods li input {
	margin: 0 0 0 1em;
}
.woocommerce form .form-row .input-checkbox {
	margin: -2px 0 0 8px;
}
.woocommerce #payment .terms,
.woocommerce #payment .wc-terms-and-conditions,
.woocommerce-page #payment .terms,
.woocommerce-page #payment .wc-terms-and-conditions {
	text-align: right;
	padding: 0 0 0 1em;
	float: right;
}
#add_payment_method .checkout .col-2 .form-row-first,
#add_payment_method .checkout .col-2 .notes,
.woocommerce-cart .checkout .col-2 .form-row-first,
.woocommerce-cart .checkout .col-2 .notes,
.woocommerce-checkout .checkout .col-2 .form-row-first,
.woocommerce-checkout .checkout .col-2 .notes {
	clear: right;
}
.woocommerce .order_details li {
	float: right;
	margin-left: 2em;
	margin-right: 0;
	border-left: 1px dashed #d3ced2;
	border-right: none;
	padding-right: 0;
	padding-left: 2em;
}
.woocommerce table.my_account_orders .order-actions {
	text-align: left;
}
.woocommerce table.my_account_orders .order-actions .button {
	margin: 0.125em 0.25em 0.125em 0;
}
.penci-recipe-heading a.penci-recipe-print,
.widget.widget_categories ul li span.category-item-count,
.woocommerce-account .addresses .title .edit,
.woocommerce-account ul.digital-downloads li .count {
	float: left;
}
.woocommerce div.product form.cart .variations select {
	margin-left: 1em;
	margin-right: 0;
}
.woocommerce div.product form.cart .variations td.label {
	padding-left: 1em;
	padding-right: 0;
}
#navigation.header-6 #logo,
.widget-social.show-text a {
	float: right;
	text-align: right;
}
#navigation.header-6 .menu {
	float: none;
}
#navigation.header-6 .pcheader-icon.shoping-cart-icon {
	margin-right: 40px;
	margin-left: 0;
}
#navigation.header-4 .pcheader-icon,
#navigation.header-4 .penci-menuhbg-toggle,
#navigation.header-5 .pcheader-icon,
#navigation.header-5 .penci-menuhbg-toggle,
#navigation.header-6 .pcheader-icon,
#navigation.header-6 .penci-menuhbg-toggle {
	margin-right: 15px;
	margin-left: 0;
}
#navigation.header-6 .container,
.woocommerce .widget_price_filter .price_slider_amount {
	text-align: left;
}
#navigation .menu > li:last-child,
#navigation .menu > ul > li:last-child,
div.penci-topbar-menu > ul > li:last-child,
ul.penci-topbar-menu > li:last-child {
	margin-left: 0;
}
.slick-slider {
	direction: ltr;
}
body.rtl .slick-slider .slick-slide {
	direction: rtl;
}
.penci-recipe-heading .penci-recipe-meta span,
.penci-review-metas .penci-review-meta {
	margin-left: 15px;
	margin-right: 0;
	display: inline-block;
}
.penci-recipe-heading .penci-recipe-meta span i,
.penci-review-metas .penci-review-meta i {
	margin-left: 4px;
	margin-right: 0;
}
.penci-review-thumb {
	float: right;
	margin-right: 0;
	margin-left: 20px;
}
.penci-review-btnbuyw {
	float: right;
}
.penci-recipe-ingredients ul li:before {
	right: -18px;
	left: auto;
}
.penci-recipe-ingredients ul {
	margin: 0;
}
.wrapper-penci-recipe .penci-recipe-method ol,
.wrapper-penci-recipe .penci-recipe-method ul {
	padding-right: 15px;
	padding-left: 0;
}
div.penci-topbar-menu > ul > li,
ul.penci-topbar-menu > li {
	float: right;
	margin-left: 25px;
	margin-right: 0;
}
.penci-pagination ul.page-numbers li a i {
	margin-right: 2px;
	margin-left: 0;
}
#navigation
	.penci-megamenu
	.penci-content-megamenu
	.penci-mega-latest-posts
	.penci-mega-post,
.navigation
	.penci-megamenu
	.penci-content-megamenu
	.penci-mega-latest-posts
	.penci-mega-post,
.penci-review-average,
.penci-review-stuff,
.penci-review-stuff .penci-review-good,
.woocommerce .widget_price_filter .price_slider_amount .button {
	float: right;
}
.penci-recipe-ingredients ul,
.penci-review .penci-review-good ul li {
	padding-right: 18px;
	padding-left: 0;
}
#navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name,
.navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name,
.penci-review .penci-review-good ul li:before,
.quote-widget > i.fa,
.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove {
	right: 0;
	left: auto !important;
}
.featured-carousel .carousel-meta span,
.woocommerce .widget_layered_nav ul li span {
	display: inline-block;
}
.featured-carousel .carousel-meta > span:after {
	margin: 0 15px 0 11px;
	border-right: 1px solid #888;
	border-left: none;
}
.quote-widget > p,
.widget ol ol,
.widget ul ul {
	padding-right: 20px;
	padding-left: 0;
}
.widget ul ul {
	padding-right: 20px;
}
.widget-social.show-text a span {
	margin-right: 10px;
	margin-left: 0;
}
.woocommerce ul.cart_list li img,
.woocommerce ul.product_list_widget li img {
	margin: 0 0 0 20px;
	float: right;
}
.woocommerce .woocommerce-product-search input[type="search"] {
	background-position: 6% 15px;
	padding: 14px 20px 14px 43px;
}
.woocommerce .widget_shopping_cart .cart_list li,
.woocommerce.widget_shopping_cart .cart_list li {
	padding-left: 40px;
	padding-right: 0;
}
.woocommerce .widget_shopping_cart p.buttons a.checkout,
.woocommerce.widget_shopping_cart p.buttons a.checkout {
	margin-right: 16px;
	margin-left: 0;
}
.footer-widget-wrapper .widget .widget-title,
.penci-mag2-carousel .mag2-item .mag2-item .mag2-header {
	text-align: right;
}
.footer-widget-wrapper {
	margin-left: 3.5%;
	margin-right: 0;
	float: right;
}
.footer-widget-wrapper.footer-widget-style-4 {
	margin-right: 0;
	width: 22.75%;
	margin-left: 3%;
}
.footer-widget-wrapper.footer-widget-style-10 {
	margin-right: 0;
}
.footer-widget-wrapper.footer-widget-style-4.last,
.footer-widget-wrapper.last {
	margin-left: 0;
}
.penci-btn-readmore .fa-angle-double-right:before,
.penci-featured-cat-seemore i.fa-angle-double-right:before {
	content: "";
}
.footer-instagram h4.footer-instagram-title > span:before {
	margin-right: 0;
	margin-left: 8px;
}
#navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before,
#navigation .penci-megamenu .penci-mega-child-categories:after,
.navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before,
.navigation .penci-megamenu .penci-mega-child-categories:after {
	left: 0;
	right: auto;
}
#navigation.menu-style-2
	.penci-megamenu
	.penci-mega-child-categories
	a.cat-active:before,
.navigation.menu-style-2
	.penci-megamenu
	.penci-mega-child-categories
	a.cat-active:before {
	box-shadow: none;
	-webkit-box-shadow: none;
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after,
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after {
	right: 20px;
	left: auto;
}
#navigation .menu li a i,
.navigation .menu li a i {
	margin-right: 0;
	margin-left: 5px;
}
#navigation.menu-style-2
	ul.sub-menu
	.penci-megamenu
	.penci-mega-child-categories
	a,
.navigation.menu-style-2
	ul.sub-menu
	.penci-megamenu
	.penci-mega-child-categories
	a {
	padding: 6px 20px 6px 0;
	text-align: right;
}
#navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a,
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
	text-align: left;
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span,
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span {
	padding-left: 20px;
	padding-right: 0;
}
body.rtl .cat > a.penci-cat-name {
	margin: 0 0 0 15px;
	padding-left: 10px;
	padding-right: 0;
}
body.rtl .cat > a.penci-cat-name:first-child {
	margin-right: 0;
	margin-left: 18px;
}
body.rtl .cat > a.penci-cat-name:last-child {
	margin-left: 0;
	padding-left: 0;
}
body.rtl .cat > a.penci-cat-name:after {
	margin-left: 0;
	margin-right: 11px;
}
body.rtl .penci-single-style-10 .header-standard,
body.rtl .penci-single-style-10 .post-box-meta-single {
	text-align: right;
}
body.rtl .penci-bgrid-based-post.pcbg-mask-subtitle .cat > a.penci-cat-name {
	margin-left: 5px;
	margin-right: 0;
}
body.rtl
	.penci-bgrid-based-post.pcbg-mask-subtitle
	.cat
	> a.penci-cat-name:last-child {
	margin-left: 0;
}
.penci_is_nosidebar .alignfull,
.penci_is_nosidebar .wp-block-cover-image.alignfull,
.penci_is_nosidebar .wp-block-cover.alignfull,
.penci_is_nosidebar .wp-block-gallery.alignfull,
.penci_is_nosidebar .wp-block-image.alignfull {
	margin-right: calc(50% - 50vw);
	margin-left: 0;
}
.penci_is_nosidebar .alignwide,
.penci_is_nosidebar .wp-block-cover-image.alignwide,
.penci_is_nosidebar .wp-block-cover.alignwide,
.penci_is_nosidebar .wp-block-gallery.alignwide,
.penci_is_nosidebar .wp-block-image.alignwide {
	margin-right: calc(25% - 25vw);
	margin-left: 0;
}
.penci-menu-hbg-inner .header-social.sidebar-nav-social,
.penci_menu_hbg_ftext {
	text-align: right;
}
@media only screen and (max-width: 767px) {
	.penci_is_nosidebar .alignwide,
	.penci_is_nosidebar .wp-block-cover-image.alignwide,
	.penci_is_nosidebar .wp-block-cover.alignwide,
	.penci_is_nosidebar .wp-block-gallery.alignwide,
	.penci_is_nosidebar .wp-block-image.alignwide {
		margin-right: calc(50% - 50vw);
		margin-left: 0;
	}
}
.wp-block-latest-posts {
	padding: 16px 36px 16px 20px !important;
}
.wp-block-separator.is-style-dots:before {
	padding-right: 0;
	padding-left: 2em;
}
@media (min-width: 600px) {
	.wp-block-columns .wp-block-column:last-child {
		margin-right: 32px;
		margin-left: 0;
	}
}
.penci-slider_btnwrap .pencislider-btn:not(:last-child) {
	margin-right: 0;
	margin-left: 15px;
}
.penci-countdown-section {
	float: right;
}
.penci-working-hours .penci-workingh-lists .penci-listitem-icon {
	padding-right: 1px;
	padding-left: 10px;
}
.penci-working-hours .penci-workingh-lists .penci-listitem-hours {
	padding-left: 0;
	padding-right: 10px;
}
.penci-working-hours .penci-workingh-lists .penci-listitem-title:before {
	right: 100%;
	margin-left: 0;
	margin-right: 10px;
}
.penci-progress-bar .penci-probar-items .penci-probar-score {
	float: left;
	text-align: left;
}
.penci-socialCT-s1 .penci-social-button,
.penci-socialCT-s2 .penci-social-button {
	float: left;
}
.penci-socialCT-s2 .penci-socialCT-item,
.penci-socialCT-s3 .penci-socialCT-item,
.penci-socialCT-s4 .penci-socialCT-item,
.penci-socialCT-s5 .penci-socialCT-item,
.penci-weather-now,
.penci-weather-section {
	float: right;
}
.penci-socialCT-s1 .penci-social-name {
	margin-right: 0;
	margin-left: 15px;
}
.penci-socialCT-wrap i {
	margin-right: 0;
	margin-left: 10px;
}
.penci-socialCT-wrap .penci-social-button span {
	margin-right: 5px;
	float: left;
}
.penci_clouds {
	text-align: right;
	padding-left: 0;
	padding-right: 10px;
}
.penci_humidty {
	text-align: left;
	padding-right: 0;
	padding-left: 10px;
}
.penci-weather-information i {
	margin-left: 5px;
	margin-right: 0;
}
.penci-weather-lo-hi__content .penci-circle {
	padding-left: 3px;
	padding-right: 3px;
}
.penci-weather-days {
	float: right;
}
.penci-testi-s2 .penci-testimonail {
	text-align: right;
}
.penci-testi-s2 .penci-testi-avatar {
	margin-left: 0;
	margin-right: 30px;
}
.penci-post-box-meta .penci-box-meta a,
.penci-post-box-meta .penci-box-meta span {
	display: inline-block;
}
.penci-ibox-float-left .penci-ibox-inner {
	text-align: right;
}
.penci-ibox-float-left .penci-ibox-icon,
.penci-video_playlist .penci-media-obj .penci-mobj-img {
	margin-right: 0;
	margin-left: 20px;
}
.penci-ibox-float-right .penci-ibox-icon {
	margin-left: 0;
	margin-right: 20px;
}
.penci-ibox-float-right .penci-ibox-inner {
	text-align: left;
}
.penci-ibox-top-right .penci-ibox-inner {
	text-align: left;
	float: left;
}
.penci-ibox-top-left .penci-ibox-inner {
	text-align: right;
	float: right;
}
.penci-video_playlist .penci-video-nav {
	float: left;
	right: auto;
	left: 0;
}
.penci-video_playlist .penci-video-nav .playlist-panel-item {
	float: right;
	text-align: right;
}
.penci-video_playlist .penci-video-playlist-item .penci-video-duration {
	float: right;
}
.pencisc-column-1.penci-video_playlist .penci-video-nav .playlist-panel-item,
.pencisc-column-2.penci-video_playlist .penci-video-nav .playlist-panel-item {
	left: auto;
	right: 0;
}
.pcilrp-flex .pcilrp-thumb {
	margin: 0 0 0 20px;
}
.pcilrt-thumbright .pcilrp-flex .pcilrp-thumb {
	margin: 0 20px 0 0;
}
.pcilrp-meta span {
	margin: 0 0 0 10px;
}
.pcilrp-meta span:last-child {
	margin-left: 0;
}
.pcilrp-meta i {
	margin: 0 0 0 5px;
}
.penci-ilrelated-posts.pcilrt-list ul.pcilrp-content {
	padding-left: 0;
	padding-right: 18px;
}
@media only screen and (max-width: 1169px) {
	.penci-headline .pctopbar-item {
		float: none;
		margin-left: 0 !important;
		margin-right: 0 !important;
	}
	.penci-headline .pctopbar-item.penci-topbar-trending {
		margin-left: auto !important;
		margin-right: auto !important;
	}
}
@media only screen and (min-width: 768px) {
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-detail {
		width: 53.75%;
		padding-left: 0;
		padding-right: 30px;
		float: left;
	}
	.penci-featured-cat-sc
		.home-featured-cat-content.style-6
		.mag-post-box.first-post
		.magcat-detail {
		padding-left: 0;
		padding-right: 30px;
		float: left;
	}
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-thumb,
	.penci-featured-cat-sc
		.home-featured-cat-content.style-6
		.mag-post-box.first-post
		.magcat-thumb {
		float: right;
	}
	.penci-grid li.list-post .item .content-list-right {
		padding-right: 30px;
		padding-left: 0;
		width: 53.75%;
		float: left;
	}
}
@media only screen and (max-width: 1169px) and (min-width: 961px) {
	#navigation.header-4 .pcheader-icon,
	#navigation.header-5 .pcheader-icon,
	#navigation.header-6 .pcheader-icon,
	#navigation.header-6 .pcheader-icon.shoping-cart-icon {
		margin-right: 26px;
		margin-left: 0;
	}
	#navigation .menu > ul > li,
	#navigation ul.menu > li,
	.navigation .menu > ul > li,
	.navigation ul.menu > li {
		margin-left: 26px;
		margin-right: 0;
	}
	.container.has-banner #logo {
		padding-left: 30px;
		padding-right: 0;
	}
}
@media only screen and (max-width: 960px) {
	#navigation.header-4 .container .pcheader-icon,
	#navigation.header-5 .container .pcheader-icon,
	#navigation.header-6 .container .pcheader-icon {
		margin-right: 15px;
		margin-left: 0;
	}
	#navigation.header-6 #logo {
		float: none;
	}
	#navigation.header-6 .container {
		text-align: center;
	}
	.footer-widget-wrapper {
		margin: 0 0 30px;
		float: none;
	}
}
@media only screen and (max-width: 960px) and (min-width: 768px) {
	.woocommerce ul.products li.product,
	.woocommerce-page ul.products li.product {
		margin-right: 0;
		margin-left: 3.8465%;
	}
	.woocommerce ul.products > li.product:nth-child(4n + 4),
	.woocommerce-page ul.products > li.product:nth-child(4n + 4) {
		margin-left: 3.8465%;
		margin-right: 0;
	}
	.woocommerce ul.products > li.product:nth-child(3n + 3),
	.woocommerce-page ul.products > li.product:nth-child(3n + 3) {
		margin-left: 0;
	}
	.penci-grid > li:nth-of-type(3n + 3) {
		margin-left: 3.9%;
		margin-right: 0;
	}
	.penci-grid > li {
		width: 48.05%;
		margin-left: 3.9%;
		margin-right: 0;
	}
	.penci-grid li:nth-of-type(2n + 2) {
		margin-left: 0;
	}
}
@media only screen and (max-width: 768px) {
	.woocommerce table.shop_table_responsive tr td,
	.woocommerce-page table.shop_table_responsive tr td {
		text-align: left !important;
	}
	.woocommerce table.shop_table_responsive tr td:before,
	.woocommerce-page table.shop_table_responsive tr td:before {
		float: right;
	}
	.woocommerce #content table.cart td.actions .coupon .button.alt,
	.woocommerce #content table.cart td.actions .coupon .input-text + .button,
	.woocommerce table.cart td.actions .coupon .button.alt,
	.woocommerce table.cart td.actions .coupon .input-text + .button,
	.woocommerce-page #content table.cart td.actions .coupon .button.alt,
	.woocommerce-page
		#content
		table.cart
		td.actions
		.coupon
		.input-text
		+ .button,
	.woocommerce-page table.cart td.actions .coupon .button.alt,
	.woocommerce-page table.cart td.actions .coupon .input-text + .button {
		float: left;
	}
	.woocommerce #content table.cart td.actions .coupon,
	.woocommerce table.cart td.actions .coupon,
	.woocommerce-page #content table.cart td.actions .coupon,
	.woocommerce-page table.cart td.actions .coupon {
		float: none;
	}
	.woocommerce .cart-collaterals .cart_totals,
	.woocommerce .cart-collaterals .cross-sells,
	.woocommerce .cart-collaterals .shipping_calculator,
	.woocommerce-page .cart-collaterals .cart_totals,
	.woocommerce-page .cart-collaterals .cross-sells,
	.woocommerce-page .cart-collaterals .shipping_calculator {
		float: none;
		text-align: right;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce .penci_sidebar ul.products li.product,
	.woocommerce ul.products li.product,
	.woocommerce-page .penci_sidebar ul.products li.product,
	.woocommerce-page ul.products li.product {
		margin-left: 4%;
		margin-right: 0;
	}
	.woocommerce .penci_sidebar ul.products > li.product:nth-child(3n + 3),
	.woocommerce-page
		.penci_sidebar
		ul.products
		> li.product:nth-child(3n + 3) {
		margin-left: 4%;
		margin-right: 0;
	}
	.woocommerce .penci_sidebar ul.products > li.product:nth-child(2n + 2),
	.woocommerce ul.products li.product:nth-child(2n + 2),
	.woocommerce-page .penci_sidebar ul.products > li.product:nth-child(2n + 2),
	.woocommerce-page ul.products li.product:nth-child(2n + 2) {
		margin-left: 0;
	}
	.woocommerce-account .woocommerce-MyAccount-content,
	.woocommerce-account .woocommerce-MyAccount-navigation {
		float: none;
	}
	.thecomment .comment-text,
	.woocommerce #reviews #comments ol.commentlist li .comment-text {
		margin-right: 0;
	}
	.penci-grid li {
		margin-left: 0 !important;
	}
	.footer-subscribe .mc4wp-form .mdes {
		width: 100%;
		margin-left: 0;
		margin-right: 0;
	}
	.penci-grid li.list-post .item .content-list-right {
		clear: both;
	}
}
@media only screen and (max-width: 960px) {
	.column-1-2,
	.column-1-3,
	.column-1-4,
	.column-2-3,
	.column-3-4 {
		margin: 0 0 30px;
	}
	.container.has-banner #logo {
		text-align: center;
	}
	.penci-topbar-social {
		float: none;
	}
	div.penci-topbar-menu > ul > li,
	ul.penci-topbar-menu > li {
		float: none;
		margin-left: 10px;
		margin-right: 0;
	}
}
@media only screen and (max-width: 479px) {
	.penci-post-box-meta .penci-post-share-box {
		float: none;
	}
	.woocommerce-cart table.cart td.actions .coupon .input-text {
		margin-left: 0;
	}
	.comments .children,
	.comments > .comment > .comment,
	.comments > .comment > .comment > .comment,
	.comments > .comment > .comment > .comment > .comment,
	.comments > .comment > .comment > .comment > .comment > .comment {
		margin: 0 30px 0 0;
	}
	.footer-subscribe .mc4wp-form .msubmit {
		margin-right: 0;
	}
	.penci-rlt-popup .rtlpopup-heading {
		padding-right: 12px;
	}
}
.penci-bgstyle-2 .item-masonry,
.penci-fixh .penci-bgitem {
	float: right;
}
.penci-bgstyle-3 .penci-fixh .penci-bgitem {
	margin-left: 0;
}
.penci-bgstyle-3 .penci-fixh .bgitem-1,
.penci-fixh .penci-bgitem {
	margin-left: var(--pcgap);
	margin-right: 0;
}
.penci-bgstyle-4 .penci-fixh .bgitem-0,
.penci-bgstyle-4 .penci-fixh .bgitem-3,
.penci-bgstyle-5 .penci-fixh .bgitem-0,
.penci-bgstyle-6 .penci-fixh .bgitem-0,
.penci-bgstyle-6 .penci-fixh .bgitem-4,
.penci-bgstyle-7 .penci-fixh .bgitem-0,
.penci-bgstyle-7 .penci-fixh .bgitem-2,
.penci-bgstyle-8 .penci-fixh .penci-bgitem {
	margin-left: 0;
}
.penci-bgstyle-8 .penci-fixh .bgitem-1 {
	margin-left: var(--pcgap);
	margin-right: 0;
}
.penci-bgstyle-10 .penci-fixh .bgitem-0,
.penci-bgstyle-10 .penci-fixh .bgitem-3,
.penci-bgstyle-11 .penci-fixh .bgitem-0,
.penci-bgstyle-11 .penci-fixh .bgitem-3,
.penci-bgstyle-12 .penci-fixh .bgitem-0,
.penci-bgstyle-12 .penci-fixh .bgitem-3,
.penci-bgstyle-13 .penci-fixh .penci-bgitem,
.penci-bgstyle-9 .penci-fixh .bgitem-0,
.penci-bgstyle-9 .penci-fixh .bgitem-2 {
	margin-left: 0;
}
.penci-bgstyle-13 .penci-fixh .bgitem-2 {
	margin-left: var(--pcgap);
	margin-right: 0;
}
.penci-bgstyle-14 .penci-fixh .bgitem-0,
.penci-bgstyle-14 .penci-fixh .bgitem-1,
.penci-bgstyle-15 .penci-fixh .bgitem-0,
.penci-bgstyle-15 .penci-fixh .bgitem-2,
.penci-bgstyle-15 .penci-fixh .bgitem-3,
.penci-bgstyle-16 .penci-fixh .bgitem-0,
.penci-bgstyle-16 .penci-fixh .bgitem-2,
.penci-bgstyle-17 .penci-fixh .bgitem-0,
.penci-bgstyle-18 .penci-fixh .bgitem-0,
.penci-bgstyle-18 .penci-fixh .bgitem-2 {
	margin-left: 0;
}
.penci-bgstyle-19 .penci-fixh .bgitem-3,
.project-pagination .prev-post a:before {
	float: left;
}
.penci-bgstyle-20 .penci-fixh .bgitem-1 {
	float: right;
}
.container:not(.penci_sidebar)
	.post-entry.portfolio-style-3
	.portfolio-page-content {
	padding-left: 0;
	padding-right: 60px;
}
ul.portfolio-meta-lists span.title {
	padding-right: 0;
	padding-left: 10px;
}
.penci-tweets-lists .tweet-intents-inner > span:not(:last-child),
.portfolio-share-box .list-posts-share a:not(:last-child) {
	margin-right: 0;
	margin-left: 10px;
}
.penci-portfolio-meta-wrapper .penci-page-header,
.post-entry blockquote,
.post-entry blockquote .author,
.post-entry blockquote cite,
.post-entry blockquote p,
.woocommerce .page-description blockquote,
.woocommerce .page-description blockquote .author,
.woocommerce .page-description blockquote cite,
.woocommerce .page-description blockquote p,
.wpb_text_column blockquote,
.wpb_text_column blockquote .author,
.wpb_text_column blockquote cite,
.wpb_text_column blockquote p {
	text-align: right;
}
.project-pagination .next-post a:after {
	float: right;
}
.post-entry blockquote,
.woocommerce .page-description blockquote,
.wpb_text_column blockquote {
	padding: 0 46px 0 0;
}
.post-entry blockquote::before,
.woocommerce .page-description blockquote::before,
.wpb_text_column blockquote::before {
	transform: scaleX(-1);
	left: auto;
	right: 0;
}
@media screen and (max-width: 960px) {
	.penci-bgstyle-3 .penci-fixh .penci-bgitem {
		margin-left: var(--pcgap);
		margin-right: 0;
	}
	.penci-bgstyle-3 .penci-fixh .bgitem-0,
	.penci-bgstyle-3 .penci-fixh .bgitem-1,
	.penci-bgstyle-6 .penci-fixh .bgitem-1 {
		margin-left: 0;
	}
	.penci-bgstyle-6 .penci-fixh .bgitem-4 {
		margin-left: var(--pcgap);
		margin-right: 0;
	}
	.penci-bgstyle-6 .penci-fixh .bgitem-0,
	.penci-bgstyle-6 .penci-fixh .bgitem-3,
	.penci-bgstyle-7 .penci-fixh .penci-bgitem {
		margin-left: 0;
	}
	.penci-bgstyle-7 .penci-fixh .bgitem-3 {
		margin-left: var(--pcgap);
		margin-right: 0;
	}
	.penci-bgstyle-10 .penci-fixh .penci-bgitem,
	.penci-bgstyle-8 .penci-fixh .bgitem-1,
	.penci-bgstyle-9 .penci-fixh .penci-bgitem {
		margin-left: 0;
	}
	.penci-bgstyle-10 .penci-fixh .bgitem-4,
	.penci-bgstyle-11 .penci-fixh .penci-bgitem,
	.penci-bgstyle-14 .penci-fixh .penci-bgitem,
	.penci-bgstyle-15 .penci-fixh .penci-bgitem,
	.penci-bgstyle-9 .penci-fixh .bgitem-1 {
		margin-left: var(--pcgap);
		margin-right: 0;
	}
	.penci-bgstyle-11 .penci-fixh .bgitem-0,
	.penci-bgstyle-11 .penci-fixh .bgitem-2,
	.penci-bgstyle-12 .penci-fixh .penci-bgitem,
	.penci-bgstyle-14 .penci-fixh .bgitem-0,
	.penci-bgstyle-14 .penci-fixh .bgitem-2,
	.penci-bgstyle-15 .penci-fixh .bgitem-0,
	.penci-bgstyle-15 .penci-fixh .bgitem-2,
	.penci-bgstyle-15 .penci-fixh .bgitem-4 {
		margin-left: 0;
	}
	.penci-bgstyle-12 .penci-fixh .bgitem-2 {
		margin-left: var(--pcgap);
		margin-right: 0;
	}
	.penci-bgstyle-12 .penci-fixh .bgitem-0,
	.penci-bgstyle-12 .penci-fixh .bgitem-3,
	.penci-bgstyle-17 .penci-fixh,
	.penci-bgstyle-17 .penci-fixh .bgitem-0,
	.penci-bgstyle-17 .penci-fixh .bgitem-1 {
		margin-left: 0;
	}
}
@media screen and (max-width: 767px) {
	.penci-bgstyle-10 .penci-fixh .bgitem-0,
	.penci-bgstyle-10 .penci-fixh .bgitem-4,
	.penci-bgstyle-9 .penci-fixh .bgitem-1,
	.penci-bgstyle-9 .penci-fixh .bgitem-2 {
		margin-left: 0;
	}
}
.header-search-style-showup .show-search {
	left: 0;
	right: auto;
}
.header-search-style-showup .show-search form.pc-searchform input.search-input {
	border-left: 0;
	border-right: 1px solid var(--pcborder-cl);
}
.header-search-style-showup .show-search:before {
	right: auto;
	left: 5px;
}
.pcnav-lgroup ul li.pcaj-next,
.pcsoc-wrapper.pcsocs-s1 .pcsoc-icon,
.pcsoc-wrapper.pcsocs-s2 .pcsoc-icon {
	float: right;
}
.pcsoc-wrapper.pcsocs-s1 .pcsoc-like,
.pcsoc-wrapper.pcsocs-s2 .pcsoc-like {
	float: left;
}
.pcsocs-s2 .pcsoc-icon {
	margin-left: 15px;
	margin-right: 0;
}
.pcsocs-s1 .pcsoc-counter,
.pcsocs-s2 .pcsoc-counter {
	float: right;
	margin-left: 5px;
	margin-right: 0;
}
.mega-menu-list .menu-label.label-style-2:before,
.mega-menu-list > li.heading-style-style-2 > a:after,
.penci-dropdown-menu.penci-mega-full-width {
	left: auto;
	right: 0;
}
.penci-builder-element.header-social a {
	margin-right: 0;
	margin-left: 10px;
}
.penci-builder-element.header-social a:last-child {
	margin-left: 0 !important;
}
.mega-menu-list .menu-label {
	right: 100%;
	left: auto;
	margin-left: 0;
	margin-right: -20px;
}
.mega-menu-list .menu-label.label-style-3 {
	left: auto;
	right: 100%;
	margin-left: 0;
	margin-right: 10px;
}
body.rtl .mega-menu-list .menu-label.label-style-1:before,
body.rtl .mega-menu-list .menu-label.label-style-2:before {
	border-right-width: 0;
	border-left-width: 5px;
	border-right-color: inherit !important;
	border-left-color: transparent !important;
}
.mega-menu-list .menu-label.label-style-3:before {
	left: auto;
	right: -4px;
	border-width: 4px 0 4px 4px;
	border-right-color: transparent !important;
	border-left-color: inherit !important;
}
.mega-menu-list .menu-label.label-style-4:before {
	right: auto;
	left: 50%;
}
.mega-menu-list > li.heading-style-style-3 > a {
	padding-left: 12px;
	padding-right: 0;
}
.mega-menu-list > li.heading-style-style-3 > a:after,
.pcnew-share .penci-social-share-text:after,
.pcnew-share .penci-social-share-text:before {
	left: auto;
	right: 100%;
}
.side-newsfeed.pctlst {
	padding-left: 0 !important;
	padding-right: 20px !important;
	margin-left: 0 !important;
	margin-right: 5px !important;
	border-left: none;
	border-right: 1px solid;
}
.side-newsfeed.pctlst .penci-feed:after,
.side-newsfeed.pctlst .penci-feed:before {
	left: auto;
	right: -25px;
}
@media only screen and (min-width: 961px) {
	.header-search-style-default
		#navigation.header-11
		.show-search
		a.close-search {
		right: auto;
		left: 10px;
	}
	.header-search-style-default
		#navigation.header-6
		.show-search
		form.pc-searchform
		input.search-input {
		height: 80px;
		padding: 26px 0 26px 35px;
	}
	.header-search-style-default
		#navigation.header-11
		.show-search
		form.pc-searchform
		input.search-input {
		height: 80px;
		padding: 26px 20px 26px 35px;
	}
	.header-search-style-default
		#navigation.header-10
		.show-search
		form.pc-searchform
		input.search-input {
		padding: 26px 0 26px 35px;
	}
}
.penci-toc-wrapper .penci-toc-title-toggle {
	right: auto;
	left: 0;
}
.penci-toc-wrapper .penci-toc-title {
	padding-right: 0;
	padding-left: 30px;
}
.pcnew-share .penci-social-share-text {
	margin-right: 0;
	margin-left: 12px;
}
.tags-share-box.tags-share-box-2_3 .penci-social-share-text {
	margin: 0 0 0 15px;
}
.penci-social-share-text i {
	margin-right: 0;
	margin-left: 8px;
}
.pcnew-share .penci-social-share-text:before {
	border-width: 8px 8px 8px 0;
	border-color: transparent var(--pcborder-cl) transparent transparent;
}
.pcnew-share .penci-social-share-text:after {
	border-width: 6px 6px 6px 0;
	border-color: transparent var(--pcbg-cl) transparent transparent;
}
.header-search-style-overlay .show-search a.close-search {
	right: auto;
	left: 30px;
}
@media only screen and (max-width: 767px) {
	.header-search-style-overlay .show-search a.close-search {
		left: 15px;
		right: auto;
	}
	.hide-table.sticky-left .penci-toc-wrapper {
		position: absolute;
		left: 0;
	}
	.hide-table.sticky-right .penci-toc-wrapper {
		transform: translateY(calc(100vh / 2 - 25px)) translateX(-10px);
	}
}
.show-txt.post-share a .dt-share {
	margin: 0 8px 0 0;
}
.show-txt.focus-icon a {
	padding-right: 0;
	padding-left: 0;
}
.show-txt a:not(.single-like-button) {
	padding-left: 12px;
}
.pcalign-right .pcnav-lgroup {
	left: 0;
	right: auto;
	justify-content: end;
}
.pcalign-center .pcnav-lgroup ul.pcflx-nav,
.pcalign-right .pcnav-lgroup ul.pcflx-nav,
.penci_comments_widget ul li .comment-body {
	padding-left: 0;
	padding-right: 15px;
}
.pcalign-center .pcnav-lgroup,
.pcalign-left .pcnav-lgroup {
	justify-content: start;
}
.pcalign-right .pcnav-lgroup ul ul {
	left: 0;
	right: auto;
	text-align: left;
}
.pcalign-center .pcnav-lgroup ul.pcflx > li:last-child > a,
.pcalign-right .pcnav-lgroup ul.pcflx > li:last-child > a {
	padding-right: 10px !important;
	padding-left: 0 !important;
}
.pcalign-center .pcnav-lgroup ul.pcflx > li:first-child > a,
.pcalign-right .pcnav-lgroup ul.pcflx > li:first-child > a {
	padding-left: 0 !important;
}
.penci_snapchat_widget .pc-snapchat-avatar {
	transform: translateX(50%) translateY(-50%);
}
.pc-widget-advanced-tax.tax-style-1 ul li,
.widget.widget_categories ul li {
	text-align: right;
}
.penci-tweets-lists .penci-tweet:before {
	right: auto;
	left: 0;
}
.penci_posts_tabs_widget .box-tabs .tabs ul > li a {
	border-right-width: 1px;
	border-left-width: 0;
}
.penci_posts_tabs_widget .recent-comments .avatar {
	margin-right: 0;
	margin-left: 15px;
}
.penci_posts_tabs_widget .box-tabs .tabs ul > li:last-child a {
	border-left-width: 1px;
}
.pc-widget-user-lists .pc-uw-ava {
	padding-right: 0;
	padding-left: 15px;
}
.pc-tiktok-feed .tiktok-feed-item .tiktok-feed-info span i,
.pc-tiktok-feed .tiktok-feed-meta.compact i {
	margin-right: 0;
	margin-left: 4px;
}
.pc-uprofile .pc-tiktok-profile-info {
	padding-left: 0;
	padding-right: 15px;
	text-align: right;
}
.penci-testi-s2 .penci-testi-company,
.penci-testi-s2 .penci-testi-name {
	margin-left: 0;
	margin-right: 30px;
}
.penci-testi-s2 .penci-testimonail .penci-testi-bq-icon:before,
.penci-testi-s5 .penci-testimonail {
	text-align: right;
}
.penci-testi-company span:last-child {
	margin-left: 0;
	margin-right: 5px;
}
.penci-testi-s4 .penci-testi-bq-icon:before,
.penci-testi-s5 .penci-testi-bq-icon:before {
	left: 0;
	right: auto;
	transform: none;
}
.penci-testi-s4.pcimgpos-right .penci-testi-bq-icon:before {
	right: 0;
	left: auto;
	transform: rotate(180deg);
}
.penci-testi-s5 .penci-testi-blockquote:after {
	left: auto;
	right: 15px;
}
.pctesti-head .pc-testiava,
.penci-testi-s4.pcimgpos-left .pc-testiava {
	margin-right: 0;
	margin-left: 20px;
}
.penci-testi-s4.pcimgpos-right .pc-testiava {
	margin-right: 20px;
	margin-left: 0;
}
.penci-testi-s4.pcimgpos-left .pctesticont {
	text-align: right;
}
.penci-testi-s4.pcimgpos-right .pctesticont {
	text-align: left;
}
.penci-header-trans .show-search a.close-search {
	right: auto;
	left: 15px;
}
.penci-search-results .autocomplete-suggestion .suggestion-thumb {
	margin: 0 0 0 15px;
}
.header-search-style-default .search-results-wrapper .no-found-msg,
.penci-search-results .autocomplete-suggestion .suggestion-content {
	text-align: right;
}
.penci-search-form form {
	padding: 0 20px 0 0;
}
.header-search-style-showup .search-results-wrapper .penci-dropdown-results {
	left: auto;
	right: -20px;
}
.pcsml_style_1 .pcsml-item-title,
.pcsml_style_2 .pcsml-item-title,
.pcsml_style_4 .pcsml-item-title {
	padding-left: 0;
	padding-right: 15px;
}
@media only screen and (min-width: 768px) {
	.pcsml_style_2 .pcsml-figure {
		padding-right: 20px;
		padding-left: 0;
	}
}
.pcsml_style_3 .pcsml-item-number {
	left: auto;
	right: 0;
}
.pcsml-button.pcsm-back i {
	padding-left: 10px;
	padding-right: 0;
}
.pcsml-button.pcsm-back i:before {
	content: "";
}
.pcsml-button.pcsm-next i:before {
	content: "";
}
.pcsml-button.pcsm-next i {
	padding-left: 0;
	padding-right: 10px;
}
.pcsml-dropdown-wrap .pcsm-back {
	text-align: right;
}
.pcsml-dropdown-wrap .pcsm-next {
	text-align: left;
}
.pcsml-dropdown-wrap .pcsml-container::before {
	right: auto;
	left: 16px;
}
.widget .penci-pagination.penci-ajax-nav {
	flex-direction: row-reverse;
}
.penci-pagination.penci-ajax-nav .pcajx-btn i {
	order: 1;
}
.penci-pagination.penci-ajax-nav .next .pcnav-title {
	order: 5;
}
.pctopbar-login-btn li.pclogin-item img {
	margin-right: 0;
	margin-left: 5px;
}
.penci-review-summary .review_rated {
	margin: 0 0 0 5px;
}
.post-box-meta-single span time {
	display: inline-block;
}
.navigation .menu .children,
.navigation .menu .sub-menu,
.penci-dropdown-menu.penci-mega-full-width {
	left: auto;
}
.penci-go-to-top-floating {
	right: auto;
	left: 20px;
}
.pc-search-form.search-style-icon-button .search-input {
	padding-right: 20px;
	padding-left: 66px;
	border-right: 1px solid #e9e9e9;
}
.block-title-icon-left .inner-arrow i {
	margin-right: 0;
	margin-left: 8px;
}
.block-title-icon-right .inner-arrow i {
	margin-left: 0;
	margin-right: 8px;
}
.penci-rlt-popup .rltpopup-thumbnail {
	float: right;
	margin: 0 0 0 20px;
}
.post-pagination .prev-post {
	float: right;
	text-align: right;
}
.post-pagination .next-post {
	float: left;
	text-align: left;
}
.penci-post-nav-thumb {
	float: right;
	margin: 0 0 0 15px;
}
.penci-post-nav-thumb.nav-thumb-next {
	float: left;
	margin: 0 15px 0 0;
}
@media only screen and (max-width: 479px) {
	.post-pagination .next-post,
	.post-pagination .prev-post {
		text-align: center;
	}
}
@media only screen and (min-width: 1170px) {
	.penci-headline .pctopbar-item:last-child:not(:first-child) {
		float: left;
	}
}
.menu-item-has-label .menu-label {
	left: auto;
	right: 100%;
	margin-left: 0;
	margin-right: -20px;
}
.menu-item-has-label .menu-label.label-style-1:before {
	left: auto;
	right: 10px;
	border-left-width: 7px;
	border-left-color: transparent !important;
	border-right-width: 0 !important;
}
.menu-item-has-label .menu-label.label-style-2:before {
	right: 0;
	left: auto;
	border-left-width: 7px;
	border-left-color: transparent !important;
	border-right-width: 0 !important;
}
.menu-item-has-label .menu-label.label-style-4:before {
	margin-left: 0;
	margin-right: -4px;
}
.penci-dropcap-bold,
.penci-dropcap-box,
.penci-dropcap-box-outline,
.penci-dropcap-circle,
.penci-dropcap-circle-outline,
.penci-dropcap-regular {
	float: right;
	margin-right: 0;
	margin-left: 13px;
}
.pcnav-lgroup ul.pcflx > li:first-child > a {
	padding-right: 0 !important;
	padding-left: 10px !important;
}
.pcnav-lgroup ul.pcflx > li:last-child:not(:first-child) > a {
	padding-left: 0 !important;
	padding-right: 10px !important;
}
.pcalign-center .pcnav-lgroup ul.pcflx > li:first-child > a,
.pcalign-right .pcnav-lgroup ul.pcflx > li:first-child > a {
	padding-left: 10px !important;
}
.pcsl-imgpos-left .pcsl-content {
	padding-right: var(--pcsl-between);
	padding-left: 0;
}
.pcsl-imgpos-right .pcsl-content {
	padding-left: var(--pcsl-between);
	padding-right: 0;
}
.post-pagination h5 {
	padding: 0 0 0 25px;
}
.post-pagination h5.next-title {
	padding: 0 25px 0 0;
}
.pcfooter-navmenu .pcfoot-navmenu > li {
	margin-right: 0;
	margin-left: var(--pcfnmn-space);
}
.pcfooter-navmenu .pcfoot-navmenu > li:last-child {
	margin-left: 0;
}
ul.pcmg-subcol-2 > li,
ul.pcmg-subcol-3 > li {
	float: right;
	margin-left: var(--pcmega-colspace);
	margin-right: 0;
}
ul.pcmg-subcol-2 > li:nth-child(2n + 2),
ul.pcmg-subcol-3 > li:nth-child(3n + 3) {
	margin-left: 0;
}
.post-box-meta-single span {
	display: inline-block;
}
.penci_recent-posts-sc ul.penci-feed-2columns li,
.widget ul.penci-feed-2columns li {
	float: right;
}
.penci_recent-posts-sc ul.penci-2columns-featured > li:nth-child(2n),
.penci_recent-posts-sc ul.penci-2columns-feed > li:nth-child(2n + 1),
.widget ul.penci-2columns-featured > li:nth-child(2n),
.widget ul.penci-2columns-feed > li:nth-child(2n + 1) {
	margin-right: 0;
	margin-left: 6%;
}
.author-url .author-a-name,
.grid-post-box-meta .author-a-name {
	margin-right: 5px;
	margin-left: 0;
}
.penci-pagination ul.page-numbers li {
	float: right;
	margin-right: 0;
	margin-left: 10px;
}
.penci-pagination ul.page-numbers li:last-child {
	margin-left: 0;
}
#sidebar-nav .menu-item-has-label .menu-label,
.pc-dropdown-menu .menu-item-has-label .menu-label,
.penci-menu-hbg .menu-item-has-label .menu-label {
	right: auto;
}
.popularpost_item {
	padding-right: 60px;
	padding-left: 0;
}
.popularpost_list.columns-format .popularpost_item {
	padding-right: 60px;
	padding-left: 15px;
}
@media only screen and (max-width: 768px) {
	.popularpost_list.columns-format .popularpost_item {
		padding-left: 0;
	}
}
.popularpost_item .pcpopular_new_post_title a:before {
	left: auto;
	right: 0;
}
.popularpost_item.first .pcpopular_new_post_title,
.popularpost_item.first .popularpost_meta {
	padding-right: 60px;
	padding-left: 0;
}
.popularpost_list,
.widget .popularpost_list {
	padding-right: 0;
}
ul.pc-advanced-cat {
	padding-right: 0;
}
ul.pc-advanced-cat li .indicator {
	right: auto;
	left: 0;
}
ul.pc-advanced-cat.toggle-enable li .category-item-count {
	margin-right: 0;
	margin-left: 30px;
}
@media only screen and (max-width: 960px) {
	.popularpost_list.columns-format.t-col-1 .popularpost_item {
		padding-right: 60px;
		padding-left: 0;
	}
}
@media only screen and (max-width: 479px) {
	.popularpost_list.columns-format .popularpost_item,
	.popularpost_list.columns-format.m-col-1 .popularpost_item {
		padding-right: 60px;
		padding-left: 0;
	}
}
.popularpost_item.first {
	padding-right: 0;
}
#navigation.menu-style-3 .menu .penci-dropdown-menu:after,
#navigation.menu-style-3 .menu .penci-dropdown-menu:before,
#navigation.menu-style-3 .menu .sub-menu:after,
#navigation.menu-style-3 .menu .sub-menu:before,
.navigation.menu-style-3 .menu .penci-dropdown-menu:after,
.navigation.menu-style-3 .menu .penci-dropdown-menu:before,
.navigation.menu-style-3 .menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu:before {
	left: auto;
	right: 14px;
}
#navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
#navigation.menu-style-3 .menu .sub-menu .sub-menu:before,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:before {
	left: auto;
	right: -6px;
}
#navigation.menu-style-3 .menu .penci-dropdown-menu:after,
#navigation.menu-style-3 .menu .sub-menu:after,
.navigation.menu-style-3 .menu .penci-dropdown-menu:after,
.navigation.menu-style-3 .menu .sub-menu:after {
	left: auto;
	right: 15px;
}
#navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:after {
	left: auto;
	right: -4px;
}
#navigation ul.sub-menu > li.menu-item-has-children > a:after {
	float: left;
	content: "\f104";
}
.woocommerce-product-gallery.thumbnail-bottom
	.penci-thumbnail-image-wrapper
	figure {
	margin-right: 0;
	margin-left: 10px;
}
.penci-post-gallery-container.thumbnail-slider figure p {
	left: 15px;
	right: auto;
}
.pcrlt-style-2 .item-related-inner,
.pcrlt-style-4 .item-related-inner,
.pcrlt-style-5 .item-related-inner {
	text-align: right;
}
.pcrlt-style-2 a.penci-cat-name,
.pcrlt-style-5 .penci-cat-name {
	left: auto;
	right: 20px;
}
.pcrlt-style-4 .related-content {
	padding-left: 0;
	padding-right: 15px;
}
.heading1-style-2 .entry-content > h1:before,
.heading1-style-3 .entry-content > h1:before,
.heading1-style-4 .entry-content > h1:before,
.heading2-style-2 .entry-content > h2:before,
.heading2-style-3 .entry-content > h2:before,
.heading2-style-4 .entry-content > h2:before,
.heading3-style-2 .entry-content > h3:before,
.heading3-style-3 .entry-content > h3:before,
.heading3-style-4 .entry-content > h3:before,
.heading4-style-2 .entry-content > h4:before,
.heading4-style-3 .entry-content > h4:before,
.heading4-style-4 .entry-content > h4:before,
.heading5-style-2 .entry-content > h5:before,
.heading5-style-3 .entry-content > h5:before,
.heading5-style-4 .entry-content > h5:before {
	left: auto;
	right: 0;
}
.heading1-style-3 .entry-content > h1,
.heading1-style-4 .entry-content > h1,
.heading2-style-3 .entry-content > h2,
.heading2-style-4 .entry-content > h2,
.heading3-style-3 .entry-content > h3,
.heading3-style-4 .entry-content > h3,
.heading4-style-3 .entry-content > h4,
.heading4-style-4 .entry-content > h4,
.heading5-style-3 .entry-content > h5,
.heading5-style-4 .entry-content > h5 {
	padding-left: 0;
	padding-right: 20px;
}
.heading1-style-2 .entry-content > h1:after,
.heading2-style-2 .entry-content > h2:after,
.heading3-style-2 .entry-content > h3:after,
.heading4-style-2 .entry-content > h4:after,
.heading5-style-2 .entry-content > h5:after {
	left: 0;
	right: 20px;
}
.heading1-style-5 .entry-content > h1:before,
.heading2-style-5 .entry-content > h2:before,
.heading3-style-5 .entry-content > h3:before,
.heading4-style-5 .entry-content > h4:before,
.heading5-style-5 .entry-content > h5:before {
	right: 0;
	left: auto;
}
.penci-sponsored-label {
	margin: 0 0 0 5px !important;
}
.penci-sponsored-logo img {
	margin-right: 5px;
	margin-left: 0;
}
.pcpagp-style-5 .post-pagination h5 {
	padding: 0;
}
.post-entry.blockquote-style-3 blockquote:not(.wp-block-quote):before {
	left: 0;
	right: auto;
	transform: rotate(0);
}
.post-entry.blockquote-style-3 blockquote:not(.wp-block-quote) {
	padding: 15px 0 15px 50px;
}
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote)::before {
	transform: translateX(50%) rotate(180deg);
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote)::after,
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote)::before,
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote)::after {
	transform: translateX(50%);
}
@media only screen and (min-width: 768px) {
	.post-pagination.pcpagp-style-5 .next-post-inner,
	.post-pagination.pcpagp-style-5 .prev-post-inner {
		margin: -60px 0 0 60px;
		padding: 20px 0 20px 20px;
	}
	.post-pagination.pcpagp-style-5 .next-post-inner {
		margin: -60px 60px 0 0;
		padding: 20px 20px 20px 0;
	}
}
@media only screen and (max-width: 767px) {
	.penci-post-nav-thumb.nav-thumb-next {
		margin: 0;
	}
}
.pcmis-4 .penci-mega-post .penci-mega-meta,
.pcmis-5 .penci-mega-post .penci-mega-meta {
	text-align: right;
	padding: 0 20px 0 0;
}
.pcmis-3 .penci-mega-post .penci-mega-meta {
	text-align: right;
}
.pc-builder-element.pc-main-menu
	.navigation.menu-item-padding
	.menu
	> ul
	> li:not(:last-child),
.pc-builder-element.pc-main-menu
	.navigation.menu-item-padding
	ul.menu
	> li:not(:last-child) {
	margin-left: var(--pchb-main-menu-mgi);
	margin-right: 0;
}
.pc-builder-element.pc-second-menu
	.navigation.menu-item-padding
	.menu
	> ul
	> li:not(:last-child),
.pc-builder-element.pc-second-menu
	.navigation.menu-item-padding
	ul.menu
	> li:not(:last-child) {
	margin-left: var(--pchb-second-menu-mgi);
	margin-right: 0;
}
.pc-builder-element.pc-third-menu
	.navigation.menu-item-padding
	.menu
	> ul
	> li:not(:last-child),
.pc-builder-element.pc-third-menu
	.navigation.menu-item-padding
	ul.menu
	> li:not(:last-child) {
	margin-left: var(--pchb-third-menu-mgi);
	margin-right: 0;
}
.penci-post-gallery-container.thumbnail-slider figure p {
	left: 15px;
	right: auto;
}
.penci-grid[data-layout="list-boxed"] li.list-post .item {
	padding-left: 20px;
	border-left: 1px solid var(--pcborder-cl);
	padding-right: 0;
	border-right: 0;
}
.penci-grid[data-layout="list-boxed-2"] li.list-post .item {
	padding-right: 20px;
	border-right: 1px solid var(--pcborder-cl);
	padding-left: 0;
	border-left: 0;
}
.penci-grid[data-layout="list-boxed-2"] li.list-post .item .content-list-right {
	padding-left: 30px;
	padding-right: 0;
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) {
	padding: 30px 90px 30px 30px;
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote)::before {
	left: auto;
	right: 40px;
	transform: scaleY(1);
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) p {
	text-align: right;
}
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote):before,
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote):before {
	transform: translateX(50%) rotate(180deg);
}
.pc-comment-s1-button i {
	margin: 0 0 0 10px;
}
.comments.pc-cms-style-2 .thecomment .comment-text span.reply,
.comments.pc-cms-style-3 .thecomment .comment-text span.reply {
	left: 30px;
	right: auto;
}
.comments.pc-cms-style-2 .thecomment .comment-text::before {
	right: -10px;
	left: auto;
	transform: translatey(-50%) rotate(90deg);
}
.pc-cms-style-3 .thecomment .comment-text {
	margin-left: 0;
	margin-right: 50px;
}
.pc-cms-style-3 .thecomment .author-img {
	margin-right: 0;
	margin-left: 20px;
}
.pc-cms-style-3 .thecomment .comment-text:after,
.pc-cms-style-3 .thecomment .comment-text:before {
	left: auto;
	right: -10px;
	border-width: 10px 0 10px 10px;
	border-color: transparent transparent transparent var(--pcborder-cl);
}
.pc-cms-style-3 .thecomment .comment-text:after {
	border-width: 8px 0 8px 8px;
	right: -8px;
	border-color: transparent transparent transparent var(--pcbg-cl);
}
@media only screen and (max-width: 767px) {
	.comments.pc-cms-style-2 .thecomment .author-img,
	.comments.pc-cms-style-3 .thecomment .author-img {
		margin-left: 10px;
		margin-right: 0;
	}
	.comments.pc-cms-style-2 .comment-text {
		margin-left: 0;
		margin-right: 40px;
	}
}
.penci-mtp-filters-wrapper.pctp-left {
	flex-direction: row-reverse;
}
.penci-mtp-filters-wrapper.pctp-right {
	flex-direction: row;
}
.penci-mtp-filters-terms ul,
.penci-mtp-filters-terms ul li {
	padding-right: 0;
}
.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .pcsl-iteminer {
	padding-right: 0;
	padding-left: 120px;
}
.penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt,
.post-entry
	.penci-mtp-filters-wrapper
	.pcsl-inner
	.grid-post-box-meta.pcmtf-mt-alt {
	right: auto;
	left: 0;
}
@media only screen and (max-width: 767px) {
	.penci-mtp-filters-close.active::after,
	.penci-mtp-filters-mobile::after {
		right: auto;
		left: 20px;
	}
	.penci-mtp-filters-close.active,
	.penci-mtp-filters-mobile {
		padding-right: 20px;
	}
}
.penci-sidebar-content.style-22 .widget-title:before {
	left: auto;
	right: 0;
}
@media screen and (max-width: 1169px) {
	.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .pcsl-iteminer {
		padding-left: 0;
	}
}
.list-post-3 .content-list-right {
	margin: 20px -40px 20px 20px;
}
.post-entry,
.post-entry p,
.widget ul li,
p {
	text-align: right;
}
.penci-post-share-box-btn {
	left: auto;
	right: 10px;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a::before {
	margin-right: 0;
	margin-left: 5px;
}
.pcstyle-style-2 .container-single .post-entry .post-tags a::before {
	margin-right: 0;
	margin-left: 2px;
}
.penci-slider44-thumb-wrapper {
	right: auto;
	left: 30px;
}
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next,
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-prev {
	left: auto;
	right: 70px;
}
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next {
	right: 30px;
}
.featured-area.featured-style-42 .penci-featured-content .feat-text,
.penci-slider41-main-wrapper .penci-featured-content .feat-text,
.penci-slider44-main-wrapper .penci-featured-content .feat-text {
	text-align: right;
}
.penci-slider42-main-wrapper .penci-featured-content .feat-text h3 a {
	text-align: right;
}
.penciimg-compare .icv__img-a {
	left: auto;
	right: 0px;
}
.penciimg-compare .icv__img-b {
	right: auto;
	left: 0px;
}
.penciimg-compare .icv__label-before {
	right: 1rem;
	left: auto;
}
.penciimg-compare .icv__label-after {
	left: 1rem;
	right: auto;
}
.penciimg-compare .icv__label-after.vertical {
	left: auto;
}
body.rtl
	.navigation
	.menu
	li.penci-block-mega.penci-mg-fullwidth
	> .penci-dropdown-menu {
	left: auto !important;
	right: calc(
		(100vw - var(--pcctain)) / 2 * -1 + 10px - var(--pcctnspc)
	) !important;
}
.pc-widget-advanced-tax.tax-style-2 .tag-link-count {
	margin-right: 3px;
	margin-left: 0;
}
.penci-single-style-10 .header-standard,
.penci-single-style-10 .post-box-meta-single,
.penci-single-style-15 .header-standard,
.penci-single-style-15 .post-box-meta-single,
.penci-single-style-13 .header-standard,
.penci-single-style-13 .post-box-meta-single {
	text-align: right;
}
.penci-single-style-15 .container.two-sidebar .penci-sidebar-content,
.penci-single-style-15 .penci-post-image-wrapper .penci-sidebar-content {
	right: 0;
	left: auto;
}
.penci-single-style-15 .penci-single-s15-content {
	padding-right: 20%;
	padding-left: 0;
}
.penci-single-style-13 .penci-single-s13-content {
	margin-right: calc((100vw - var(--pcctain)) / -2);
	margin-left: 0;
}
.penci-single-style-13
	.penci-post-image-wrapper
	.penci-sidebar-content
	.single-header {
	padding: 50px 50px 50px 0;
}
.penci-single-style-13 .penci-container-inside.penci-breadcrumb {
	padding-left: 0;
	padding-right: 50px;
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:before {
	left: auto;
	right: 100%;
}
@media only screen and (max-width: 960px) {
	.penci-single-style-15 .penci-single-s15-content {
		padding-left: 0;
		padding-right: 0;
	}
	.penci-body-single-style-20 .penci-container-inside.penci-breadcrumb {
		text-align: center;
	}
	.penci-single-style-13 .penci-single-s13-content {
		margin-right: 0;
	}
	.penci-single-style-13.penci-show-ft-caption
		.penci-post-image-wrapper
		.penci-sidebar-content:after {
		display: none;
	}
}
@media only screen and (min-width: 961px) {
	.penci-single-style-14:not(.penci-single-pheader-noimg).penci_sidebar
		#main
		article.post {
		margin-right: 40px;
		padding-right: 40px;
		margin-left: 0;
		padding-left: 0;
	}
}
.penci-body-single-style-22 .post-image .penci-author-wrapper {
	transform: translateX(50%);
}
.rtl.penci-body-single-style-22 .container-single .post-box-meta-single,
.rtl.penci-body-single-style-22 .container-single .header-standard {
	text-align: center;
}
@media only screen and (min-width: 768px) {
	.penci-grid
		li.pclist-layout.pc-has-thumb.pc-list-imgright
		.item
		.content-list-right {
		padding-left: 30px;
		padding-right: 0;
	}
}
.penci-grid[data-layout="grid-boxed-3"] li .item {
	margin-left: 0;
	margin-right: 15px;
}
.penci-grid[data-layout="grid-boxed-3"] li .item .cat {
	left: auto;
	right: 0;
	transform: translate(calc(0px + 50% + 18px), 80px) rotate(-90deg);
	justify-content: flex-start;
}
.penci-grid[data-layout="grid-boxed-3"] li.pchide-cat .item {
	margin-right: 0;
}
.post-tags.penci-post-sources > span::before {
	margin: 0 0 0 4px;
}
.penci-visitor-count {
	padding: 10px 35px 10px 20px;
}
.penci-grid4-date {
	left: auto;
	right: 20px;
	padding-right: 0;
	padding-left: 20px;
}
.penci-grid4-date span {
	margin-right: 0;
	margin-left: 10px;
}
.grid-boxed-4-item .grid-header-box {
	text-align: right;
}
.penci-post-sticky-nav-wrap {
	flex-direction: row-reverse;
}
.penci-pshare-dropdown a i {
	margin-right: 0;
	margin-left: 5px;
}
.penci-focus-mode-icon:before {
	margin-right: 0;
	margin-left: 6px;
}
.penci-post-sticky-nav-wrap .prev-post {
	justify-content: end;
}
.penci-post-sticky-nav-wrap .next-post {
	justify-content: start;
}
body.rtl.penci-gtt-enable .penci-focus-mode-button.right {
	right: 20px;
}
.penci-tiline .penci-tiline-date span {
	display: inline-block;
}
.show-search.pcbds-popup {
	text-align: right;
}
.show-search.pcbds-popup .close-search{
	right:auto;
	left:10px;
}
.penci-pshare-dropdown {
	left: auto;
	right: 12px;
}
@media (min-width: 960px) {
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-line {
		right: auto;
		left: 0;
	}
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-icon {
		right: auto;
		left: 0;
	}
	body.rtl .penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
		transform: translate(50%, 50%);
		top: 0;
	}
	body.rtl
		.penci-tiline
		.penci-tiline-item-main-wrapper
		.penci-tiline-icon
		span {
		transform: translate(50%, 0%);
	}
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-item-main-container {
		padding-right: 0;
		padding-left: 50px;
	}
	body.rtl .penci-tiline-center .penci-tiline-item.right-part .penci-tiline-icon {
		left: auto;
		right: 0;
	}
	body.rtl .penci-tiline-center
		.penci-tiline-item.right-part
		.penci-tiline-item-main-container {
		padding-left: 0;
		padding-right: 50px;
	}
}
body.rtl .penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line span,
body.rtl
	.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line::before {
	transform: translateX(50%);
}
body.rtl .penci-tiline-item-date-wrap.right {
	text-align: left;
}
body.rtl .penci-tiline-meta li:not(:last-child),
body.rtl .post-entry .penci-tiline-meta li:not(:last-child) {
	margin-right: 0;
	margin-left: 20px;
}