.forum-archive .penci-content-post {
    padding: 20px;
    background: #ffffff;
}
.forum-archive .penci-entry-title {
    font-size: 30px;
    line-height: 1.2;
    color: #111111;
    margin-top: 9px;
    margin-bottom: 6px;
}
.forum-archive .penci-entry-title.penci-title-center {
    text-align: center;
}
.forum-archive .penci-entry-title.penci-title-right {
    text-align: right;
}
#sidebar .bbp-login-form label {
    width: 120px;
}
#bbpress-forums {
    font-size: 15px;
}
#bbpress-forums ul.bbp-forums {
    border: none;
}
#bbpress-forums ul.bbp-forums .forum-titles li:before {
    display: none;
}
#bbpress-forums ul.bbp-lead-topic,
#bbpress-forums ul.bbp-topics,
#bbpress-forums ul.bbp-forums,
#bbpress-forums ul.bbp-replies,
#bbpress-forums ul.bbp-search-results {
    border: none;
}
#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-footer,
#bbpress-forums li ul.forum {
    background: none;
}
#bbpress-forums li.bbp-header {
    background: none #313131;
    color: #fff;
    border-top: 0;
    padding: 7px 15px;
}
#bbpress-forums li.bbp-header ul.forum-titles li,
#bbpress-forums li.bbp-header .bbp-reply-author,
#bbpress-forums li.bbp-header .bbp-reply-content {
    font-size: 14px;
}
#bbpress-forums li.bbp-body {
    margin-top: 20px;
}
#bbpress-forums li.bbp-body div.odd,
#bbpress-forums li.bbp-body ul.odd {
    background: none;
}
#bbpress-forums li.bbp-body ul.forum,
#bbpress-forums li.bbp-body ul.topic {
    border-top-color: #ECECEC;
    padding: 20px 0 27px;
    background: transparent;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-info a,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-title a {
    font-size: 14px;
    color: #111111;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-info a.bbp-forum-title,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-title a.bbp-forum-title {
    font-size: 16px;
    font-weight: 700;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-info a:hover,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-title a:hover {
    text-decoration: none;
    color: var(--pcaccent-cl);
}
#bbpress-forums li.bbp-body .bbp-forums-list li {
    color: #fff;
    display: block;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-info .bbp-forum-content,
#bbpress-forums li.bbp-body ul.topic p.bbp-topic-meta {
    font-style: italic;
    color: #c3c3c3;
    line-height: 1.6;
    font-size: 12px;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-info .bbp-forum-content a,
#bbpress-forums li.bbp-body ul.topic p.bbp-topic-meta a {
    font-size: 12px;
    font-weight: 400;
    color: var(--pcaccent-cl);
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-topic-count,
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-reply-count,
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness,
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness a,
#bbpress-forums li.bbp-body ul.topic li.bbp-forum-topic-count,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-voice-count,
#bbpress-forums li.bbp-body ul.topic li.bbp-forum-reply-count,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness > a,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-reply-count {
    font-size: 12px;
    color: #111111;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness p.bbp-topic-meta,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness p.bbp-topic-meta {
    margin: -6px 0;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness p.bbp-topic-meta a,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness p.bbp-topic-meta a {
    font-weight: 500;
    font-size: 12px;
}
#bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness p.bbp-topic-meta a:hover,
#bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness p.bbp-topic-meta a:hover {
    text-decoration: none;
}
#bbpress-forums li.bbp-footer {
    border-top-color: #ECECEC;
}
#bbpress-forums li:before {
    display: none;
}
#bbpress-forums li.bbp-forum-info,
#bbpress-forums li.bbp-topic-title {
    width: 45%;
}
#bbpress-forums li.bbp-forum-topic-count,
#bbpress-forums li.bbp-topic-voice-count,
#bbpress-forums li.bbp-forum-reply-count,
#bbpress-forums li.bbp-topic-reply-count {
    width: 15%;
}
#bbpress-forums li.bbp-forum-freshness,
#bbpress-forums li.bbp-topic-freshness {
    float: right;
    text-align: right;
}
#bbpress-forums .forum-titles li.bbp-forum-freshness,
#bbpress-forums .forum-titles li.bbp-topic-freshness {
    padding-right: 0;
}
#bbpress-forums div.bbp-search-form {
    position: relative;
    float: none;
    width: 100%;
    padding-bottom: 21px;
}
#bbpress-forums #bbp-search-form #bbp_search {
    font-size: 13px;
    font-weight: normal;
    width: 95%;
    height: 40px;
    padding: 10px 43px 10px 15px;
    color: #313131;
    border: 1px solid var(--pcborder-cl);
    background: transparent;
    -webkit-appearance: textfield;
}
#buddypress #pass-strength-result {
    color: #000;
}
#bbpress-forums #bbp-search-form .button {
    font-family: var(--pchead-font);
    font-size: 13px;
    font-weight: bold;
    line-height: 40px;
    position: absolute;
    top: 0;
    right: 0;
    display: block;
    height: 40px;
    margin: 0;
    padding: 0 20px;
    cursor: pointer;
    -moz-transition: all 0.3s;
    -webkit-transition: all 0.3s;
    transition: all 0.3s;
    text-transform: uppercase;
    color: #fff;
    border: none;
    background: var(--pcaccent-cl);
}
#bbpress-forums #bbp-search-form .button:hover {
    color: #fff;
    background: var(--pcaccent-cl);
}
#bbpress-forums div.even, #bbpress-forums ul.even {
    background: transparent;
}
#bbpress-forums .bbp-breadcrumb p {
    font-size: 12px;
    line-height: 1.4;
    color: #888888;
    margin-bottom: 0;
    margin-top: 0;
    margin-left: 2px;
}
#bbpress-forums .bbp-breadcrumb a,
#bbpress-forums .bbp-breadcrumb .bbp-breadcrumb-current {
    font-size: 12px;
    color: #888888;
}
#bbpress-forums .bbp-breadcrumb a:hover {
    text-decoration: none;
    color: var(--pcaccent-cl);
}
#bbpress-forums .bbp-breadcrumb .bbp-breadcrumb-sep {
    font-size: 12px;
    margin: 0 5px 0 5px;
}
#bbpress-forums .subscription-toggle {
    display: none;
}
#bbpress-forums div.bbp-template-notice.info {
    border: 1px solid #ECECEC;
    background-color: transparent;
    border-radius: 0;
    padding-top: 2px;
}
#bbpress-forums div.bbp-template-notice.info img {
    width: 20px !important;
    display: inline;
    vertical-align: middle;
    margin-bottom: 0 !important;
    margin-left: 5px;
    margin-right: 5px;
}
#bbpress-forums .bbp-pagination-count {
    margin-top: 2px;
    color: #111111;
    font-weight: normal;
    font-size: 13px;
}
#bbpress-forums .bbp-topic-started-by,
#bbpress-forums .bbp-topic-started-in {
    color: #c3c3c3;
    font-size: 12px;
}
#bbpress-forums .bbp-topic-started-by a,
#bbpress-forums .bbp-topic-started-in a {
    font-size: 12px;
}
#bbpress-forums .bbp-topic-started-by img,
#bbpress-forums .bbp-topic-started-in img {
    position: absolute;
    top: 2px;
    left: 0;
    margin: 0;
}
#bbpress-forums p.bbp-topic-meta span {
    white-space: initial;
}
#bbpress-forums li.bbp-topic-title .bbp-topic-permalink,
#bbpress-forums li.bbp-topic-title .bbp-topic-meta {
    padding-left: 50px;
}
#bbpress-forums div.bbp-topic-tags {
    float: left;
}
#bbpress-forums .bbp-topic-freshness-author {
    margin-top: 8px;
    display: inline-block;
}
#bbpress-forums .bbp-forum-freshness a,
#bbpress-forums .bbp-topic-freshness a {
    color: #111111;
    font-size: 12px;
    font-weight: 600;
}
#bbpress-forums .bbp-forum-freshness a:hover,
#bbpress-forums .bbp-topic-freshness a:hover {
    color: var(--pcaccent-cl);
}
#bbpress-forums .bbp-body .bbp-forum-freshness img,
#bbpress-forums .bbp-body .bbp-topic-freshness img {
    position: absolute;
    right: 0;
    top: 3px;
    margin: 0;
}
#bbpress-forums li.bbp-forum-topic-count,
#bbpress-forums li.bbp-forum-reply-count,
#bbpress-forums li.bbp-topic-voice-count,
#bbpress-forums li.bbp-topic-reply-count {
    width: 9%;
}
#bbpress-forums .bbp-forum-freshness,
#bbpress-forums .bbp-topic-freshness {
    width: 33%;
    padding-right: 50px;
    padding-left: 10px;
}
#bbpress-forums li.bbp-body .bbp-forum-freshness > a,
#bbpress-forums li.bbp-body .bbp-topic-freshness > a {
    font-size: 10px;
    color: #c3c3c3;
    font-weight: normal;
    line-height: 12px;
    display: inline-block;
}
#bbpress-forums .bbp-body .bbp-forum-freshness p,
#bbpress-forums .bbp-body .bbp-topic-freshness p {
    margin: 0;
    line-height: 17px;
}
#bbpress-forums p.bbp-topic-meta img.avatar,
#bbpress-forums ul.bbp-reply-revision-log img.avatar,
#bbpress-forums ul.bbp-topic-revision-log img.avatar,
#bbpress-forums div.bbp-template-notice img.avatar,
#bbpress-forums .widget_display_topics img.avatar,
#bbpress-forums .widget_display_replies img.avatar {
    border: none;
    width: 40px;
}
div.bbp-submit-wrapper {
    float: left;
}
#bbpress-forums fieldset.bbp-form {
    border: 0;
    padding: 0;
    margin-left: 0;
    margin-right: 0;
}
#bbpress-forums fieldset.bbp-form legend {
    font-size: 22px;
    padding: 0;
    margin-bottom: 20px;
    color: #111111;
}
.bbp-pagination-links a,
.bbp-pagination-links span.current {
    font-size: 14px;
    line-height: 28px;
    display: inline-block;
    min-width: 30px;
    height: 30px;
    padding: 0;
    text-align: center;
    text-decoration: none;
    color: #888;
    color: #313131;
    border: 1px solid var(--pcborder-cl);
}
#favorite-toggle,
#subscription-toggle {
    color: #777;
}
#favorite-toggle a,
#subscription-toggle a {
    color: #fff;
    opacity: 1;
}
.wrapper-boxed .bbp-pagination-links a:hover,
.wrapper-boxed .bbp-pagination-links span.current {
    color: #313131;
    border-color: #999999;
    text-decoration: none;
    background: none;
    opacity: 1;
}
.wrapper-boxed .bbp-pagination-links span.current {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background: var(--pcaccent-cl);
}
#bbpress-forums #bbp_topic_title,
#bbpress-forums #bbp_topic_tags {
    font-family: var(--pcbody-font);
    font-size: 12px;
    line-height: normal;
    display: block;
    display: block;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    height: auto;
    margin-bottom: 20px;
    padding: 11px 20px;
    cursor: auto;
    vertical-align: baseline;
    border: 1px solid var(--pcborder-cl);
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
    outline: none;
    background: none;
}
#bbpress-forums #bbp_reply_submit,
#bbpress-forums #bbp_topic_submit {
    font-family: var(--pchead-font);
    font-size: 14px;
    font-weight: bold;
    display: block;
    max-width: 450px;
    margin: 0;
    padding: 12px 20px;
    cursor: pointer;
    -moz-transition: all 0.3s;
    -webkit-transition: all 0.3s;
    transition: all 0.3s;
    text-transform: uppercase;
    color: #313131;
    border: none;
    background: #F5F5F5;
}
#bbpress-forums #bbp_reply_submit:hover,
#bbpress-forums #bbp_topic_submit:hover {
    color: #fff;
    background: var(--pcaccent-cl);
}
#bbpress-forums.bbpress-wrapper .bbp-forums-list {
    margin: 0 0 0 7px;
    padding-left: 12px;
    border-left: 1px solid var(--pcborder-cl);
}
/* = Buddypress
-----------------------------------------------------*/
#buddypress .standard-form textarea {
    border: 1px solid #ECECEC;
    border-radius: 0;
    color: #999;
    font-size: 100%;
    font-weight: normal;
    padding: 6px;
    background-color: transparent;
}
#buddypress .standard-form input[type=text],
#buddypress .standard-form input[type=color],
#buddypress .standard-form input[type=date],
#buddypress .standard-form input[type=datetime],
#buddypress .standard-form input[type=datetime-local],
#buddypress .standard-form input[type=email],
#buddypress .standard-form input[type=month],
#buddypress .standard-form input[type=number],
#buddypress .standard-form input[type=range],
#buddypress .standard-form input[type=search],
#buddypress .standard-form input[type=password],
#buddypress .standard-form input[type=tel],
#buddypress .standard-form input[type=time],
#buddypress .standard-form input[type=url],
#buddypress .standard-form input[type=week] {
    border: 1px solid #ECECEC;
    border-radius: 0;
    color: #999;
    font-size: 100%;
    font-weight: normal;
    padding: 6px;
    width: 100%;
    max-width: 300px;
    background-color: transparent;
    padding-left: 15px;
    padding-right: 15px;
}
#buddypress .standard-form select,
#buddypress .standard-form input[type=password] {
    border: 1px solid #ECECEC;
    border-radius: 0;
    color: #999;
    font-size: 100%;
    font-weight: normal;
    padding: 6px;
    background-color: transparent !important;
}
#buddypress .dir-search input[type=search], #buddypress .dir-search input[type=text],
#buddypress .groups-members-search input[type=search],
#buddypress .groups-members-search input[type=text] {
    width: 95%;
    height: 40px;
    border: 1px solid #ECECEC;
    padding: 10px 43px 10px 15px;
    font-weight: normal;
    font-size: 12px;
    -webkit-appearance: textfield;
    background: transparent;
}
#buddypress div.dir-search input[type=text] {
    padding-left: 15px;
}
#buddypress .dir-search input[type=submit],
#buddypress .groups-members-search input[type=submit] {
    font-size: 14px;
    line-height: 38px;
    position: absolute;
    top: 0;
    right: 0;
    height: 40px;
    padding: 0 15px 0;
    cursor: pointer;
    transition: all 0.25s;
    text-align: center;
    text-transform: uppercase;
    color: #ffffff;
    color: #ffffff;
    border: 1px solid #000000;
    border-color: var(--pcaccent-cl);
    border-radius: 0;
    background: #000000;
    background: var(--pcaccent-cl);
}
#buddypress button,
#buddypress a.button {
    border: 1px solid #ECECEC;
    color: #999;
    font-size: 12px;
    padding: 6px 10px;
}
#buddypress input[type=button], #buddypress input[type=reset] {
    border: 1px solid #ECECEC;
    color: #999;
    font-size: 12px;
    padding: 6px 10px;
}
#buddypress ul.button-nav li a,
#buddypress div.generic-button a,
#buddypress .comment-reply-link {
    border: 1px solid #ECECEC;
    color: #999;
    font-size: 12px;
    padding: 6px 10px;
}
a.bp-title-button {
    border: 1px solid #ECECEC;
    color: #999;
    font-size: 12px;
    padding: 6px 10px;
}
#buddypress button:hover {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress a.button:hover, #buddypress a.button:focus {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress input[type=button]:hover,
#buddypress input[type=reset]:hover {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress ul.button-nav li a:hover,
#buddypress ul.button-nav li.current a {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress div.generic-button a:hover,
#buddypress .comment-reply-link:hover {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress input[type=submit] {
    font-size: 14px;
    line-height: 1;
    padding: 12px 20px;
    text-transform: uppercase;
    color: #fff;
    border: 0px;
    border: none !important;
    background-color: var(--pcaccent-cl);
}
#buddypress input[type=submit]:hover {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
#buddypress select {
    padding: 3px 10px;
    color: #999;
    background-color: transparent;
    border: 1px solid #ECECEC;
    -webkit-box-shadow: none;
    box-shadow: none;
    transition: all .15s;
    outline: none;
}
#buddypress div.dir-search {
    position: relative;
    float: none;
    width: 100%;
    margin-top: 0;
    padding-bottom: 21px;
}
#buddypress div#item-header {
    margin-bottom: 10px;
}
#buddypress div#item-header div#item-actions h3 {
    font-size: 14px;
    color: #999;
}
#buddypress div#item-header img.avatar {
    margin: 0 30px 19px 0;
    width: 150px;
    height: 150px;
}
#buddypress div#item-header div#item-meta {
    font-size: 90%;
    margin: 10px 0 5px 0;
}
#buddypress ul.item-list,
#buddypress .profile[role=main] {
    border-top: 1px solid #ECECEC;
    padding-top: 10px;
}
#buddypress ul.item-list li {
    border-bottom: 1px solid #ECECEC;
    padding: 20px 0 22px;
    margin-bottom: 10px;
}
#buddypress .activity-list li.mini .activity-avatar img.avatar, #buddypress .activity-list li.mini .activity-avatar img.FB_profile_pic {
    height: 66px;
    margin-left: 0px;
    width: 66px;
}
#buddypress a.bp-primary-action span,
#buddypress #reply-title small a span {
    background: transparent !important;
    color: inherit;
    font-size: 100%;
    margin-left: 0;
    padding: 0;
}
#buddypress a.bp-primary-action span:before,
#buddypress #reply-title small a span:before {
    content: "(";
}
#buddypress a.bp-primary-action span:after,
#buddypress #reply-title small a span:after {
    content: ")";
}
/*section*/
.activity-inner {
    color: #444;
}
#buddypress ul.item-list li div.action {
    top: 25px;
}
#buddypress ul.item-list li div.item-title span {
    font-size: 90%;
}
#buddypress ul.item-list li div.item-desc, #buddypress ul.item-list li div.meta {
    color: #999;
    font-size: 90%;
}
#buddypress ul.item-list li div.item-title {
    font-weight: normal;
    font-size: 100%;
}
#buddypress ul.item-list li h4 {
    font-weight: normal;
    font-size: 100%;
}
#buddypress ul.item-list li div.item-title a,
#buddypress ul.item-list li h4 a {
    font-weight: 600;
    color: var(--pcaccent-cl);
}
#buddypress div.pagination {
    padding-bottom: 20px;
}
#buddypress div.pagination .pagination-links {
    margin-right: 0;
}
#buddypress div.pagination .pag-count {
    font-size: 100%;
    margin-left: 0;
    border: solid 1px #ECECEC;
    padding: 5px 15px;
    color: #888;
    display: inline-block;
    line-height: 1.5;
}
#buddypress div.pagination .pagination-links span,
#buddypress div.pagination .pagination-links a {
    font-size: 14px;
    line-height: 28px;
    display: inline-block;
    min-width: 30px;
    height: 30px;
    padding: 0;
    -webkit-transition: all 0.3s;
    transition: all 0.3s;
    text-align: center;
    text-decoration: none;
    color: #888;
    border: 1px solid var(--pcborder-cl);
    background: none;
}
#buddypress div.pagination .pagination-links a:hover {
    color: #313131;
    border-color: #999999;
    text-decoration: none;
    font-weight: inherit;
}
#buddypress div.pagination .pagination-links .current {
    text-decoration: none;
    color: #fff;
    border-color: var(--pcaccent-cl);
    background: var(--pcaccent-cl);
}
#buddypress div.item-list-tabs {
    background: #f5f5f5;
}
#buddypress div.item-list-tabs:not(#subnav) ul li a,
#buddypress div.item-list-tabs:not(#subnav) ul li > span {
    padding: 8px 15px;
    font-size: 14px;
    color: #999;
    border-right: solid 1px #ececec;
    border-bottom: 0;
}
#buddypress div.item-list-tabs:not(#subnav) ul li.selected a,
#buddypress div.item-list-tabs:not(#subnav) ul li.current a,
#buddypress div.item-list-tabs:not(#subnav) ul li a:hover {
    background-color: transparent;
    color: #444;
    opacity: 1;
    font-weight: normal;
}
#buddypress div.item-list-tabs ul li a span {
    background: transparent !important;
    border: none !important;
    color: inherit;
    display: inline;
    vertical-align: top;
    font-size: 100%;
    margin-left: 0;
    padding: 0;
}
#buddypress div.item-list-tabs ul li a span:before {
    content: "(";
}
#buddypress div.item-list-tabs ul li a span:after {
    content: ")";
}
#buddypress #activity-all a:before,
#buddypress #groups-all a:before,
#buddypress #members-all a:before,
#buddypress #activity-friends a:before,
#buddypress #user-friends:before,
#buddypress #members-personal a:before,
#buddypress #activity-groups a:before,
#buddypress #user-groups:before,
#buddypress #groups-personal a:before,
#buddypress #members:before,
#buddypress #activity-favorites a:before,
#buddypress #user-activity:before,
#buddypress #user-xprofile:before,
#buddypress #user-notifications:before,
#buddypress #user-messages:before,
#buddypress .send-message:before,
#buddypress #user-settings:before,
#buddypress #admin:before,
#buddypress .generic-button .friendship-button.add:before,
#buddypress #home:before,
#buddypress #invite:before {
    content: "\f0ac";
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: normal;
    line-height: 1;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    margin-right: 5px;
}
#buddypress #activity-friends a:before,
#buddypress #user-friends:before,
#buddypress #members-personal a:before {
    content: "\f007";
}
#buddypress #activity-groups a:before,
#buddypress #user-groups:before,
#buddypress #groups-personal a:before,
#buddypress #members:before {
    content: "\f0c0";
}
#buddypress #activity-favorites a:before {
    content: "\f005";
}
#buddypress #user-activity:before {
    content: "\f1d8";
}
#buddypress #user-xprofile:before {
    content: "\f114";
}
#buddypress #user-notifications:before {
    content: "\f0a2";
}
#buddypress #user-messages:before,
#buddypress .send-message:before {
    content: "\f003";
}
#buddypress #user-settings:before,
#buddypress #admin:before {
    content: "\f013";
}
#buddypress #activity-mentions a:before,
#buddypress .activity-button.mention:before {
    font-family: Arial, Helvetica, sans-serif;
    content: "@";
    font-weight: bold;
    margin-right: 5px;
}
#buddypress #home:before {
    content: "\f015";
}
#buddypress #invite:before {
    content: "\f046";
}
#buddypress .generic-button .friendship-button.add:before {
    content: "\f067";
}
#buddypress div.item-list-tabs#subnav {
    margin: 40px 0 10px;
}
#buddypress div.item-list-tabs ul li a,
#buddypress div.item-list-tabs ul li > span {
    padding: 8px 15px;
    color: #999;
    font-size: 14px;
}
#buddypress div.item-list-tabs ul li.selected a,
#buddypress div.item-list-tabs ul li.current a,
#buddypress div.item-list-tabs ul li a:hover {
    font-weight: normal;
    opacity: 1;
    color: #fff;
    background-color: var(--pcaccent-cl);
}
@media (max-width: 479px) {
    #buddypress div.pagination {
        clear: both;
        float: none;
    }
    #buddypress div.pagination .pag-count {
        clear: both;
        float: none;
    }
    #buddypress div.pagination .pagination-links {
        float: none;
        margin: 10px 0;
        clear: both;
    }
}
/*tabs*/
@media (max-width: 991px) {
    #buddypress div.item-list-tabs:not(#subnav) ul {
        margin-right: -1px;
    }
    #buddypress div.item-list-tabs:not(#subnav) ul li {
        width: 33.33333%;
    }
}
@media (max-width: 767px) {
    #buddypress div.item-list-tabs:not(#subnav) ul li {
        width: 50%;
    }
    #bbpress-forums .bbp-body .bbp-forum-freshness img,
    #bbpress-forums .bbp-body .bbp-topic-freshness img {
        display: none;
    }
}
@media (max-width: 360px) {
    #buddypress div.item-list-tabs:not(#subnav) ul li {
        width: 100%;
    }
}
/*activity*/
.activity-greeting {
    color: #999;
}
#buddypress ul.item-list li.activity img.avatar,
#buddypress .activity-list .activity-avatar img,
#buddypress form#whats-new-form #whats-new-avatar img {
    width: 50px;
    height: auto;
}
#buddypress #item-body #subnav + form#whats-new-form {
    margin-top: 30px;
}
#buddypress form#whats-new-form textarea {
    font-size: 1em;
    width: 100%;
    min-height: 100px;
    border-color: var(--pcborder-cl);
    background: none;
}
#buddypress #whats-new-options {
    overflow: visible;
    min-height: 55px;
    height: auto !important;
}
#whats-new-post-in-box {
    color: #999;
}
#buddypress #activity-stream {
    margin-top: 20px;
}
#buddypress .activity-list .activity-content {
    margin: 0 0 0 64px;
}
#buddypress .activity-header a:first-child,
#buddypress .comment-meta a:first-child,
#buddypress .acomment-meta a:first-child {
    font-weight: bold;
    color: var(--pcaccent-cl);
}
#buddypress .activity-list .activity-content .activity-header {
    color: #999;
}
#buddypress .activity-list .activity-content .activity-header img.avatar {
    width: 22px;
    margin: 0 5px 0px 0 !important;
}
#buddypress .activity-list .activity-content .comment-header {
    color: #999;
}
#buddypress #activity-stream p {
    margin-top: 0;
}
#buddypress div.activity-meta a {
    padding: 5px 10px;
    display: inline-block;
    margin-bottom: 8px;
    line-height: 1;
    text-transform: none;
}
#buddypress div.activity-meta a.delete-activity:hover {
    background: #f93636;
    border-color: #f93636;
}
#buddypress div.activity-meta a.acomment-reply:before,
#buddypress div.activity-meta a.fav:before,
#buddypress div.activity-meta a.unfav:before,
#buddypress div.activity-meta a.delete-activity:before {
    content: "\f086";
    display: inline-block;
    font-family: FontAwesome;
    font-style: normal;
    font-weight: normal;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
    margin-right: 6px;
}
#buddypress div.activity-meta a.fav:before {
    content: "\f004";
}
#buddypress div.activity-meta a.unfav:before {
    content: "\f08a";
}
#buddypress div.activity-meta a.delete-activity:before {
    content: "\f014";
}
#buddypress div.activity-comments ul li {
    padding: 20px 0 0;
}
#buddypress div.activity-comments div.acomment-meta, #buddypress div.activity-comments div.acomment-content {
    font-size: 100%;
}
#buddypress div.activity-comments div.acomment-avatar img {
    height: 30px;
    width: 30px;
}
#buddypress .activity-list li.load-more, #buddypress .activity-list li.load-newest {
    background: none;
    font-size: 100%;
    margin: 30px 0;
    padding: 0;
    text-transform: none;
    border-bottom: none;
}
#buddypress .activity-list li.load-more a,
#buddypress .activity-list li.load-newest a {
    display: block;
    padding: 9px 10px;
    max-width: 400px;
    margin: 0 auto;
    border: 1px solid #ececec;
    line-height: 1.4;
    text-align: center;
    transition: all 0.25s;
    -webkit-transition: all 0.25s;
    background: transparent !important;
    color: #999;
    text-decoration: none;
    text-transform: uppercase;
}
#buddypress .activity-list li.load-more:hover a,
#buddypress .activity-list li.load-newest:hover a {
    opacity: 0.85;
}
#buddypress .activity-list li.load-more.loading a:after,
#buddypress .activity-list li.load-newest.loading a:after {
    content: "...";
}
/*single activity*/
body.activity-permalink #buddypress div.activity-comments {
    border-top: solid 3px #ECECEC;
    margin-top: 20px;
    padding-top: 20px;
}
body.activity-permalink #buddypress div.activity-comments > ul {
    padding: 0 10px 0 0px;
}
body.activity-permalink #buddypress div.activity-comments ul li {
    padding: 20px 0 0 0;
}
body.activity-permalink #buddypress div.activity-comments ul li > ul {
    margin-left: 60px;
}
body.activity-permalink #buddypress .activity-list li.mini .activity-avatar img {
    width: 150px;
    height: auto;
}
body.activity-permalink #buddypress div.activity-comments div.acomment-avatar img {
    height: 50px;
    width: 50px;
    margin-right: 20px;
}
body.activity-permalink #buddypress div.activity-comments div.acomment-content {
    font-size: 100%;
    margin-left: 70px;
}
body.activity-permalink #buddypress .acomment-options {
    margin-left: 70px;
}
/*comment*/
#buddypress div.activity-comments form div.ac-reply-content {
    color: #888;
    margin-left: 65px;
}
#buddypress div.activity-comments form .ac-textarea {
    border: 1px solid #ECECEC;
    padding: 5px 5px 0;
}
#buddypress div.profile h4 {
    font-size: 21px;
    font-weight: bold;
    margin-bottom: 20px;
}
#buddypress table.notifications,
#buddypress table.notifications-settings,
#buddypress table.profile-settings,
#buddypress table.profile-fields,
#buddypress table.wp-profile-fields,
#buddypress table.messages-notices,
#buddypress table.forum {
    margin-bottom: 30px;
}
#buddypress table.notifications tr td.label,
#buddypress table.notifications-settings tr td.label,
#buddypress table.profile-fields tr td.label,
#buddypress table.wp-profile-fields tr td.label,
#buddypress table.messages-notices tr td.label,
#buddypress table.forum tr td.label {
    display: table-cell;
    color: inherit;
    text-align: left;
    font-weight: normal;
    font-size: inherit;
    text-transform: uppercase;
    border-radius: 0;
    background: transparent;
}
#buddypress table.notifications thead tr,
#buddypress table.notifications-settings thead tr,
#buddypress table.profile-settings thead tr,
#buddypress table.profile-fields thead tr,
#buddypress table.wp-profile-fields thead tr,
#buddypress table.messages-notices thead tr,
#buddypress table.forum thead tr {
    background: var(--pcaccent-cl);
}
#buddypress table.notifications tr.alt td,
#buddypress table.notifications-settings tr.alt td,
#buddypress table.profile-settings tr.alt td,
#buddypress table.profile-fields tr.alt td,
#buddypress table.wp-profile-fields tr.alt td,
#buddypress table.messages-notices tr.alt td,
#buddypress table.forum tr.alt td {
    background: transparent;
}
#buddypress input[type="submit"].pending,
#buddypress input[type="button"].pending,
#buddypress input[type="reset"].pending,
#buddypress input[type="submit"].disabled,
#buddypress input[type="button"].disabled,
#buddypress input[type="reset"].disabled,
#buddypress input[type="submit"][disabled=disabled] {
    border-color: inherit;
    color: #fff;
}
#buddypress button.pending, #buddypress button.disabled {
    border-color: inherit;
    color: #fff;
}
#buddypress div.pending a,
#buddypress a.disabled {
    border-color: inherit;
    color: #fff;
}
#buddypress #profile-edit-form ul.button-nav {
    padding-left: 0;
}
#buddypress table.profile-fields {
    margin-bottom: 30px;
    border-top: 1px solid #e9e9e9;
}
#buddypress table.profile-fields:last-child {
    margin-bottom: 30px;
    border-top: 1px solid #e9e9e9;
}
/*profile*/
/*group*/
@media (min-width: 768px) {
    #buddypress div#item-header div#item-header-content {
        float: none;
    }
}
@media only screen and (max-width: 479px) {
    #buddypress div.dir-search {
        float: none;
    }
    #buddypress div.dir-search input[type="text"] {
        margin-bottom: 0;
        width: 100%;
    }
}
.groups #item-header-content span.highlight {
    background-color: #eaeaea;
    padding: 10px 10px;
    font-size: 100%;
    line-height: 1;
    color: #999;
    display: inline-block;
    margin-bottom: 10px;
}
.groups #item-header-content span.activity {
    display: block;
}
#buddypress div#invite-list {
    background-color: transparent;
    padding: 0;
    height: auto;
    max-height: 400px;
}
#buddypress form.standard-form .left-menu #invite-list ul {
    padding: 0;
}
#buddypress form.standard-form .left-menu #invite-list ul li {
    margin: 0 0 5px 1%;
}
#buddypress .invite div.submit input {
    float: right;
    margin-right: 0;
}
#buddypress #members-dir-list ul.item-list li {
    padding: 10px 0 19px;
}
#buddypress div.profile h2 {
    margin-bottom: 10px;
}
#buddypress .field-visibility-settings-toggle {
    margin-top: 15px;
}
#buddypress .standard-form button {
    line-height: 1.3;
    padding: 3px 10px;
}
#buddypress .standard-form select {
    padding: 2px 6px;
}
#buddypress .standard-form #basic-details-section input[type=password],
#buddypress .standard-form #blog-details-section input#signup_blog_url {
    width: 100%;
}
#main #bbpress-forums .bbp-login-form fieldset.bbp-form select,
#main #bbpress-forums .bbp-login-form .bbp-form input[type="password"],
#main #bbpress-forums .bbp-login-form .bbp-form input[type="text"] {
    font-family: var(--pcbody-font);
    font-size: 12px;
    line-height: normal;
    display: block;
    display: block;
    -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    box-sizing: border-box;
    width: 100%;
    height: auto;
    margin-bottom: 20px !important;
    padding: 11px 20px;
    cursor: auto;
    vertical-align: baseline;
    border: 1px solid var(--pcborder-cl);
    -moz-border-radius: 0;
    -webkit-border-radius: 0;
    border-radius: 0;
    outline: none;
    background: none;
}
#main #bbpress-forums .bbp-login-form fieldset.bbp-form label {
    margin-bottom: 6px;
}
#main .bbp-login-form .bbp-submit-wrapper button[type="submit"] {
    font-family: var(--pchead-font);
    font-size: 14px;
    font-weight: bold;
    display: block;
    width: 100%;
    max-width: 500px;
    margin: 0;
    padding: 12px 20px;
    cursor: pointer;
    -moz-transition: all 0.3s;
    -webkit-transition: all 0.3s;
    transition: all 0.3s;
    text-transform: uppercase;
    color: #313131;
    border: none;
    outline: none;
    background: #F5F5F5;
}
#main .bbp-login-form .bbp-submit-wrapper button[type="submit"]:hover {
    color: #fff;
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
/*--------- Max width 479px ---------*/
@media only screen and (max-width: 479px) {
    #bbpress-forums li.bbp-forum-info, #bbpress-forums li.bbp-topic-title,
    #bbpress-forums .bbp-forum-freshness, #bbpress-forums .bbp-topic-freshness {
        width: 30%;
    }
    #bbpress-forums li.bbp-forum-topic-count,
    #bbpress-forums li.bbp-forum-reply-count,
    #bbpress-forums li.bbp-topic-voice-count,
    #bbpress-forums li.bbp-topic-reply-count {
        width: 20%;
    }
    #bbpress-forums a.bbp-author-avatar {
        display: none;
    }
    #bbpress-forums .bbp-forum-freshness,
    #bbpress-forums .bbp-topic-freshness {
        padding-right: 0;
    }
    #bbpress-forums li.bbp-topic-title .bbp-topic-permalink,
    #bbpress-forums li.bbp-topic-title .bbp-topic-meta {
        padding-left: 0;
    }
}
