@font-face {
  font-family: "penciicon";
  font-display: swap;
  src: url("../fonts/penciicon.ttf?v=1.2") format("truetype"),
    url("../fonts/penciicon.woff?v=1.2") format("woff"),
    url("../fonts/penciicon.woff2?v=1.2") format("woff2"),
    url("../fonts/penciicon.eot?v=1.2#iefix") format("embedded-opentype"),
    url("../fonts/penciicon.svg?v=1.2#penciicon") format("svg");
}
i[class^="penciicon-"],
i[class*=" penciicon-"] {
  display: inline-block;
  font-family: penciicon !important;
  font-style: normal;
  font-weight: normal !important;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.penciicon-left-quote:before {
  content: "\f101";
}
.penciicon-messenger:before {
  content: "\f102";
}
.penciicon-goodreads:before {
  content: "\f103";
}
.penciicon-viber:before {
  content: "\f104";
}
.penciicon-discord:before {
  content: "\f105";
}
.penciicon-tik-tok:before {
  content: "\f106";
}
.penciicon-line:before {
  content: "\f107";
}
.penciicon-magnifiying-glass:before {
  content: "\f108";
}
.penciicon-heart:before {
  content: "\f109";
}
.penciicon-shuffle:before {
  content: "\f10a";
}
.penciicon-shopping-bag:before {
  content: "\f10b";
}
.penciicon-shopping-cart:before {
  content: "\f10c";
}
.penciicon-share:before {
  content: "\f10d";
}
.penciicon-sharing:before {
  content: "\f10e";
}
.penciicon-user:before {
  content: "\f10f";
}
.penciicon-close-button:before {
  content: "\f110";
}
.penciicon-check-symbol:before {
  content: "\f111";
}
.penciicon-expand:before {
  content: "\f112";
}
.penciicon-avatar:before {
  content: "\f113";
}
.penciicon-search:before {
  content: "\f114";
}
.penciicon-ruler:before {
  content: "\f115";
}
.penciicon-moon:before {
  content: "\f116";
}
.penciicon-sun:before {
  content: "\f117";
}
.penciicon-shopping-cart-1:before {
  content: "\f118";
}
.penciicon-shopping-cart-2:before {
  content: "\f119";
}
.penciicon-right-chevron:before {
  content: "\f11a";
}
.penciicon-left-chevron:before {
  content: "\f11b";
}
.penciicon-down-chevron:before {
  content: "\f11c";
}
.penciicon-up-chevron:before {
  content: "\f11d";
}
.penciicon-exchange:before {
  content: "\f11e";
}
.penciicon-down-arrow:before {
  content: "\f11f";
}
.penciicon-left-arrow:before {
  content: "\f120";
}
.penciicon-exchange-1:before {
  content: "\f121";
}
.penciicon-right-chevron-1:before {
  content: "\f122";
}
.penciicon-down-chevron-1:before {
  content: "\f123";
}
.penciicon-left-chevron-1:before {
  content: "\f124";
}
.penciicon-up-chevron-1:before {
  content: "\f125";
}
.penciicon-undo:before {
  content: "\f126";
}
.penciicon-free-delivery:before {
  content: "\f127";
}
.penciicon-facebook:before {
  content: "\f128";
}
.penciicon-twitter:before {
  content: "\f129";
}
.penciicon-instagram:before {
  content: "\f12a";
}
.penciicon-pinterest:before {
  content: "\f12b";
}
.penciicon-linkedin:before {
  content: "\f12c";
}
.penciicon-flickr:before {
  content: "\f12d";
}
.penciicon-behance:before {
  content: "\f12e";
}
.penciicon-tumblr:before {
  content: "\f12f";
}
.penciicon-youtube:before {
  content: "\f130";
}
.penciicon-email:before {
  content: "\f131";
}
.penciicon-vk:before {
  content: "\f132";
}
.penciicon-vine:before {
  content: "\f133";
}
.penciicon-soundcloud:before {
  content: "\f134";
}
.penciicon-snapchat:before {
  content: "\f135";
}
.penciicon-spotify:before {
  content: "\f136";
}
.penciicon-github:before {
  content: "\f137";
}
.penciicon-stack-overflow:before {
  content: "\f138";
}
.penciicon-twitch:before {
  content: "\f139";
}
.penciicon-steam:before {
  content: "\f13a";
}
.penciicon-vimeo:before {
  content: "\f13b";
}
.penciicon-xing:before {
  content: "\f13c";
}
.penciicon-whatsapp:before {
  content: "\f13d";
}
.penciicon-telegram:before {
  content: "\f13e";
}
.penciicon-reddit:before {
  content: "\f13f";
}
.penciicon-odnoklassniki:before {
  content: "\f140";
}
.penciicon-500px-monogram:before {
  content: "\f141";
}
.penciicon-stumbleupon:before {
  content: "\f142";
}
.penciicon-wechat:before {
  content: "\f143";
}
.penciicon-sina-weibo:before {
  content: "\f144";
}
.penciicon-line-1:before {
  content: "\f145";
}
.penciicon-viber-1:before {
  content: "\f146";
}
.penciicon-discord-1:before {
  content: "\f147";
}
.penciicon-rss:before {
  content: "\f148";
}
.penciicon-slack:before {
  content: "\f149";
}
.penciicon-slack-1:before {
  content: "\f14a";
}
.penciicon-tripadvisor:before {
  content: "\f14b";
}
.penciicon-tik-tok-1:before {
  content: "\f14c";
}
.penciicon-letter-d:before {
  content: "\f14d";
}
.penciicon-d:before {
  content: "\f14e";
}
.penciicon-blogger:before {
  content: "\f14f";
}
.penciicon-blogger-1:before {
  content: "\f150";
}
.penciicon-delicious:before {
  content: "\f151";
}
.penciicon-deviantart:before {
  content: "\f152";
}
.penciicon-digg:before {
  content: "\f153";
}
.penciicon-dribbble:before {
  content: "\f154";
}
.penciicon-ebay:before {
  content: "\f155";
}
.penciicon-ebay-1:before {
  content: "\f156";
}
.penciicon-evernote:before {
  content: "\f157";
}
.penciicon-evernote-1:before {
  content: "\f158";
}
.penciicon-flipboard:before {
  content: "\f159";
}
.penciicon-forrst:before {
  content: "\f15a";
}
.penciicon-forrst-1:before {
  content: "\f15b";
}
.penciicon-grooveshark:before {
  content: "\f15c";
}
.penciicon-grooveshark-1:before {
  content: "\f15d";
}
.penciicon-lastfm:before {
  content: "\f15e";
}
.penciicon-myspace:before {
  content: "\f15f";
}
.penciicon-myspace-logo:before {
  content: "\f160";
}
.penciicon-brand:before {
  content: "\f161";
}
.penciicon-skype:before {
  content: "\f162";
}
.penciicon-windows:before {
  content: "\f163";
}
.penciicon-yahoo-logo:before {
  content: "\f164";
}
.penciicon-yahoo:before {
  content: "\f165";
}
.penciicon-y:before {
  content: "\f166";
}
.penciicon-right-quotation-sign:before {
  content: "\f167";
}
.penciicon-deviantart-1:before {
  content: "\f168";
}
.penciicon-transfer:before {
  content: "\f169";
}
.penciicon-right-and-left:before {
  content: "\f16a";
}
.penciicon-exchange-2:before {
  content: "\f16b";
}
.penciicon-shopping-cart-3:before {
  content: "\f16c";
}
.penciicon-shop:before {
  content: "\f16d";
}
.penciicon-home:before {
  content: "\f16e";
}
.penciicon-user-1:before {
  content: "\f16f";
}
.penciicon-gallery:before {
  content: "\f170";
}
.penciicon-megaphone:before {
  content: "\f171";
}
.penciicon-news:before {
  content: "\f172";
}
.penciicon-newspaper:before {
  content: "\f173";
}
.penciicon-add:before {
  content: "\f174";
}
.penciicon-calculation-operations-minus-sign:before {
  content: "\f175";
}
.penciicon-x-twitter:before {
  content: "\f176";
}
.penciicon-threads:before {
  content: "\f177";
}
.penciicon-butterfly:before {
  content: "\f178";
}
.penciicon-square:before {
  content: "\f179";
}
.penci-faicon.penciicon-line,
.penci-faicon.penciicon-viber,
.penci-faicon.penciicon-x-twitter {
  transform: translateY(2px);
}
.pcsoc-icon.pcsoci-twitter .penci-faicon.penciicon-x-twitter,
.penci-builder-element .penci-faicon.penciicon-x-twitter,
#header .inner-header-social .penci-faicon.penciicon-x-twitter,
.pcnew-share.penci-icon-full .post-share-item .penci-faicon.penciicon-x-twitter,
.show-txt.focus-icon .post-share-item .penci-faicon.penciicon-x-twitter,
.penci-social-colored .penci-faicon.penciicon-x-twitter,
.penci-social-colored .penci-faicon.penciicon-viber,
.penci-social-colored .penci-faicon.penciicon-line,
.penci-social-square .penci-faicon.penciicon-x-twitter,
.penci-social-square .penci-faicon.penciicon-viber,
.penci-social-square .penci-faicon.penciicon-line,
.footer-socials .penci-faicon.penciicon-line,
.footer-socials .penci-faicon.penciicon-viber,
.footer-socials .penci-faicon.penciicon-x-twitter,
.single-product-share .new-ver-share .penci-faicon.penciicon-line,
.single-product-share .new-ver-share .penci-faicon.penciicon-viber,
.single-product-share .new-ver-share .penci-faicon.penciicon-x-twitter {
    transform: translateY(0)
}

.widget-social.penci-social-colored .penci-faicon.penciicon-x-twitter,
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-x-twitter,
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-viber,
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-line {
    transform: translateY(2px)
}