body.rtl #navigation.header-10 .pcheader-icon.top-search-classes {
	margin-right: 10px;
}
body.rtl .penci-woo-before-main-content .penci-products-per-page a {
	margin-left: 0;
	margin-right: 10px;
}
body.rtl .products.product-style-4 .woocommerce-loop-product__title, .products.product-style-4 .price {
	text-align: right;
}
body.rtl .products.product-style-4 .penci-product-loop-title .button {
	text-align: right;
}
body.rtl .products.product-style-4 .penci-product-loop-title .button {
	justify-content: right;
}
body.rtl .products.product-style-4 .penci-product-loop-title .button.loading:before{
	margin: -2px 0 0 10px;
}
body.rtl .pcheader-icon.shoping-cart-icon {
	margin-left: 0;
}
body.rtl .penci-product-top-filter-button,
body.rtl .penci-woo-before-main-content .penci-products-per-page,
body.rtl .penci-woo-before-main-content .penci-products-shop-view {
	margin-left: 0;
	margin-right: 15px;
}
body.rtl .penci-woo-before-main-content .penci-wofilter-inner > div:first-child {
	margin-right: 0;
}
body.rtl .penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-both .penci-single-product-sidebar-wrap,
body.rtl .penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
	padding-left: 0;
	padding-right: 60px;
}
body.rtl .penci-extra-buttons .penci-addtowishlist.button:before,
body.rtl .penci-extra-buttons .compare.button:before {
	margin-right: 0;
	margin-left: 5px;
}
body.rtl.woocommerce .penci-extra-buttons > .button {
	margin-right: 0;
	margin-left: 20px;
}
.woocommerce ul.cart_list .product-cart-info,
.woocommerce ul.product_list_widget .product-cart-info,
.woocommerce div.product div.images,
.woocommerce #content div.product div.images,
.woocommerce-page div.product div.images,
.woocommerce-page #content div.product div.images {
	float: right;
}
.penci-sidebar-cart .woocommerce-mini-cart__total.total .amount,
.woocommerce div.product div.summary,
.woocommerce #content div.product div.summary,
.woocommerce-page div.product div.summary,
.woocommerce-page #content div.product div.summary {
	float: left;
}
.penci-top-relate-post {
	right: auto;
	left: 0;
}
.penci-top-relate-post ul {
	flex-direction: row-reverse;
}
.penci-top-relate-post ul li:last-child {
	margin-left: 0;
}
.penci-top-relate-post .inner-content {
	right: auto;
	left: 0;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary {
	margin-left: 0;
	margin-right: 15px;
}
@media only screen and (min-width: 768px) {
	.woocommerce div.product .product_title {
		padding-right: 0;
		padding-left: 110px;
	}
	.woocommerce div.product.penci-summary-align-center .product_title {
		padding-right: 110px;
	}
	.woocommerce div.product.penci-product-img-fullwidth .product_title,
	.woocommerce div.product.penci-product-img-fullwidth-container .product_title,
	.woocommerce div.product.penci-product-img-large .product_title {
		padding-left: 0;
		padding-right: 0;
	}
}
body.rtl.woocommerce .penci_sidebar ul.products li.product,
body.rtl.woocommerce-page .penci_sidebar ul.products li.product {
	margin-left: 0;
}
.variations_form a.reset_variations::before {
	margin-left: 5px;
	margin-right: 0;
}
.woocommerce div.product form.cart .reset_variations, .variations_form a.reset_variations {
	margin-right: 10px;
	margin-left: 0;
}
.products .penci-soledad-product .penci-removewishlist.button:before {
	margin-left: 5px;
	margin-right: 0;
}
.penci-header-cart-detail,
.brands-list .brand-item,
.header-header-ecommerce #logo,
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary,
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul.menu-shop,
.woocommerce div.penci-summary-align-center form.cart .variations td.value,
.products.product-list .penci-soledad-product .penci-product-loop-title,
.products.product-style-4 .woocommerce-loop-product__title,
.products.product-style-4 .price,
.products.product-style-4 .penci-product-loop-title .button,
.products.product-style-2 .woocommerce-loop-product__title,
.products.product-style-6 .woocommerce-loop-product__title,
.products.product-style-6 .price,
.penci-products-compare-table .compare-field {
	text-align: right;
}
.penci-products-compare-table .compare-value .stock.in-stock:before {
	margin-left: 5px;
	margin-right: 0;
}
.penci-products-compare-table .penci-compare-col {
	border-right: 0;
	border-left: 1px solid var(--pcpage_gbdr_cl);
}
.penci-products-compare-table .penci-compare-col:last-child {
	border-left: 0;
}
.woocommerce #respond input#submit.loading:after,
body.rtl .woocommerce a.button.loading:after,
.woocommerce button.button.loading:after,
.woocommerce input.button.loading:after {
	margin-right: -5px;
}
.quick-view-wrapper .summary.entry-summary,
.woocommerce div.product .product_meta {
	text-align: right;
}
.woocommerce .penci-extra-buttons > .button {
	margin-right: 0;
	margin-left: 15px;
}
.woocommerce .penci-extra-buttons > .button:after {
	display: inline-block;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button.penci-product-slider-prev {
	left: 0;
}
body.rtl.woocommerce ul.products li.product,
body.rtl.woocommerce-page ul.products li.product {
	margin-left: 0;
	margin-bottom: 30px;
}
.products.icon-style-round .penci-product-loop-button > a.button.loading:after {
	margin: -2px -8px 0 0;
}
.woocommerce ul.products.penci-owl-carousel-slider li.product,
.woocommerce-page ul.products.penci-owl-carousel-slider li.product {
	float: none;
	margin: 0 0 30px;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table th {
	padding-right: 0;
}
.penci-swatches .swatch {
	margin-right: 0;
	margin-left: 8px;
}
.penci-swatches .swatch:last-child {
	margin-left: 0;
}
body.rtl .woocommerce ul.products li.product,
body.rtl.woocommerce ul.products li.product,
body.rtl.woocommerce-page ul.products li.product,
body.rtl .woocommerce-page ul.products li.product {
	float: none;
	margin: 0 0 30px;
}
.woocommerce .thumbnail-left .penci-single-product-top-container .product-labels,
.woocommerce .penci-single-product-top-container .product-labels {
	left: auto;
	right: 10px;
	top: auto;
	transform: translateY(10px);
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
	right: auto;
	left: 120px;
}
.single-product-share .share-title {
	margin-right: 0;
	margin-left: 5px;
}
.woocommerce table.shop_attributes tr td {
	text-align: left;
}
.woocommerce #review_form #respond p.stars > span {
	padding: 5px 15px 0 0;
}
.penci-sidebar-cart .sidecart-content ul li {
	padding: 15px 15px 15px 40px;
}
.woocommerce .widget_shopping_cart .cart_list li,
.woocommerce.widget_shopping_cart .cart_list li {
	padding-left: 40px;
}
body.rtl .woocommerce .widget_shopping_cart .cart_list li a.remove,
body.rtl .woocommerce.widget_shopping_cart .cart_list li a.remove {
	right: auto;
	left: 0;
}
.woocommerce .widget_price_filter .price_label {
	text-align: right;
}
.penci-product-top-filter-button a span {
	margin-left: 0;
	margin-right: 5px;
}
.woocommerce .widget.woocommerce.widget_product_categories li span.count {
	float: left;
}
.single-product-share a {
	margin-right: 0;
	margin-left: 12px;
}
.woocommerce div.product .woocommerce-tabs .panel > h2:first-child, .woocommerce div.product .woocommerce-tabs .panel #reviews #comments h2, .woocommerce div.product .woocommerce-tabs .panel #respond h3.comment-reply-title, .woocommerce div.product .woocommerce-tabs .panel #respond .comment-reply-title {
	text-align: right;
}
.woocommerce ul.cart_list li, .woocommerce ul.product_list_widget li {
	padding-right: 20px;
	padding-left: 40px;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch {
	margin-right: 0;
	margin-left: 10px;
}
.soledad-product-filter .swatches-display-list li .layered-nav-link, .soledad-product-filter .swatches-display-double li .layered-nav-link {
	float: right;
}
.soledad-product-filter .swatches-display-list li .count, .soledad-product-filter .swatches-display-double li .count {
	float: left;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color .count {
	padding-left: 0;
	padding-right: 0;
}
.penci-products-compare-table .penci-top-button a:before {
	margin-left: 5px;
	margin-right: 0;
}
body.rtl .woocommerce.penci-products-compare-table .penci-top-button a.button.penci-compare.loading:after,
.products .penci-soledad-product .penci-removewishlist.button.loading:after {
	margin-left: 0;
	margin-right: 5px;
}
.products.icon-style-round.icon-align-vertical.icon-position-top-left .penci-product-loop-buttons,
.products.icon-style-round.icon-align-vertical.icon-position-bottom-left .penci-product-loop-buttons {
	left: 0;
	right: auto;
	justify-content: flex-start;
}
.woocommerce .widget_layered_nav_filters ul li {
	float: right;
}
.woocommerce .penci-active-filters .widget_layered_nav_filters ul li {
	padding-right: 0;
	margin-right: 0;
	border-right: 0;
	padding-left: 10px;
	margin-left: 10px;
	border-left: 1px solid var(--pcpage_gbdr_cl);
}
.summary .penci-breadcrumb.penci-woo-breadcrumb {
	padding-left: 40px;
	padding-right: 0;
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title:after {
	right: auto;
	left: 0;
}
.woocommerce div.penci-summary-align-center form.cart {
	display: flex;
	flex-wrap: wrap;
	justify-content: center;
}
.woocommerce div.penci-summary-align-center .product_meta {
	text-align: center;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove {
	right: auto;
	left: 30px;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table td {
	padding-left: 0;
	padding-right: 30px;
}
.woocommerce div.product form.cart .penci-swatches + .reset_variations,
.woocommerce div.product form.cart .jquery-grid-picker-widget + .reset_variations {
	margin: 0 10px 5px 0;
}
.products.product-list .penci-soledad-product .penci-product-loop-title {
	padding-left: 0;
	padding-right: 30px;
}
.woocommerce ul.products li.product .star-rating {
	right: auto;
	left: 10px;
}
.woocommerce nav.woocommerce-pagination ul li, .woocommerce .woocommerce-pagination ul.page-numbers li, .woocommerce-page .woocommerce-pagination ul.page-numbers li {
	float: right;
	margin-right: 0;
	margin-left: 10px;
}
.woocommerce nav.woocommerce-pagination ul > li:last-child, .woocommerce .woocommerce-pagination ul.page-numbers li:last-child, .woocommerce-page .woocommerce-pagination ul.page-numbers li:last-child {
	margin-left: 0;
}
.woocommerce .products.product-style-2 .penci-product-cats,
.woocommerce .products.product-style-2 .woocommerce-loop-product__title {
	padding-right: 0;
	padding-left: 80px;
}
.woocommerce .products.product-style-2 .product-labels {
	right: auto;
	left: 10px;
}
.woocommerce .penci-content-quickview .product-labels {
	right: 25px;
	left: auto;
}
.woocommerce .widget_shopping_cart .amount,
.woocommerce.widget_shopping_cart .amount {
	float: none;
}
.penci-content-quickview button.mfp-close, .penci-content-quickview button.mfp-arrow {
	right: auto;
	left: 0;
}
.product_meta .penci-product-brands .penci-product-brand a {
	margin-left: 0;
	margin-right: 10px;
}
.products.product-style-4 .penci-product-loop-title .button {
	left: auto;
	right: 0;
}
body.rtl .slick-slider {
	direction: rtl;
}
body.rtl .woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-image-list {
	direction: ltr;
}
.woocommerce div.product div.images.woocommerce-product-gallery.thumbnail-bottom .woocommerce-product-gallery__trigger {
	right: auto;
	left: 10px;
}
.penci-extra-buttons .penci-addtowishlist.button.loading:before,
.penci-extra-buttons .compare.button.loading:before {
	margin: -2px 0 0 5px;
}
.soledad-product-filter .with-swatch-image .layer-term-name img {
	margin-right: 0;
	margin-left: 5px;
}
.header-search-style-showup .show-search {
	left: 0;
	right: auto;
}
.header-search-style-showup .show-search form.pc-searchform input.search-input {
	border-left: 0 !important;
	border-right: 1px solid var(--pcborder-cl) !important;
}
.header-search-style-showup .show-search:before {
	right: auto;
	left: 15px;
}
.penci-header-cart-detail {
	right: auto;
	left: 0;
}
body.rtl #navigation.header-6 .pcheader-icon.shoping-cart-icon {
	margin-right: 15px;
}
body.rtl #navigation.header-6 .pcheader-icon:last-child {
	margin-right: 40px;
}
.penci-header-cart-detail ul.product_list_widget li a.remove {
	right: auto;
	left: 10px;
}
.woocommerce ul.cart_list li, .woocommerce ul.product_list_widget li {
	padding-right: 0;
	padding-left: 20px;
}
body.rtl .products.product-style-4 .penci-product-loop-title .button.added:after {
	margin-left: 10px;
	margin-right: 0;
}
body.rtl #navigation.header-4 .pcheader-icon.shoping-cart-icon,
body.rtl #navigation.header-5 .pcheader-icon.shoping-cart-icon,
#navigation.header-1 .pcheader-icon.penci-top-search,
#navigation.header-2 .pcheader-icon.penci-top-search,
#navigation.header-3 .pcheader-icon.penci-top-search,
#navigation.header-6 .pcheader-icon.penci-top-search,
#navigation.header-7 .pcheader-icon.penci-top-search,
#navigation.header-8 .pcheader-icon.penci-top-search,
#navigation .pcheader-icon:first-child {
	margin-right: 10px;
}
.penci-header-wrap .penci-menuhbg-wapper{
	margin-left: 0;
	margin-right: 12px;
}
.penci-header-wrap .pc-builder-element.penci-menuhbg-wapper {
	margin-right: 0;
}
.penci-header-wrap .header-4 .penci-menuhbg-wapper,
.penci-header-wrap .header-5 .penci-menuhbg-wapper{
	margin-left: 12px;
}
.penci-header-wrap .header-6 .penci-menuhbg-wapper{
	margin-left: 12px;
	margin-right: 0;
}
#navigation .pcheader-icon:last-child {
	margin-right: 0;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li::after {
	transform: rotate(180deg);
}
.woocommerce .product.penci-product-img-fullwidth-container .penci-top-relate-post {
	right: auto;
	left: calc((100% - 1170px) / 2);
}
.woocommerce div.penci-product-img-fullwidth-container div.images .woocommerce-product-gallery__trigger {
	right: auto;
	left: calc((100% - 1170px) / 2);
}
html .jq-toast-heading {
	text-align: right;
}
html .jq-toast-heading .product_image{
	margin-right: 0;
	margin-left: 10px;
}
.close-jq-toast-single {
	right: auto;
	left: 7px;
}
@media only screen and (min-width: 768px) {
	.woocommerce .product.penci-product-img-fullwidth-container .penci-single-product-top-container .product-labels {
		left: auto;
		right: 10px;
		transform: scaleX(-1);
	}
	.woocommerce div.product.penci-summary-align-center .product_title {
		padding-left: 110px;
		padding-right: 110px;
	}
}
@media only screen and (min-width: 768px) {
	.top-related-posts-show .summary .penci-breadcrumb.penci-woo-breadcrumb {
		padding-left: 110px;
		padding-right: 0;
	}
}
