/*
Theme Name: soledad
Theme URI: https://pencidesign.net/
Description: A Multipurpose, Newspaper, Blog & WooCommerce WordPress Theme
Author: PenciDesign
Author URI: https://pencidesign.net/
Version: 8.6.8
Requires PHP: 7.4
License: GNU General Public License version 3.0
License URI: http://www.gnu.org/licenses/gpl-3.0.html
Tags: black, green, white, light, one-column, two-columns, three-columns, right-sidebar, left-sidebar, fluid-layout, responsive-layout, custom-header, custom-menu, featured-images, post-formats, translation-ready
Text Domain: soledad
Domain Path: /languages
*/
/*
 * Silence is gold
 */
/* The main css file is located in "themes/soledad/main.css" */
