@charset "UTF-8";
/**
 * woocommerce.scss
 * Governs the general look and feel of WooCommerce sections of stores using themes that do not
 * integrate with WooCommerce specifically.
 */
/**
 * Imports
 */
/**
 * Deprecated
 * Fallback for bourbon equivalent
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Vendor prefix no longer required.
 */
/**
 * Deprecated
 * Use bourbon mixin instead `@include transform(scale(1.5));`
 */
/**
 * Deprecated
 * Use bourbon mixin instead `@include box-sizing(border-box);`
 */
/**
 * Objects
 */
/**
 * WooCommerce CSS Variables
 */
:root {
  --woocommerce: #a46497;
  --wc-green: #7ad03a;
  --wc-red: #a00;
  --wc-orange: #ffba00;
  --wc-blue: #2ea2cc;
  --wc-primary: #a46497;
  --wc-primary-text: white;
  --wc-secondary: #ebe9eb;
  --wc-secondary-text: #515151;
  --wc-highlight: #77a464;
  --wc-highligh-text: white;
  --wc-content-bg: #fff;
  --wc-subtext: #767676;
}

/**
 * _animation.scss
 * Custom WooCommerce Animations.
 */
@keyframes spin {
  100% {
    transform: rotate(360deg);
  }
}
/**
 * _fonts.scss
 * Custom WooCommerce fonts.
 */
@font-face {
  font-family: "star";
  src: url("../../../../../../plugins/woocommerce/assets/fonts/star.eot");
  src: url("../../../../../../plugins/woocommerce/assets/fonts/star.eot?#iefix") format("embedded-opentype"), url("../../../../../../plugins/woocommerce/assets/fonts/star.woff") format("woff"), url("../../../../../../plugins/woocommerce/assets/fonts/star.ttf") format("truetype"), url("../../../../../../plugins/woocommerce/assets/fonts/star.svg#star") format("svg");
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: "WooCommerce";
  src: url("../../../../../../plugins/woocommerce/assets/fonts/WooCommerce.eot");
  src: url("../../../../../../plugins/woocommerce/assets/fonts/WooCommerce.eot?#iefix") format("embedded-opentype"), url("../../../../../../plugins/woocommerce/assets/fonts/WooCommerce.woff") format("woff"), url("../../../../../../plugins/woocommerce/assets/fonts/WooCommerce.ttf") format("truetype"), url("../../../../../../plugins/woocommerce/assets/fonts/WooCommerce.svg#WooCommerce") format("svg");
  font-weight: normal;
  font-style: normal;
}
/**
 * Global styles
 */
p.demo_store,
.woocommerce-store-notice {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  margin: 0;
  width: 100%;
  font-size: 1em;
  padding: 1em 0;
  text-align: center;
  background-color: #a46497;
  color: white;
  z-index: 99998;
  box-shadow: 0 1px 1em rgba(0, 0, 0, 0.2);
  display: none;
}
p.demo_store a,
.woocommerce-store-notice a {
  color: white;
  text-decoration: underline;
}

.screen-reader-text {
  clip: rect(1px, 1px, 1px, 1px);
  height: 1px;
  overflow: hidden;
  position: absolute !important;
  width: 1px;
  word-wrap: normal !important;
}

.admin-bar p.demo_store {
  top: 32px;
}

/**
 * Utility classes
 */
.clear {
  clear: both;
}

/**
 * Main WooCommerce styles
 */
.woocommerce {
  /**
   * Product Page
   */
  /**
   * Product loops
   */
  /**
   * Buttons
   */
  /**
   * Reviews
   */
  /**
   * Star ratings
   */
  /**
   * Tables
   */
  /**
   * Cart sidebar
   */
  /**
   * Forms
   */
  /**
   * Order page
   */
  /**
   * Layered nav widget
   */
  /**
   * Price filter widget
   */
  /**
   * Rating Filter Widget
   */
}
.woocommerce .blockUI.blockOverlay {
  position: relative;
}
.woocommerce a.remove {
  display: block;
  font-size: 1.5em;
  height: 1em;
  width: 1em;
  text-align: center;
  line-height: 1;
  border-radius: 100%;
  color: red;
  text-decoration: none;
  font-weight: 700;
  border: 0;
}
.woocommerce a.remove:hover {
  color: #fff !important;
  background: red;
}
.woocommerce small.note {
  display: block;
  color: #767676;
  font-size: 0.857em;
  margin-top: 10px;
}
.woocommerce .woocommerce-breadcrumb {
  *zoom: 1;
  margin: 0 0 1em;
  padding: 0;
  font-size: 0.92em;
  color: #767676;
}
.woocommerce .woocommerce-breadcrumb::before, .woocommerce .woocommerce-breadcrumb::after {
  content: " ";
  display: table;
}
.woocommerce .woocommerce-breadcrumb::after {
  clear: both;
}
.woocommerce .woocommerce-breadcrumb a {
  color: #767676;
}
.woocommerce .quantity .qty {
  width: 3.631em;
  text-align: center;
}
.woocommerce div.product {
  margin-bottom: 0;
  position: relative;
}
.woocommerce div.product .product_title {
  clear: none;
  margin-top: 0;
  padding: 0;
}
.woocommerce div.product span.price,
.woocommerce div.product p.price {
  color: #77a464;
  font-size: 1.25em;
}
.woocommerce div.product span.price ins,
.woocommerce div.product p.price ins {
  background: inherit;
  font-weight: 700;
  display: inline-block;
}
.woocommerce div.product span.price del,
.woocommerce div.product p.price del {
  opacity: 0.5;
  display: inline-block;
}
.woocommerce div.product p.stock {
  font-size: 0.92em;
}
.woocommerce div.product .stock {
  color: #77a464;
}
.woocommerce div.product .woocommerce-product-rating {
  margin-bottom: 1.618em;
}
.woocommerce div.product div.images {
  margin-bottom: 2em;
}
.woocommerce div.product div.images img {
  display: block;
  width: 100%;
  height: auto;
  box-shadow: none;
}
.woocommerce div.product div.images div.thumbnails {
  padding-top: 1em;
}
.woocommerce div.product div.images.woocommerce-product-gallery {
  position: relative;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper {
  transition: all cubic-bezier(0.795, -0.035, 0, 1) 0.5s;
  margin: 0;
  padding: 0;
  vertical-align: top;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .zoomImg {
  background-color: #fff;
  opacity: 0;
}
.woocommerce div.product div.images .woocommerce-product-gallery__image--placeholder {
  border: 1px solid #f2f2f2;
}
.woocommerce div.product div.images .woocommerce-product-gallery__image:nth-child(n+2) {
  width: 25%;
  display: inline-block;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
  position: absolute;
  top: 0.5em;
  right: 0.5em;
  font-size: 2em;
  z-index: 9;
  width: 36px;
  height: 36px;
  background: #fff;
  text-indent: -9999px;
  border-radius: 100%;
  box-sizing: content-box;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger::before {
  content: "";
  display: block;
  width: 10px;
  height: 10px;
  border: 2px solid #000;
  border-radius: 100%;
  position: absolute;
  top: 9px;
  left: 9px;
  box-sizing: content-box;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger::after {
  content: "";
  display: block;
  width: 2px;
  height: 8px;
  background: #000;
  border-radius: 6px;
  position: absolute;
  top: 19px;
  left: 22px;
  transform: rotate(-45deg);
  box-sizing: content-box;
}
.woocommerce div.product div.images .flex-control-thumbs {
  overflow: hidden;
  zoom: 1;
  margin: 0;
  padding: 0;
}
.woocommerce div.product div.images .flex-control-thumbs li {
  width: 25%;
  float: left;
  margin: 0;
  list-style: none;
}
.woocommerce div.product div.images .flex-control-thumbs li img {
  cursor: pointer;
  opacity: 0.5;
  margin: 0;
}
.woocommerce div.product div.images .flex-control-thumbs li img.flex-active, .woocommerce div.product div.images .flex-control-thumbs li img:hover {
  opacity: 1;
}
.woocommerce div.product .woocommerce-product-gallery--columns-3 .flex-control-thumbs li:nth-child(3n+1) {
  clear: left;
}
.woocommerce div.product .woocommerce-product-gallery--columns-4 .flex-control-thumbs li:nth-child(4n+1) {
  clear: left;
}
.woocommerce div.product .woocommerce-product-gallery--columns-5 .flex-control-thumbs li:nth-child(5n+1) {
  clear: left;
}
.woocommerce div.product div.summary {
  margin-bottom: 2em;
}
.woocommerce div.product div.social {
  text-align: right;
  margin: 0 0 1em;
}
.woocommerce div.product div.social span {
  margin: 0 0 0 2px;
}
.woocommerce div.product div.social span span {
  margin: 0;
}
.woocommerce div.product div.social span .stButton .chicklets {
  padding-left: 16px;
  width: 0;
}
.woocommerce div.product div.social iframe {
  float: left;
  margin-top: 3px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
  list-style: none;
  padding: 0 0 0 1em;
  margin: 0 0 1.618em;
  overflow: hidden;
  position: relative;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
  border: 1px solid #d3ced2;
  background-color: #ebe9eb;
  display: inline-block;
  position: relative;
  z-index: 0;
  border-radius: 4px 4px 0 0;
  margin: 0 -5px;
  padding: 0 1em;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
  display: inline-block;
  padding: 0.5em 0;
  font-weight: 700;
  color: #515151;
  text-decoration: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover {
  text-decoration: none;
  color: #6b6b6b;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
  background: #fff;
  z-index: 2;
  border-bottom-color: #fff;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a {
  color: inherit;
  text-shadow: inherit;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active::before {
  box-shadow: 2px 2px 0 #fff;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active::after {
  box-shadow: -2px 2px 0 #fff;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li::before, .woocommerce div.product .woocommerce-tabs ul.tabs li::after {
  border: 1px solid #d3ced2;
  position: absolute;
  bottom: -1px;
  width: 5px;
  height: 5px;
  content: " ";
  box-sizing: border-box;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li::before {
  left: -5px;
  border-bottom-right-radius: 4px;
  border-width: 0 1px 1px 0;
  box-shadow: 2px 2px 0 #ebe9eb;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li::after {
  right: -5px;
  border-bottom-left-radius: 4px;
  border-width: 0 0 1px 1px;
  box-shadow: -2px 2px 0 #ebe9eb;
}
.woocommerce div.product .woocommerce-tabs ul.tabs::before {
  position: absolute;
  content: " ";
  width: 100%;
  bottom: 0;
  left: 0;
  border-bottom: 1px solid #d3ced2;
  z-index: 1;
}
.woocommerce div.product .woocommerce-tabs .panel {
  margin: 0 0 2em;
  padding: 0;
}
.woocommerce div.product p.cart {
  margin-bottom: 2em;
  *zoom: 1;
}
.woocommerce div.product p.cart::before, .woocommerce div.product p.cart::after {
  content: " ";
  display: table;
}
.woocommerce div.product p.cart::after {
  clear: both;
}
.woocommerce div.product form.cart {
  margin-bottom: 2em;
  *zoom: 1;
}
.woocommerce div.product form.cart::before, .woocommerce div.product form.cart::after {
  content: " ";
  display: table;
}
.woocommerce div.product form.cart::after {
  clear: both;
}
.woocommerce div.product form.cart div.quantity {
  float: left;
  margin: 0 4px 0 0;
}
.woocommerce div.product form.cart table {
  border-width: 0 0 1px;
}
.woocommerce div.product form.cart table td {
  padding-left: 0;
}
.woocommerce div.product form.cart table div.quantity {
  float: none;
  margin: 0;
}
.woocommerce div.product form.cart table small.stock {
  display: block;
  float: none;
}
.woocommerce div.product form.cart .variations {
  margin-bottom: 1em;
  border: 0;
  width: 100%;
}
.woocommerce div.product form.cart .variations td,
.woocommerce div.product form.cart .variations th {
  border: 0;
  vertical-align: top;
  line-height: 2em;
}
.woocommerce div.product form.cart .variations label {
  font-weight: 700;
}
.woocommerce div.product form.cart .variations select {
  max-width: 100%;
  min-width: 75%;
  display: inline-block;
  margin-right: 1em;
}
.woocommerce div.product form.cart .variations td.label {
  padding-right: 1em;
}
.woocommerce div.product form.cart .woocommerce-variation-description p {
  margin-bottom: 1em;
}
.woocommerce div.product form.cart .reset_variations {
  visibility: hidden;
  font-size: 0.83em;
}
.woocommerce div.product form.cart .wc-no-matching-variations {
  display: none;
}
.woocommerce div.product form.cart .button {
  vertical-align: middle;
  float: left;
}
.woocommerce div.product form.cart .group_table td.woocommerce-grouped-product-list-item__label {
  padding-right: 1em;
  padding-left: 1em;
}
.woocommerce div.product form.cart .group_table td {
  vertical-align: top;
  padding-bottom: 0.5em;
  border: 0;
}
.woocommerce div.product form.cart .group_table td:first-child {
  width: 4em;
  text-align: center;
}
.woocommerce div.product form.cart .group_table .wc-grouped-product-add-to-cart-checkbox {
  display: inline-block;
  width: auto;
  margin: 0 auto;
  transform: scale(1.5, 1.5);
}
.woocommerce span.onsale {
  min-height: 3.236em;
  min-width: 3.236em;
  padding: 0.202em;
  font-size: 1em;
  font-weight: 700;
  position: absolute;
  text-align: center;
  line-height: 3.236;
  top: -0.5em;
  left: -0.5em;
  margin: 0;
  border-radius: 100%;
  background-color: #77a464;
  color: white;
  font-size: 0.857em;
  z-index: 9;
}
.woocommerce .products ul,
.woocommerce ul.products {
  margin: 0 0 1em;
  padding: 0;
  list-style: none outside;
  clear: both;
  *zoom: 1;
}
.woocommerce .products ul::before, .woocommerce .products ul::after,
.woocommerce ul.products::before,
.woocommerce ul.products::after {
  content: " ";
  display: table;
}
.woocommerce .products ul::after,
.woocommerce ul.products::after {
  clear: both;
}
.woocommerce .products ul li,
.woocommerce ul.products li {
  list-style: none outside;
}
.woocommerce ul.products li.product {
  /*.price {
      color: $highlight;
      display: block;
      font-weight: normal;
      margin-bottom: 0.5em;
      font-size: 0.857em;

      del {
          color: inherit;
          opacity: 0.5;
          display: inline-block;
      }

      ins {
          background: none;
          font-weight: 700;
          display: inline-block;
      }

      .from {
          font-size: 0.67em;
          margin: -2px 0 0 0;
          text-transform: uppercase;
          color: rgba(desaturate($highlight, 75%), 0.5);
      }
  }*/
}
.woocommerce ul.products li.product .onsale {
  top: 0;
  right: 0;
  left: auto;
  margin: -0.5em -0.5em 0 0;
}
.woocommerce ul.products li.product a {
  text-decoration: none;
}
.woocommerce ul.products li.product a img {
  width: 100%;
  height: auto;
  display: block;
  box-shadow: none;
}
.woocommerce ul.products li.product strong {
  display: block;
}
.woocommerce ul.products li.product .woocommerce-placeholder {
  border: 1px solid #f2f2f2;
}
.woocommerce ul.products li.product .star-rating {
  font-size: 0.857em;
}
.woocommerce ul.products li.product .button {
  margin-top: 1em;
}
.woocommerce .woocommerce-result-count {
  margin: 0 0 1em;
}
.woocommerce .woocommerce-ordering {
  margin: 0 0 1em;
}
.woocommerce .woocommerce-ordering select {
  vertical-align: top;
}
.woocommerce nav.woocommerce-pagination {
  text-align: center;
}
.woocommerce nav.woocommerce-pagination ul {
  display: inline-block;
  white-space: nowrap;
  padding: 0;
  clear: both;
  border: 1px solid #d3ced2;
  border-right: 0;
  margin: 1px;
}
.woocommerce nav.woocommerce-pagination ul li {
  border-right: 1px solid #d3ced2;
  padding: 0;
  margin: 0;
  float: left;
  display: inline;
  overflow: hidden;
}
.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li span {
  margin: 0;
  text-decoration: none;
  padding: 0;
  line-height: 1;
  font-size: 1em;
  font-weight: normal;
  padding: 0.5em;
  min-width: 1em;
  display: block;
}
.woocommerce nav.woocommerce-pagination ul li span.current,
.woocommerce nav.woocommerce-pagination ul li a:hover,
.woocommerce nav.woocommerce-pagination ul li a:focus {
  background: #ebe9eb;
  color: #8a7e88;
}
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button,
.woocommerce #respond input#submit {
  font-size: 100%;
  margin: 0;
  line-height: 1;
  cursor: pointer;
  position: relative;
  text-decoration: none;
  overflow: visible;
  padding: 0.618em 1em;
  font-weight: 700;
  border-radius: 3px;
  left: auto;
  color: #515151;
  background-color: #ebe9eb;
  border: 0;
  display: inline-block;
  background-image: none;
  box-shadow: none;
  text-shadow: none;
}
.woocommerce a.button.loading,
.woocommerce button.button.loading,
.woocommerce input.button.loading,
.woocommerce #respond input#submit.loading {
  opacity: 0.25;
}
.woocommerce a.button.loading::after,
.woocommerce button.button.loading::after,
.woocommerce input.button.loading::after,
.woocommerce #respond input#submit.loading::after {
  font-family: "WooCommerce";
  content: "";
  vertical-align: top;
  font-weight: 400;
  position: absolute;
  top: 0.618em;
  right: 1em;
  animation: spin 2s linear infinite;
}
.woocommerce a.button.added::after,
.woocommerce button.button.added::after,
.woocommerce input.button.added::after,
.woocommerce #respond input#submit.added::after {
  font-family: "WooCommerce";
  content: "";
  margin-left: 0.53em;
  vertical-align: bottom;
}
.woocommerce a.button:hover,
.woocommerce button.button:hover,
.woocommerce input.button:hover,
.woocommerce #respond input#submit:hover {
  background-color: #dfdcde;
  text-decoration: none;
  background-image: none;
  color: #515151;
}
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt,
.woocommerce #respond input#submit.alt {
  background-color: #a46497;
  color: white;
  -webkit-font-smoothing: antialiased;
}
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover,
.woocommerce #respond input#submit.alt:hover {
  background-color: #96588a;
  color: white;
}
.woocommerce a.button.alt.disabled, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled[disabled], .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt:disabled[disabled]:hover,
.woocommerce button.button.alt.disabled,
.woocommerce button.button.alt:disabled,
.woocommerce button.button.alt:disabled[disabled],
.woocommerce button.button.alt.disabled:hover,
.woocommerce button.button.alt:disabled:hover,
.woocommerce button.button.alt:disabled[disabled]:hover,
.woocommerce input.button.alt.disabled,
.woocommerce input.button.alt:disabled,
.woocommerce input.button.alt:disabled[disabled],
.woocommerce input.button.alt.disabled:hover,
.woocommerce input.button.alt:disabled:hover,
.woocommerce input.button.alt:disabled[disabled]:hover,
.woocommerce #respond input#submit.alt.disabled,
.woocommerce #respond input#submit.alt:disabled,
.woocommerce #respond input#submit.alt:disabled[disabled],
.woocommerce #respond input#submit.alt.disabled:hover,
.woocommerce #respond input#submit.alt:disabled:hover,
.woocommerce #respond input#submit.alt:disabled[disabled]:hover {
  background-color: #a46497;
  color: white;
}
.woocommerce a.button:disabled, .woocommerce a.button.disabled, .woocommerce a.button:disabled[disabled],
.woocommerce button.button:disabled,
.woocommerce button.button.disabled,
.woocommerce button.button:disabled[disabled],
.woocommerce input.button:disabled,
.woocommerce input.button.disabled,
.woocommerce input.button:disabled[disabled],
.woocommerce #respond input#submit:disabled,
.woocommerce #respond input#submit.disabled,
.woocommerce #respond input#submit:disabled[disabled] {
  color: inherit;
  cursor: not-allowed;
  opacity: 0.5;
  padding: 0.618em 1em;
}
.woocommerce a.button:disabled:hover, .woocommerce a.button.disabled:hover, .woocommerce a.button:disabled[disabled]:hover,
.woocommerce button.button:disabled:hover,
.woocommerce button.button.disabled:hover,
.woocommerce button.button:disabled[disabled]:hover,
.woocommerce input.button:disabled:hover,
.woocommerce input.button.disabled:hover,
.woocommerce input.button:disabled[disabled]:hover,
.woocommerce #respond input#submit:disabled:hover,
.woocommerce #respond input#submit.disabled:hover,
.woocommerce #respond input#submit:disabled[disabled]:hover {
  color: inherit;
  background-color: #ebe9eb;
}
.woocommerce .cart .button,
.woocommerce .cart input.button {
  float: none;
}
.woocommerce a.added_to_cart {
  padding-top: 0.5em;
  display: inline-block;
}
.woocommerce #reviews h2 small {
  float: right;
  color: #767676;
  font-size: 15px;
  margin: 10px 0 0;
}
.woocommerce #reviews h2 small a {
  text-decoration: none;
  color: #767676;
}
.woocommerce #reviews h3 {
  margin: 0;
}
.woocommerce #reviews #respond {
  margin: 0;
  border: 0;
  padding: 0;
}
.woocommerce #reviews #comment {
  height: 75px;
}
.woocommerce #reviews #comments .add_review {
  *zoom: 1;
}
.woocommerce #reviews #comments .add_review::before, .woocommerce #reviews #comments .add_review::after {
  content: " ";
  display: table;
}
.woocommerce #reviews #comments .add_review::after {
  clear: both;
}
.woocommerce #reviews #comments h2 {
  clear: none;
}
.woocommerce #reviews #comments ol.commentlist {
  *zoom: 1;
  margin: 0;
  width: 100%;
  background: none;
  list-style: none;
}
.woocommerce #reviews #comments ol.commentlist::before, .woocommerce #reviews #comments ol.commentlist::after {
  content: " ";
  display: table;
}
.woocommerce #reviews #comments ol.commentlist::after {
  clear: both;
}
.woocommerce #reviews #comments ol.commentlist li {
  padding: 0;
  margin: 0 0 20px;
  border: 0;
  position: relative;
  background: 0;
  border: 0;
}
.woocommerce #reviews #comments ol.commentlist li .meta {
  color: #767676;
  font-size: 0.75em;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
  float: left;
  position: absolute;
  top: 0;
  left: 0;
  padding: 3px;
  width: 32px;
  height: auto;
  background: #ebe9eb;
  border: 1px solid #e4e1e3;
  margin: 0;
  box-shadow: none;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text {
  margin: 0 0 0 50px;
  border: 1px solid #e4e1e3;
  border-radius: 4px;
  padding: 1em 1em 0;
  *zoom: 1;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text::before, .woocommerce #reviews #comments ol.commentlist li .comment-text::after {
  content: " ";
  display: table;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text::after {
  clear: both;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p {
  margin: 0 0 1em;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta {
  font-size: 0.83em;
}
.woocommerce #reviews #comments ol.commentlist ul.children {
  list-style: none outside;
  margin: 20px 0 0 50px;
}
.woocommerce #reviews #comments ol.commentlist ul.children .star-rating {
  display: none;
}
.woocommerce #reviews #comments ol.commentlist #respond {
  border: 1px solid #e4e1e3;
  border-radius: 4px;
  padding: 1em 1em 0;
  margin: 20px 0 0 50px;
}
.woocommerce #reviews #comments .commentlist > li::before {
  content: "";
}
.woocommerce .star-rating {
  float: right;
  overflow: hidden;
  position: relative;
  height: 1em;
  line-height: 1;
  font-size: 1em;
  width: 5.4em;
  font-family: "star";
}
.woocommerce .star-rating::before {
  content: "sssss";
  color: #d3ced2;
  float: left;
  top: 0;
  left: 0;
  position: absolute;
}
.woocommerce .star-rating span {
  overflow: hidden;
  float: left;
  top: 0;
  left: 0;
  position: absolute;
  padding-top: 1.5em;
}
.woocommerce .star-rating span::before {
  content: "SSSSS";
  top: 0;
  position: absolute;
  left: 0;
}
.woocommerce .woocommerce-product-rating {
  *zoom: 1;
  line-height: 2;
  display: block;
}
.woocommerce .woocommerce-product-rating::before, .woocommerce .woocommerce-product-rating::after {
  content: " ";
  display: table;
}
.woocommerce .woocommerce-product-rating::after {
  clear: both;
}
.woocommerce .woocommerce-product-rating .star-rating {
  margin: 0.5em 4px 0 0;
  float: left;
}
.woocommerce .products .star-rating {
  display: block;
  margin: 0 0 0.5em;
  float: none;
}
.woocommerce .hreview-aggregate .star-rating {
  margin: 10px 0 0;
}
.woocommerce #review_form #respond {
  *zoom: 1;
  position: static;
  margin: 0;
  width: auto;
  padding: 0;
  background: transparent none;
  border: 0;
}
.woocommerce #review_form #respond::before, .woocommerce #review_form #respond::after {
  content: " ";
  display: table;
}
.woocommerce #review_form #respond::after {
  clear: both;
}
.woocommerce #review_form #respond p {
  margin: 0 0 10px;
}
.woocommerce #review_form #respond .form-submit input {
  left: auto;
}
.woocommerce #review_form #respond textarea {
  box-sizing: border-box;
  width: 100%;
}
.woocommerce p.stars a {
  position: relative;
  height: 1em;
  width: 1em;
  text-indent: -999em;
  display: inline-block;
  text-decoration: none;
}
.woocommerce p.stars a::before {
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  width: 1em;
  height: 1em;
  line-height: 1;
  font-family: "WooCommerce";
  content: "";
  text-indent: 0;
}
.woocommerce p.stars a:hover ~ a::before {
  content: "";
}
.woocommerce p.stars:hover a::before {
  content: "";
}
.woocommerce p.stars.selected a.active::before {
  content: "";
}
.woocommerce p.stars.selected a.active ~ a::before {
  content: "";
}
.woocommerce p.stars.selected a:not(.active)::before {
  content: "";
}
.woocommerce table.shop_attributes {
  border: 0;
  border-top: 1px solid var(--pcborder-cl);
  margin-bottom: 1.618em;
  width: 100%;
}
.woocommerce table.shop_attributes th {
  width: 150px;
  font-weight: 700;
  padding: 8px 0;
  border-top: 0;
  border-bottom: 1px solid var(--pcborder-cl);
  margin: 0;
  line-height: 1.5;
}
.woocommerce table.shop_attributes td {
  font-style: normal;
  padding: 0;
  border-top: 0;
  border-bottom: 1px solid var(--pcborder-cl);
  margin: 0;
  line-height: 1.5;
}
.woocommerce table.shop_attributes td p {
  margin: 0;
  padding: 8px 0;
}
.woocommerce table.shop_attributes tr:nth-child(even) td,
.woocommerce table.shop_attributes tr:nth-child(even) th {
  background: rgba(0, 0, 0, 0.025);
}
.woocommerce table.shop_table {
  border: 1px solid var(--pcborder-cl);
  margin: 0 -1px 24px 0;
  text-align: left;
  width: 100%;
  border-collapse: separate;
  border-radius: 5px;
}
.woocommerce table.shop_table th {
  font-weight: 700;
  padding: 9px 12px;
  line-height: 1.5em;
}
.woocommerce table.shop_table td {
  border-top: 1px solid var(--pcborder-cl);
  padding: 9px 12px;
  vertical-align: middle;
  line-height: 1.5em;
}
.woocommerce table.shop_table td small {
  font-weight: normal;
}
.woocommerce table.shop_table td del {
  font-weight: normal;
}
.woocommerce table.shop_table tbody:first-child tr:first-child th,
.woocommerce table.shop_table tbody:first-child tr:first-child td {
  border-top: 0;
}
.woocommerce table.shop_table tfoot td,
.woocommerce table.shop_table tfoot th,
.woocommerce table.shop_table tbody th {
  font-weight: 700;
  border-top: 1px solid var(--pcborder-cl);
}
.woocommerce table.my_account_orders {
  font-size: 0.85em;
}
.woocommerce table.my_account_orders th,
.woocommerce table.my_account_orders td {
  padding: 4px 8px;
  vertical-align: middle;
}
.woocommerce table.my_account_orders .button {
  white-space: nowrap;
}
.woocommerce table.woocommerce-MyAccount-downloads td,
.woocommerce table.woocommerce-MyAccount-downloads th {
  vertical-align: top;
  text-align: center;
}
.woocommerce table.woocommerce-MyAccount-downloads td:first-child,
.woocommerce table.woocommerce-MyAccount-downloads th:first-child {
  text-align: left;
}
.woocommerce table.woocommerce-MyAccount-downloads td:last-child,
.woocommerce table.woocommerce-MyAccount-downloads th:last-child {
  text-align: left;
}
.woocommerce table.woocommerce-MyAccount-downloads td .woocommerce-MyAccount-downloads-file::before,
.woocommerce table.woocommerce-MyAccount-downloads th .woocommerce-MyAccount-downloads-file::before {
  content: "↓";
  display: inline-block;
}
.woocommerce td.product-name dl.variation,
.woocommerce td.product-name .wc-item-meta {
  list-style: none outside;
}
.woocommerce td.product-name dl.variation dt,
.woocommerce td.product-name dl.variation .wc-item-meta-label,
.woocommerce td.product-name .wc-item-meta dt,
.woocommerce td.product-name .wc-item-meta .wc-item-meta-label {
  float: left;
  clear: both;
  margin-right: 0.25em;
  display: inline-block;
  list-style: none outside;
}
.woocommerce td.product-name dl.variation dd,
.woocommerce td.product-name .wc-item-meta dd {
  margin: 0;
}
.woocommerce td.product-name dl.variation p, .woocommerce td.product-name dl.variation:last-child,
.woocommerce td.product-name .wc-item-meta p,
.woocommerce td.product-name .wc-item-meta:last-child {
  margin-bottom: 0;
  line-height: inherit;
}
.woocommerce td.product-name p.backorder_notification {
  font-size: 0.83em;
}
.woocommerce td.product-quantity {
  min-width: 80px;
}
.woocommerce ul.cart_list,
.woocommerce ul.product_list_widget {
  list-style: none outside;
  padding: 0;
  margin: 0;
}
.woocommerce ul.cart_list li,
.woocommerce ul.product_list_widget li {
  padding: 4px 0;
  margin: 0;
  *zoom: 1;
  list-style: none;
}
.woocommerce ul.cart_list li::before, .woocommerce ul.cart_list li::after,
.woocommerce ul.product_list_widget li::before,
.woocommerce ul.product_list_widget li::after {
  content: " ";
  display: table;
}
.woocommerce ul.cart_list li::after,
.woocommerce ul.product_list_widget li::after {
  clear: both;
}
.woocommerce ul.cart_list li a,
.woocommerce ul.product_list_widget li a {
  display: block;
  font-weight: 700;
}
.woocommerce ul.cart_list li img,
.woocommerce ul.product_list_widget li img {
  float: right;
  margin-left: 4px;
  width: 32px;
  height: auto;
  box-shadow: none;
}
.woocommerce ul.cart_list li dl,
.woocommerce ul.product_list_widget li dl {
  margin: 0;
  padding-left: 1em;
  border-left: 2px solid var(--pcborder-cl);
  *zoom: 1;
}
.woocommerce ul.cart_list li dl::before, .woocommerce ul.cart_list li dl::after,
.woocommerce ul.product_list_widget li dl::before,
.woocommerce ul.product_list_widget li dl::after {
  content: " ";
  display: table;
}
.woocommerce ul.cart_list li dl::after,
.woocommerce ul.product_list_widget li dl::after {
  clear: both;
}
.woocommerce ul.cart_list li dl dt,
.woocommerce ul.cart_list li dl dd,
.woocommerce ul.product_list_widget li dl dt,
.woocommerce ul.product_list_widget li dl dd {
  display: inline-block;
  float: left;
  margin-bottom: 1em;
}
.woocommerce ul.cart_list li dl dt,
.woocommerce ul.product_list_widget li dl dt {
  font-weight: 700;
  padding: 0 0 0.25em;
  margin: 0 4px 0 0;
  clear: left;
}
.woocommerce ul.cart_list li dl dd,
.woocommerce ul.product_list_widget li dl dd {
  padding: 0 0 0.25em;
}
.woocommerce ul.cart_list li dl dd p:last-child,
.woocommerce ul.product_list_widget li dl dd p:last-child {
  margin-bottom: 0;
}
.woocommerce ul.cart_list li .star-rating,
.woocommerce ul.product_list_widget li .star-rating {
  float: none;
}
.woocommerce.widget_shopping_cart .total,
.woocommerce .widget_shopping_cart .total {
  border-top: 3px double #ebe9eb;
  padding: 4px 0 0;
}
.woocommerce.widget_shopping_cart .total strong,
.woocommerce .widget_shopping_cart .total strong {
  min-width: 40px;
  display: inline-block;
}
.woocommerce.widget_shopping_cart .cart_list li,
.woocommerce .widget_shopping_cart .cart_list li {
  padding-left: 2em;
  position: relative;
  padding-top: 0;
}
.woocommerce.widget_shopping_cart .cart_list li a.remove,
.woocommerce .widget_shopping_cart .cart_list li a.remove {
  position: absolute;
  top: 0;
  left: 0;
}
.woocommerce.widget_shopping_cart .buttons,
.woocommerce .widget_shopping_cart .buttons {
  *zoom: 1;
}
.woocommerce.widget_shopping_cart .buttons::before, .woocommerce.widget_shopping_cart .buttons::after,
.woocommerce .widget_shopping_cart .buttons::before,
.woocommerce .widget_shopping_cart .buttons::after {
  content: " ";
  display: table;
}
.woocommerce.widget_shopping_cart .buttons::after,
.woocommerce .widget_shopping_cart .buttons::after {
  clear: both;
}
.woocommerce.widget_shopping_cart .buttons a,
.woocommerce .widget_shopping_cart .buttons a {
  margin-right: 5px;
  margin-bottom: 5px;
}
.woocommerce form .form-row {
  padding: 3px;
  margin: 0 0 6px;
}
.woocommerce form .form-row [placeholder]:focus::-webkit-input-placeholder {
  transition: opacity 0.5s 0.5s ease;
  opacity: 0;
}
.woocommerce form .form-row label {
  line-height: 2;
}
.woocommerce form .form-row label.hidden {
  visibility: hidden;
}
.woocommerce form .form-row label.inline {
  display: inline;
}
.woocommerce form .form-row .woocommerce-input-wrapper .description {
  background: #1e85be;
  color: #fff;
  border-radius: 3px;
  padding: 1em;
  margin: 0.5em 0 0;
  clear: both;
  display: none;
  position: relative;
}
.woocommerce form .form-row .woocommerce-input-wrapper .description a {
  color: #fff;
  text-decoration: underline;
  border: 0;
  box-shadow: none;
}
.woocommerce form .form-row .woocommerce-input-wrapper .description::before {
  left: 50%;
  top: 0%;
  margin-top: -4px;
  transform: translateX(-50%) rotate(180deg);
  content: "";
  position: absolute;
  border-width: 4px 6px 0 6px;
  border-style: solid;
  border-color: #1e85be transparent transparent transparent;
  z-index: 100;
  display: block;
}
.woocommerce form .form-row select {
  cursor: pointer;
  margin: 0;
}
.woocommerce form .form-row .required {
  color: red;
  font-weight: 700;
  border: 0 !important;
  text-decoration: none;
}
.woocommerce form .form-row .optional {
  visibility: visible;
}
.woocommerce form .form-row .input-checkbox {
  display: inline;
  margin: -2px 8px 0 0;
  text-align: center;
  vertical-align: middle;
}
.woocommerce form .form-row input.input-text,
.woocommerce form .form-row textarea {
  box-sizing: border-box;
  width: 100%;
  margin: 0;
  outline: 0;
}
.woocommerce form .form-row textarea {
  height: 4em;
  line-height: 1.5;
  display: block;
  box-shadow: none;
}
.woocommerce form .form-row .select2-container {
  width: 100%;
  line-height: 2em;
}
.woocommerce form .form-row.woocommerce-invalid label {
  color: #a00;
}
.woocommerce form .form-row.woocommerce-invalid .select2-container,
.woocommerce form .form-row.woocommerce-invalid input.input-text,
.woocommerce form .form-row.woocommerce-invalid select {
  border-color: #a00;
}
.woocommerce form .form-row.woocommerce-validated .select2-container,
.woocommerce form .form-row.woocommerce-validated input.input-text,
.woocommerce form .form-row.woocommerce-validated select {
  border-color: #6dc22e;
}
.woocommerce form .form-row ::-webkit-input-placeholder {
  line-height: normal;
}
.woocommerce form .form-row :-moz-placeholder {
  line-height: normal;
}
.woocommerce form .form-row :-ms-input-placeholder {
  line-height: normal;
}
.woocommerce form.login,
.woocommerce form.checkout_coupon,
.woocommerce form.register {
  border: 1px solid #d3ced2;
  padding: 20px;
  margin: 2em 0;
  text-align: left;
  border-radius: 5px;
}
.woocommerce ul#shipping_method {
  list-style: none outside;
  margin: 0;
  padding: 0;
}
.woocommerce ul#shipping_method li {
  margin: 0 0 0.5em;
  line-height: 1.5em;
  list-style: none outside;
}
.woocommerce ul#shipping_method li input {
  margin: 3px 0.4375em 0 0;
  vertical-align: top;
}
.woocommerce ul#shipping_method li label {
  display: inline;
}
.woocommerce ul#shipping_method .amount {
  font-weight: 700;
}
.woocommerce p.woocommerce-shipping-contents {
  margin: 0;
}
.woocommerce ul.order_details {
  *zoom: 1;
  margin: 0 0 3em;
  list-style: none;
}
.woocommerce ul.order_details::before, .woocommerce ul.order_details::after {
  content: " ";
  display: table;
}
.woocommerce ul.order_details::after {
  clear: both;
}
.woocommerce ul.order_details li {
  float: left;
  margin-right: 2em;
  text-transform: uppercase;
  font-size: 0.715em;
  line-height: 1;
  border-right: 1px dashed #d3ced2;
  padding-right: 2em;
  margin-left: 0;
  padding-left: 0;
  list-style-type: none;
}
.woocommerce ul.order_details li strong {
  display: block;
  font-size: 1.4em;
  text-transform: none;
  line-height: 1.5;
}
.woocommerce ul.order_details li:last-of-type {
  border: none;
}
.woocommerce .wc-bacs-bank-details-account-name {
  font-weight: bold;
}
.woocommerce .woocommerce-order-downloads,
.woocommerce .woocommerce-customer-details,
.woocommerce .woocommerce-order-details {
  margin-bottom: 2em;
}
.woocommerce .woocommerce-order-downloads *:last-child,
.woocommerce .woocommerce-customer-details *:last-child,
.woocommerce .woocommerce-order-details *:last-child {
  margin-bottom: 0;
}
.woocommerce .woocommerce-customer-details address {
  font-style: normal;
  margin-bottom: 0;
  border: 1px solid var(--pcborder-cl);
  border-bottom-width: 2px;
  border-right-width: 2px;
  text-align: left;
  width: 100%;
  border-radius: 5px;
  padding: 6px 12px;
}
.woocommerce .woocommerce-customer-details .woocommerce-customer-details--phone,
.woocommerce .woocommerce-customer-details .woocommerce-customer-details--email {
  margin-bottom: 0;
  padding-left: 1.5em;
}
.woocommerce .woocommerce-customer-details .woocommerce-customer-details--phone::before {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-right: 0.618em;
  content: "";
  text-decoration: none;
  margin-left: -1.5em;
  line-height: 1.75;
  position: absolute;
}
.woocommerce .woocommerce-customer-details .woocommerce-customer-details--email::before {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-right: 0.618em;
  content: "";
  text-decoration: none;
  margin-left: -1.5em;
  line-height: 1.75;
  position: absolute;
}
.woocommerce .woocommerce-widget-layered-nav-list {
  margin: 0;
  padding: 0;
  border: 0;
  list-style: none outside;
}
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item {
  *zoom: 1;
  padding: 0 0 1px;
  list-style: none;
}
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item::before, .woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item::after {
  content: " ";
  display: table;
}
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item::after {
  clear: both;
}
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a,
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item span {
  padding: 1px 0;
}
.woocommerce .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item--chosen a::before {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-right: 0.618em;
  content: "";
  text-decoration: none;
  color: #a00;
}
.woocommerce .woocommerce-widget-layered-nav-dropdown__submit {
  margin-top: 1em;
}
.woocommerce .widget_layered_nav_filters ul {
  /*margin: 0;
  padding: 0;
  border: 0;*/
  list-style: none outside;
  overflow: hidden;
  zoom: 1;
}
.woocommerce .widget_layered_nav_filters ul li {
  float: left;
  padding: 0 1em 1px 1px;
  list-style: none;
  border: 0;
}
.woocommerce .widget_layered_nav_filters ul li a {
  text-decoration: none;
}
.woocommerce .widget_layered_nav_filters ul li a::before {
  font-family: penciicon, Serif;
  content: "";
  color: black;
  font-size: 10px;
  margin-right: 0.5em;
}
.woocommerce .widget_price_filter .price_slider {
  margin-bottom: 1em;
}
.woocommerce .widget_price_filter .price_slider_amount {
  text-align: right;
  line-height: 2.4;
  font-size: 0.8751em;
}
.woocommerce .widget_price_filter .price_slider_amount .button {
  font-size: 1.15em;
  float: left;
}
.woocommerce .widget_price_filter .ui-slider {
  position: relative;
  text-align: left;
  margin-left: 0.5em;
  margin-right: 0.5em;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
  position: absolute;
  z-index: 2;
  width: 1em;
  height: 1em;
  background-color: #a46497;
  border-radius: 1em;
  cursor: ew-resize;
  outline: none;
  top: -0.3em;
  /* rtl:ignore */
  margin-left: -0.5em;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
  position: absolute;
  z-index: 1;
  font-size: 0.7em;
  display: block;
  border: 0;
  border-radius: 1em;
  background-color: #a46497;
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
  border-radius: 1em;
  background-color: #462940;
  border: 0;
}
.woocommerce .widget_price_filter .ui-slider-horizontal {
  height: 0.5em;
}
.woocommerce .widget_price_filter .ui-slider-horizontal .ui-slider-range {
  top: 0;
  height: 100%;
}
.woocommerce .widget_price_filter .ui-slider-horizontal .ui-slider-range-min {
  left: -1px;
}
.woocommerce .widget_price_filter .ui-slider-horizontal .ui-slider-range-max {
  right: -1px;
}
.woocommerce .widget_rating_filter ul {
  margin: 0;
  padding: 0;
  border: 0;
  list-style: none outside;
}
.woocommerce .widget_rating_filter ul li {
  *zoom: 1;
  padding: 0 0 1px;
  list-style: none;
}
.woocommerce .widget_rating_filter ul li::before, .woocommerce .widget_rating_filter ul li::after {
  content: " ";
  display: table;
}
.woocommerce .widget_rating_filter ul li::after {
  clear: both;
}
.woocommerce .widget_rating_filter ul li a {
  padding: 1px 0;
  text-decoration: none;
}
.woocommerce .widget_rating_filter ul li .star-rating {
  float: none;
  display: inline-block;
}
.woocommerce .widget_rating_filter ul li.chosen a::before {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-right: 0.618em;
  content: "";
  text-decoration: none;
  color: #a00;
}
.woocommerce .woocommerce-form-login .woocommerce-form-login__submit {
  float: left;
  margin-right: 1em;
}
.woocommerce .woocommerce-form-login .woocommerce-form-login__rememberme {
  display: inline-block;
}

.woocommerce-no-js form.woocommerce-form-login,
.woocommerce-no-js form.woocommerce-form-coupon {
  display: block !important;
}
.woocommerce-no-js .woocommerce-form-login-toggle,
.woocommerce-no-js .woocommerce-form-coupon-toggle,
.woocommerce-no-js .showcoupon {
  display: none !important;
}

.woocommerce-message,
.woocommerce-error,
.woocommerce-info {
  padding: 1em 2em 1em 3.5em;
  margin: 0 0 2em;
  position: relative;
  background-color: #f7f6f7;
  color: #515151;
  border-top: 3px solid #a46497;
  list-style: none outside;
  *zoom: 1;
  width: auto;
  word-wrap: break-word;
}
.woocommerce-message::before, .woocommerce-message::after,
.woocommerce-error::before,
.woocommerce-error::after,
.woocommerce-info::before,
.woocommerce-info::after {
  content: " ";
  display: table;
}
.woocommerce-message::after,
.woocommerce-error::after,
.woocommerce-info::after {
  clear: both;
}
.woocommerce-message::before,
.woocommerce-error::before,
.woocommerce-info::before {
  font-family: "WooCommerce";
  content: "";
  display: inline-block;
  position: absolute;
  top: 1em;
  left: 1.5em;
}
.woocommerce-message .button,
.woocommerce-error .button,
.woocommerce-info .button {
  float: right;
}
.woocommerce-message li,
.woocommerce-error li,
.woocommerce-info li {
  list-style: none outside !important;
  padding-left: 0 !important;
  margin-left: 0 !important;
}

/**
 * Right to left styles
 */
.rtl.woocommerce .price_label,
.rtl.woocommerce .price_label span {
  /* rtl:ignore */
  direction: ltr;
  unicode-bidi: embed;
}

.woocommerce-message {
  border-top-color: #8fae1b;
}
.woocommerce-message::before {
  content: "";
  color: #8fae1b;
}

.woocommerce-info {
  border-top-color: #1e85be;
}
.woocommerce-info::before {
  color: #1e85be;
}

.woocommerce-error {
  border-top-color: #b81c23;
}
.woocommerce-error::before {
  content: "";
  color: #b81c23;
}

/**
 * Account page
 */
.woocommerce-account .woocommerce {
  *zoom: 1;
}
.woocommerce-account .woocommerce::before, .woocommerce-account .woocommerce::after {
  content: " ";
  display: table;
}
.woocommerce-account .woocommerce::after {
  clear: both;
}
.woocommerce-account .addresses .title {
  *zoom: 1;
}
.woocommerce-account .addresses .title::before, .woocommerce-account .addresses .title::after {
  content: " ";
  display: table;
}
.woocommerce-account .addresses .title::after {
  clear: both;
}
.woocommerce-account .addresses .title h3 {
  float: left;
}
.woocommerce-account .addresses .title .edit {
  float: right;
}
.woocommerce-account ol.commentlist.notes li.note p.meta {
  font-weight: 700;
  margin-bottom: 0;
}
.woocommerce-account ol.commentlist.notes li.note .description p:last-child {
  margin-bottom: 0;
}
.woocommerce-account ul.digital-downloads {
  margin-left: 0;
  padding-left: 0;
}
.woocommerce-account ul.digital-downloads li {
  list-style: none;
  margin-left: 0;
  padding-left: 0;
}
.woocommerce-account ul.digital-downloads li::before {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-right: 0.618em;
  content: "";
  text-decoration: none;
}
.woocommerce-account ul.digital-downloads li .count {
  float: right;
}

/**
 * Cart/checkout page
 */
.woocommerce-cart table.cart .product-thumbnail,
.woocommerce-checkout table.cart .product-thumbnail,
#add_payment_method table.cart .product-thumbnail {
  min-width: 32px;
}
.woocommerce-cart table.cart img,
.woocommerce-checkout table.cart img,
#add_payment_method table.cart img {
  width: 32px;
  box-shadow: none;
}
.woocommerce-cart table.cart th,
.woocommerce-cart table.cart td,
.woocommerce-checkout table.cart th,
.woocommerce-checkout table.cart td,
#add_payment_method table.cart th,
#add_payment_method table.cart td {
  vertical-align: middle;
}
.woocommerce-cart table.cart td.actions .coupon .input-text,
.woocommerce-checkout table.cart td.actions .coupon .input-text,
#add_payment_method table.cart td.actions .coupon .input-text {
  float: left;
  box-sizing: border-box;
  border: 1px solid #d3ced2;
  padding: 6px 6px 5px;
  margin: 0 4px 0 0;
  outline: 0;
}
.woocommerce-cart table.cart input,
.woocommerce-checkout table.cart input,
#add_payment_method table.cart input {
  margin: 0;
  vertical-align: middle;
}
.woocommerce-cart .wc-proceed-to-checkout,
.woocommerce-checkout .wc-proceed-to-checkout,
#add_payment_method .wc-proceed-to-checkout {
  *zoom: 1;
  padding: 1em 0;
}
.woocommerce-cart .wc-proceed-to-checkout::before, .woocommerce-cart .wc-proceed-to-checkout::after,
.woocommerce-checkout .wc-proceed-to-checkout::before,
.woocommerce-checkout .wc-proceed-to-checkout::after,
#add_payment_method .wc-proceed-to-checkout::before,
#add_payment_method .wc-proceed-to-checkout::after {
  content: " ";
  display: table;
}
.woocommerce-cart .wc-proceed-to-checkout::after,
.woocommerce-checkout .wc-proceed-to-checkout::after,
#add_payment_method .wc-proceed-to-checkout::after {
  clear: both;
}
.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button,
#add_payment_method .wc-proceed-to-checkout a.checkout-button {
  display: block;
  text-align: center;
  margin-bottom: 1em;
  font-size: 1.25em;
  padding: 1em;
}
.woocommerce-cart .cart-collaterals .shipping-calculator-button,
.woocommerce-checkout .cart-collaterals .shipping-calculator-button,
#add_payment_method .cart-collaterals .shipping-calculator-button {
  float: none;
  margin-top: 0.5em;
  display: inline-block;
}
.woocommerce-cart .cart-collaterals .shipping-calculator-button::after,
.woocommerce-checkout .cart-collaterals .shipping-calculator-button::after,
#add_payment_method .cart-collaterals .shipping-calculator-button::after {
  font-family: "WooCommerce";
  speak: never;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  margin-left: 0.618em;
  content: "";
  text-decoration: none;
}
.woocommerce-cart .cart-collaterals .shipping-calculator-form,
.woocommerce-checkout .cart-collaterals .shipping-calculator-form,
#add_payment_method .cart-collaterals .shipping-calculator-form {
  margin: 1em 0 0 0;
}
.woocommerce-cart .cart-collaterals .cart_totals p small,
.woocommerce-checkout .cart-collaterals .cart_totals p small,
#add_payment_method .cart-collaterals .cart_totals p small {
  color: #767676;
  font-size: 0.83em;
}
.woocommerce-cart .cart-collaterals .cart_totals table,
.woocommerce-checkout .cart-collaterals .cart_totals table,
#add_payment_method .cart-collaterals .cart_totals table {
  border-collapse: separate;
  margin: 0 0 6px;
  padding: 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table tr:first-child th,
.woocommerce-cart .cart-collaterals .cart_totals table tr:first-child td,
.woocommerce-checkout .cart-collaterals .cart_totals table tr:first-child th,
.woocommerce-checkout .cart-collaterals .cart_totals table tr:first-child td,
#add_payment_method .cart-collaterals .cart_totals table tr:first-child th,
#add_payment_method .cart-collaterals .cart_totals table tr:first-child td {
  border-top: 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table th,
.woocommerce-checkout .cart-collaterals .cart_totals table th,
#add_payment_method .cart-collaterals .cart_totals table th {
  width: 35%;
}
.woocommerce-cart .cart-collaterals .cart_totals table td,
.woocommerce-cart .cart-collaterals .cart_totals table th,
.woocommerce-checkout .cart-collaterals .cart_totals table td,
.woocommerce-checkout .cart-collaterals .cart_totals table th,
#add_payment_method .cart-collaterals .cart_totals table td,
#add_payment_method .cart-collaterals .cart_totals table th {
  vertical-align: top;
  border-left: 0;
  border-right: 0;
  line-height: 1.5em;
}
.woocommerce-cart .cart-collaterals .cart_totals table small,
.woocommerce-checkout .cart-collaterals .cart_totals table small,
#add_payment_method .cart-collaterals .cart_totals table small {
  color: #767676;
}
.woocommerce-cart .cart-collaterals .cart_totals table select,
.woocommerce-checkout .cart-collaterals .cart_totals table select,
#add_payment_method .cart-collaterals .cart_totals table select {
  width: 100%;
}
.woocommerce-cart .cart-collaterals .cart_totals .discount td,
.woocommerce-checkout .cart-collaterals .cart_totals .discount td,
#add_payment_method .cart-collaterals .cart_totals .discount td {
  color: #77a464;
}
.woocommerce-cart .cart-collaterals .cart_totals tr td,
.woocommerce-cart .cart-collaterals .cart_totals tr th,
.woocommerce-checkout .cart-collaterals .cart_totals tr td,
.woocommerce-checkout .cart-collaterals .cart_totals tr th,
#add_payment_method .cart-collaterals .cart_totals tr td,
#add_payment_method .cart-collaterals .cart_totals tr th {
  border-top: 1px solid #ebe9eb;
}
.woocommerce-cart .cart-collaterals .cart_totals .woocommerce-shipping-destination,
.woocommerce-checkout .cart-collaterals .cart_totals .woocommerce-shipping-destination,
#add_payment_method .cart-collaterals .cart_totals .woocommerce-shipping-destination {
  margin-bottom: 0;
}
.woocommerce-cart .cart-collaterals .cross-sells ul.products li.product,
.woocommerce-checkout .cart-collaterals .cross-sells ul.products li.product,
#add_payment_method .cart-collaterals .cross-sells ul.products li.product {
  margin-top: 0;
}
.woocommerce-cart .checkout .col-2 h3#ship-to-different-address,
.woocommerce-checkout .checkout .col-2 h3#ship-to-different-address,
#add_payment_method .checkout .col-2 h3#ship-to-different-address {
  float: left;
  clear: none;
}
.woocommerce-cart .checkout .col-2 .notes,
.woocommerce-checkout .checkout .col-2 .notes,
#add_payment_method .checkout .col-2 .notes {
  clear: left;
}
.woocommerce-cart .checkout .col-2 .form-row-first,
.woocommerce-checkout .checkout .col-2 .form-row-first,
#add_payment_method .checkout .col-2 .form-row-first {
  clear: left;
}
.woocommerce-cart .checkout .create-account small,
.woocommerce-checkout .checkout .create-account small,
#add_payment_method .checkout .create-account small {
  font-size: 11px;
  color: #767676;
  font-weight: normal;
}
.woocommerce-cart .checkout div.shipping-address,
.woocommerce-checkout .checkout div.shipping-address,
#add_payment_method .checkout div.shipping-address {
  padding: 0;
  clear: left;
  width: 100%;
}
.woocommerce-cart .checkout .shipping_address,
.woocommerce-checkout .checkout .shipping_address,
#add_payment_method .checkout .shipping_address {
  clear: both;
}
.woocommerce-cart #payment,
.woocommerce-checkout #payment,
#add_payment_method #payment {
  background: #ebe9eb;
  border-radius: 5px;
}
.woocommerce-cart #payment ul.payment_methods,
.woocommerce-checkout #payment ul.payment_methods,
#add_payment_method #payment ul.payment_methods {
  *zoom: 1;
  text-align: left;
  padding: 1em;
  border-bottom: 1px solid #d3ced2;
  margin: 0;
  list-style: none outside;
}
.woocommerce-cart #payment ul.payment_methods::before, .woocommerce-cart #payment ul.payment_methods::after,
.woocommerce-checkout #payment ul.payment_methods::before,
.woocommerce-checkout #payment ul.payment_methods::after,
#add_payment_method #payment ul.payment_methods::before,
#add_payment_method #payment ul.payment_methods::after {
  content: " ";
  display: table;
}
.woocommerce-cart #payment ul.payment_methods::after,
.woocommerce-checkout #payment ul.payment_methods::after,
#add_payment_method #payment ul.payment_methods::after {
  clear: both;
}
.woocommerce-cart #payment ul.payment_methods li,
.woocommerce-checkout #payment ul.payment_methods li,
#add_payment_method #payment ul.payment_methods li {
  line-height: 2;
  text-align: left;
  margin: 0;
  font-weight: normal;
}
.woocommerce-cart #payment ul.payment_methods li input,
.woocommerce-checkout #payment ul.payment_methods li input,
#add_payment_method #payment ul.payment_methods li input {
  margin: 0 1em 0 0;
}
.woocommerce-cart #payment ul.payment_methods li img,
.woocommerce-checkout #payment ul.payment_methods li img,
#add_payment_method #payment ul.payment_methods li img {
  vertical-align: middle;
  margin: -2px 0 0 0.5em;
  padding: 0;
  position: relative;
  box-shadow: none;
}
.woocommerce-cart #payment ul.payment_methods li img + img,
.woocommerce-checkout #payment ul.payment_methods li img + img,
#add_payment_method #payment ul.payment_methods li img + img {
  margin-left: 2px;
}
.woocommerce-cart #payment ul.payment_methods li:not(.woocommerce-notice),
.woocommerce-checkout #payment ul.payment_methods li:not(.woocommerce-notice),
#add_payment_method #payment ul.payment_methods li:not(.woocommerce-notice) {
  *zoom: 1;
}
.woocommerce-cart #payment ul.payment_methods li:not(.woocommerce-notice)::before, .woocommerce-cart #payment ul.payment_methods li:not(.woocommerce-notice)::after,
.woocommerce-checkout #payment ul.payment_methods li:not(.woocommerce-notice)::before,
.woocommerce-checkout #payment ul.payment_methods li:not(.woocommerce-notice)::after,
#add_payment_method #payment ul.payment_methods li:not(.woocommerce-notice)::before,
#add_payment_method #payment ul.payment_methods li:not(.woocommerce-notice)::after {
  content: " ";
  display: table;
}
.woocommerce-cart #payment ul.payment_methods li:not(.woocommerce-notice)::after,
.woocommerce-checkout #payment ul.payment_methods li:not(.woocommerce-notice)::after,
#add_payment_method #payment ul.payment_methods li:not(.woocommerce-notice)::after {
  clear: both;
}
.woocommerce-cart #payment div.form-row,
.woocommerce-checkout #payment div.form-row,
#add_payment_method #payment div.form-row {
  padding: 1em;
}
.woocommerce-cart #payment div.payment_box,
.woocommerce-checkout #payment div.payment_box,
#add_payment_method #payment div.payment_box {
  position: relative;
  box-sizing: border-box;
  width: 100%;
  padding: 1em;
  margin: 1em 0;
  font-size: 0.92em;
  border-radius: 2px;
  line-height: 1.5;
  background-color: #dfdcde;
  color: #515151;
}
.woocommerce-cart #payment div.payment_box input.input-text,
.woocommerce-cart #payment div.payment_box textarea,
.woocommerce-checkout #payment div.payment_box input.input-text,
.woocommerce-checkout #payment div.payment_box textarea,
#add_payment_method #payment div.payment_box input.input-text,
#add_payment_method #payment div.payment_box textarea {
  border-color: #c7c1c6;
  border-top-color: #bbb3b9;
}
.woocommerce-cart #payment div.payment_box ::-webkit-input-placeholder,
.woocommerce-checkout #payment div.payment_box ::-webkit-input-placeholder,
#add_payment_method #payment div.payment_box ::-webkit-input-placeholder {
  color: #bbb3b9;
}
.woocommerce-cart #payment div.payment_box :-moz-placeholder,
.woocommerce-checkout #payment div.payment_box :-moz-placeholder,
#add_payment_method #payment div.payment_box :-moz-placeholder {
  color: #bbb3b9;
}
.woocommerce-cart #payment div.payment_box :-ms-input-placeholder,
.woocommerce-checkout #payment div.payment_box :-ms-input-placeholder,
#add_payment_method #payment div.payment_box :-ms-input-placeholder {
  color: #bbb3b9;
}
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods {
  list-style: none outside;
  margin: 0;
}
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token,
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new {
  margin: 0 0 0.5em;
}
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token label,
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new label,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token label,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new label,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-token label,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-new label {
  cursor: pointer;
}
.woocommerce-cart #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-tokenInput,
.woocommerce-checkout #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-tokenInput,
#add_payment_method #payment div.payment_box .woocommerce-SavedPaymentMethods .woocommerce-SavedPaymentMethods-tokenInput {
  vertical-align: middle;
  margin: -3px 1em 0 0;
  position: relative;
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form,
#add_payment_method #payment div.payment_box .wc-credit-card-form {
  border: 0;
  padding: 0;
  margin: 1em 0 0;
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc {
  font-size: 1.5em;
  padding: 8px;
  background-repeat: no-repeat;
  background-position: right 0.618em center;
  background-size: 32px 20px;
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.visa,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.visa,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.visa,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.visa,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.visa,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.visa,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.visa,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.visa,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.visa {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/visa.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.mastercard,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.mastercard,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.mastercard,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.mastercard,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.mastercard,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.mastercard,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.mastercard,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.mastercard,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.mastercard {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/mastercard.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.laser,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.laser,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.laser,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.laser,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.laser,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.laser,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.laser,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.laser,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.laser {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/laser.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.dinersclub,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.dinersclub,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.dinersclub,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.dinersclub,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.dinersclub,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.dinersclub,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.dinersclub,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.dinersclub,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.dinersclub {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/diners.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.maestro,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.maestro,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.maestro,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.maestro,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.maestro,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.maestro,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.maestro,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.maestro,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.maestro {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/maestro.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.jcb,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.jcb,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.jcb,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.jcb,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.jcb,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.jcb,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.jcb,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.jcb,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.jcb {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/jcb.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.amex,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.amex,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.amex,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.amex,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.amex,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.amex,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.amex,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.amex,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.amex {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/amex.svg");
}
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-number.discover,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-expiry.discover,
.woocommerce-cart #payment div.payment_box .wc-credit-card-form-card-cvc.discover,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-number.discover,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-expiry.discover,
.woocommerce-checkout #payment div.payment_box .wc-credit-card-form-card-cvc.discover,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-number.discover,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-expiry.discover,
#add_payment_method #payment div.payment_box .wc-credit-card-form-card-cvc.discover {
  background-image: url("../../../../../../plugins/woocommerce/assets/images/icons/credit-cards/discover.svg");
}
.woocommerce-cart #payment div.payment_box span.help,
.woocommerce-checkout #payment div.payment_box span.help,
#add_payment_method #payment div.payment_box span.help {
  font-size: 0.857em;
  color: #767676;
  font-weight: normal;
}
.woocommerce-cart #payment div.payment_box .form-row,
.woocommerce-checkout #payment div.payment_box .form-row,
#add_payment_method #payment div.payment_box .form-row {
  margin: 0 0 1em;
}
.woocommerce-cart #payment div.payment_box p:last-child,
.woocommerce-checkout #payment div.payment_box p:last-child,
#add_payment_method #payment div.payment_box p:last-child {
  margin-bottom: 0;
}
.woocommerce-cart #payment div.payment_box::before,
.woocommerce-checkout #payment div.payment_box::before,
#add_payment_method #payment div.payment_box::before {
  content: "";
  display: block;
  border: 1em solid #dfdcde;
  /* arrow size / color */
  border-right-color: transparent;
  border-left-color: transparent;
  border-top-color: transparent;
  position: absolute;
  top: -0.75em;
  left: 0;
  margin: -1em 0 0 2em;
}
.woocommerce-cart #payment .payment_method_paypal .about_paypal,
.woocommerce-checkout #payment .payment_method_paypal .about_paypal,
#add_payment_method #payment .payment_method_paypal .about_paypal {
  float: right;
  line-height: 52px;
  font-size: 0.83em;
}
.woocommerce-cart #payment .payment_method_paypal img,
.woocommerce-checkout #payment .payment_method_paypal img,
#add_payment_method #payment .payment_method_paypal img {
  max-height: 52px;
  vertical-align: middle;
}

.woocommerce-terms-and-conditions {
  border: 1px solid var(--pcborder-cl);
  box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
  background: rgba(0, 0, 0, 0.05);
}

.woocommerce-invalid #terms {
  outline: 2px solid red;
  outline-offset: 2px;
}

/**
 * Password strength meter
 */
.woocommerce-password-strength {
  text-align: center;
  font-weight: 600;
  padding: 3px 0.5em;
  font-size: 1em;
}
.woocommerce-password-strength.strong {
  background-color: #c1e1b9;
  border-color: #83c373;
}
.woocommerce-password-strength.short {
  background-color: #f1adad;
  border-color: #e35b5b;
}
.woocommerce-password-strength.bad {
  background-color: #fbc5a9;
  border-color: #f78b53;
}
.woocommerce-password-strength.good {
  background-color: #ffe399;
  border-color: #ffc733;
}

.woocommerce-password-hint {
  margin: 0.5em 0 0;
  display: block;
}
