/*!
*  Weather Icons 2.0
*  Maintained at http://erikflowers.github.io/weather-icons
*/@font-face{font-family:weathericons;src:url(../fonts/weathericons.eot);src:url(../fonts/weathericons.eot?#iefix) format('embedded-opentype'),url(../fonts/weathericons.woff2) format('woff2'),url(../fonts/weathericons.woff) format('woff'),url(../fonts/weathericons.ttf) format('truetype'),url(../fonts/weathericons.svg#weather_iconsregular) format('svg');font-weight:400;font-display:swap;font-style:normal}.wi{display:inline-block;font-family:weathericons;font-style:normal;font-weight:400;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.wi-day-sunny:before{content:"\f00d"}.wi-cloudy:before{content:"\f013"}.wi-day-rain:before{content:"\f008"}.wi-day-thunderstorm:before{content:"\f010"}.wi-day-showers:before{content:"\f009"}.wi-day-cloudy-high:before{content:"\f07d"}.wi-night-clear:before{content:"\f02e"}.wi-night-alt-cloudy:before{content:"\f086"}.wi-night-cloudy:before{content:"\f031"}.wi-night-showers:before{content:"\f037"}.wi-night-rain:before{content:"\f036"}.wi-night-thunderstorm:before{content:"\f03b"}.wi-night-snow-wind:before{content:"\f066"}.wi-night-alt-cloudy-high:before{content:"\f07e"}.wi-windy:before{content:"\f021"}.wi-humidity:before{content: "\f078";}