/* General */
.wp-full-overlay-sidebar .wp-full-overlay-sidebar-content {
    bottom: 120px;
}
.expanded .wp-full-overlay-footer {
    height: 120px;
}
body.header-builder-open .expanded .wp-full-overlay-footer {
    height: 45px;
}
.customizer-reset-area,
.customizer-reset-area * {
    box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
/* Panel */
.customizer-reset-footer {
    display: flex;
    align-items: center;
    justify-content: space-between;
    position: relative;
    padding-left: 10px;
    padding-right: 10px;
    height: 75px;
    background-color: #fff;
    border-bottom: 1px solid #ddd;
    flex-direction: row-reverse;
}
body.header-builder-open .customizer-reset-footer {
    display: none;
}
/* Button */
.customizer-reset-footer .customizer-reset-button,
.customizer-reset-footer .customizer-reset-button:hover {
    background-color: red;
    border-color: red;
}
.customizer-reset-footer i {
    display: inline-block;
    vertical-align: middle;
}
.customizer-reset-footer .customizer-restore-button,
.customizer-reset-footer .customizer-reset-button {
    padding: 5px 10px;
}
.customizer-reset-footer .customizer-reset-button:active {
    background-color: red;
    border-color: red;
}
#customize-controls .customizer-reset-footer .customizer-reset-button img {
    max-width: 14px;
    vertical-align: middle;
    margin-right: 10px;
    margin-top: -3px;
}
.customizer-reset-footer.has-previous-btn a,
.customizer-reset-footer.has-previous-btn button {
    font-size: 11px;
    padding-left: 5px;
    padding-right: 5px;
}
.customizer-reset-footer.has-previous-btn i,
.customizer-reset-footer.has-previous-btn i {
    font-size: 13px;
    line-height: 20px;
    width: 15px;
}
/* Icons */
.customizer-reset-footer .customizer-export-import {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    align-items: center;
    justify-content: center;
    text-align: center;
    cursor: pointer;
    padding: 5px 10px;
    box-shadow: none;
}
#customize-controls .customizer-reset-footer .customizer-export-import img {
    max-width: 14px;
    opacity: 0.4;
}
#customize-controls .customizer-reset-footer .customizer-export-import:hover img {
    opacity: 0.8;
}
/* Import */
.customizer-import-form {
    padding: 10px;
    display: flex;
    align-items: center;
    position: absolute;
    left: 0;
    bottom: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    max-height: 0;
    background-color: #fff;
    transition: all 0.5s;
    overflow: hidden;
}
.customizer-import-form.is-expanded {
    padding: 10px;
    max-height: 500px;
    transition: all 1s;
}
.customizer-import-form .close {
    position: absolute;
    right: 5px;
    top: 5px;
    display: block;
    width: 17px;
    height: 17px;
    line-height: 17px;
    font-size: 18px;
    text-align: center;
    color: #444;
    cursor: pointer;
}
.customizer-import-form .close:hover {
    color: #0073aa;
}
.customizer-import-form .fields {
    display: flex;
    flex-wrap: wrap;
    align-items: center;
    width: 100%;
}
.customizer-import-form .left-field {
    width: 70%;
    overflow: hidden;
}
.customizer-import-form .right-field {
    width: 30%;
    text-align: right;
    align-self: flex-end;
}
.customizer-import-form .label {
    display: block;
    margin-bottom: 5px;
    font-weight: 600;
}
.customizer-import-file {
    font-size: 11px;
}
