.swatch-preview {
    width: 44px;
    height: 44px;
    line-height: 44px;
    text-align: center;
    font-weight: 700;
    border: 1px solid #ccc;
}

.penci-modal-container {
    position: relative;
    display: none;
}

.penci-modal {
    transform: translate(-50%, -50%);
    position: fixed;
    top: 50%;
    left: 50%;
    width: 360px;
    max-width: 90%;
    z-index: 159990;
    background-color: #fcfcfc;
}

.penci-modal input.error {
    border-color: #dc3232;
}

.penci-modal-header,
.penci-modal-content,
.penci-modal-footer {
    padding: 20px;
}

.penci-modal-header {
    padding-top: 0;
    padding-bottom: 0;
}

.penci-modal-content {
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
    background-color: #fff;
}

.penci-modal-footer {
    text-align: right;
}

.penci-modal-footer .message,
.penci-modal-footer .spinner {
    float: left;
}

.penci-modal-footer .message.error {
    color: #dc3232;
}

.penci-modal-footer .message.success {
    color: #46b450;
}
