<?php if( get_theme_mod(  'penci_menu_hbg_show' ) && ! get_theme_mod( 'penci_vertical_nav_show' ) ): ?>
<div class="penci-menuhbg-wapper penci-menu-toggle-wapper">
	<a href="#" class="penci-menuhbg-toggle">
		<span class="penci-menuhbg-inner">
			<i class="lines-button lines-button-double">
				<i class="penci-lines"></i>
			</i>
			<i class="lines-button lines-button-double penci-hover-effect">
				<i class="penci-lines"></i>
			</i>
		</span>
	</a>
</div>
<?php  endif; ?>
