body.rtl .penci-marquee-el {
	direction: rtl;
}
.elementor-widget-penci-marquee-el {
	--marquee-rotate: var(--penci-marquee-el-rotate);
	--marquee-offset: var(--penci-marquee-el-offset);
	--marquee-adjustment: var(--penci-marquee-el-adjustment);
	-webkit-transform: rotate(var(--marquee-rotate));
	-ms-transform: rotate(var(--marquee-rotate));
	transform: rotate(var(--marquee-rotate));
	margin-left: calc(var(--marquee-offset));
	width: calc(100% + var(--marquee-adjustment));
}
.penci-marquee-el {
	height: 100%;
	display: flex;
	align-items: center;
	overflow: hidden;
}
.penci-marquee-el .marquee-content {
	overflow: hidden;
	display: flex;
	align-items: center;
	justify-content: center;
	height: 100%;
	flex-shrink: 0;
	cursor: pointer;
	margin-left: 5px;
	position: relative;
}
.penci-marquee-el .marquee-content.marquee-text {
	background-color: var(--pcaccent-cl);
	font-size: 21px;
	padding: 20px;
	color: #fff;
}
.penci-marquee-el .marquee-content.marquee-image {
	width: fit-content;
}
.marquee-content.marquee-image img {
	width: 100%;
	height: 100%;
	object-fit: cover;
	display: block;
}