.penci-tiline-grid {
	display: flex;
	flex-wrap: wrap;
	margin: 0;
	margin-left: 0px;
	padding: 0;
	list-style: none;
}
.penci-tiline-item {
	width: 100%;
}
.penci-tiline-align-center .penci-tiline-item {
	width: 50%;
}
.penci-tiline .penci-tiline-item-main-container {
	padding-left: 50px;
	padding-bottom: 50px;
}
.penci-tiline .penci-tiline-thumbnail {
	overflow: hidden;
	position: relative;
	z-index: 2;
}
.penci-tiline .penci-tiline-thumbnail img {
	width: 100%;
	object-fit: cover;
}
.penci-tiline .penci-tiline-item-main-wrapper {
	position: relative;
	padding-left: 50px;
}
.penci-tiline
	.penci-tiline-item-main-wrapper
	.penci-tiline-item-main-container {
	padding-left: 50px;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-item-main {
	position: relative;
	background: #f1f1f1;
}
.penci-tiline.penci-tiline-posts .penci-tiline-item-main-wrapper .penci-tiline-item-main {
	background: #fff;
}
.penci-tiline.penci-tiline-posts .penci-biggrid .penci-bgitin {
	border: 1px solid var(--pcborder-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-title a,
.post-entry .penci-tiline.penci-tiline-posts .pcbg-title a {
	color: var(--pcheading-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-title a:hover,
.post-entry .penci-tiline.penci-tiline-posts .pcbg-title a:hover {
	color: var(--pcaccent-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-readmore-sec .pcbg-readmorebtn {
	background: #555;
	color: #fff;
	font-weight: 600;
}
.penci-tiline.penci-tiline-posts .pcbg-readmore-sec .pcbg-readmorebtn:hover {
	background: #000;
}
.penci-tiline.penci-tiline-posts .grid-post-box-meta span:after {
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	width: 4px;
	height: 4px;
	border: 2px solid;
	border-radius: 2px;
	transform: translateY(-2px);
	-webkit-transform: translateY(-2px);
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line {
	position: absolute;
	top: 0;
	height: 100%;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line span {
	height: 100%;
	position: absolute;
	transform: translateX(-50%);
	transform-origin: center;
	display: block;
	border-width: 2px;
	border-left-style: dashed;
	border-color: var(--pcborder-cl);
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
	position: absolute;
	top: 20px;
	transform: translate(-50%, -50%);
	left: 51px;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span {
	position: absolute;
	text-align: center;
	border: 4px solid color-mix(in srgb, var(--pcaccent-cl) 40%, #fff);
	transform: translate(-50%, -50%);
	border-radius: 50%;
	height: 48px;
	width: 48px;
	background: var(--pcaccent-cl);
	display: flex;
	align-items: center;
	justify-content: center;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span i,
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span svg {
	color: #fff;
}
.penci-tiline .penci-tiline-meta {
	margin-bottom: 0;
}
.penci-tiline .penci-tiline-meta li {
	display: inline-block;
}
.penci-tiline .penci-tiline-title,
.penci-tiline .penci-tiline-excerpt,
.penci-tiline .penci-tiline-excerpt p {
	margin: 0;
	padding: 0;
}
.penci-tiline .penci-tiline-title {
	font-size: 18px;
}
.penci-tiline .penci-tiline-readmore {
	margin: 0;
}
.penci-tiline .penci-tiline-readmore svg {
	width: 1em;
	height: 1em;
	vertical-align: middle;
}
.penci-tiline .penci-tiline-arrow {
	position: absolute;
	width: 15px;
	height: 15px;
	transform: rotate(45deg);
	z-index: 0;
	top: 15px;
	left: -8px;
	background: #f1f1f1;
}
.penci-tiline
	.penci-tiline-item:nth-last-child(-n + 1)
	.penci-tiline-item-main-container {
	padding-bottom: 0;
}
.penci-tiline .penci-tiline-item:nth-last-child(-n + 1) .penci-tiline-line {
	display: none;
}
.penci-tiline-right .penci-tiline-item {
	margin-left: auto;
}
.penci-tiline-right .penci-tiline-item .penci-tiline-item-main-wrapper {
	padding-left: 0;
}
.penci-tiline-right
	.penci-tiline-item.left-part
	.penci-tiline-item-main-container,
.penci-tiline-right
	.penci-tiline-item.right-part
	.penci-tiline-item-main-container {
	padding-right: 50px;
	padding-left: 0;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-arrow,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-arrow {
	right: -8px;
	left: auto;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-line,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-line {
	right: 0;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-icon,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-icon {
	right: 0;
	left: auto;
}
.penci-tiline-right .penci-tiline-date {
	padding: 10px 50px;
}
.penci-tiline-icon svg {
	width: 1em;
	height: 1em;
}
.penci-tiline-desc {
	padding: 30px;
}
@media (max-width: 959px) {
	.penci-tiline-right .penci-tiline-item .penci-tiline-item-main-wrapper {
		padding-right: 55px;
	}
	.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-line,
	.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-line {
		right: 55px;
	}
	.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-icon,
	.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-icon {
		right: 55px;
		left: auto;
	}
}
@media (min-width: 960px) {
	.penci-tiline-center .penci-tiline-item .penci-tiline-item-main-wrapper {
		padding-left: 0;
	}
	.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-item-main-container {
		padding-right: 50px;
		padding-left: 0;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-arrow {
		right: -8px;
		left: auto;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-line {
		right: 0;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-icon {
		right: 0;
		left: auto;
	}
	.penci-tiline-center
		.penci-tiline-item.right-part
		.penci-tiline-item-main-container {
		padding-left: 50px;
		padding-right: 0;
	}
	.penci-tiline-center .penci-tiline-item.right-part .penci-tiline-icon {
		left: 0;
	}
	.penci-tiline-center .penci-tiline-date {
		padding: 5px 50px;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-child(-n + 2)
		.penci-tiline-item-main-container {
		padding-top: 0;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-child(-n + 2)
		.penci-tiline-icon {
		top: 22px;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-last-child(-n + 2)
		.penci-tiline-item-main-container {
		padding-bottom: 0;
	}
	.penci-tiline-archive.penci-tiline-center .penci-tiline-date {
		margin-top: 5px;
	}
}
.penci-tiline figcaption {
	margin-bottom: 0;
}
@keyframes fadeIn {
	0% {
		opacity: 0;
		top: 70px;
	}
	100% {
		opacity: 1;
		top: 0;
	}
}
@keyframes liftUp {
	0% {
		top: 0;
	}
	100% {
		top: -15px;
	}
}
.post-entry .penci-tiline-meta,
.post-entry .penci-tiline-meta li {
	margin: 0;
	padding: 0;
}
.penci-tiline-meta,
.post-entry .penci-tiline-meta {
	list-style: none;
	font-size: 13px;
	padding: 10px 0;
}
.penci-tiline-meta li:not(:last-child),
.post-entry .penci-tiline-meta li:not(:last-child) {
	margin-right: 20px;
}
.penci-tiline-readmore,
.post-entry .penci-tiline-readmore {
	padding: 5px 15px;
	display: inline-block;
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
	transition: 0.3 all ease-in-out;
	margin-top: 20px;
}
.penci-tiline-readmore:hover {
	opacity: 0.8;
}
.penci-tiline-item-date-wrap.right {
	text-align: right;
}
.penci-tiline .penci-tiline-icon span {
	background: #fff;
}
.penci-tiline .penci-tiline-date span {
	background: #1c1b1b;
	color: #fff;
	padding: 10px 15px;
	display: inline;
	box-decoration-break: clone;
  	-webkit-box-decoration-break: clone;
}
.penci-tiline-item--top .penci-tiline-content:after {
	border-top-color: #f1f1f1;
}
.penci-tiline-item--bottom .penci-tiline-content:after {
	border-bottom-color: #f1f1f1;
}
.penci-tiline--mobile .penci-tiline-content:after {
	border-right-color: #f1f1f1;
}
@media only screen and (max-width: 960px) {
	.penci-tiline-align-center .penci-tiline-item {
		width: 100%;
	}
	.penci-tiline-align-center .penci-tiline-item-date-wrap {
		display: none;
	}
	.penci-tiline .penci-tiline-item-main-wrapper {
		padding: 0;
	}
	.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
		left: 0;
	}
}
.penci-tiline {
	padding-top: 30px;
}
.penci-tiline-archive {
	padding-top: 60px;
	padding-bottom: 60px;
}
.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line {
	top: -30px;
	height: calc(100% + 30px);
}
.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line:before {
	width: 10px;
	height: 10px;
	content: "";
	background: var(--pcborder-cl);
	top: -20px;
	position: absolute;
	transform: translateX(-50%);
	z-index: 9;
	border-radius: 50%;
}
.penci-tiline-meta a,
.post-entry .penci-tiline-meta a {
	color: var(--pcheading-cl);
	text-decoration: none;
}
.post-entry .penci-tiline-item a {
	text-decoration: none;
}
.penci-tiline .penci-biggrid-wrapper .pcbg-content-inner {
	background: #fff;
}
.penci-tiline .penci-biggrid-wrapper,
.penci-tiline .penci-bgstyle-1 .penci-dflex .penci-bgitem {
	margin-bottom: 0;
}
.penci-tiline-item .pcbg-readmorebtn svg {
	max-height: 15px;
	width: auto;
}
@media (min-width: 960px) {
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-line {
		right: auto;
		left: 0;
	}
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-icon {
		right: auto;
		left: 0;
	}
	body.rtl .penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
		transform: translate(50%, 50%);
		top: 0;
	}
	body.rtl
		.penci-tiline
		.penci-tiline-item-main-wrapper
		.penci-tiline-icon
		span {
		transform: translate(50%, 0%);
	}
	body.rtl
		.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-item-main-container {
		padding-right: 0;
		padding-left: 50px;
	}
	body.rtl .penci-tiline-center .penci-tiline-item.right-part .penci-tiline-icon {
		left: auto;
		right: 0;
	}
	body.rtl .penci-tiline-center
		.penci-tiline-item.right-part
		.penci-tiline-item-main-container {
		padding-left: 0;
		padding-right: 50px;
	}
}
body.rtl .penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line span,
body.rtl
	.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line::before {
	transform: translateX(50%);
}
body.rtl .penci-tiline-item-date-wrap.right {
	text-align: left;
}
body.rtl .penci-tiline-meta li:not(:last-child),
body.rtl .post-entry .penci-tiline-meta li:not(:last-child) {
	margin-right: 0;
	margin-left: 20px;
}