.mfp-bg {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 9999999;
	overflow: hidden;
	position: fixed;
	background: #0b0b0b;
	opacity: .8
}
.mfp-wrap {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 9999999;
	position: fixed;
	outline: 0 !important;
	-webkit-backface-visibility: hidden
}
.mfp-container {
	text-align: center;
	position: absolute;
	width: 100%;
	height: 100%;
	left: 0;
	top: 0;
	padding: 0 8px;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box
}
.mfp-container:before {
	content: "";
	display: inline-block;
	height: 100%;
	vertical-align: middle
}
.mfp-align-top .mfp-container:before {
	display: none
}
.mfp-content {
	position: relative;
	display: inline-block;
	vertical-align: middle;
	margin: 0 auto;
	text-align: left;
	z-index: 1045
}
.mfp-ajax-holder .mfp-content,
.mfp-inline-holder .mfp-content {
	width: 100%;
	cursor: auto
}
.mfp-ajax-cur {
	cursor: progress
}
.mfp-zoom-out-cur,
.mfp-zoom-out-cur .mfp-image-holder .mfp-close {
	cursor: -moz-zoom-out;
	cursor: -webkit-zoom-out;
	cursor: zoom-out
}
.mfp-zoom {
	cursor: pointer;
	cursor: -webkit-zoom-in;
	cursor: -moz-zoom-in;
	cursor: zoom-in
}
.mfp-auto-cursor .mfp-content {
	cursor: auto
}
.mfp-arrow,
.mfp-close,
.mfp-counter,
.mfp-preloader {
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none
}
.mfp-loading.mfp-figure {
	display: none
}
.mfp-hide {
	display: none !important
}
.mfp-preloader {
	color: #ccc;
	position: absolute;
	top: 50%;
	width: auto;
	text-align: center;
	margin-top: -.8em;
	left: 8px;
	right: 8px;
	z-index: 1044
}
.mfp-preloader a {
	color: #ccc
}
.mfp-preloader a:hover {
	color: #fff
}
.mfp-s-ready .mfp-preloader {
	display: none
}
.mfp-s-error .mfp-content {
	display: none
}
button.mfp-arrow,
button.mfp-close {
	overflow: visible;
	cursor: pointer;
	background: 0 0;
	border: 0;
	-webkit-appearance: none;
	display: block;
	outline: 0;
	padding: 0;
	z-index: 1046;
	-webkit-box-shadow: none;
	box-shadow: none;
	position: absolute
}
button.mfp-arrow,
button.mfp-close {
	font-size: 28px
}
button::-moz-focus-inner {
	padding: 0;
	border: 0
}
button.mfp-close {
	width: 44px;
	height: 44px;
	line-height: 44px;
	position: absolute;
	right: 0;
	top: 0;
	text-decoration: none;
	text-align: center;
	opacity: .65;
	padding: 0 0 18px 10px;
	color: #fff;
	font-style: normal;
	font-size: 30px;
	font-family: Arial, Baskerville, monospace
}
.mfp-close:focus,
.mfp-close:hover {
	opacity: 1
}
.mfp-close:active {
	top: 1px
}
.mfp-close-btn-in .mfp-close {
	color: #333;
	font-size: 28px
}
.mfp-iframe-holder .mfp-close,
.mfp-image-holder .mfp-close {
	color: #fff;
	right: -6px;
	text-align: right;
	padding-right: 6px;
	width: 100%
}
.mfp-counter {
	position: absolute;
	top: 0;
	right: 0;
	color: #ccc;
	font-size: 12px;
	line-height: 18px
}
.mfp-arrow {
	position: absolute;
	opacity: .65;
	margin: 0;
	top: 50%;
	margin-top: -55px;
	padding: 0;
	width: 90px;
	height: 110px;
	-webkit-tap-highlight-color: transparent
}
.mfp-arrow:active {
	margin-top: -54px
}
.mfp-arrow:focus,
.mfp-arrow:hover {
	opacity: 1
}
.mfp-arrow .mfp-a,
.mfp-arrow .mfp-b,
.mfp-arrow:after,
.mfp-arrow:before {
	content: "";
	display: block;
	width: 0;
	height: 0;
	position: absolute;
	left: 0;
	top: 0;
	margin-top: 35px;
	margin-left: 35px;
	border: medium inset transparent
}
.mfp-arrow .mfp-a,
.mfp-arrow:after {
	border-top-width: 13px;
	border-bottom-width: 13px;
	top: 8px
}
.mfp-arrow .mfp-b,
.mfp-arrow:before {
	border-top-width: 21px;
	border-bottom-width: 21px;
	opacity: .7
}
.mfp-arrow-left {
	left: 0
}
.mfp-arrow-left .mfp-a,
.mfp-arrow-left:after {
	border-right: 17px solid #fff;
	margin-left: 31px
}
.mfp-arrow-left .mfp-b,
.mfp-arrow-left:before {
	margin-left: 25px;
	border-right: 27px solid #3f3f3f
}
.mfp-arrow-right {
	right: 0
}
.mfp-arrow-right .mfp-a,
.mfp-arrow-right:after {
	border-left: 17px solid #fff;
	margin-left: 39px
}
.mfp-arrow-right .mfp-b,
.mfp-arrow-right:before {
	border-left: 27px solid #3f3f3f
}
.mfp-iframe-holder {
	padding-top: 40px;
	padding-bottom: 40px
}
.mfp-iframe-holder .mfp-content {
	line-height: 0;
	width: 100%;
	max-width: 1200px
}
.mfp-iframe-holder .mfp-close {
	top: -40px
}
.mfp-iframe-scaler {
	width: 100%;
	height: 0;
	overflow: hidden;
	padding-top: 56.25%
}
.mfp-iframe-scaler iframe {
	position: absolute;
	display: block;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	box-shadow: 0 0 8px rgba(0, 0, 0, .6);
	background: #000
}
img.mfp-img {
	width: auto;
	max-width: 100%;
	height: auto;
	display: block;
	line-height: 0;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	padding: 40px 0;
	margin: 0 auto
}
.mfp-figure {
	line-height: 0
}
.mfp-figure:after {
	content: "";
	position: absolute;
	left: 0;
	top: 40px;
	bottom: 40px;
	display: block;
	right: 0;
	width: auto;
	height: auto;
	z-index: -1;
	box-shadow: 0 0 8px rgba(0, 0, 0, .6);
	background: #444
}
.mfp-figure small {
	color: #bdbdbd;
	display: block;
	font-size: 12px;
	line-height: 14px
}
.mfp-figure figure {
	margin: 0
}
.mfp-bottom-bar {
	margin-top: -36px;
	position: absolute;
	top: 100%;
	left: 0;
	width: 100%;
	cursor: auto
}
.mfp-title {
	text-align: left;
	line-height: 18px;
	color: #f3f3f3;
	word-wrap: break-word;
	padding-right: 36px
}
.mfp-image-holder .mfp-content {
	max-width: 100%
}
.mfp-gallery .mfp-image-holder .mfp-figure {
	cursor: pointer
}
@media screen and (max-width:800px) and (orientation:landscape), screen and (max-height:300px) {
	.mfp-img-mobile .mfp-image-holder {
		padding-left: 0;
		padding-right: 0
	}
	.mfp-img-mobile img.mfp-img {
		padding: 0
	}
	.mfp-img-mobile .mfp-figure:after {
		top: 0;
		bottom: 0
	}
	.mfp-img-mobile .mfp-figure small {
		display: inline;
		margin-left: 5px
	}
	.mfp-img-mobile .mfp-bottom-bar {
		background: rgba(0, 0, 0, .6);
		bottom: 0;
		margin: 0;
		top: auto;
		padding: 3px 5px;
		position: fixed;
		-webkit-box-sizing: border-box;
		-moz-box-sizing: border-box;
		box-sizing: border-box
	}
	.mfp-img-mobile .mfp-bottom-bar:empty {
		padding: 0
	}
	.mfp-img-mobile .mfp-counter {
		right: 5px;
		top: 3px
	}
	.mfp-img-mobile .mfp-close {
		top: 0;
		right: 0;
		width: 35px;
		height: 35px;
		line-height: 35px;
		background: rgba(0, 0, 0, .6);
		position: fixed;
		text-align: center;
		padding: 0
	}
}
@media all and (max-width:900px) {
	.mfp-arrow {
		-webkit-transform: scale(.75);
		transform: scale(.75)
	}
	.mfp-arrow-left {
		-webkit-transform-origin: 0;
		transform-origin: 0
	}
	.mfp-arrow-right {
		-webkit-transform-origin: 100%;
		transform-origin: 100%
	}
	.mfp-container {
		padding-left: 6px;
		padding-right: 6px
	}
}
.mfp-ie7 .mfp-img {
	padding: 0
}
.mfp-ie7 .mfp-bottom-bar {
	width: 600px;
	left: 50%;
	margin-left: -300px;
	margin-top: 5px;
	padding-bottom: 5px
}
.mfp-ie7 .mfp-container {
	padding: 0
}
.mfp-ie7 .mfp-content {
	padding-top: 44px
}
.mfp-ie7 .mfp-close {
	top: 0;
	right: 0;
	padding-top: 0
}
.mfp-ani-wrap .mfp-with-anim .summary-inner {
	opacity: 0;
	transition: transform .3s ease, opacity .3s ease;
	transform: translateX(30px)
}
.mfp-ani-wrap.mfp-bg {
	opacity: 0;
	transition: opacity .25s ease, visibility 0s ease .25s
}
.mfp-ani-wrap.mfp-ready.mfp-bg {
	opacity: .75;
	transition: opacity .25s ease, visibility 0s ease
}
.mfp-ani-wrap .mfp-with-anim {
	opacity: 0;
	transition: transform .3s ease, opacity .3s ease
}
.mfp-ani-wrap.mfp-removing .mfp-close {
	display: none
}
.mfp-ani-wrap .mfp-with-anim.move-to-top {
	transform: translateY(100px)
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim.move-to-top {
	transform: translateY(-100px)
}
.mfp-ani-wrap .mfp-with-anim.move-to-bottom {
	transform: translateY(-100px)
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim.move-to-bottom {
	transform: translateY(100px)
}
.mfp-ani-wrap .mfp-with-anim.move-to-left {
	transform: translateX(100px)
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim.move-to-left {
	transform: translateX(-100px)
}
.mfp-ani-wrap .mfp-with-anim.move-to-right {
	transform: translateX(-100px)
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim.move-to-right {
	transform: translateX(100px)
}
.mfp-ani-wrap .mfp-with-anim.zoomin {
	transform: scale(.8)
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim.zoomin {
	transform: scale(1)
}
.mfp-ani-wrap.mfp-ready .mfp-with-anim,
.mfp-ani-wrap.mfp-ready .mfp-with-anim .summary-inner {
	opacity: 1;
	transform: none
}
.mfp-ani-wrap.mfp-removing .mfp-with-anim {
	opacity: 0
}
.mfp-ani-wrap.mfp-removing.mfp-bg {
	opacity: 0
}
.mfp-ani-wrap .bottom-left,
.mfp-ani-wrap .middle-left,
.mfp-ani-wrap .top-left {
	margin-left: 0
}
.mfp-ani-wrap.bottom-left .mfp-container,
.mfp-ani-wrap.middle-left .mfp-container,
.mfp-ani-wrap.top-left .mfp-container {
	margin-left: 0;
	padding-left: 0
}
.mfp-ani-wrap .bottom-right,
.mfp-ani-wrap .middle-right,
.mfp-ani-wrap .top-right {
	margin-right: 0
}
.mfp-ani-wrap.bottom-right .mfp-container,
.mfp-ani-wrap.middle-right .mfp-container,
.mfp-ani-wrap.top-right .mfp-container {
	margin-right: 0;
	padding-right: 0
}
.mfp-ani-wrap.bottom-center .mfp-container,
.mfp-ani-wrap.bottom-left .mfp-container,
.mfp-ani-wrap.bottom-right .mfp-container,
.mfp-ani-wrap.top-center .mfp-container,
.mfp-ani-wrap.top-left .mfp-container,
.mfp-ani-wrap.top-right .mfp-container {
	height: unset
}
.mfp-ani-wrap.top-center .mfp-container,
.mfp-ani-wrap.top-left .mfp-container,
.mfp-ani-wrap.top-right .mfp-container {
	top: 0;
	left: 0
}
.mfp-ani-wrap.bottom-center .mfp-container,
.mfp-ani-wrap.bottom-left .mfp-container,
.mfp-ani-wrap.bottom-right .mfp-container {
	top: auto;
	bottom: 0
}
.penci-owl-carousel .animated {
	-webkit-animation-duration: 1s;
	animation-duration: 1s;
	-webkit-animation-fill-mode: both;
	animation-fill-mode: both
}
.penci-owl-carousel .owl-animated-in {
	z-index: 0
}
.penci-owl-carousel .owl-animated-out {
	z-index: 1
}
.penci-owl-carousel .fadeOut {
	-webkit-animation-name: fadeOut;
	animation-name: fadeOut
}
@-webkit-keyframes fadeOut {
	0% {
		opacity: 1
	}
	100% {
		opacity: 0
	}
}
@keyframes fadeOut {
	0% {
		opacity: 1
	}
	100% {
		opacity: 0
	}
}
.owl-height {
	-webkit-transition: height .5s ease-in-out;
	-moz-transition: height .5s ease-in-out;
	-ms-transition: height .5s ease-in-out;
	-o-transition: height .5s ease-in-out;
	transition: height .5s ease-in-out
}
.penci-owl-carousel {
	display: block;
	width: 100%;
	-webkit-tap-highlight-color: transparent;
	position: relative;
	z-index: 1;
	--pcfs-delay: 0.5s
}
.penci-owl-carousel .penci-owl-dot,
.penci-owl-carousel .penci-owl-nav .owl-next,
.penci-owl-carousel .penci-owl-nav .owl-prev {
	cursor: pointer;
	cursor: hand;
	-webkit-user-select: none;
	-khtml-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none
}
.penci-owl-carousel.penci-owl-loaded {
	display: block
}
.penci-owl-carousel.owl-loading {
	opacity: 0;
	display: block
}
.penci-owl-carousel.owl-hidden {
	opacity: 0
}
.penci-owl-carousel .owl-refresh .owl-item {
	display: none
}
.penci-owl-carousel.owl-rtl {
	direction: rtl
}
.penci-owl-carousel.owl-rtl .owl-item {
	float: right
}
.animated {
	-webkit-animation-duration: 1s;
	animation-duration: 1s;
	-webkit-animation-fill-mode: both;
	animation-fill-mode: both
}
.animated.infinite {
	-webkit-animation-iteration-count: infinite;
	animation-iteration-count: infinite
}
.animated.hinge {
	-webkit-animation-duration: 2s;
	animation-duration: 2s
}
.animated.bounceIn,
.animated.bounceOut,
.animated.flipOutX,
.animated.flipOutY {
	-webkit-animation-duration: .75s;
	animation-duration: .75s
}
@-webkit-keyframes bounce {
	20%,
	53%,
	80%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	40%,
	43% {
		-webkit-animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		-webkit-transform: translate3d(0, -30px, 0);
		transform: translate3d(0, -30px, 0)
	}
	70% {
		-webkit-animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		-webkit-transform: translate3d(0, -15px, 0);
		transform: translate3d(0, -15px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, -4px, 0);
		transform: translate3d(0, -4px, 0)
	}
}
@keyframes bounce {
	20%,
	53%,
	80%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	40%,
	43% {
		-webkit-animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		-webkit-transform: translate3d(0, -30px, 0);
		transform: translate3d(0, -30px, 0)
	}
	70% {
		-webkit-animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		animation-timing-function: cubic-bezier(.755, .05, .855, .06);
		-webkit-transform: translate3d(0, -15px, 0);
		transform: translate3d(0, -15px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, -4px, 0);
		transform: translate3d(0, -4px, 0)
	}
}
.bounce {
	-webkit-animation-name: bounce;
	animation-name: bounce;
	-webkit-transform-origin: center bottom;
	transform-origin: center bottom
}
@-webkit-keyframes flash {
	50%,
	from,
	to {
		opacity: 1
	}
	25%,
	75% {
		opacity: 0
	}
}
@keyframes flash {
	50%,
	from,
	to {
		opacity: 1
	}
	25%,
	75% {
		opacity: 0
	}
}
.flash {
	-webkit-animation-name: flash;
	animation-name: flash
}
@-webkit-keyframes pulse {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	50% {
		-webkit-transform: scale3d(1.05, 1.05, 1.05);
		transform: scale3d(1.05, 1.05, 1.05)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
@keyframes pulse {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	50% {
		-webkit-transform: scale3d(1.05, 1.05, 1.05);
		transform: scale3d(1.05, 1.05, 1.05)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
.pulse {
	-webkit-animation-name: pulse;
	animation-name: pulse
}
@-webkit-keyframes rubberBand {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	30% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	40% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	75% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
@keyframes rubberBand {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	30% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	40% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	75% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
.rubberBand {
	-webkit-animation-name: rubberBand;
	animation-name: rubberBand
}
@-webkit-keyframes shake {
	from,
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	10%,
	30%,
	50%,
	70%,
	90% {
		-webkit-transform: translate3d(-10px, 0, 0);
		transform: translate3d(-10px, 0, 0)
	}
	20%,
	40%,
	60%,
	80% {
		-webkit-transform: translate3d(10px, 0, 0);
		transform: translate3d(10px, 0, 0)
	}
}
@keyframes shake {
	from,
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	10%,
	30%,
	50%,
	70%,
	90% {
		-webkit-transform: translate3d(-10px, 0, 0);
		transform: translate3d(-10px, 0, 0)
	}
	20%,
	40%,
	60%,
	80% {
		-webkit-transform: translate3d(10px, 0, 0);
		transform: translate3d(10px, 0, 0)
	}
}
.shake {
	-webkit-animation-name: shake;
	animation-name: shake
}
@-webkit-keyframes headShake {
	0% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	6.5% {
		-webkit-transform: translateX(-6px) rotateY(-9deg);
		transform: translateX(-6px) rotateY(-9deg)
	}
	18.5% {
		-webkit-transform: translateX(5px) rotateY(7deg);
		transform: translateX(5px) rotateY(7deg)
	}
	31.5% {
		-webkit-transform: translateX(-3px) rotateY(-5deg);
		transform: translateX(-3px) rotateY(-5deg)
	}
	43.5% {
		-webkit-transform: translateX(2px) rotateY(3deg);
		transform: translateX(2px) rotateY(3deg)
	}
	50% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@keyframes headShake {
	0% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	6.5% {
		-webkit-transform: translateX(-6px) rotateY(-9deg);
		transform: translateX(-6px) rotateY(-9deg)
	}
	18.5% {
		-webkit-transform: translateX(5px) rotateY(7deg);
		transform: translateX(5px) rotateY(7deg)
	}
	31.5% {
		-webkit-transform: translateX(-3px) rotateY(-5deg);
		transform: translateX(-3px) rotateY(-5deg)
	}
	43.5% {
		-webkit-transform: translateX(2px) rotateY(3deg);
		transform: translateX(2px) rotateY(3deg)
	}
	50% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
.headShake {
	-webkit-animation-timing-function: ease-in-out;
	animation-timing-function: ease-in-out;
	-webkit-animation-name: headShake;
	animation-name: headShake
}
@-webkit-keyframes swing {
	20% {
		-webkit-transform: rotate3d(0, 0, 1, 15deg);
		transform: rotate3d(0, 0, 1, 15deg)
	}
	40% {
		-webkit-transform: rotate3d(0, 0, 1, -10deg);
		transform: rotate3d(0, 0, 1, -10deg)
	}
	60% {
		-webkit-transform: rotate3d(0, 0, 1, 5deg);
		transform: rotate3d(0, 0, 1, 5deg)
	}
	80% {
		-webkit-transform: rotate3d(0, 0, 1, -5deg);
		transform: rotate3d(0, 0, 1, -5deg)
	}
	to {
		-webkit-transform: rotate3d(0, 0, 1, 0deg);
		transform: rotate3d(0, 0, 1, 0deg)
	}
}
@keyframes swing {
	20% {
		-webkit-transform: rotate3d(0, 0, 1, 15deg);
		transform: rotate3d(0, 0, 1, 15deg)
	}
	40% {
		-webkit-transform: rotate3d(0, 0, 1, -10deg);
		transform: rotate3d(0, 0, 1, -10deg)
	}
	60% {
		-webkit-transform: rotate3d(0, 0, 1, 5deg);
		transform: rotate3d(0, 0, 1, 5deg)
	}
	80% {
		-webkit-transform: rotate3d(0, 0, 1, -5deg);
		transform: rotate3d(0, 0, 1, -5deg)
	}
	to {
		-webkit-transform: rotate3d(0, 0, 1, 0deg);
		transform: rotate3d(0, 0, 1, 0deg)
	}
}
.swing {
	-webkit-transform-origin: top center;
	transform-origin: top center;
	-webkit-animation-name: swing;
	animation-name: swing
}
@-webkit-keyframes tada {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	10%,
	20% {
		-webkit-transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
		transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg)
	}
	30%,
	50%,
	70%,
	90% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
		transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)
	}
	40%,
	60%,
	80% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
		transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
@keyframes tada {
	from {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
	10%,
	20% {
		-webkit-transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg);
		transform: scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg)
	}
	30%,
	50%,
	70%,
	90% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
		transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)
	}
	40%,
	60%,
	80% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
		transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg)
	}
	to {
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
.tada {
	-webkit-animation-name: tada;
	animation-name: tada
}
@-webkit-keyframes wobble {
	from {
		-webkit-transform: none;
		transform: none
	}
	15% {
		-webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
		transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg)
	}
	30% {
		-webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
		transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg)
	}
	45% {
		-webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
		transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg)
	}
	60% {
		-webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
		transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg)
	}
	75% {
		-webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
		transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
@keyframes wobble {
	from {
		-webkit-transform: none;
		transform: none
	}
	15% {
		-webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
		transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg)
	}
	30% {
		-webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
		transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg)
	}
	45% {
		-webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
		transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg)
	}
	60% {
		-webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
		transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg)
	}
	75% {
		-webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
		transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
.wobble {
	-webkit-animation-name: wobble;
	animation-name: wobble
}
@-webkit-keyframes jello {
	11.1%,
	from,
	to {
		-webkit-transform: none;
		transform: none
	}
	22.2% {
		-webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
		transform: skewX(-12.5deg) skewY(-12.5deg)
	}
	33.3% {
		-webkit-transform: skewX(6.25deg) skewY(6.25deg);
		transform: skewX(6.25deg) skewY(6.25deg)
	}
	44.4% {
		-webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
		transform: skewX(-3.125deg) skewY(-3.125deg)
	}
	55.5% {
		-webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
		transform: skewX(1.5625deg) skewY(1.5625deg)
	}
	66.6% {
		-webkit-transform: skewX(-.78125deg) skewY(-.78125deg);
		transform: skewX(-.78125deg) skewY(-.78125deg)
	}
	77.7% {
		-webkit-transform: skewX(.390625deg) skewY(.390625deg);
		transform: skewX(.390625deg) skewY(.390625deg)
	}
	88.8% {
		-webkit-transform: skewX(-.1953125deg) skewY(-.1953125deg);
		transform: skewX(-.1953125deg) skewY(-.1953125deg)
	}
}
@keyframes jello {
	11.1%,
	from,
	to {
		-webkit-transform: none;
		transform: none
	}
	22.2% {
		-webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
		transform: skewX(-12.5deg) skewY(-12.5deg)
	}
	33.3% {
		-webkit-transform: skewX(6.25deg) skewY(6.25deg);
		transform: skewX(6.25deg) skewY(6.25deg)
	}
	44.4% {
		-webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
		transform: skewX(-3.125deg) skewY(-3.125deg)
	}
	55.5% {
		-webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
		transform: skewX(1.5625deg) skewY(1.5625deg)
	}
	66.6% {
		-webkit-transform: skewX(-.78125deg) skewY(-.78125deg);
		transform: skewX(-.78125deg) skewY(-.78125deg)
	}
	77.7% {
		-webkit-transform: skewX(.390625deg) skewY(.390625deg);
		transform: skewX(.390625deg) skewY(.390625deg)
	}
	88.8% {
		-webkit-transform: skewX(-.1953125deg) skewY(-.1953125deg);
		transform: skewX(-.1953125deg) skewY(-.1953125deg)
	}
}
.jello {
	-webkit-animation-name: jello;
	animation-name: jello;
	-webkit-transform-origin: center;
	transform-origin: center
}
@-webkit-keyframes bounceIn {
	20%,
	40%,
	60%,
	80%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03)
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97)
	}
	to {
		opacity: 1;
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
@keyframes bounceIn {
	20%,
	40%,
	60%,
	80%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03)
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97)
	}
	to {
		opacity: 1;
		-webkit-transform: scale3d(1, 1, 1);
		transform: scale3d(1, 1, 1)
	}
}
.bounceIn {
	-webkit-animation-name: bounceIn;
	animation-name: bounceIn
}
@-webkit-keyframes bounceInDown {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -3000px, 0);
		transform: translate3d(0, -3000px, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(0, 25px, 0);
		transform: translate3d(0, 25px, 0)
	}
	75% {
		-webkit-transform: translate3d(0, -10px, 0);
		transform: translate3d(0, -10px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, 5px, 0);
		transform: translate3d(0, 5px, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
@keyframes bounceInDown {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -3000px, 0);
		transform: translate3d(0, -3000px, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(0, 25px, 0);
		transform: translate3d(0, 25px, 0)
	}
	75% {
		-webkit-transform: translate3d(0, -10px, 0);
		transform: translate3d(0, -10px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, 5px, 0);
		transform: translate3d(0, 5px, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
.bounceInDown {
	-webkit-animation-name: bounceInDown;
	animation-name: bounceInDown
}
@-webkit-keyframes bounceInLeft {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-3000px, 0, 0);
		transform: translate3d(-3000px, 0, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(25px, 0, 0);
		transform: translate3d(25px, 0, 0)
	}
	75% {
		-webkit-transform: translate3d(-10px, 0, 0);
		transform: translate3d(-10px, 0, 0)
	}
	90% {
		-webkit-transform: translate3d(5px, 0, 0);
		transform: translate3d(5px, 0, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
@keyframes bounceInLeft {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-3000px, 0, 0);
		transform: translate3d(-3000px, 0, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(25px, 0, 0);
		transform: translate3d(25px, 0, 0)
	}
	75% {
		-webkit-transform: translate3d(-10px, 0, 0);
		transform: translate3d(-10px, 0, 0)
	}
	90% {
		-webkit-transform: translate3d(5px, 0, 0);
		transform: translate3d(5px, 0, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
.bounceInLeft {
	-webkit-animation-name: bounceInLeft;
	animation-name: bounceInLeft
}
@-webkit-keyframes bounceInRight {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	from {
		opacity: 0;
		-webkit-transform: translate3d(3000px, 0, 0);
		transform: translate3d(3000px, 0, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(-25px, 0, 0);
		transform: translate3d(-25px, 0, 0)
	}
	75% {
		-webkit-transform: translate3d(10px, 0, 0);
		transform: translate3d(10px, 0, 0)
	}
	90% {
		-webkit-transform: translate3d(-5px, 0, 0);
		transform: translate3d(-5px, 0, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
@keyframes bounceInRight {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	from {
		opacity: 0;
		-webkit-transform: translate3d(3000px, 0, 0);
		transform: translate3d(3000px, 0, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(-25px, 0, 0);
		transform: translate3d(-25px, 0, 0)
	}
	75% {
		-webkit-transform: translate3d(10px, 0, 0);
		transform: translate3d(10px, 0, 0)
	}
	90% {
		-webkit-transform: translate3d(-5px, 0, 0);
		transform: translate3d(-5px, 0, 0)
	}
	to {
		-webkit-transform: none;
		transform: none
	}
}
.bounceInRight {
	-webkit-animation-name: bounceInRight;
	animation-name: bounceInRight
}
@-webkit-keyframes bounceInUp {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 3000px, 0);
		transform: translate3d(0, 3000px, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(0, -20px, 0);
		transform: translate3d(0, -20px, 0)
	}
	75% {
		-webkit-transform: translate3d(0, 10px, 0);
		transform: translate3d(0, 10px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, -5px, 0);
		transform: translate3d(0, -5px, 0)
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
@keyframes bounceInUp {
	60%,
	75%,
	90%,
	from,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 3000px, 0);
		transform: translate3d(0, 3000px, 0)
	}
	60% {
		opacity: 1;
		-webkit-transform: translate3d(0, -20px, 0);
		transform: translate3d(0, -20px, 0)
	}
	75% {
		-webkit-transform: translate3d(0, 10px, 0);
		transform: translate3d(0, 10px, 0)
	}
	90% {
		-webkit-transform: translate3d(0, -5px, 0);
		transform: translate3d(0, -5px, 0)
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
.bounceInUp {
	-webkit-animation-name: bounceInUp;
	animation-name: bounceInUp
}
@-webkit-keyframes bounceOut {
	20% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	50%,
	55% {
		opacity: 1;
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
}
@keyframes bounceOut {
	20% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	50%,
	55% {
		opacity: 1;
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
}
.bounceOut {
	-webkit-animation-name: bounceOut;
	animation-name: bounceOut
}
@-webkit-keyframes bounceOutDown {
	20% {
		-webkit-transform: translate3d(0, 10px, 0);
		transform: translate3d(0, 10px, 0)
	}
	40%,
	45% {
		opacity: 1;
		-webkit-transform: translate3d(0, -20px, 0);
		transform: translate3d(0, -20px, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
}
@keyframes bounceOutDown {
	20% {
		-webkit-transform: translate3d(0, 10px, 0);
		transform: translate3d(0, 10px, 0)
	}
	40%,
	45% {
		opacity: 1;
		-webkit-transform: translate3d(0, -20px, 0);
		transform: translate3d(0, -20px, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
}
.bounceOutDown {
	-webkit-animation-name: bounceOutDown;
	animation-name: bounceOutDown
}
@-webkit-keyframes bounceOutLeft {
	20% {
		opacity: 1;
		-webkit-transform: translate3d(20px, 0, 0);
		transform: translate3d(20px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
}
@keyframes bounceOutLeft {
	20% {
		opacity: 1;
		-webkit-transform: translate3d(20px, 0, 0);
		transform: translate3d(20px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
}
.bounceOutLeft {
	-webkit-animation-name: bounceOutLeft;
	animation-name: bounceOutLeft
}
@-webkit-keyframes bounceOutRight {
	20% {
		opacity: 1;
		-webkit-transform: translate3d(-20px, 0, 0);
		transform: translate3d(-20px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
}
@keyframes bounceOutRight {
	20% {
		opacity: 1;
		-webkit-transform: translate3d(-20px, 0, 0);
		transform: translate3d(-20px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
}
.bounceOutRight {
	-webkit-animation-name: bounceOutRight;
	animation-name: bounceOutRight
}
@-webkit-keyframes bounceOutUp {
	20% {
		-webkit-transform: translate3d(0, -10px, 0);
		transform: translate3d(0, -10px, 0)
	}
	40%,
	45% {
		opacity: 1;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
}
@keyframes bounceOutUp {
	20% {
		-webkit-transform: translate3d(0, -10px, 0);
		transform: translate3d(0, -10px, 0)
	}
	40%,
	45% {
		opacity: 1;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
}
.bounceOutUp {
	-webkit-animation-name: bounceOutUp;
	animation-name: bounceOutUp
}
@-webkit-keyframes fadeIn {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
@keyframes fadeIn {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
.fadeIn {
	-webkit-animation-name: fadeIn;
	animation-name: fadeIn
}
@-webkit-keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInDown {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInDown {
	-webkit-animation-name: fadeInDown;
	animation-name: fadeInDown
}
@-webkit-keyframes fadeInDownBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInDownBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInDownBig {
	-webkit-animation-name: fadeInDownBig;
	animation-name: fadeInDownBig
}
@-webkit-keyframes fadeInLeft {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInLeft {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInLeft {
	-webkit-animation-name: fadeInLeft;
	animation-name: fadeInLeft
}
@-webkit-keyframes fadeInLeftBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInLeftBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInLeftBig {
	-webkit-animation-name: fadeInLeftBig;
	animation-name: fadeInLeftBig
}
@-webkit-keyframes fadeInRight {
	from {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInRight {
	from {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInRight {
	-webkit-animation-name: fadeInRight;
	animation-name: fadeInRight
}
@-webkit-keyframes fadeInRightBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInRightBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInRightBig {
	-webkit-animation-name: fadeInRightBig;
	animation-name: fadeInRightBig
}
@-webkit-keyframes fadeInUp {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInUp {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInUp {
	-webkit-animation-name: fadeInUp;
	animation-name: fadeInUp
}
@-webkit-keyframes fadeInUpBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInUpBig {
	from {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.fadeInUpBig {
	-webkit-animation-name: fadeInUpBig;
	animation-name: fadeInUpBig
}
@-webkit-keyframes fadeOut {
	from {
		opacity: 1
	}
	to {
		opacity: 0
	}
}
@keyframes fadeOut {
	from {
		opacity: 1
	}
	to {
		opacity: 0
	}
}
.fadeOut {
	-webkit-animation-name: fadeOut;
	animation-name: fadeOut
}
@-webkit-keyframes fadeOutDown {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
}
@keyframes fadeOutDown {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
}
.fadeOutDown {
	-webkit-animation-name: fadeOutDown;
	animation-name: fadeOutDown
}
@-webkit-keyframes fadeOutDownBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
}
@keyframes fadeOutDownBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, 2000px, 0);
		transform: translate3d(0, 2000px, 0)
	}
}
.fadeOutDownBig {
	-webkit-animation-name: fadeOutDownBig;
	animation-name: fadeOutDownBig
}
@-webkit-keyframes fadeOutLeft {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
}
@keyframes fadeOutLeft {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
}
.fadeOutLeft {
	-webkit-animation-name: fadeOutLeft;
	animation-name: fadeOutLeft
}
@-webkit-keyframes fadeOutLeftBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
}
@keyframes fadeOutLeftBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(-2000px, 0, 0);
		transform: translate3d(-2000px, 0, 0)
	}
}
.fadeOutLeftBig {
	-webkit-animation-name: fadeOutLeftBig;
	animation-name: fadeOutLeftBig
}
@-webkit-keyframes fadeOutRight {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
}
@keyframes fadeOutRight {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
}
.fadeOutRight {
	-webkit-animation-name: fadeOutRight;
	animation-name: fadeOutRight
}
@-webkit-keyframes fadeOutRightBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
}
@keyframes fadeOutRightBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(2000px, 0, 0);
		transform: translate3d(2000px, 0, 0)
	}
}
.fadeOutRightBig {
	-webkit-animation-name: fadeOutRightBig;
	animation-name: fadeOutRightBig
}
@-webkit-keyframes fadeOutUp {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
}
@keyframes fadeOutUp {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
}
.fadeOutUp {
	-webkit-animation-name: fadeOutUp;
	animation-name: fadeOutUp
}
@-webkit-keyframes fadeOutUpBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
}
@keyframes fadeOutUpBig {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(0, -2000px, 0);
		transform: translate3d(0, -2000px, 0)
	}
}
.fadeOutUpBig {
	-webkit-animation-name: fadeOutUpBig;
	animation-name: fadeOutUpBig
}
@-webkit-keyframes flip {
	from {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
		-webkit-animation-timing-function: ease-out;
		animation-timing-function: ease-out
	}
	40% {
		-webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
		transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
		-webkit-animation-timing-function: ease-out;
		animation-timing-function: ease-out
	}
	50% {
		-webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
		transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	80% {
		-webkit-transform: perspective(400px) scale3d(.95, .95, .95);
		transform: perspective(400px) scale3d(.95, .95, .95);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
}
@keyframes flip {
	from {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
		-webkit-animation-timing-function: ease-out;
		animation-timing-function: ease-out
	}
	40% {
		-webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
		transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
		-webkit-animation-timing-function: ease-out;
		animation-timing-function: ease-out
	}
	50% {
		-webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
		transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	80% {
		-webkit-transform: perspective(400px) scale3d(.95, .95, .95);
		transform: perspective(400px) scale3d(.95, .95, .95);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
}
.animated.flip {
	-webkit-backface-visibility: visible;
	backface-visibility: visible;
	-webkit-animation-name: flip;
	animation-name: flip
}
@-webkit-keyframes flipInX {
	from {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in;
		opacity: 0
	}
	40% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	60% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
		opacity: 1
	}
	80% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -5deg)
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
}
@keyframes flipInX {
	from {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in;
		opacity: 0
	}
	40% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	60% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
		opacity: 1
	}
	80% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -5deg)
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
}
.flipInX {
	-webkit-backface-visibility: visible !important;
	backface-visibility: visible !important;
	-webkit-animation-name: flipInX;
	animation-name: flipInX
}
@-webkit-keyframes flipInY {
	from {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in;
		opacity: 0
	}
	40% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	60% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
		opacity: 1
	}
	80% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -5deg)
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
}
@keyframes flipInY {
	from {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in;
		opacity: 0
	}
	40% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
		-webkit-animation-timing-function: ease-in;
		animation-timing-function: ease-in
	}
	60% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
		opacity: 1
	}
	80% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -5deg)
	}
	to {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
}
.flipInY {
	-webkit-backface-visibility: visible !important;
	backface-visibility: visible !important;
	-webkit-animation-name: flipInY;
	animation-name: flipInY
}
@-webkit-keyframes flipOutX {
	from {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
	30% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		opacity: 1
	}
	to {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		opacity: 0
	}
}
@keyframes flipOutX {
	from {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
	30% {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
		opacity: 1
	}
	to {
		-webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
		opacity: 0
	}
}
.flipOutX {
	-webkit-animation-name: flipOutX;
	animation-name: flipOutX;
	-webkit-backface-visibility: visible !important;
	backface-visibility: visible !important
}
@-webkit-keyframes flipOutY {
	from {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
	30% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
		opacity: 1
	}
	to {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		opacity: 0
	}
}
@keyframes flipOutY {
	from {
		-webkit-transform: perspective(400px);
		transform: perspective(400px)
	}
	30% {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
		transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
		opacity: 1
	}
	to {
		-webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
		opacity: 0
	}
}
.flipOutY {
	-webkit-backface-visibility: visible !important;
	backface-visibility: visible !important;
	-webkit-animation-name: flipOutY;
	animation-name: flipOutY
}
@-webkit-keyframes lightSpeedIn {
	from {
		-webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
		transform: translate3d(100%, 0, 0) skewX(-30deg);
		opacity: 0
	}
	60% {
		-webkit-transform: skewX(20deg);
		transform: skewX(20deg);
		opacity: 1
	}
	80% {
		-webkit-transform: skewX(-5deg);
		transform: skewX(-5deg);
		opacity: 1
	}
	to {
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes lightSpeedIn {
	from {
		-webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
		transform: translate3d(100%, 0, 0) skewX(-30deg);
		opacity: 0
	}
	60% {
		-webkit-transform: skewX(20deg);
		transform: skewX(20deg);
		opacity: 1
	}
	80% {
		-webkit-transform: skewX(-5deg);
		transform: skewX(-5deg);
		opacity: 1
	}
	to {
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.lightSpeedIn {
	-webkit-animation-name: lightSpeedIn;
	animation-name: lightSpeedIn;
	-webkit-animation-timing-function: ease-out;
	animation-timing-function: ease-out
}
@-webkit-keyframes lightSpeedOut {
	from {
		opacity: 1
	}
	to {
		-webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
		transform: translate3d(100%, 0, 0) skewX(30deg);
		opacity: 0
	}
}
@keyframes lightSpeedOut {
	from {
		opacity: 1
	}
	to {
		-webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
		transform: translate3d(100%, 0, 0) skewX(30deg);
		opacity: 0
	}
}
.lightSpeedOut {
	-webkit-animation-name: lightSpeedOut;
	animation-name: lightSpeedOut;
	-webkit-animation-timing-function: ease-in;
	animation-timing-function: ease-in
}
@-webkit-keyframes rotateIn {
	from {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: rotate3d(0, 0, 1, -200deg);
		transform: rotate3d(0, 0, 1, -200deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes rotateIn {
	from {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: rotate3d(0, 0, 1, -200deg);
		transform: rotate3d(0, 0, 1, -200deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.rotateIn {
	-webkit-animation-name: rotateIn;
	animation-name: rotateIn
}
@-webkit-keyframes rotateInDownLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes rotateInDownLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.rotateInDownLeft {
	-webkit-animation-name: rotateInDownLeft;
	animation-name: rotateInDownLeft
}
@-webkit-keyframes rotateInDownRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes rotateInDownRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.rotateInDownRight {
	-webkit-animation-name: rotateInDownRight;
	animation-name: rotateInDownRight
}
@-webkit-keyframes rotateInUpLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes rotateInUpLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.rotateInUpLeft {
	-webkit-animation-name: rotateInUpLeft;
	animation-name: rotateInUpLeft
}
@-webkit-keyframes rotateInUpRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, -90deg);
		transform: rotate3d(0, 0, 1, -90deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
@keyframes rotateInUpRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, -90deg);
		transform: rotate3d(0, 0, 1, -90deg);
		opacity: 0
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: none;
		transform: none;
		opacity: 1
	}
}
.rotateInUpRight {
	-webkit-animation-name: rotateInUpRight;
	animation-name: rotateInUpRight
}
@-webkit-keyframes rotateOut {
	from {
		-webkit-transform-origin: center;
		transform-origin: center;
		opacity: 1
	}
	to {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: rotate3d(0, 0, 1, 200deg);
		transform: rotate3d(0, 0, 1, 200deg);
		opacity: 0
	}
}
@keyframes rotateOut {
	from {
		-webkit-transform-origin: center;
		transform-origin: center;
		opacity: 1
	}
	to {
		-webkit-transform-origin: center;
		transform-origin: center;
		-webkit-transform: rotate3d(0, 0, 1, 200deg);
		transform: rotate3d(0, 0, 1, 200deg);
		opacity: 0
	}
}
.rotateOut {
	-webkit-animation-name: rotateOut;
	animation-name: rotateOut
}
@-webkit-keyframes rotateOutDownLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
}
@keyframes rotateOutDownLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, 45deg);
		transform: rotate3d(0, 0, 1, 45deg);
		opacity: 0
	}
}
.rotateOutDownLeft {
	-webkit-animation-name: rotateOutDownLeft;
	animation-name: rotateOutDownLeft
}
@-webkit-keyframes rotateOutDownRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
}
@keyframes rotateOutDownRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
}
.rotateOutDownRight {
	-webkit-animation-name: rotateOutDownRight;
	animation-name: rotateOutDownRight
}
@-webkit-keyframes rotateOutUpLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
}
@keyframes rotateOutUpLeft {
	from {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: left bottom;
		transform-origin: left bottom;
		-webkit-transform: rotate3d(0, 0, 1, -45deg);
		transform: rotate3d(0, 0, 1, -45deg);
		opacity: 0
	}
}
.rotateOutUpLeft {
	-webkit-animation-name: rotateOutUpLeft;
	animation-name: rotateOutUpLeft
}
@-webkit-keyframes rotateOutUpRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, 90deg);
		transform: rotate3d(0, 0, 1, 90deg);
		opacity: 0
	}
}
@keyframes rotateOutUpRight {
	from {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		opacity: 1
	}
	to {
		-webkit-transform-origin: right bottom;
		transform-origin: right bottom;
		-webkit-transform: rotate3d(0, 0, 1, 90deg);
		transform: rotate3d(0, 0, 1, 90deg);
		opacity: 0
	}
}
.rotateOutUpRight {
	-webkit-animation-name: rotateOutUpRight;
	animation-name: rotateOutUpRight
}
@-webkit-keyframes hinge {
	0% {
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out
	}
	20%,
	60% {
		-webkit-transform: rotate3d(0, 0, 1, 80deg);
		transform: rotate3d(0, 0, 1, 80deg);
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out
	}
	40%,
	80% {
		-webkit-transform: rotate3d(0, 0, 1, 60deg);
		transform: rotate3d(0, 0, 1, 60deg);
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out;
		opacity: 1
	}
	to {
		-webkit-transform: translate3d(0, 700px, 0);
		transform: translate3d(0, 700px, 0);
		opacity: 0
	}
}
@keyframes hinge {
	0% {
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out
	}
	20%,
	60% {
		-webkit-transform: rotate3d(0, 0, 1, 80deg);
		transform: rotate3d(0, 0, 1, 80deg);
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out
	}
	40%,
	80% {
		-webkit-transform: rotate3d(0, 0, 1, 60deg);
		transform: rotate3d(0, 0, 1, 60deg);
		-webkit-transform-origin: top left;
		transform-origin: top left;
		-webkit-animation-timing-function: ease-in-out;
		animation-timing-function: ease-in-out;
		opacity: 1
	}
	to {
		-webkit-transform: translate3d(0, 700px, 0);
		transform: translate3d(0, 700px, 0);
		opacity: 0
	}
}
.hinge {
	-webkit-animation-name: hinge;
	animation-name: hinge
}
@-webkit-keyframes rollIn {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
		transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes rollIn {
	from {
		opacity: 0;
		-webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
		transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.rollIn {
	-webkit-animation-name: rollIn;
	animation-name: rollIn
}
@-webkit-keyframes rollOut {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
		transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg)
	}
}
@keyframes rollOut {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		-webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
		transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg)
	}
}
.rollOut {
	-webkit-animation-name: rollOut;
	animation-name: rollOut
}
@-webkit-keyframes zoomIn {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	50% {
		opacity: 1
	}
}
@keyframes zoomIn {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	50% {
		opacity: 1
	}
}
.zoomIn {
	-webkit-animation-name: zoomIn;
	animation-name: zoomIn
}
@-webkit-keyframes zoomInDown {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomInDown {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, -1000px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomInDown {
	-webkit-animation-name: zoomInDown;
	animation-name: zoomInDown
}
@-webkit-keyframes zoomInLeft {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
		transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomInLeft {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
		transform: scale3d(.1, .1, .1) translate3d(-1000px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(10px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomInLeft {
	-webkit-animation-name: zoomInLeft;
	animation-name: zoomInLeft
}
@-webkit-keyframes zoomInRight {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
		transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomInRight {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
		transform: scale3d(.1, .1, .1) translate3d(1000px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(-10px, 0, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomInRight {
	-webkit-animation-name: zoomInRight;
	animation-name: zoomInRight
}
@-webkit-keyframes zoomInUp {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomInUp {
	from {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, 1000px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomInUp {
	-webkit-animation-name: zoomInUp;
	animation-name: zoomInUp
}
@-webkit-keyframes zoomOut {
	from {
		opacity: 1
	}
	50% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	to {
		opacity: 0
	}
}
@keyframes zoomOut {
	from {
		opacity: 1
	}
	50% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	to {
		opacity: 0
	}
}
.zoomOut {
	-webkit-animation-name: zoomOut;
	animation-name: zoomOut
}
@-webkit-keyframes zoomOutDown {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
		-webkit-transform-origin: center bottom;
		transform-origin: center bottom;
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomOutDown {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, -60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, 2000px, 0);
		-webkit-transform-origin: center bottom;
		transform-origin: center bottom;
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomOutDown {
	-webkit-animation-name: zoomOutDown;
	animation-name: zoomOutDown
}
@-webkit-keyframes zoomOutLeft {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: scale(.1) translate3d(-2000px, 0, 0);
		transform: scale(.1) translate3d(-2000px, 0, 0);
		-webkit-transform-origin: left center;
		transform-origin: left center
	}
}
@keyframes zoomOutLeft {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(42px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: scale(.1) translate3d(-2000px, 0, 0);
		transform: scale(.1) translate3d(-2000px, 0, 0);
		-webkit-transform-origin: left center;
		transform-origin: left center
	}
}
.zoomOutLeft {
	-webkit-animation-name: zoomOutLeft;
	animation-name: zoomOutLeft
}
@-webkit-keyframes zoomOutRight {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: scale(.1) translate3d(2000px, 0, 0);
		transform: scale(.1) translate3d(2000px, 0, 0);
		-webkit-transform-origin: right center;
		transform-origin: right center
	}
}
@keyframes zoomOutRight {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0);
		transform: scale3d(.475, .475, .475) translate3d(-42px, 0, 0)
	}
	to {
		opacity: 0;
		-webkit-transform: scale(.1) translate3d(2000px, 0, 0);
		transform: scale(.1) translate3d(2000px, 0, 0);
		-webkit-transform-origin: right center;
		transform-origin: right center
	}
}
.zoomOutRight {
	-webkit-animation-name: zoomOutRight;
	animation-name: zoomOutRight
}
@-webkit-keyframes zoomOutUp {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
		-webkit-transform-origin: center bottom;
		transform-origin: center bottom;
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
@keyframes zoomOutUp {
	40% {
		opacity: 1;
		-webkit-transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		transform: scale3d(.475, .475, .475) translate3d(0, 60px, 0);
		-webkit-animation-timing-function: cubic-bezier(.55, .055, .675, .19);
		animation-timing-function: cubic-bezier(.55, .055, .675, .19)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
		transform: scale3d(.1, .1, .1) translate3d(0, -2000px, 0);
		-webkit-transform-origin: center bottom;
		transform-origin: center bottom;
		-webkit-animation-timing-function: cubic-bezier(.175, .885, .32, 1);
		animation-timing-function: cubic-bezier(.175, .885, .32, 1)
	}
}
.zoomOutUp {
	-webkit-animation-name: zoomOutUp;
	animation-name: zoomOutUp
}
@-webkit-keyframes slideInDown {
	from {
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
@keyframes slideInDown {
	from {
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
.slideInDown {
	-webkit-animation-name: slideInDown;
	animation-name: slideInDown
}
@-webkit-keyframes slideInLeft {
	from {
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
@keyframes slideInLeft {
	from {
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
.slideInLeft {
	-webkit-animation-name: slideInLeft;
	animation-name: slideInLeft
}
@-webkit-keyframes slideInRight {
	from {
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
@keyframes slideInRight {
	from {
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
.slideInRight {
	-webkit-animation-name: slideInRight;
	animation-name: slideInRight
}
@-webkit-keyframes slideInUp {
	from {
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
@keyframes slideInUp {
	from {
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0);
		visibility: visible
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
}
.slideInUp {
	-webkit-animation-name: slideInUp;
	animation-name: slideInUp
}
@-webkit-keyframes slideOutDown {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
}
@keyframes slideOutDown {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(0, 100%, 0);
		transform: translate3d(0, 100%, 0)
	}
}
.slideOutDown {
	-webkit-animation-name: slideOutDown;
	animation-name: slideOutDown
}
@-webkit-keyframes slideOutLeft {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
}
@keyframes slideOutLeft {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(-100%, 0, 0);
		transform: translate3d(-100%, 0, 0)
	}
}
.slideOutLeft {
	-webkit-animation-name: slideOutLeft;
	animation-name: slideOutLeft
}
@-webkit-keyframes slideOutRight {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
}
@keyframes slideOutRight {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(100%, 0, 0);
		transform: translate3d(100%, 0, 0)
	}
}
.slideOutRight {
	-webkit-animation-name: slideOutRight;
	animation-name: slideOutRight
}
@-webkit-keyframes slideOutUp {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
}
@keyframes slideOutUp {
	from {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0)
	}
	to {
		visibility: hidden;
		-webkit-transform: translate3d(0, -100%, 0);
		transform: translate3d(0, -100%, 0)
	}
}
.slideOutUp {
	-webkit-animation-name: slideOutUp;
	animation-name: slideOutUp
}
@-webkit-keyframes justified-gallery-show-caption-animation {
	from {
		opacity: 0
	}
	to {
		opacity: .7
	}
}
@-moz-keyframes justified-gallery-show-caption-animation {
	from {
		opacity: 0
	}
	to {
		opacity: .7
	}
}
@-o-keyframes justified-gallery-show-caption-animation {
	from {
		opacity: 0
	}
	to {
		opacity: .7
	}
}
@keyframes justified-gallery-show-caption-animation {
	from {
		opacity: 0
	}
	to {
		opacity: .7
	}
}
@-webkit-keyframes justified-gallery-show-entry-animation {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
@-moz-keyframes justified-gallery-show-entry-animation {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
@-o-keyframes justified-gallery-show-entry-animation {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
@keyframes justified-gallery-show-entry-animation {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
.justified-gallery {
	width: 100%;
	position: relative;
	overflow: hidden
}
.justified-gallery>a,
.justified-gallery>div {
	position: absolute;
	display: inline-block;
	overflow: hidden;
	opacity: 0
}
.justified-gallery>a>a>img,
.justified-gallery>a>img,
.justified-gallery>div>a>img,
.justified-gallery>div>img {
	position: absolute;
	top: 50%;
	left: 50%;
	margin: 0;
	padding: 0;
	border: 0
}
.justified-gallery>a>.caption,
.justified-gallery>div>.caption {
	display: none;
	position: absolute;
	bottom: 0;
	padding: 5px;
	background-color: #000;
	left: 0;
	right: 0;
	margin: 0;
	color: #fff;
	font-size: 12px;
	font-weight: 300;
	font-family: sans-serif
}
.justified-gallery>a>.caption.caption-visible,
.justified-gallery>div>.caption.caption-visible {
	display: initial;
	opacity: .7;
	filter: "alpha(opacity=70)";
	-webkit-animation: justified-gallery-show-caption-animation .5s 0 ease;
	-moz-animation: justified-gallery-show-caption-animation .5s 0 ease;
	-ms-animation: justified-gallery-show-caption-animation .5s 0 ease
}
.justified-gallery>.entry-visible {
	opacity: 1;
	-webkit-animation: justified-gallery-show-entry-animation .5s 0 ease;
	-moz-animation: justified-gallery-show-entry-animation .5s 0 ease;
	-ms-animation: justified-gallery-show-entry-animation .5s 0 ease
}
.justified-gallery>.jg-filtered {
	display: none
}
.justified-gallery>.spinner {
	position: absolute;
	bottom: 0;
	margin-left: -24px;
	padding: 10px 0;
	left: 50%;
	opacity: initial;
	filter: initial;
	overflow: initial
}
.justified-gallery>.spinner>span {
	display: inline-block;
	opacity: 0;
	width: 8px;
	height: 8px;
	margin: 0 4px;
	background-color: #000;
	border-top-left-radius: 6px;
	border-top-right-radius: 6px;
	border-bottom-right-radius: 6px;
	border-bottom-left-radius: 6px
}
.jq-ry-container {
	position: relative;
	padding: 0 5px;
	line-height: 0;
	display: block;
	cursor: pointer;
	-webkit-box-sizing: content-box;
	-moz-box-sizing: content-box;
	box-sizing: content-box;
	direction: ltr
}
.jq-ry-container[readonly=readonly] {
	cursor: default
}
.jq-ry-container>.jq-ry-group-wrapper {
	position: relative;
	width: 100%
}
.jq-ry-container>.jq-ry-group-wrapper>.jq-ry-group {
	position: relative;
	line-height: 0;
	z-index: 10;
	white-space: nowrap
}
.jq-ry-container>.jq-ry-group-wrapper>.jq-ry-group>svg {
	display: inline-block
}
.jq-ry-container>.jq-ry-group-wrapper>.jq-ry-group.jq-ry-normal-group {
	width: 100%
}
.jq-ry-container>.jq-ry-group-wrapper>.jq-ry-group.jq-ry-rated-group {
	width: 0;
	z-index: 11;
	position: absolute;
	top: 0;
	left: 0;
	overflow: hidden
}
* {
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	-moz-box-sizing: border-box;
	outline: 0
}
*,
blockquote,
body,
dd,
div,
dl,
dt,
fieldset,
form,
h1,
h2,
h3,
h4,
h5,
h6,
html,
input,
label,
li,
ol,
p,
pre,
td,
th,
ul {
	margin: 0;
	padding: 0
}
input {
	background-color: transparent
}
table {
	border-collapse: collapse;
	border-spacing: 0
}
fieldset,
img {
	border: 0
}
address,
caption,
cite,
code,
dfn,
strong,
th,
var {
	font-style: normal;
	font-weight: 400
}
li,
ol,
ul {
	list-style: none
}
caption,
th {
	text-align: left
}
h1,
h2,
h3,
h4,
h5,
h6 {
	font-size: 100%;
	font-weight: 400
}
q:after,
q:before {
	content: ""
}
strong {
	font-weight: 700
}
em {
	font-style: italic
}
img {
	max-width: 100%;
	vertical-align: top;
	height: auto
}
a img {
	border: none
}
iframe {
	border: none;
	max-width: none
}
iframe[name=google_conversion_frame] {
	height: 0;
	display: block;
	overflow: hidden
}
.penci-center {
	text-align: center
}
body:not(.penci-fawesome-ver5) .penci-faicon {
	font-family: FontAwesome;
	font-weight: 400
}
body:not(.penci-fawesome-ver5) .penci-faicon.fa-vimeo:before {
	content: "\f27d"
}
button,
input[type=button],
input[type=email],
input[type=search],
input[type=submit],
input[type=text],
textarea {
	-webkit-appearance: none;
	border-radius: 0;
	-webkit-border-radius: 0
}
p:empty:before {
	content: none
}
body,
html {
	-webkit-font-smoothing: antialiased
}
body {
	font-family: var(--pcbody-font);
	color: #313131;
	background-color: #fff;
	font-size: 14px;
	overflow-x: hidden;
	text-rendering: optimizeLegibility;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	--pcbg-cl: #fff;
	--pctext-cl: #313131;
	--pcborder-cl: #dedede;
	--pcheading-cl: #313131;
	--pcmeta-cl: #888888;
	--pcaccent-cl: #6eb48c;
	--pcbody-font: "PT Serif", serif;
	--pchead-font: "Raleway", sans-serif;
	--pchead-wei: bold;
	--pchd-mg: 60px;
	--pcctain: 1170px;
	--pcctain2:1400px;
	--pcajs_tcl: var(--pcheading-cl);
	--pcajs_thcl: var(--pcaccent-cl);
	--pcajs_mcl: var(--pcmeta-cl);
	--pcajs_mhcl: var(--pcmeta-cl);
	--pcajs_ncl: var(--pctext-cl);
	--pcajs_bcl: var(--pcborder-cl);
	--pcajs_bgcl: var(--pcbg-cl);
	--pcajs_bghcl: #f9f9f9;
	--pcajs_tfz: 13px;
	--pcajs_mfz: 12px;
	--pcajs_nfz: 13px;
	--pcsnav-w: 270px
}
textarea {
	min-height: 100px
}
input[type=date],
input[type=email],
input[type=number],
input[type=password],
input[type=search],
input[type=tel],
input[type=text],
input[type=url],
select,
textarea {
	font-family: var(--pcbody-font);
	padding: 11px 20px;
	max-width: 100%;
	width: 100%;
	border: 1px solid var(--pcborder-cl);
	border-radius: 0;
	background-color: transparent;
	box-shadow: none;
	color: var(--pctext-cl);
	vertical-align: middle;
	font-size: inherit
}
select {
	padding: 8px 28px 8px 15px;
	background-image: url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHdpZHRoPSIyNSIgaGVpZ2h0PSIyNSIgZmlsbD0ibm9uZSIgc3Ryb2tlLXdpZHRoPSIyIiBzdHJva2U9IiNiYmIiPjxwYXRoIGQ9Ik02IDlsNiA2IDYtNiIvPjwvc3ZnPg==);
	background-position: right 10px top 50%;
	background-size: auto 18px;
	background-repeat: no-repeat;
	-webkit-appearance: none;
	-moz-appearance: none;
	appearance: none
}
input[type=date]:focus,
input[type=email]:focus,
input[type=number]:focus,
input[type=password]:focus,
input[type=search]:focus,
input[type=tel]:focus,
input[type=text]:focus,
input[type=url]:focus,
select:focus,
textarea:focus {
	outline: 0
}
[type=button],
[type=submit],
button {
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	padding: 12px 20px;
	font-size: 13px;
	line-height: 1.2;
	background-color: var(--pcaccent-cl);
	color: #fff;
	text-align: center;
	display: inline-block;
	outline: 0;
	border: 0;
	border-radius: 0;
	box-shadow: none;
	text-decoration: none;
	text-shadow: none;
	cursor: pointer;
	text-transform: uppercase
}
button[disabled],
input[disabled] {
	opacity: .6 !important;
	cursor: default
}
p {
	font-size: 14px;
	line-height: 28px
}
.elementor-widget-text-editor p {
	font-size: inherit;
	line-height: inherit;
	text-align: inherit
}
a {
	text-decoration: none;
	color: var(--pcaccent-cl);
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s;
	outline: 0;
	cursor: pointer
}
h1,
h2,
h3,
h4,
h5,
h6 {
	font-family: var(--pchead-font);
	font-style: normal;
	font-weight: var(--pchead-wei);
	line-height: 1.35
}
.container {
	width: var(--pcctain);
	margin: 0 auto
}
.container.container-1400 {
	max-width: var(--pcctain2);
	width: 100%
}
.container.container-fullwidth {
	max-width: 100%;
	width: 100%
}
.pc-wrapbuilder-header-inner .container.container-1400,
.penci-header-wrap .container.container-1400 {
	--pcctain: var(--pcctain2)
}
.pc-wrapbuilder-header-inner .container.container-fullwidth,
.penci-header-wrap .container.container-fullwidth {
	--pcctain: 100vw
}
.penci-page-container-smaller {
	max-width: 900px;
	margin-left: auto;
	margin-right: auto;
	display: block
}
.container.penci_sidebar:after,
.container.penci_sidebar:before {
	content: "";
	display: table;
	clear: both
}
body:not(.penci-fawesome-ver5) .penci-faicon.fa-facebook-f:before,
body:not(.penci-fawesome-ver5) .penci-faicon.fa-facebook:before {
	content: "\f09a"
}
#main {
	width: 100%
}
.container.penci_sidebar #main,
.penci-single-style-10 .penci-single-s10-content{
	width: 70.94%;
	padding-right: 50px;
	float: left
}
.penci-single-style-20 .penci-single-s20-content{
	width: 55%;
}
.penci-single-style-20 .penci-post-image-wrapper .penci-sidebar-content {
	width: 40%;
}
.penci-single-style-13 .penci-single-s13-content {
	width: calc(50vw + (100vw - var(--pcctain)) / 2);
	margin-left: calc((100vw - var(--pcctain)) / -2);
}
.container.penci_sidebar.left-sidebar #main,
.penci-single-style-10.penci_sidebar.left-sidebar .penci-single-s10-content,
.penci-single-style-20.penci_sidebar.left-sidebar .penci-single-s20-content,
.penci-single-style-13.penci_sidebar.left-sidebar .penci-single-s13-content {
	float: right;
	padding: 0 0 0 60px
}
.penci-single-style-20 .header-standard .post-box-meta-single {
	margin-top: 20px;
}
.penci-sidebar-content {
	width: 29.06%;
	float: right
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content {
	width: 60%;
}
.penci-single-style-13 .container.two-sidebar .penci-sidebar-content {
	width: 50%;
}
.penci-single-style-13 .post-format-entry-header {
	display: flex;
	flex-direction: row-reverse;
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content {
	align-content: center;
	position: relative;
	z-index: 4;
	background: var(--pcaccent-cl);
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:before,
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:after {
	content: '';
	position: absolute;
	bottom: -40px;
	width: 100%;
	height: 40px;
	left: 0;
	right: 0;
	background: var(--pcaccent-cl);
	z-index: 2;
}
.penci-single-style-13.penci-show-ft-caption .penci-post-image-wrapper .penci-sidebar-content:after {
	display: block;
}
@media only screen and (max-width: 960px) {
	.penci-single-style-13.penci-show-ft-caption .penci-post-image-wrapper .penci-sidebar-content:after,
	.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:after {
		display: none;
	}
}
@media only screen and (min-width: 768px){
	.penci-single-style-13.penci-show-ft-caption .penci-featured-caption {
		position: absolute;
		text-align: right;
		background: transparent;
		color: var(--pcheading-cl);
		bottom: -40px;
	}
}
.penci-single-style-13.penci-show-ft-caption .post-image {
	overflow: visible;
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:before {
	right: auto;
	opacity: 0.5;
	left: 100%;
	bottom: 0;
	z-index: -1;
	background: var(--pcbg-cl);
	opacity: 0.1;
}
.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content .single-header {
	position: relative;
	padding: 50px 0 50px 50px;
}  
.penci-single-style-13 .penci-container-inside.penci-breadcrumb {
	position: relative;
	padding-left: 50px;
}
.penci-single-style-13 .penci-container-inside.penci-breadcrumb span,
.penci-single-style-13 .penci-container-inside.penci-breadcrumb i,
.penci-single-style-13 .penci-container-inside.penci-breadcrumb span a {
	color: #fff;
}
.penci-single-style-13 .penci-sidebar-content,
.penci-single-style-13 .penci-main-sticky-sidebar {
	margin-top: 40px;
}
@media only screen and (min-width:961px) {
	.penci-single-style-10 .penci-post-image-wrapper .container.two-sidebar .penci-sidebar-content {
		width: 29.06%
	}
	.penci-single-style-20 .penci-post-image-wrapper .container.two-sidebar .penci-sidebar-content {
		width: 39%;
	}
}
.penci-sidebar-content-vc {
	width: 100% !important;
	float: none
}
.penci_sidebar.left-sidebar .penci-sidebar-content {
	float: left
}
.penci-sidebar-content.penci-sticky-sidebar.is-sticky {
	margin-top: 75px
}
.admin-bar .penci-sidebar-content.penci-sticky-sidebar.is-sticky {
	margin-top: 107px
}
#penci-end-sidebar-sticky {
	margin-top: -300px;
	padding-top: 300px
}
.clear-footer {
	height: 1px;
	margin-bottom: 29px;
	clear: both;
	display: block;
	width: 100%
}
.clearfix {
	clear: both
}
.penci-clearfix {
	clear: both
}
.penci-clearfix:after,
.penci-clearfix:before {
	content: "";
	display: table;
	clear: both
}
.wrapper-boxed {
	overflow: hidden
}
body.penci-body-boxed {
	background: #f5f5f5;
	background-position: center center;
	background-size: cover;
	background-repeat: no-repeat;
	background-attachment: fixed
}
.wrapper-boxed.enable-boxed {
	background: #fff;
	max-width: calc(var(--pcctain) + 60px);
	display: block;
	overflow: hidden;
	margin: 0 auto;
	box-shadow: 0 5px 8px rgba(0, 0, 0, .2);
	-webkit-box-shadow: 0 5px 8px rgba(0, 0, 0, .2);
	-moz-box-shadow: 0 5px 8px rgba(0, 0, 0, .2)
}
.wrapper-boxed.enable-boxed .penci_header.penci_builder_sticky_header_desktop {
	--pmx: calc(var(--pcctain) + 60px);
	width: 100%;
	max-width: var(--pmx);
	display: block;
	margin-left: auto;
	margin-right: auto;
}
.penci-body-boxed.penci-two-sidebar .wrapper-boxed.enable-boxed {
	max-width: calc(var(--pcctain2) + 30px)
}
.penci-body-boxed.penci-two-sidebar .container.penci-breadcrumb,
.penci-body-boxed.penci-two-sidebar .container.two-sidebar {
	width: 100%;
	padding-left: 15px;
	padding-right: 15px
}
.penci-top-bar {
	background: #313131;
	height: auto
}
.penci-top-bar.topbar-1400px,
.penci-top-bar.topbar-fullwidth {
	padding: 0 20px
}
.penci-top-bar.topbar-fullwidth .container {
	width: 100%
}
.penci-headline {
	display: block
}
.penci-headline:after,
.penci-headline:before {
	content: "";
	display: table;
	clear: both
}
.penci-headline .pctopbar-item {
	display: flex;
	margin: 0 15px;
	float: left;
	line-height: 32px;
	color: #fff
}
.penci-topbar-ctext {
	font-size: 13px
}
.penci-topbar-ctext * {
	color: inherit;
	font-size: inherit
}
.penci-headline .pctopbar-item:first-child {
	margin-left: 0
}
.penci-headline .pctopbar-item:last-child {
	margin-right: 0
}
@media only screen and (min-width:1170px) {
	.penci-headline .pctopbar-item:last-child:not(:first-child) {
		float: right
	}
}
.headline-title {
	height: 32px;
	line-height: 32px;
	padding: 0 15px;
	font-size: 12px;
	color: #fff;
	background: var(--pcaccent-cl);
	float: left;
	text-transform: uppercase;
	font-family: var(--pchead-font);
	z-index: 10;
	position: relative;
	display: inline-block;
	font-weight: var(--pchead-wei)
}
.penci-top-bar .penci-owl-carousel:not(.penci-owl-loaded)>div:first-child {
	height: 32px
}
.penci-owl-carousel.penci-headline-posts .owl-stage-outer {
	height: 32px !important
}
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next,
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev {
	width: 16px;
	height: 20px;
	border: none;
	background: 0 0;
	display: inline-block;
	text-align: center;
	line-height: 20px;
	left: -54px;
	outline: 0;
	cursor: pointer;
	position: absolute;
	color: #999;
	opacity: 1 !important;
	font-size: 18px;
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s;
	padding: 0;
	top: 50%;
	margin-top: -10px
}
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next {
	left: -32px
}
.penci-trending-nav {
	line-height: 32px
}
.penci-trending-nav a {
	font-size: 16px;
	line-height: inherit;
	padding-left: 5px;
	padding-right: 5px;
	cursor: pointer;
	display: inline-block;
	vertical-align: top;
	text-decoration: none !important;
	color: #999;
	position: relative
}
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next:hover,
.penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev:hover,
.penci-trending-nav a:hover {
	color: #fff
}
@keyframes TickerslideOutRight {
	from {
		opacity: 1
	}
	to {
		opacity: 0;
		transform: translate3d(20px, 0, 0)
	}
}
@keyframes TickerslideInRight {
	from {
		opacity: 0;
		transform: translate3d(20px, 0, 0)
	}
	to {
		opacity: 1;
		transform: none
	}
}
.penci-headline-posts .owl-item.sliderInUp {
	animation-name: sliderInUp;
	-webkit-animation-name: sliderInUp
}
.penci-headline-posts .owl-item.sliderOutUp {
	animation-name: sliderOutUp;
	-webkit-animation-name: sliderOutUp
}
.penci-headline-posts .slideInUp {
	-webkit-animation-name: slideInUp !important;
	animation-name: slideInUp !important
}
.penci-headline-posts .slideOutUp {
	-webkit-animation-name: slideOutUp !important;
	animation-name: slideOutUp !important
}
.penci-headline-posts .TickerslideInRight {
	-webkit-animation-name: TickerslideInRight !important;
	animation-name: TickerslideInRight !important
}
.penci-headline-posts .TickerslideOutRight {
	-webkit-animation-name: TickerslideOutRight !important;
	animation-name: TickerslideOutRight !important
}
.penci-headline-posts .fadeIn {
	-webkit-animation-name: fadeIn !important;
	animation-name: fadeIn !important
}
.penci-headline-posts .fadeOut {
	-webkit-animation-name: fadeOut !important;
	animation-name: fadeOut !important
}
a.penci-topbar-post-title {
	color: #fff;
	font-size: 12px;
	font-family: var(--pchead-font);
	text-decoration: none !important;
	text-transform: uppercase;
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s;
	display: inline-block;
	white-space: nowrap;
	line-height: 32px;
	font-weight: var(--pchead-wei)
}
a.penci-topbar-post-title:hover {
	color: var(--pcaccent-cl)
}
.loaded a.penci-topbar-post-title {
	opacity: 1
}
.penci-owl-carousel-slider.swiper-fade .swiper-slide {
	pointer-events: initial;
}
.penci-topbar-social {
	display: inline-block;
	float: right;
	z-index: 10;
	position: relative
}
.penci-topbar-social>div {
	display: inline-block;
	vertical-align: top
}
.penci-topbar-social a {
	float: left;
	display: inline-block;
	vertical-align: top;
	margin-left: 13px;
	font-size: 13px;
	color: #fff;
	-webkit-transition: all .2s linear;
	-moz-transition: all .2s linear;
	-ms-transition: all .2s linear;
	-o-transition: all .2s linear;
	transition: all .2s linear;
	line-height: 32px
}
.penci-topbar-social a:first-child {
	margin-left: 0
}
.penci-topbar-social a:hover {
	color: var(--pcaccent-cl)
}
.penci-topbar-trending .animated.TickerslideInRight,
.penci-topbar-trending .animated.TickerslideOutRight,
.penci-topbar-trending .animated.fadeIn,
.penci-topbar-trending .animated.fadeOut,
.penci-topbar-trending .animated.slideInUp,
.penci-topbar-trending .animated.slideOutUp {
	-webkit-animation-duration: .3s;
	animation-duration: .3s
}
.penci-topbar-trending {
	display: flex;
	float: left;
	overflow: hidden;
	width: 100%;
	max-width: 420px;
	text-align: left;
	text-overflow: ellipsis;
	white-space: nowrap
}
.penci-topbar-trending .penci-trending-nav {
	float: left;
	position: relative;
	z-index: 100;
	padding-left: 8px;
	padding-right: 8px
}
.penci-topbar-trending .swiper {
	overflow: visible;
	max-height: 32px;
}
.penci-topbar-trending .penci-owl-carousel .owl-item {
	background: #313131
}
.headline-title.nticker-style-2 {
	margin-right: 8px
}
.headline-title.nticker-style-4 {
	margin-right: 9px
}
.headline-title.nticker-style-2:after {
	width: 0;
	height: 0;
	border-top: 8px solid transparent;
	border-left: 9px solid var(--pcaccent-cl);
	border-bottom: 8px solid transparent;
	border-top-color: transparent !important;
	border-bottom-color: transparent !important;
	content: "";
	position: absolute;
	right: -8px;
	top: 50%;
	margin-top: -8px;
	display: inline-block
}
.headline-title.nticker-style-3 {
	padding-right: 25px
}
.headline-title.nticker-style-3:after {
	width: 0;
	height: 0;
	border-top: 16px solid transparent;
	border-right: 11px solid #313131;
	border-bottom: 16px solid transparent;
	border-top-color: transparent !important;
	border-bottom-color: transparent !important;
	content: "";
	position: absolute;
	right: 0;
	top: 0;
	display: inline-block
}
.headline-title.nticker-style-4:after {
	width: 0;
	height: 0;
	content: "";
	position: absolute;
	right: -9px;
	top: 0;
	display: inline-block;
	border-bottom: 32px solid var(--pcaccent-cl);
	border-right: 9px solid transparent;
	border-right-color: transparent !important;
	opacity: .8
}
.penci-enews-ticker.penci-topbar-trending {
	float: none;
	display: flex;
	text-overflow: clip;
	max-width: 100%
}
.penci-enews-ticker.penci-topbar-trending .penci-owl-carousel .owl-item {
	background: #fff
}
.penci-enews-ticker .headline-title.nticker-style-3:after {
	border-color: #fff
}
.penci-enews-ticker .penci-trending-nav a,
.penci-enews-ticker .penci-trending-nav a:hover {
	color: #666
}
div.penci-topbar-menu>ul,
ul.penci-topbar-menu {
	display: inline-block;
	vertical-align: top;
	padding: 0;
	margin: 0
}
div.penci-topbar-menu>ul li,
ul.penci-topbar-menu li {
	position: relative
}
div.penci-topbar-menu>ul>li,
ul.penci-topbar-menu>li {
	display: inline-block;
	float: left;
	margin-right: 20px
}
div.penci-topbar-menu>ul>li:last-child,
ul.penci-topbar-menu>li:last-child {
	margin-right: 0
}
div.penci-topbar-menu>ul>li a,
ul.penci-topbar-menu>li a {
	color: #fff;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	background: 0 0;
	font-size: 11px;
	text-transform: uppercase;
	line-height: 32px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
div.penci-topbar-menu>ul>li>a,
ul.penci-topbar-menu>li>a {
	display: inline-block;
	vertical-align: top
}
.penci-topbar-menu img {
	vertical-align: middle
}
div.penci-topbar-menu>ul>li a:hover,
ul.penci-topbar-menu>li a:hover {
	color: var(--pcaccent-cl)
}
div.penci-topbar-menu>ul ul.sub-menu,
ul.penci-topbar-menu ul.sub-menu {
	display: none;
	position: absolute;
	left: 0;
	background: #313131;
	box-shadow: 0 3px 3px rgba(0, 0, 0, .15);
	-webkit-box-shadow: 0 3px 3px rgba(0, 0, 0, .15);
	-moz-box-shadow: 0 3px 3px rgba(0, 0, 0, .15)
}
div.penci-topbar-menu>ul li:hover>ul.sub-menu,
ul.penci-topbar-menu li:hover>ul.sub-menu {
	display: block;
	z-index: 105
}
div.penci-topbar-menu>ul li:hover ul.sub-menu ul.sub-menu,
ul.penci-topbar-menu li:hover ul.sub-menu ul.sub-menu {
	left: 100%;
	top: 0
}
div.penci-topbar-menu>ul ul.sub-menu li a,
ul.penci-topbar-menu ul.sub-menu li a {
	width: 150px;
	padding: 7px 0;
	margin: 0 20px;
	line-height: 1.7;
	display: block;
	text-align: left
}
div.penci-topbar-menu>ul ul.sub-menu li a,
div.penci-topbar-menu>ul>li>ul.sub-menu>li:first-child,
ul.penci-topbar-menu ul.sub-menu li a,
ul.penci-topbar-menu>li>ul.sub-menu>li:first-child {
	border-top: 1px solid #414141
}
div.penci-topbar-menu>ul ul.sub-menu li:first-child>a,
ul.penci-topbar-menu ul.sub-menu>li:first-child>a {
	border-top: none
}
.penci-top-bar .pclogin-item,
.penci-top-bar .pctopbar-login-btn {
	display: inline-block;
	position: relative;
	vertical-align: top
}
.penci-topbar-social .pclogin-item,
.penci-topbar-social-mobile .pclogin-item {
	margin-right: 13px
}
.penci-top-bar .pclogin-item:not(.penci-login-popup-btn) a,.penci-top-bar .penci-login-popup-btn a {
	font-size: inherit
}
.penci-top-bar .penci-login-popup-btn a i {
	font-size: 13px
}
.pclogin-item.login-popup span {
	margin-left: 4px;
	font-size: inherit
}
.penci-topbar-social.penci-lgdisplay-right .pclogin-item {
	margin-right: 0;
	margin-left: 13px
}
.pctopbar-login-btn .pclogin-sub {
	position: absolute;
	left: 0;
	width: 200px;
	top: 32px;
	background: #313131;
	padding: 10px 20px;
	display: none;
	z-index: 10
}
.pctopbar-login-btn li.pclogin-item:hover>.pclogin-sub {
	display: block
}
.pctopbar-login-btn li.pclogin-item img {
	position: relative;
	top: 5px;
	margin: 0;
	margin-right: 5px
}
.pctopbar-login-btn .pclogin-sub li {
	display: block;
	float: none;
	font-size: inherit
}
.pctopbar-login-btn .pclogin-sub li a {
	display: block;
	float: none;
	font-size: inherit
}
.pctopbar-login-btn .pclogin-sub li a i {
	margin-right: 5px;
	font-style: normal
}
.penci-loader-effect {
	width: 40px;
	height: 40px;
	margin: 0 auto;
	margin-top: -26px;
	margin-left: -26px;
	display: none;
	position: absolute;
	top: 50%;
	left: 50%;
	z-index: 300
}
.penci-loader-effect .penci-ld {
	width: 40px;
	height: 40px;
	position: relative;
	margin: 0;
	display: block
}
.penci-ld .penci-ldin {
	width: 100%;
	height: 100%;
	position: absolute;
	left: 0;
	top: 0
}
.penci-ld .penci-ld2 {
	-webkit-transform: rotate(30deg);
	-ms-transform: rotate(30deg);
	transform: rotate(30deg)
}
.penci-ld .penci-ld3 {
	-webkit-transform: rotate(60deg);
	-ms-transform: rotate(60deg);
	transform: rotate(60deg)
}
.penci-ld .penci-ld4 {
	-webkit-transform: rotate(90deg);
	-ms-transform: rotate(90deg);
	transform: rotate(90deg)
}
.penci-ld .penci-ld5 {
	-webkit-transform: rotate(120deg);
	-ms-transform: rotate(120deg);
	transform: rotate(120deg)
}
.penci-ld .penci-ld6 {
	-webkit-transform: rotate(150deg);
	-ms-transform: rotate(150deg);
	transform: rotate(150deg)
}
.penci-ld .penci-ld7 {
	-webkit-transform: rotate(180deg);
	-ms-transform: rotate(180deg);
	transform: rotate(180deg)
}
.penci-ld .penci-ld8 {
	-webkit-transform: rotate(210deg);
	-ms-transform: rotate(210deg);
	transform: rotate(210deg)
}
.penci-ld .penci-ld9 {
	-webkit-transform: rotate(240deg);
	-ms-transform: rotate(240deg);
	transform: rotate(240deg)
}
.penci-ld .penci-ld10 {
	-webkit-transform: rotate(270deg);
	-ms-transform: rotate(270deg);
	transform: rotate(270deg)
}
.penci-ld .penci-ld11 {
	-webkit-transform: rotate(300deg);
	-ms-transform: rotate(300deg);
	transform: rotate(300deg)
}
.penci-ld .penci-ld12 {
	-webkit-transform: rotate(330deg);
	-ms-transform: rotate(330deg);
	transform: rotate(330deg)
}
.penci-ld .penci-ldin:before {
	content: "";
	display: block;
	margin: 0 auto;
	width: 15%;
	height: 15%;
	border-radius: 100%;
	-webkit-animation: LoadingCircleEf .7s infinite ease-in-out both;
	animation: LoadingCircleEf .7s infinite ease-in-out both;
	background: var(--pcaccent-cl)
}
.penci-ld .penci-ld2:before {
	-webkit-animation-delay: -1.1s;
	animation-delay: -1.1s
}
.penci-ld .penci-ld3:before {
	-webkit-animation-delay: -1s;
	animation-delay: -1s
}
.penci-ld .penci-ld4:before {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}
.penci-ld .penci-ld5:before {
	-webkit-animation-delay: -.8s;
	animation-delay: -.8s
}
.penci-ld .penci-ld6:before {
	-webkit-animation-delay: -.7s;
	animation-delay: -.7s
}
.penci-ld .penci-ld7:before {
	-webkit-animation-delay: -.6s;
	animation-delay: -.6s
}
.penci-ld .penci-ld8:before {
	-webkit-animation-delay: -.5s;
	animation-delay: -.5s
}
.penci-ld .penci-ld9:before {
	-webkit-animation-delay: -.4s;
	animation-delay: -.4s
}
.penci-ld .penci-ld10:before {
	-webkit-animation-delay: -.3s;
	animation-delay: -.3s
}
.penci-ld .penci-ld11:before {
	-webkit-animation-delay: -.2s;
	animation-delay: -.2s
}
.penci-ld .penci-ld12:before {
	-webkit-animation-delay: -.1s;
	animation-delay: -.1s
}
@-webkit-keyframes LoadingCircleEf {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1);
		transform: scale(1)
	}
}
@keyframes LoadingCircleEf {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1);
		transform: scale(1)
	}
}
.pc-login-register-mobile .pclogin-sub {
	left: auto;
	right: auto;
	z-index: 999999
}
.penci-hidden {
	display: none
}
#penci-login-popup {
	position: relative;
	display: block;
	vertical-align: middle;
	margin: 0 auto;
	text-align: left;
	z-index: 10;
	width: 100%;
	max-width: 470px;
	padding: 44px;
	background: 0 0;
	background-size: auto;
	color: #313131;
	opacity: 0;
	-webkit-transition: all .4s cubic-bezier(.5, 0, .1, 1);
	transition: all .4s cubic-bezier(.5, 0, .1, 1);
	transform: scale(.6);
	-webkit-transform: scale(.6)
}
#penci-login-popup:after,
#penci-login-popup:before {
	content: "";
	position: absolute;
	z-index: -1;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	display: block;
	background: #fff no-repeat fixed center center;
	opacity: .75
}
#penci-login-popup:after {
	z-index: -2;
	background-color: transparent;
	opacity: 1
}
.mfp-ready #penci-login-popup {
	opacity: 1;
	transform: scale(1);
	-webkit-transform: scale(1)
}
.mfp-ready.mfp-removing #penci-login-popup {
	opacity: 0;
	transform: scale(.6);
	-webkit-transform: scale(.6)
}
.mfp-bg.penci-popup-animation {
	opacity: 0;
	transition: all .3s ease-out
}
.mfp-bg.penci-popup-animation.mfp-ready {
	opacity: .9
}
.mfp-bg.penci-popup-animation.mfp-ready.mfp-removing {
	opacity: 0
}
#penci-login-popup.ajax-loading:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 10;
	background: #fff;
	opacity: .65
}
#penci-login-popup.ajax-loading .penci-loader-effect {
	display: block
}
.penci-login-container .penci-login .register-input-checkbox,
.penci-login-container .penci-login input[type=email],
.penci-login-container .penci-login input[type=tel],
.penci-login-container .penci-login input[type=password],
.penci-login-container .penci-login input[type=submit],
.penci-login-container .penci-login input[type=text] {
	width: 100%;
	padding: 0 15px;
	border-radius: 0;
	margin-bottom: 20px;
	line-height: 40px
}
.register-input-checkbox:not(.checked) .pcpop-button {
	pointer-events: none;
	cursor: disabled;
	opacity: .6;
}
.penci-lgpop-title {
	text-align: center;
	line-height: 1.2;
	text-transform: uppercase;
	font-size: 24px;
	margin-bottom: 20px;
	letter-spacing: 0;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.pclogin-input-checkbox {
	margin-bottom: 20px
}
.pclg-2col>div {
	float: left;
	width: 47.5%;
	margin-right: 5%
}
.pclg-2col>div:last-child {
	margin-right: 0
}
.top-search-classes {
	float: right;
	width: 20px;
	text-align: center;
	margin-right: 0
}
#navigation .pcheader-icon.penci-top-search {
	margin-right: 0
}
#navigation .pcheader-icon,
.top-search-classes.shoping-cart-icon {
	margin-right: 10px
}
.top-search-classes.shoping-cart-icon {
	position: relative
}
#navigation .pcheader-icon:first-child,
#navigation.header-4 .pcheader-icon,
#navigation.header-5 .pcheader-icon,
#navigation.header-6 .pcheader-icon {
	margin-right: 0
}
.top-search-classes a.cart-contents,
.top-search-classes>a {
	font-size: 14px;
	line-height: 58px;
	display: block;
	height: 58px;
	cursor: pointer;
	-moz-transition: all .3s;
	-o-transition: all .3s;
	-webkit-transition: all .3s;
	transition: all .3s;
	color: #313131;
	background: 0 0
}
#navigation.header-6 .menu {
	margin-right: 30px
}
@media only screen and (min-width:961px) {
	#navigation.header-10 .top-search-classes>a,
	#navigation.header-10 a.cart-contents,
	#navigation.header-11 .top-search-classes>a,
	#navigation.header-11 a.cart-contents,
	#navigation.header-6 .top-search-classes>a,
	#navigation.header-6 a.cart-contents {
		line-height: 80px;
		height: 80px
	}
}
@media only screen and (max-width:960px) {
	#navigation.header-10 .top-search-classes>a,
	#navigation.header-10 a.cart-contents,
	#navigation.header-11 .top-search-classes>a,
	#navigation.header-11 a.cart-contents,
	#navigation.header-6 .top-search-classes>a,
	#navigation.header-6 a.cart-contents {
		line-height: 60px;
		height: 60px
	}
}
.is-sticky #navigation.header-10 .top-search-classes>a,
.is-sticky #navigation.header-10 a.cart-contents,
.is-sticky #navigation.header-11 .top-search-classes>a,
.is-sticky #navigation.header-11 a.cart-contents,
.is-sticky #navigation.header-6 .top-search-classes>a,
.is-sticky #navigation.header-6 a.cart-contents {
	line-height: 58px;
	height: 58px
}
.top-search-classes a.cart-contents>i,
.top-search-classes>a>i {
	width: 20px
}
.top-search-classes a.cart-contents,
.top-search-classes.compare-icon>a,
.top-search-classes.shoping-cart-icon>a,
.top-search-classes.wishlist-icon>a {
	position: relative
}
.top-search-classes a.cart-contents>i,
.top-search-classes.shoping-cart-icon>a>i {
	font-size: 17px
}
.top-search-classes a.cart-contents>span,
.top-search-classes.compare-icon>a>span,
.top-search-classes.shoping-cart-icon>a>span,
.top-search-classes.wishlist-icon>a>span {
	font-family: var(--pcbody-font);
	font-size: 9px;
	line-height: 14px;
	position: absolute;
	z-index: 1;
	top: calc(50% - 17px);
	right: -4px;
	display: inline-block;
	width: 14px;
	height: 14px;
	-moz-transition: all .3s;
	-webkit-transition: all .3s;
	transition: all .3s;
	text-align: center;
	white-space: nowrap;
	color: #fff;
	-moz-border-radius: 50%;
	-webkit-border-radius: 50%;
	border-radius: 50%;
	background: var(--pcaccent-cl)
}
.top-search-classes .svg-icon {
	display: inline-block;
	margin-top: 5px
}
.top-search-classes.shoping-cart-icon .svg-icon {
	margin-top: 3px
}
@media only screen and (max-width:960px) {
	#navigation.header-10 .pcheader-icon a.cart-contents,
	#navigation.header-10 .pcheader-icon>a,
	#navigation.header-11 .pcheader-icon a.cart-contents,
	#navigation.header-11 .pcheader-icon>a,
	#navigation.header-9 .pcheader-icon a.cart-contents,
	#navigation.header-9 .pcheader-icon>a {
		height: 58px;
		line-height: 58px
	}
}
#navigation {
	background: #fff;
	height: 60px;
	z-index: 9999;
	width: 100%;
	-webkit-backface-visibility: hidden;
	border-bottom: 1px solid #ececec;
	transition: box-shadow .3s;
	-webkit-transition: box-shadow .3s;
	-moz-transition: box-shadow .3s;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.wrapper-boxed.enable-boxed #navigation {
	transition: height .3s, box-shadow .3s;
	-webkit-transition: height .3s, box-shadow .3s;
	-moz-transition: height .3s, box-shadow .3s
}
#navigation.sticky-active {
	z-index: 99999
}
#navigation.header-6,
#navigation.header-9 {
	transition: box-shadow .3s, height .3s;
	-webkit-transition: box-shadow .3s, height .3s;
	-moz-transition: box-shadow .3s, height .3s
}
#navigation.header-7,
#navigation.header-8,
#navigation.header-9 {
	padding: 0 20px
}
#navigation.header-layout-bottom {
	box-shadow: 0 0 0 transparent;
	-webkit-box-shadow: 0 0 0 transparent;
	-moz-box-shadow: 0 0 0 transparent;
	border-top: 1px solid #ececec
}
#navigation.header-1,
#navigation.header-4,
#navigation.header-7 {
	border-top: 1px solid transparent !important
}
.is-sticky #navigation {
	box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-webkit-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-moz-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	border-color: transparent !important
}
.wrapper-boxed.enable-boxed .is-sticky #navigation {
	margin: 0 auto;
	left: 0;
	right: 0;
	width: 100%;
	max-width: calc(var(--pcctain) + 60px)
}
.penci-body-boxed.penci-two-sidebar .wrapper-boxed.enable-boxed .is-sticky #navigation {
	max-width: calc(var(--pcctain2) + 30px)
}
.slicknav_menu {
	display: none
}
#navigation .container {
	position: relative;
	display: table;
	text-align: center
}
#navigation.header-7 .container,
#navigation.header-8 .container,
#navigation.header-9 .container {
	width: 100%;
	--pcctain: calc(100vw - 40px)
}
#navigation .container .inner-top-navigation {
	display: inline-block;
	vertical-align: top
}
#navigation .menu {
	float: left
}
#navigation.header-4 .menu,
#navigation.header-4 .pcheader-icon,
#navigation.header-4 .top-search-classes,
#navigation.header-5 .menu,
#navigation.header-5 .pcheader-icon,
#navigation.header-5 .top-search-classes {
	float: none;
	vertical-align: top
}
#navigation.header-4 .pcheader-icon,
#navigation.header-4 .top-search-classes,
#navigation.header-5 .pcheader-icon,
#navigation.header-5 .top-search-classes {
	margin-left: 40px;
	display: inline-block
}
#navigation .menu>ul>li,
#navigation ul.menu>li {
	display: inline-block;
	position: relative;
	float: left;
	margin-right: 30px
}
#navigation .menu>li:last-child,
#navigation .menu>ul>li:last-child {
	margin-right: 0
}
#navigation .menu>li>a,
#navigation .sub-menu li a {
	font-family: var(--pchead-font);
	font-size: 12px;
	color: #313131;
	text-transform: uppercase;
	display: inline-block;
	-o-transition: .3s;
	-ms-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	position: relative;
	font-weight: var(--pchead-wei);
	text-decoration: none
}
#navigation .menu>li>a {
	line-height: 58px
}
#navigation .menu>li>a>i,
#navigation .sub-menu li>a>i {
	font-size: 13px;
	margin-right: 5px
}
#navigation .menu>ul>li>a:before,
#navigation ul.menu>li>a:before {
	content: "";
	position: absolute;
	bottom: 18px;
	transition: all .2s;
	-webkit-transition: all .2s;
	-moz-transition: all .2s;
	left: 50%;
	height: 2px;
	width: 0;
	background: var(--pcaccent-cl)
}
#navigation .menu>ul>li:hover>a:before,
#navigation .menu>ul>li>a:hover:before,
#navigation ul.menu>li:hover>a:before,
#navigation ul.menu>li>a:hover:before {
	left: 0;
	width: 100%
}
#navigation .menu>li.current-menu-ancestor>a,
#navigation .menu>li.current-menu-item>a,
#navigation .menu>li.current_page_item>a,
#navigation .menu>li:hover>a,
#navigation .menu>li>a:hover {
	color: var(--pcaccent-cl)
}
#navigation .menu>ul>li>a>img,
#navigation ul.menu>li>a>img {
	vertical-align: middle
}
#navigation .button-menu-mobile {
	display: none;
	float: left;
	line-height: 60px;
	text-align: center;
	color: #313131;
	font-size: 21px;
	cursor: pointer;
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s
}
#logo a {
	display: inline-block;
	vertical-align: top
}
#logo h1 {
	margin: 0
}
.penci-mobile-hlogo {
	display: none;
	float: left;
	margin-left: 10px
}
.penci-mobile-hlogo a {
	display: inline-block
}
.penci-mobile-hlogo img {
	max-height: 60px;
	padding: 8px 0;
	width: auto
}
@media only screen and (max-width:960px) {
	.penci-hlogo-center #navigation.header-6 #logo,
	.penci-hlogo-center .penci-mobile-hlogo {
		float: none;
		margin: 0;
		position: absolute;
		left: 50%;
		top: 0;
		transform: translateX(-50%);
		-webkit-transform: translateX(-50%);
		z-index: 10
	}
	.penci-mobile-hlogo {
		display: inline-block
	}
}
#navigation.header-6 {
	height: 82px
}
#navigation.header-6 .container {
	text-align: right
}
#navigation.header-6 .menu {
	float: none
}
#navigation.header-6 #logo {
	float: left;
	display: block;
	text-align: left
}
#navigation.header-6 #logo img {
	padding: 12px 0;
	max-height: 80px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	width: auto
}
#navigation.header-6 .menu>li>a,
#navigation.header-6 ul.menu>li>a {
	line-height: 80px
}
#navigation.header-6 .menu>ul>li>a:before,
#navigation.header-6 ul.menu>li>a:before {
	bottom: 29px
}
#navigation.header-6 .pcheader-icon {
	margin-left: 40px
}
#navigation.header-6 .pcheader-icon>a {
	height: 80px;
	line-height: 80px
}
@media only screen and (min-width:961px) {
	.header-search-style-default #navigation.header-6 .penci-menuhbg-toggle,
	.header-search-style-default #navigation.header-6 .show-search {
		height: 80px
	}
	.header-search-style-default #navigation.header-6 .show-search a.close-search {
		height: 80px;
		line-height: 80px
	}
	.header-search-style-default #navigation.header-6 .show-search form.pc-searchform input.search-input {
		height: 80px;
		padding: 26px 35px 26px 0
	}
}
#navigation.header-10>.container,
#navigation.header-11>.container {
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-flex-wrap: wrap;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap
}
#navigation.header-10 .penci-menu-wrap,
#navigation.header-11 .penci-menu-wrap {
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	flex: 3 0;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-flex-wrap: wrap;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap;
	width: 100%;
	float: left;
	text-align: center;
	-webkit-justify-content: space-between;
	justify-content: space-between
}
#navigation.header-10 .penci-menu-wrap #logo,
#navigation.header-11 .penci-menu-wrap #logo {
	width: 24%;
	display: flex;
	justify-content: center;
	align-items: center;
	position: relative
}
#navigation.header-10 .penci-menu-wrap .menu,
#navigation.header-11 .penci-menu-wrap .menu {
	padding: 0;
	margin: 0;
	display: flex;
	align-items: center;
	flex-wrap: wrap
}
#navigation.header-10,
#navigation.header-11 {
	height: 82px
}
#navigation.header-10 .menu>li>a,
#navigation.header-10 ul.menu>li>a,
#navigation.header-11 .menu>li>a,
#navigation.header-11 ul.menu>li>a {
	line-height: 80px
}
#navigation.header-10 #logo img,
#navigation.header-11 #logo img {
	padding: 12px 0;
	max-height: 80px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	width: auto
}
.is-sticky #navigation.header-10 #logo img,
.is-sticky #navigation.header-11 #logo img {
	padding: 7px 0
}
#navigation.header-10 .penci-header-extra,
#navigation.header-11 .penci-header-extra {
	margin-left: 15px
}
#navigation.header-10 .pcheader-icon>a,
#navigation.header-10 .penci-menuhbg-toggle,
#navigation.header-10 .show-search a.close-search,
#navigation.header-11 .pcheader-icon>a,
#navigation.header-11 .penci-menuhbg-toggle,
#navigation.header-11 .show-search a.close-search {
	height: 80px;
	line-height: 80px
}
@media only screen and (min-width:961px) {
	.header-search-style-default #navigation.header-11 .show-search form.pc-searchform input.search-input {
		height: 80px;
		padding: 26px 35px 26px 20px
	}
	.header-search-style-default #navigation.header-10 .show-search form.pc-searchform input.search-input {
		height: 80px;
		padding: 26px 35px 26px 0
	}
	.header-search-style-default #navigation.header-10 .show-search,
	.header-search-style-default #navigation.header-11 .show-search {
		height: 80px
	}
	.header-search-style-default #navigation.header-11 .show-search a.close-search {
		right: 10px
	}
}
.is-sticky #navigation.header-10,
.is-sticky #navigation.header-11,
.is-sticky #navigation.header-6 {
	height: 60px
}
.is-sticky #navigation.header-6 #logo img {
	max-height: 58px;
	padding: 7px 0
}
.is-sticky #navigation.header-6 .menu>li>a,
.is-sticky #navigation.header-6 ul.menu>li>a {
	line-height: 58px
}
.is-sticky #navigation.header-6 .menu>ul>li>a:before,
.is-sticky #navigation.header-6 ul.menu>li>a:before {
	bottom: 18px
}
.is-sticky #navigation.header-10 .penci-menuhbg-toggle,
.is-sticky #navigation.header-10 .show-search,
.is-sticky #navigation.header-11 .penci-menuhbg-toggle,
.is-sticky #navigation.header-11 .show-search,
.is-sticky #navigation.header-6 .penci-menuhbg-toggle,
.is-sticky #navigation.header-6 .show-search {
	height: 58px
}
.is-sticky #navigation.header-10 .pcheader-icon>a,
.is-sticky #navigation.header-10 .show-search a.close-search,
.is-sticky #navigation.header-11 .pcheader-icon>a,
.is-sticky #navigation.header-11 .show-search a.close-search,
.is-sticky #navigation.header-6 .pcheader-icon>a,
.is-sticky #navigation.header-6 .show-search a.close-search {
	height: 58px;
	line-height: 58px
}
.is-sticky #navigation.header-11 .show-search form.pc-searchform input.search-input {
	padding: 15px 35px 15px 15px;
	height: 58px
}
.is-sticky #navigation.header-10 .show-search form.pc-searchform input.search-input,
.is-sticky #navigation.header-6 .show-search form.pc-searchform input.search-input {
	height: 58px;
	padding: 15px 35px 15px 0
}
#navigation .penci-dropdown-menu,
#navigation .sub-menu,
.navigation .penci-dropdown-menu,
.navigation .sub-menu {
	pointer-events: none
}
#navigation li:hover>.penci-dropdown-menu,
#navigation li:hover>.sub-menu,
.navigation li:hover>.penci-dropdown-menu,
.navigation li:hover>.sub-menu {
	pointer-events: auto
}
#navigation .menu .sub-menu {
	visibility: hidden;
	opacity: 0;
	position: absolute;
	left: 0;
	z-index: 9999;
	box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-webkit-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-moz-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	border-top: 1px solid #ececec;
	margin-top: 0;
	background: #fff
}
#navigation ul.menu ul.sub-menu li>a {
	margin: 0 20px;
	padding: 12px 0;
	font-size: 12px;
	min-width: 200px;
	line-height: 1.4;
	-moz-transition: color .3s, background-color .3s;
	-webkit-transition: color .3s, background-color .3s;
	transition: color .3s, background-color .3s;
	border-bottom: 1px solid #e0e0e0;
	text-align: left;
	border-left: none !important;
	position: relative;
	overflow: hidden;
	vertical-align: top
}
#navigation ul.menu ul.sub-menu li,
#navigation ul.menu ul.sub-menu ul li {
	padding-right: 0;
	margin-right: 0;
	float: none;
	position: relative;
	width: 100%
}
#navigation .menu ul.sub-menu>li:last-child>a {
	border-bottom: none
}
#navigation .menu .sub-menu ul {
	left: 100%;
	top: 0
}
body #navigation .menu .sub-menu,
body .navigation .menu .sub-menu,
body .penci-dropdown-menu {
	transition: transform .27s ease-in-out, opacity .27s ease-in-out, visibility .27s ease-in-out;
	-webkit-transform-origin: 0 0;
	-moz-transform-origin: 0 0;
	-ms-transform-origin: 0 0;
	-o-transform-origin: 0 0;
	transform-origin: 0 0
}
body.pcmn-drdw-style-slide_down #navigation .menu .sub-menu,
body.pcmn-drdw-style-slide_down .navigation .menu .sub-menu,
body.pcmn-drdw-style-slide_down .penci-dropdown-menu {
	-webkit-transform: rotateX(-90deg);
	-moz-transform: rotateX(-90deg);
	-ms-transform: rotateX(-90deg);
	-o-transform: rotateX(-90deg);
	transform: rotateX(-90deg)
}
body.pcmn-drdw-style-slide_down #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-slide_down #navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-slide_down #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-slide_down #navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-slide_down .navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-slide_down .navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-slide_down .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-slide_down .navigation ul.menu li:hover>ul {
	visibility: visible;
	opacity: 1;
	-webkit-transform: rotateX(0);
	-moz-transform: rotateX(0);
	-ms-transform: rotateX(0);
	-o-transform: rotateX(0);
	transform: rotateX(0)
}
body.pcmn-drdw-style-fadein_up #navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_up .navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_up .penci-dropdown-menu {
	-ms-transform: translateY(10px);
	transform: translateY(10px)
}
body.pcmn-drdw-style-fadein_down #navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_down .navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_down .penci-dropdown-menu {
	-ms-transform: translateY(-10px);
	transform: translateY(-10px)
}
body.pcmn-drdw-style-fadein_down #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_down #navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_down #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_down #navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_down .navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_down .navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_down .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_down .navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_up #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_up #navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_up #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_up #navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_up .navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_up .navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_up .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_up .navigation ul.menu li:hover>ul {
	visibility: visible;
	opacity: 1;
	-ms-transform: translateY(0);
	transform: translateY(0)
}
body.pcmn-drdw-style-fadein_left #navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_left .navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_left .penci-dropdown-menu {
	-ms-transform: translateX(-10px);
	transform: translateX(-10px)
}
body.pcmn-drdw-style-fadein_right #navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_right .navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_right .penci-dropdown-menu {
	-ms-transform: translateX(10px);
	transform: translateX(10px)
}
body.pcmn-drdw-style-fadein_left #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_left #navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_left #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_left #navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_left .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_left .navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_right #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_right #navigation .menu ul li:hover>ul,
body.pcmn-drdw-style-fadein_right #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_right #navigation ul.menu li:hover>ul,
body.pcmn-drdw-style-fadein_right .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_right .navigation ul.menu li:hover>ul {
	visibility: visible;
	opacity: 1;
	-ms-transform: translateX(0);
	transform: translateX(0)
}
body.pcmn-drdw-style-fadein_none #navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_none .navigation .menu .sub-menu,
body.pcmn-drdw-style-fadein_none .penci-dropdown-menu {
	opacity: 0
}
body.pcmn-drdw-style-fadein_none #navigation .menu ul li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_none #navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_none .navigation ul.menu li:hover>.penci-dropdown-menu,
body.pcmn-drdw-style-fadein_none .navigation ul.menu li:hover>ul {
	visibility: visible;
	opacity: 1
}
#navigation .menu li.penci-mega-menu {
	position: static !important
}
li.penci-mega-menu>ul.sub-menu {
	display: none
}
#sidebar-nav li.penci-mega-menu .penci-content-megamenu,
.penci-menu-hbg li.penci-mega-menu .penci-content-megamenu {
	display: none !important
}
#navigation .menu li.penci-mega-menu>ul.sub-menu {
	width: 100%;
	padding: 0 !important;
	clear: both;
	display: block
}
#navigation .menu li.penci-block-mega.penci-mg-fullwidth>.penci-dropdown-menu {
	width: 100vw !important;
	left: calc((100vw - var(--pcctain))/ 2 * -1) !important
}
#navigation .menu li.penci-block-mega.penci-mg-fullwidth,
#navigation .menu li.penci-block-mega.penci-mg-fullwidth.penci-megapos-center,
#navigation .menu li.penci-block-mega.penci-mg-fullwidth.penci-megapos-flexible,
.navigation .menu li.penci-block-mega.penci-mg-fullwidth.penci-megapos-center,
.navigation .menu li.penci-block-mega.penci-mg-fullwidth.penci-megapos-flexible {
	position: static !important
}
#navigation .menu li.penci-block-mega.penci-mg-fullwidth>.penci-dropdown-menu>.container {
	width: 100%
}
#navigation .penci-megamenu {
	width: 100%;
	display: table
}
#navigation .penci-megamenu .penci-mega-child-categories {
	width: 230px;
	display: table-cell;
	vertical-align: top;
	background: #fff;
	padding: 20px 0;
	position: relative
}
#navigation .penci-megamenu .penci-mega-child-categories.pcmit-top {
	display: table-row;
	width: 100%
}
#navigation .penci-megamenu .penci-mega-child-categories.pcmit-bottom {
	display: table-footer-group;
	width: 100%
}
#navigation .penci-megamenu .penci-mega-child-categories:after {
	content: "";
	width: 1px;
	height: 100%;
	position: absolute;
	top: 0;
	right: 0;
	background-color: #ececec
}
#navigation .penci-megamenu .penci-mega-child-categories a {
	min-width: 0;
	display: block;
	font-size: 12px;
	text-align: right;
	line-height: 1.4em;
	margin: 0;
	padding: 12px 20px;
	border-top: 1px solid transparent;
	border-bottom: 1px solid transparent;
	position: relative
}
#navigation .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
#navigation .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	display: inline-block
}
#navigation .penci-megamenu .penci-mega-child-categories a.cat-active {
	border-top-color: #ececec;
	border-bottom-color: #ececec;
	background: #fff;
	color: var(--pcaccent-cl);
	z-index: 10;
	position: relative
}
#navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before {
	content: "";
	width: 1px;
	height: 100%;
	position: absolute;
	top: 0;
	right: 0;
	background: #fff;
	z-index: 1;
	transition: none;
	-webkit-transition: none;
	-moz-transition: none
}
#navigation .penci-megamenu .penci-content-megamenu {
	display: table-cell
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts {
	padding: 20px 10px 0 10px
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-row {
	width: 100%;
	display: none;
	vertical-align: top
}
.penci-mega-post-inner {
	position: relative;
	overflow: hidden;
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post,
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
	width: 20%;
	padding: 0 10px;
	float: left;
	margin-bottom: 20px;
	position: relative
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post,
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
	width: 25%
}
#navigation .penci-megamenu .pcmit-side+.penci-content-megamenu.pcmis-4 .penci-mega-latest-posts.col-mn-4 .penci-mega-post,
.navigation .penci-megamenu .pcmit-side+.penci-content-megamenu.pcmis-4 .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
	width: calc(100% / 3)
}
.navigation .penci-megamenu .pcmit-side+.penci-content-megamenu.pcmis-4 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(3n+1),
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(5n+1),
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(5n+1) {
	clear: both
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(4n+1),
.navigation .penci-megamenu .pcmit-side+.penci-content-megamenu.pcmis-4 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(3n+1){
	clear: none
}
.penci-megamenu .penci-image-holder:before {
	padding-top: 66.6667%
}
@media only screen and (min-width:1800px) {
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 14.2857%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 16.66666%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(6n+1),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(7n+1) {
		clear: both
	}
}
@media only screen and (max-width:1799px) and (min-width:1500px) {
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 16.66666%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 20%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(5n+1),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(6n+1) {
		clear: both
	}
	#navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(5n+1) {
		clear: none
	}
}
@media only screen and (max-width:1799px) {
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(6),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(11),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(12),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(16),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(17),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(18),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(7),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(13),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(14),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(19),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(20),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(21) {
		display: none
	}
}
@media only screen and (max-width:1499px) and (min-width:1170px) {
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 20%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 25%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(4n+1),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(5n+1) {
		clear: both
	}
}
@media only screen and (max-width:1499px) {
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(5),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(10),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(9),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(13),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(14),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(15),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(6),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(11),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(12),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(16),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(17),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(18) {
		display: none
	}
}
@media only screen and (max-width:1169px) {
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 25%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 33.33333%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(3n+1),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(4n+1) {
		clear: both
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(4),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(7),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(8),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(10),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(11),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(12),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(5),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(10),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(9),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(13),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(14),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(15) {
		display: none
	}
}
#navigation .penci-megamenu .penci-mega-thumbnail {
	display: block;
	margin: 0 0 17px 0;
	position: relative
}
#navigation .penci-megamenu .penci-mega-thumbnail a {
	width: 100%
}
#navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
	font-size: 10px;
	background: var(--pcaccent-cl);
	text-transform: uppercase;
	position: absolute;
	display: inline-block;
	padding: 0 6px;
	color: #fff;
	top: 0;
	left: 0;
	z-index: 3;
	height: 18px;
	font-weight: 400;
	line-height: 18px
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post a {
	margin: 0;
	padding: 0;
	min-width: 0;
	border-bottom: none;
	position: relative;
	text-align: center;
	line-height: 1.4
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post a:hover,
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post a:hover {
	color: var(--pcaccent-cl)
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail a {
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail a:hover {
	opacity: .8
}
#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail .mega-cat-name a {
	font-size: inherit !important;
	font-family: inherit !important;
	font-weight: inherit !important;
	line-height: inherit !important;
	color: inherit !important;
	opacity: 1;
	padding: 0;
	margin: 0;
	text-transform: none;
	letter-spacing: 0
}
#navigation .penci-megamenu .penci-mega-thumbnail img {
	width: 100%;
	height: auto
}
.penci-megamenu .post-mega-title {
	font-family: var(--pchead-font);
	font-style: normal;
	font-weight: var(--pchead-wei);
	line-height: 1.35
}
#navigation .penci-megamenu .post-mega-title {
	text-align: center;
	margin: 0
}
#navigation .penci-megamenu .post-mega-title a {
	text-align: center
}
#navigation .penci-megamenu .penci-mega-date {
	line-height: 1;
	font-size: 12px;
	color: #999;
	text-align: center;
	margin-top: 6px
}
#navigation ul.menu>li.megamenu {
	position: static
}
#navigation ul.menu>li.megamenu>ul.sub-menu {
	width: var(--pcctain);
	padding: 15px 0;
	display: table;
	table-layout: fixed;
	background: #fff;
	left: 0
}
#navigation.header-7 ul.menu>li.megamenu>ul.sub-menu,
#navigation.header-8 ul.menu>li.megamenu>ul.sub-menu,
#navigation.header-9 ul.menu>li.megamenu>ul.sub-menu {
	width: 100%
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li {
	min-width: 200px;
	max-width: 300px;
	display: table-cell;
	vertical-align: top;
	padding: 0 5px;
	margin: 0;
	position: relative
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li:before {
	left: 0;
	content: "";
	position: absolute;
	top: 15px;
	bottom: 15px;
	width: 1px;
	display: block;
	background: #e0e0e0
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li:first-child:before {
	content: none;
	display: none
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li>a {
	margin: 0 20px;
	border-bottom: 1px solid #e0e0e0;
	display: none
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu {
	visibility: visible;
	opacity: 1;
	transform: none;
	-webkit-transform: none;
	-moz-transform: none;
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	position: static;
	border: none
}
#navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu li,
#navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu li a {
	display: block
}
#navigation.menu-style-2 .menu>ul>li>a:before,
#navigation.menu-style-2 ul.menu>li>a:before {
	content: none;
	display: none
}
#navigation .menu>ul>li.menu-item-has-children>a:after,
#navigation .menu>ul>li.penci-mega-menu>a:after,
#navigation ul.menu>li.menu-item-has-children>a:after,
#navigation ul.menu>li.penci-mega-menu>a:after {
	font-family: FontAwesome;
	content: "\f107";
	margin-left: 5px;
	color: inherit;
	font-size: 13px;
	font-weight: 400;
	width: auto;
	display: inline-block;
	transform: scale(.8)
}
#navigation ul.sub-menu>li.menu-item-has-children>a:after {
	font-family: FontAwesome;
	content: "\f105";
	margin-left: 5px;
	color: inherit;
	font-size: 13px;
	font-weight: 400;
	width: auto;
	display: inline-block;
	float: right;
	transform: scale(.8)
}
.penci-fawesome-ver5 #navigation .menu>ul>li.menu-item-has-children>a:after,
.penci-fawesome-ver5 #navigation .menu>ul>li.penci-mega-menu>a:after,
.penci-fawesome-ver5 #navigation ul.menu>li.menu-item-has-children>a:after,
.penci-fawesome-ver5 #navigation ul.menu>li.penci-mega-menu>a:after {
	font-family: "Font Awesome 5 Free";
	content: "\f107";
	font-weight: 900
}
#navigation.menu-style-2 .menu .children,
#navigation.menu-style-2 .menu .sub-menu {
	border-top: 4px solid #e0e0e0;
	padding: 8px 0
}
#navigation.menu-style-2 .menu ul ul.sub-menu:before,
#navigation.menu-style-2 ul.menu ul.sub-menu:before {
	width: 0;
	height: 4px;
	top: -4px;
	position: absolute;
	background: var(--pcaccent-cl);
	left: 0;
	-webkit-transition: width .4s cubic-bezier(.87, .02, .23, 1);
	-webkit-transition: width .4s cubic-bezier(.87, .02, .23, 1.005);
	-moz-transition: width .4s cubic-bezier(.87, .02, .23, 1.005);
	-o-transition: width .5s cubic-bezier(.87, .02, .23, 1.005);
	transition: width .5s cubic-bezier(.87, .02, .23, 1.005);
	content: "";
	transition-delay: .3s;
	-webkit-transition-delay: .3s;
	-moz-transition-delay: .3s
}
#navigation.menu-style-2 .menu ul li:hover>ul:before,
#navigation.menu-style-2 ul.menu li:hover>ul:before {
	width: 100%
}
#navigation.menu-style-2 ul.menu ul.sub-menu a {
	padding: 8px 0;
	border: none !important
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts {
	padding: 0
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
	margin: 0;
	position: relative;
	z-index: 5
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu.pcmis-1 .penci-mega-latest-posts .penci-mega-post {
	padding: 0 0 15px;
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-thumbnail {
	position: relative;
	z-index: 5
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-meta {
	padding: 0 5px
}
#navigation.menu-style-2 .penci-megamenu .post-mega-title {
	line-height: 1
}
.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post:before {
	position: absolute;
	content: "";
	right: 0;
	top: 0;
	bottom: 0;
	width: 1px;
	background: #f1f1f2;
	z-index: 1
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
	bottom: 0;
	top: auto
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories {
	padding: 12px 0
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories:after {
	background-color: #f1f1f2
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a {
	min-width: 0;
	display: block;
	text-align: left;
	line-height: 1.4em;
	margin: 0;
	padding: 6px 0 6px 20px;
	position: relative;
	border: none;
	background-color: inherit;
	z-index: 0
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	display: inline-block
}
#navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories a,
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
	padding: 6px 0 6px 20px
}
#navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
#navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	padding-top: 20px;
	padding-bottom: 20px
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after {
	content: "";
	display: block;
	position: absolute;
	top: 50%;
	margin-top: -.5px;
	-webkit-transition: width .4s ease-in-out;
	-o-transition: width .4s ease-in-out;
	transition: width .4s ease-in-out;
	border-bottom: 1px solid;
	width: 0;
	opacity: .3;
	left: 20px;
	z-index: 1;
	box-shadow: none;
	-webkit-box-shadow: none;
	color: inherit
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:hover:after {
	width: calc(100% + 20px)
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span {
	position: relative;
	z-index: 2;
	background-color: inherit;
	padding-right: 20px;
	display: inline-block
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.all-style:before {
	content: "";
	background: #f1f1f2;
	width: 24px;
	display: block;
	height: 1px;
	margin: 4px 0 17px;
	opacity: 1;
	position: static;
	box-shadow: none;
	-webkit-box-shadow: none
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-bottom a.all-style:before,
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-top a.all-style:before {
	display: none
}
#navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.all-style:after {
	content: none;
	display: none
}
#navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu {
	padding: 5px 0
}
#navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu:before {
	display: none;
	content: none
}
#navigation.menu-style-3 .menu .children,
#navigation.menu-style-3 .menu .penci-dropdown-menu,
#navigation.menu-style-3 .menu .sub-menu,
.navigation.menu-style-3 .menu .children,
.navigation.menu-style-3 .menu .penci-dropdown-menu,
.navigation.menu-style-3 .menu .sub-menu {
	border: 1px solid var(--pcborder-cl)
}
#navigation.menu-style-3 .menu .sub-menu:after,
#navigation.menu-style-3 .menu .sub-menu:before,
.navigation.menu-style-3 .menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu:before {
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 0 6px 6px 6px;
	border-color: transparent transparent var(--pcborder-cl) transparent;
	transform: rotate(0);
	position: absolute;
	top: -6px;
	left: 14px;
	content: "";
	z-index: 99
}
#navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
#navigation.menu-style-3 .menu .sub-menu .sub-menu:before,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:before {
	top: 10px;
	left: -6px;
	border-width: 6px 6px 6px 0;
	border-color: transparent var(--pcborder-cl) transparent transparent;
	border-bottom-color: transparent !important
}
#navigation.menu-style-3 .menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu:after {
	border-width: 0 5px 5px 5px;
	border-color: transparent transparent #fff transparent;
	top: -4px;
	left: 15px
}
#navigation.menu-style-3 .menu .sub-menu .sub-menu:after,
.navigation.menu-style-3 .menu .sub-menu .sub-menu:after {
	top: 11px;
	left: -4px;
	border-width: 5px 5px 5px 0;
	border-color: transparent #fff transparent transparent;
	border-bottom-color: transparent !important
}
#navigation.menu-style-3 .menu .megamenu .sub-menu:after,
#navigation.menu-style-3 .menu .megamenu .sub-menu:before,
#navigation.menu-style-3 .menu .penci-mega-menu .sub-menu:after,
#navigation.menu-style-3 .menu .penci-mega-menu .sub-menu:before,
.navigation.menu-style-3 .menu .megamenu .sub-menu:after,
.navigation.menu-style-3 .menu .megamenu .sub-menu:before,
.navigation.menu-style-3 .menu .penci-mega-menu .sub-menu:after,
.navigation.menu-style-3 .menu .penci-mega-menu .sub-menu:before {
	content: none;
	display: none
}
#navigation.menu-item-padding .menu>ul>li,
#navigation.menu-item-padding ul.menu>li {
	margin: 0
}
#navigation.menu-item-padding .menu>ul>li>a,
#navigation.menu-item-padding ul.menu>li>a {
	padding: 0 15px
}
#navigation.menu-item-padding .menu>li.current-menu-ancestor>a,
#navigation.menu-item-padding .menu>li.current-menu-item>a,
#navigation.menu-item-padding .menu>li.current_page_item>a,
#navigation.menu-item-padding .menu>li:hover>a,
#navigation.menu-item-padding .menu>li>a:hover {
	background-color: #ececec
}
#navigation.menu-item-padding .menu>ul>li>a:before,
#navigation.menu-item-padding ul.menu>li>a:before {
	content: none;
	display: none
}
@media only screen and (min-width:961px) {
	#navigation.header-1.menu-item-padding,
	#navigation.header-1.menu-item-padding ul.menu>li>a,
	#navigation.header-4.menu-item-padding,
	#navigation.header-4.menu-item-padding ul.menu>li>a,
	#navigation.header-7.menu-item-padding,
	#navigation.header-7.menu-item-padding ul.menu>li>a {
		height: 59px
	}
	.is-sticky #navigation.header-1.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-10.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-11.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-4.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-6.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-7.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-9.menu-item-padding ul.menu>li>a {
		height: 58px
	}
	.is-sticky #navigation.header-10.penci-logo-overflow #logo,
	.is-sticky #navigation.header-11.penci-logo-overflow #logo {
		height: 58px !important
	}
	.is-sticky #navigation.header-10 #logo img,
	.is-sticky #navigation.header-11 #logo img {
		max-height: 58px
	}
	.is-sticky #navigation.header-10 .menu>li>a,
	.is-sticky #navigation.header-10 ul.menu>li>a,
	.is-sticky #navigation.header-11 .menu>li>a,
	.is-sticky #navigation.header-11 ul.menu>li>a {
		line-height: 58px
	}
	#navigation.header-10.menu-item-padding,
	#navigation.header-10.menu-item-padding ul.menu>li>a,
	#navigation.header-11.menu-item-padding,
	#navigation.header-11.menu-item-padding ul.menu>li>a,
	#navigation.header-6.menu-item-padding,
	#navigation.header-6.menu-item-padding ul.menu>li>a,
	#navigation.header-9.menu-item-padding,
	#navigation.header-9.menu-item-padding ul.menu>li>a {
		height: 81px
	}
	#navigation.header-2.menu-item-padding ul.menu>li>a,
	#navigation.header-3.menu-item-padding ul.menu>li>a,
	#navigation.header-5.menu-item-padding ul.menu>li>a,
	#navigation.header-8.menu-item-padding ul.menu>li>a {
		height: 60px;
		margin-top: -1px
	}
	.is-sticky #navigation.header-2.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-3.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-5.menu-item-padding ul.menu>li>a,
	.is-sticky #navigation.header-8.menu-item-padding ul.menu>li>a {
		height: 58px;
		margin-top: 0
	}
	#navigation.header-1.menu-item-padding,
	#navigation.header-4.menu-item-padding,
	#navigation.header-6.menu-item-padding,
	#navigation.header-7.menu-item-padding,
	#navigation.header-9.menu-item-padding {
		border-top: none !important
	}
	.is-sticky #navigation.menu-item-padding {
		height: 58px;
		border: none !important
	}
	#navigation-sticky-wrapper:not(.is-sticky) .menu .children,
	#navigation-sticky-wrapper:not(.is-sticky) .menu .sub-menu {
		margin-top: -1px
	}
}
@-moz-document url-prefix() {
	#navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu:before {
		top: 0
	}
}
.pcmis-2 .penci-mega-post .penci-mega-meta {
	position: absolute;
	left: 0;
	right: 0;
	bottom: 0;
	background: #000;
	background: linear-gradient(0deg, rgba(0, 0, 0, 1) 0, rgba(0, 0, 0, 0) 100%);
	width: 100%;
	padding: 10px 5px;
	z-index: 6
}
#navigation.menu-style-2 .pcmis-2 .penci-mega-post .penci-mega-meta,
.navigation.menu-style-2 .pcmis-2 .penci-mega-post .penci-mega-meta {
	left: 0;
	right: 0;
	width: 100%;
	padding-bottom: 15px
}
#navigation.menu-style-2 .penci-megamenu .pcmis-2.penci-content-megamenu .penci-mega-latest-posts .penci-mega-post,
#navigation.menu-style-2 .penci-megamenu .pcmis-3.penci-content-megamenu .penci-mega-latest-posts .penci-mega-post,
.navigation.menu-style-2 .penci-megamenu .pcmis-2.penci-content-megamenu .penci-mega-latest-posts .penci-mega-post,
.navigation.menu-style-2 .penci-megamenu .pcmis-3.penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
	padding-bottom: 0
}
#navigation .penci-megamenu .pcmis-2 .penci-mega-thumbnail,
.navigation .penci-megamenu .pcmis-2 .penci-mega-thumbnail {
	margin-bottom: 0
}
.penci-megamenu .pcmis-2 .penci-image-holder:before {
	padding-top: 100%
}
#navigation.menu-style-2 .penci-megamenu .pcmis-2 .penci-mega-thumbnail .mega-cat-name,
#navigation.menu-style-2 .penci-megamenu .pcmis-3 .penci-mega-thumbnail .mega-cat-name,
.navigation.menu-style-2 .penci-megamenu .pcmis-2 .penci-mega-thumbnail .mega-cat-name,
.navigation.menu-style-2 .penci-megamenu .pcmis-3 .penci-mega-thumbnail .mega-cat-name {
	top: 0;
	bottom: auto
}
#navigation .menu ul.sub-menu li .pcmis-2 .penci-mega-post a,
#navigation .penci-megamenu .pcmis-2 .penci-mega-date,
.navigation .penci-megamenu .pcmis-2 .penci-mega-date,
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.pcmis-2 .penci-mega-post a {
	color: var(--pcbg-cl)
}
.pcmis-3 .penci-mega-post .penci-mega-meta {
	position: absolute;
	left: 0;
	right: 0;
	bottom: 10px;
	width: 100%;
	z-index: 6;
	text-align: left
}
#navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title,
#navigation .pcmis-4 .penci-mega-post .penci-mega-meta .post-mega-title,
#navigation .pcmis-5 .penci-mega-post .penci-mega-meta .post-mega-title,
#navigation .penci-megamenu .pcmis-3 .penci-mega-date,
#navigation .penci-megamenu .pcmis-4 .penci-mega-date,
#navigation .penci-megamenu .pcmis-5 .penci-mega-date,
#navigation .penci-megamenu .penci-content-megamenu.pcmis-3 .penci-mega-latest-posts .penci-mega-post a,
#navigation .penci-megamenu .penci-content-megamenu.pcmis-4 .penci-mega-latest-posts .penci-mega-post a,
#navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts .penci-mega-post a,
.navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title,
.navigation .pcmis-4 .penci-mega-post .penci-mega-meta .post-mega-title,
.navigation .pcmis-5 .penci-mega-post .penci-mega-meta .post-mega-title,
.navigation .penci-megamenu .pcmis-3 .penci-mega-date,
.navigation .penci-megamenu .pcmis-4 .penci-mega-date,
.navigation .penci-megamenu .pcmis-5 .penci-mega-date,
.navigation .penci-megamenu .penci-content-megamenu.pcmis-3 .penci-mega-latest-posts .penci-mega-post a,
.navigation .penci-megamenu .penci-content-megamenu.pcmis-4 .penci-mega-latest-posts .penci-mega-post a,
.navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts .penci-mega-post a {
	text-align: inherit
}
#navigation .penci-megamenu .pcmis-3 .penci-mega-date time,
.navigation .penci-megamenu .pcmis-3 .penci-mega-date time {
	background: var(--pcbg-cl);
	display: inline
}
#navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title,
.navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title {
	display: inline;
	background: #fff;
	line-height: normal;
	box-decoration-break: clone;
	-webkit-box-decoration-break: clone
}
#navigation .penci-megamenu .penci-content-megamenu.pcmis-3 .penci-mega-latest-posts .penci-mega-post a,
.navigation .penci-megamenu .penci-content-megamenu.pcmis-3 .penci-mega-latest-posts .penci-mega-post a {
	line-height: normal
}
#navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title a,
.navigation .pcmis-3 .penci-mega-post .penci-mega-meta .post-mega-title a {
	display: inline
}
#navigation .penci-megamenu .pcmis-3 .penci-mega-thumbnail,
.navigation .penci-megamenu .pcmis-3 .penci-mega-thumbnail {
	margin-bottom: 0
}
.pcmis-4 .penci-mega-post .penci-mega-post-inner,
.pcmis-5 .penci-mega-post .penci-mega-post-inner {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	align-items: center
}
.pcmis-4 .penci-mega-post .penci-mega-post-inner .penci-mega-thumbnail,
.pcmis-5 .penci-mega-post .penci-mega-post-inner .penci-mega-thumbnail {
	width: 100px
}
.pcmis-4 .penci-mega-post .penci-mega-post-inner .penci-mega-meta,
.pcmis-5 .penci-mega-post .penci-mega-post-inner .penci-mega-meta {
	width: calc(100% - 100px)
}
.pcmis-4 .penci-mega-post .penci-mega-meta,
.pcmis-5 .penci-mega-post .penci-mega-meta {
	text-align: left;
	padding: 0 0 0 20px
}
#navigation .penci-megamenu .pcmis-4 .penci-mega-thumbnail,
#navigation .penci-megamenu .pcmis-5 .penci-mega-thumbnail,
.navigation .penci-megamenu .pcmis-4 .penci-mega-thumbnail,
.navigation .penci-megamenu .pcmis-5 .penci-mega-thumbnail {
	margin-bottom: 0
}
.penci-megamenu .pcmis-4 .penci-image-holder:before {
	padding-top: 100%
}
.penci-megamenu .pcmis-5 .penci-image-holder:before {
	padding-top: 130px
}
#navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1),
#navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1),
.navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1),
.navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) {
	width: 40%;
	clear: both
}
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner .penci-mega-meta,
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner .penci-mega-thumbnail,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner .penci-mega-meta,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner .penci-mega-thumbnail {
	width: 100%;
	padding: 0
}
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner .penci-mega-thumbnail .penci-image-holder:before,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner .penci-mega-thumbnail .penci-image-holder:before {
	padding-top: 275px
}
#navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post,
.navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
	width: 30%
}
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner {
	display: block
}
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner .penci-mega-meta,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner .penci-mega-meta {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	padding: 20px;
	background: #000;
	background: linear-gradient(0deg, rgba(0, 0, 0, 1) 0, rgba(0, 0, 0, 0) 100%);
	z-index: 9
}
.pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-post-inner .penci-mega-meta .post-mega-title a,
.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-post-inner .penci-mega-meta .post-mega-title a {
	font-size: 18px
}
#navigation.menu-style-2 .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-meta,
#navigation.menu-style-2 .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-meta,
.navigation.menu-style-2 .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-meta,
.navigation.menu-style-2 .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-meta {
	padding: 30px
}
@media only screen and (min-width:961px) and (max-width:1170px) {
	.pcmis-4 .penci-mega-latest-posts .penci-mega-post .penci-mega-post-inner .penci-mega-meta .post-mega-title a,
	.pcmis-5 .penci-mega-latest-posts .penci-mega-post .penci-mega-post-inner .penci-mega-meta .post-mega-title a {
		overflow: hidden;
		text-overflow: ellipsis;
		display: -webkit-box !important;
		-webkit-line-clamp: 3;
		-webkit-box-orient: vertical
	}
}
#navigation .menu ul.sub-menu li .pcmis-2 .penci-mega-post a:not(:hover),
#navigation .menu ul.sub-menu li .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) a:not(:hover),
#navigation .menu ul.sub-menu li .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) a:not(:hover),
#navigation .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-date,
#navigation .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-date,
#navigation .penci-megamenu .penci-content-megamenu.pcmis-2 .penci-mega-post .penci-mega-date,
.navigation .menu ul.sub-menu li .pcmis-2 .penci-mega-post a:not(:hover),
.navigation .menu ul.sub-menu li .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) a:not(:hover),
.navigation .menu ul.sub-menu li .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) a:not(:hover),
.navigation .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(5n+1) .penci-mega-date,
.navigation .penci-megamenu .pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(7n+1) .penci-mega-date,.navigation .penci-megamenu .penci-content-megamenu.pcmis-2 .penci-mega-post .penci-mega-date {
	color: #fff
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post .penci-mega-post-inner,
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post .penci-mega-post-inner {
	margin: 10px
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post,
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
	padding-bottom: 0
}
.menu-style-2 .pcmis-5 .penci-mega-post {
	padding-left: 15px;
	padding-right: 15px
}
#navigation .penci-megamenu .pcmit-side.penci-mega-child-categories a.pcmnl-ci,
.navigation .penci-megamenu .pcmit-side.penci-mega-child-categories a.pcmnl-ci {
	font-size: 80%
}
#sidebar-nav,
.penci-menu-hbg {
	position: fixed !important;
	top: 0;
	height: 100%;
	z-index: 99997;
	width: 270px;
	overflow-y: auto;
	padding: 30px 20px 20px;
	background: #fff;
	left: 0;
	transition: all .5s;
	-webkit-transition: all .5s;
	-moz-transition: all .5s;
	transform: translateX(-270px);
	-webkit-transform: translateX(-270px);
	-moz-transform: translateX(-270px)
}
#sidebar-nav {
	transform: translateX(calc(var(--pcsnav-w) * -1));
	-webkit-transform: translateX(calc(var(--pcsnav-w) * -1));
	-moz-transform: translateX(calc(var(--pcsnav-w) * -1))
}
.penci-menu-hbg.penci-vernav-show {
	z-index: 100
}
@media only screen and (min-width:961px) {
	#sidebar-nav {
		display: none
	}
}
#sidebar-nav #logo {
	display: none !important
}
#sidebar-nav #logo+ul {
	border-top: 1px solid #dedede
}
.penci-menu-hbg {
	width: 330px;
	transform: translateX(-330px);
	-webkit-transform: translateX(-330px);
	-moz-transform: translateX(-330px)
}
.admin-bar .penci-menu-hbg {
	padding-top: 62px
}
.open-sidebar-nav #sidebar-nav {
	left: 270px
}
.penci-menuhbg-open .penci-menu-hbg.penci-menu-hbg-left {
	left: 330px
}
.penci-menu-hbg::-webkit-scrollbar {
	width: 0
}
#sidebar-nav::-webkit-scrollbar {
	width: 6px;
	background: #848484
}
#sidebar-nav::-webkit-scrollbar-thumb {
	background-color: #313131;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
#sidebar-nav::-webkit-scrollbar-corner {
	background-color: #dedede
}
#sidebar-nav-logo {
	padding: 0 20px 20px;
	text-align: center;
	margin: 0 0 15px 0;
	position: relative
}
#sidebar-nav-logo:before {
	content: "";
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	position: absolute;
	bottom: 0;
	left: 50%;
	margin-left: -30px
}
.header-social.sidebar-nav-social {
	margin: 0 0 43px 0;
	padding: 0 10px
}
.header-social.sidebar-nav-social .inner-header-social:after,
.header-social.sidebar-nav-social .inner-header-social:before {
	content: none
}
.header-social.sidebar-nav-social a i {
	color: #313131
}
.penci-menu-hbg .header-social.sidebar-nav-social a i {
	font-size: 14px;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	-o-transition: all .2s ease-in-out;
	transition: all .2s ease-in-out
}
.header-social.sidebar-nav-social a i:hover {
	color: var(--pcaccent-cl)
}
.penci-menu-hbg .header-social.penci-hbg-social-style-2 a,
.penci-menu-hbg .header-social.penci-hbg-social-style-4 a {
	margin: 0 3px 6px
}
.penci-menu-hbg .header-social.penci-hbg-social-style-2 a i,
.penci-menu-hbg .header-social.penci-hbg-social-style-4 a i {
	width: 36px;
	height: 36px;
	line-height: 34px;
	background: 0 0;
	border: 1px solid #e0e0e0;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	margin: 0;
	display: inline-block;
	text-align: center
}
.penci-menu-hbg .header-social.penci-hbg-social-style-2 a:hover i {
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	color: #fff
}
.penci-menu-hbg .header-social.penci-hbg-social-style-2.hgb-social-style-3 a i,
.penci-menu-hbg .header-social.penci-hbg-social-style-4.hgb-social-style-5 a i {
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
.penci-menu-hbg .header-social.penci-hbg-social-style-4 a i,
.penci-menu-hbg .header-social.penci-hbg-social-style-4 a:hover i,
.penci-social-colored ul.footer-socials li a i {
	color: #fff !important;
	border: none !important;
	line-height: 36px
}
.penci-social-colored a i.pccsi-img,
.penci-social-colored a i.pccsi-svg,
.penci-social-colored ul.footer-socials li a i.pccsi-img,
.penci-social-colored ul.footer-socials li a i.pccsi-svg {
	background-color: var(--pcci, var(--pcaccent-cl)) !important
}
.penci-social-colored ul.footer-socials li a i svg {
	fill: #fff
}
.penci-menu-hbg .header-social.penci-hbg-social-style-4 a:hover i,
.penci-social-colored ul.footer-socials li a:hover i {
	opacity: .85
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-facebook,
.penci-social-colored a i.fa-facebook,
.penci-social-colored a i.fa-facebook-f,
.penci-social-colored a i.penciicon-facebook,
.tags-share-box.tags-share-box-s2 .post-share-facebook {
	background: #0d47a1 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-twitter,
.penci-social-colored a i.fa-twitter,
.penci-social-colored a i.penciicon-twitter,
.penci-social-colored a i.penciicon-x-twitter,
.tags-share-box.tags-share-box-s2 .post-share-twitter {
	background: #40c4ff !important
}
.penci-social-colored a i.fa-google-plus {
	background: #eb4026 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-instagram,
.penci-social-colored a i.fa-instagram,
.penci-social-colored a i.penciicon-instagram {
	background: #4d7a9e !important;
	background: radial-gradient(circle farthest-corner at 35% 90%, #ffa100, transparent 50%), radial-gradient(circle farthest-corner at 0 140%, #efa11c, transparent 50%), radial-gradient(ellipse farthest-corner at 0 -25%, #5258cf, transparent 50%), radial-gradient(ellipse farthest-corner at 20% -50%, #5258cf, transparent 50%), radial-gradient(ellipse farthest-corner at 100% 0, #893dc2, transparent 50%), radial-gradient(ellipse farthest-corner at 60% -20%, #8f44c7, transparent 50%), radial-gradient(ellipse farthest-corner at 100% 100%, #d43178, transparent), linear-gradient(#6559ca, #bc318f 30%, #e33f5f 50%, #f77638 70%, #fec66d 100%) !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-pinterest,
.penci-social-colored a i.fa-pinterest,
.penci-social-colored a i.penciicon-pinterest,
.tags-share-box.tags-share-box-s2 .post-share-pinterest {
	background: #bd081c !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-threads,
.penci-social-colored a i.fa-threads,
.penci-social-colored a i.penciicon-threads,
.tags-share-box.tags-share-box-s2 .post-share-threads {
	background: #000 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-bluesky,
.penci-social-colored a i.fa-bluesky,
.penci-social-colored a i.penciicon-bluesky,
.tags-share-box.tags-share-box-s2 .post-share-bluesky {
	background: rgb(16, 131, 254) !important
}
.penci-social-colored a i.fa-linkedin,
.penci-social-colored a i.fa-linkedin-in,
.penci-social-colored a i.penciicon-linkedin,
.penci-social-linkedin .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-linkedin {
	background: #0077b5 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-flickr,
.penci-social-colored a i.fa-flickr,
.penci-social-colored a i.penciicon-flickr {
	background: #ff0084 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-behance,
.penci-social-colored a i.fa-behance,
.penci-social-colored a i.penciicon-behance {
	background: #053eff !important
}
.penci-social-colored a i.fa-tumblr,
.penci-social-colored a i.penciicon-tumblr,
.penci-social-tumblr .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-tumblr {
	background: #34465d !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-youtube,
.penci-social-colored a i.fa-youtube,
.penci-social-colored a i.fa-youtube-play,
.penci-social-colored a i.penciicon-youtube {
	background: red !important
}
.penci-social-colored a i.fa-envelope,
.penci-social-colored a i.fa-envelope-o,
.penci-social-colored a i.penciicon-email,
.penci-social-email .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-email {
	background: #0084ff !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-vk,
.penci-social-colored a i.fa-vk,
.penci-social-colored a i.penciicon-vk,
.tags-share-box.tags-share-box-s2 .post-share-vk {
	background: #5181b8 !important
}
.penci-social-colored a i.fa-pocket,
.penci-social-pocket .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-pocket {
	background: #ef4056 !important
}
.penci-social-colored a i.fa-skype,
.penci-social-skype .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-skype {
	background: #00aff0 !important
}
.penci-social-colored a i.fa-heart,
.penci-social-heart .penci-social-content {
	background: #000 !important
}
.penci-social-colored a i.fa-vine,
.penci-social-colored a i.penciicon-vine,
.penci-social-vine .penci-social-content {
	background: #00b98a !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-soundcloud,
.penci-social-colored a i.fa-soundcloud,
.penci-social-colored a i.penciicon-soundcloud {
	background: #f76201 !important
}
.penci-social-colored a i.fa-snapchat,
.penci-social-colored a i.fa-snapchat-ghost,
.penci-social-colored a i.penciicon-snapchat,
.penci-social-snapchat .penci-social-content {
	background: #f6f600 !important
}
.penci-social-colored a i.fa-spotify,
.penci-social-colored a i.penciicon-spotify,
.penci-social-spotify .penci-social-content {
	background: #22c95c !important
}
.penci-social-colored a i.fa-github,
.penci-social-colored a i.penciicon-github,
.penci-social-github .penci-social-content {
	background: #302f2f !important
}
.penci-social-colored a i.fa-stack-overflow,
.penci-social-colored a i.penciicon-stack-overflow,
.penci-social-stack .penci-social-content {
	background: #f7a000 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-twitch,
.penci-social-colored a i.fa-twitch,
.penci-social-colored a i.penciicon-twitch {
	background: #613fa0 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-vimeo,
.penci-social-colored a i.fa-vimeo,
.penci-social-colored a i.fa-vimeo-v,
.penci-social-colored a i.penciicon-vimeo {
	background: #00a8e8 !important
}
.penci-social-colored a i.fa-steam,
.penci-social-colored a i.penciicon-steam,
.penci-social-steam .penci-social-content {
	background: #bcbab8 !important
}
.penci-social-colored a i.fa-xing,
.penci-social-colored a i.penciicon-xing,
.penci-social-xing .penci-social-content {
	background: #007c7c !important
}
.penci-social-colored a i.fa-whatsapp,
.penci-social-colored a i.penciicon-whatsapp,
.penci-social-whatsapp .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-whatsapp {
	background: #00e676 !important
}
.penci-social-colored a i.fa-heart-o {
	background: #000 !important
}
.penci-social-colored a i.fa-telegram,
.penci-social-colored a i.penciicon-telegram,
.penci-social-telegram .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-telegram {
	background: #289fd9 !important
}
.penci-social-colored a i.fa-reddit-alien,
.penci-social-colored a i.penciicon-reddit,
.penci-social-reddit .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-reddit {
	background: #f74300 !important
}
.penci-social-colored a i.fa-odnoklassniki,
.penci-social-colored a i.penciicon-odnoklassniki,
.penci-social-odnoklassniki .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-ok {
	background: #f18f00 !important
}
.penci-social-500px .penci-social-content,
.penci-social-colored a i.fa-500px {
	background: #0af !important
}
.penci-social-colored a i.fa-stumbleupon,
.penci-social-colored a i.penciicon-stumbleupon,
.penci-social-stumbleupon .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-stumbleupon {
	background: #eb4823 !important
}
.penci-social-colored a i.fa-weixin,
.penci-social-colored a i.penciicon-wechat,
.penci-social-weixin .penci-social-content {
	background: #0fc91c !important
}
.penci-social-colored a i.fa-weibo,
.penci-social-colored a i.penciicon-sina-weibo,
.penci-social-weibo .penci-social-content {
	background: #df152c !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-rss,
.penci-social-colored a i.fa-rss,
.penci-social-colored a i.penciicon-rss {
	background: #f0941a !important
}
.penci-social-colored a i.fa-line,
.penci-social-colored a i.penci-icon-line,
.penci-social-colored a i.penciicon-line,
.penci-social-colored a i.penciicon-line-1,
.penci-social-line .penci-social-content {
	background: #01b901 !important
}
.penci-social-colored a i.fa-viber,
.penci-social-colored a i.penci-icon-viber,
.penci-social-colored a i.penciicon-viber,
.penci-social-colored a i.penciicon-viber-1,
.penci-social-viber .penci-social-content,
.tags-share-box.tags-share-box-s2 .post-share-viber {
	background: #7d51a0 !important
}
.penci-social-colored a i.fa-discord,
.penci-social-colored a i.penci-icon-discord,
.penci-social-colored a i.penciicon-discord,
.penci-social-colored a i.penciicon-discord-1,
.penci-social-discord .penci-social-content {
	background: #7289da !important
}
.penci-social-colored a i.fa-slack,
.penci-social-colored a i.penciicon-slack {
	background: #611f69 !important
}
.penci-social-colored a i.fa-mixcloud {
	background: #f3b2a6 !important
}
.penci-social-colored a i.fa-goodreads,
.penci-social-colored a i.penci-icon-goodreads,
.penci-social-colored a i.penciicon-goodreads {
	background: #8a5724 !important
}
.penci-social-colored a i.fa-tripadvisor,
.penci-social-colored a i.penciicon-tripadvisor {
	background: #34e0a1 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-tiktok,
.penci-social-colored a i.fa-tiktok,
.penci-social-colored a i.penci-icon-tiktok,
.penci-social-colored a i.penciicon-tik-tok,
.penci-social-colored a i.penciicon-tik-tok-1 {
	background: #fe2c55 !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-butterfly,
.penci-social-colored a i.penciicon-butterfly{
	background: #1185fe !important
}
.pcsoccl-brandbg .pcsc-brandflag.pcsoci-threads,
.penci-social-colored a i.penciicon-threads{
	background: #000 !important
}
.pcsoccl-brandbg .pcsc-brandflag.fa-yelp,
.penci-social-colored a i.fa-yelp{
	background: rgba(244,13,21,1) !important
}
.penci-social-colored a i.penciicon-douban-logo {
	background: #00b51d !important
}
.penci-social-colored a i.penciicon-qq-social-logo-of-a-penguin {
	background: #4292ff !important
}
.tags-share-box.tags-share-box-s2 .post-share-line {
	background: #01b901 !important
}
.tags-share-box.tags-share-box-s2 .post-share-plike {
	background: var(--pcaccent-cl)
}
.penci-social-delicious .penci-social-content {
	background: var(--pcaccent-cl) !important
}
.penci-social-dribbble .penci-social-content {
	background: #ea4c89 !important
}
.penci-social-colored a i.penciicon-letter-d {
	background: #000 !important
}
.penci-social-colored a i.penciicon-blogger,
.penci-social-colored a i.penciicon-blogger-1 {
	background: #ed7800 !important
}
.penci-social-colored a i.fa-delicious {
	background: #0078f0 !important
}
.penci-social-colored a i.penciicon-deviantart,
.penci-social-colored a i.penciicon-deviantart-1 {
	background: #01ca3a !important
}
.penci-social-colored a i.fa-digg {
	background: #005be2 !important
}
.penci-social-colored a i.penciicon-evernote,
.penci-social-colored a i.penciicon-evernote-1 {
	background: #00a32c !important
}
.penci-social-colored a i.penciicon-forrst,
.penci-social-colored a i.penciicon-forrst-1 {
	background: #054958 !important
}
.penci-social-colored a i.penciicon-grooveshark,
.penci-social-colored a i.penciicon-grooveshark-1 {
	background: #f75421 !important
}
.penci-social-colored a i.penciicon-lastfm {
	background: #e31b23 !important
}
.penci-social-colored a i.penciicon-myspace,
.penci-social-colored a i.penciicon-myspace-logo {
	background: #0037c1 !important
}
.penci-social-colored a i.fa-paypal,
.penci-social-colored a i.penciicon-brand {
	background: #0070ba !important
}
.penci-social-colored a i.fa-skype,
.penci-social-colored a i.penciicon-skype {
	background: #00aff0 !important
}
.penci-social-colored a i.fa-windows,
.penci-social-colored a i.penciicon-windows {
	background: #00adef !important
}
.penci-social-colored a i.fa-wordpress,
.penci-social-colored a i.penciicon-wordpress-logo {
	background: #21759b !important
}
.penci-social-colored a i.penciicon-yahoo-logo {
	background: #6001d2 !important
}
.penci-social-colored a i.penciicon-y {
	background: #fc401d !important
}
.penci-social-colored a i.fa-globe {
	background: var(--pcaccent-cl) !important
}
.penci-social-colored a i.fa-dribbble {
	background: #ea4c89 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-facebook i,
.penci-social-textcolored a i.fa-facebook,
.penci-social-textcolored a i.fa-facebook-f,
.penci-social-textcolored a i.penciicon-facebook {
	color: #0d47a1 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-twitter i,
.penci-social-textcolored a i.fa-twitter,
.penci-social-textcolored a i.penciicon-twitter,
.penci-social-textcolored a i.penciicon-x-twitter {
	color: #40c4ff !important
}
.penci-social-textcolored a i.fa-google-plus {
	color: #eb4026 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-instagram i,
.penci-social-textcolored a i.fa-instagram,
.penci-social-textcolored a i.penciicon-instagram {
	color: #4d7a9e !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-pinterest i,
.penci-social-textcolored a i.fa-pinterest,
.penci-social-textcolored a i.penciicon-pinterest {
	color: #bd081c !important
}
.penci-social-textcolored a i.fa-linkedin,
.penci-social-textcolored a i.fa-linkedin-in,
.penci-social-textcolored a i.penciicon-linkedin {
	color: #0077b5 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-flickr i,
.penci-social-textcolored a i.fa-flickr,
.penci-social-textcolored a i.penciicon-flickr {
	color: #ff0084 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-behance i,
.penci-social-textcolored a i.fa-behance,
.penci-social-textcolored a i.penciicon-behance {
	color: #053eff !important
}
.penci-social-textcolored a i.fa-tumblr,
.penci-social-textcolored a i.penciicon-tumblr {
	color: #34465d !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-youtube i,
.penci-social-textcolored a i.fa-youtube,
.penci-social-textcolored a i.fa-youtube-play,
.penci-social-textcolored a i.penciicon-youtube {
	color: red !important
}
.penci-social-textcolored a i.fa-envelope,
.penci-social-textcolored a i.fa-envelope-o,
.penci-social-textcolored a i.penciicon-email {
	color: #0084ff !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-vk i,
.penci-social-textcolored a i.fa-vk,
.penci-social-textcolored a i.penciicon-vk {
	color: #5181b8 !important
}
.penci-social-textcolored a i.fa-heart,
.penci-social-textcolored a i.fa-heart-o {
	color: #000 !important
}
.penci-social-textcolored a i.fa-vine,
.penci-social-textcolored a i.penciicon-vine {
	color: #00b98a !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-soundcloud i,
.penci-social-textcolored a i.fa-soundcloud,
.penci-social-textcolored a i.penciicon-soundcloud {
	color: #f76201 !important
}
.penci-social-textcolored a i.fa-pocket {
	color: #ef4056 !important
}
.penci-social-textcolored a i.fa-snapchat,
.penci-social-textcolored a i.fa-snapchat-ghost,
.penci-social-textcolored a i.penciicon-snapchat {
	color: #f6f600 !important
}
.penci-social-textcolored a i.fa-spotify,
.penci-social-textcolored a i.penciicon-spotify {
	color: #22c95c !important
}
.penci-social-textcolored a i.fa-github,
.penci-social-textcolored a i.penciicon-github {
	color: #302f2f !important
}
.penci-social-textcolored a i.fa-stack-overflow,
.penci-social-textcolored a i.penciicon-stack-overflow {
	color: #f7a000 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-twitch i,
.penci-social-textcolored a i.fa-twitch,
.penci-social-textcolored a i.penciicon-twitch {
	color: #613fa0 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-vimeo i,
.penci-social-textcolored a i.fa-vimeo,
.penci-social-textcolored a i.fa-vimeo-v,
.penci-social-textcolored a i.penciicon-vimeo {
	color: #00a8e8 !important
}
.penci-social-textcolored a i.fa-steam,
.penci-social-textcolored a i.penciicon-steam {
	color: #bcbab8 !important
}
.penci-social-textcolored a i.fa-xing,
.penci-social-textcolored a i.penciicon-xing {
	color: #007c7c !important
}
.penci-social-textcolored a i.fa-whatsapp,
.penci-social-textcolored a i.penciicon-whatsapp {
	color: #00e676 !important
}
.penci-social-textcolored a i.fa-telegram,
.penci-social-textcolored a i.penciicon-telegram {
	color: #289fd9 !important
}
.penci-social-textcolored a i.fa-reddit-alien,
.penci-social-textcolored a i.penciicon-reddit {
	color: #f74300 !important
}
.penci-social-textcolored a i.fa-odnoklassniki,
.penci-social-textcolored a i.penciicon-odnoklassniki {
	color: #f18f00 !important
}
.penci-social-textcolored a i.fa-500px {
	color: #0af !important
}
.penci-social-textcolored a i.fa-stumbleupon,
.penci-social-textcolored a i.penciicon-stumbleupon {
	color: #eb4823 !important
}
.penci-social-textcolored a i.fa-weixin,
.penci-social-textcolored a i.penciicon-wechat {
	color: #0fc91c !important
}
.penci-social-textcolored a i.fa-weibo,
.penci-social-textcolored a i.penciicon-sina-weibo {
	color: #df152c !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-rss i,
.penci-social-textcolored a i.fa-rss,
.penci-social-textcolored a i.penciicon-rss {
	color: #f0941a !important
}
.penci-social-textcolored a i.fa-slack,
.penci-social-textcolored a i.penciicon-slack {
	color: #611f69 !important
}
.penci-social-textcolored a i.fa-mixcloud {
	color: #f3b2a6 !important
}
.penci-social-textcolored a i.fa-goodreads,
.penci-social-textcolored a i.penci-icon-goodreads,
.penci-social-textcolored a i.penciicon-goodreads {
	color: #8a5724 !important
}
.penci-social-textcolored a i.fa-tripadvisor,
.penci-social-textcolored a i.penciicon-tripadvisor {
	color: #34e0a1 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-tiktok i,
.penci-social-textcolored a i.fa-tiktok,
.penci-social-textcolored a i.penci-icon-tiktok,
.penci-social-textcolored a i.penciicon-tik-tok,
.penci-social-textcolored a i.penciicon-tik-tok-1 {
	color: #fe2c55 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-butterfly i,
.pcsoccl-brandtext .pcsc-brandflag.penciicon-butterfly i,
.penci-social-textcolored a i.penciicon-butterfly{
	color: #1185fe !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-threads i,
.pcsoccl-brandtext .pcsc-brandflag.penciicon-threads i,
.penci-social-textcolored a i.penciicon-threads{
	color: #B0B0B0 !important
}
.pcsoccl-brandtext .pcsc-brandflag.pcsoci-yelp i,
.pcsoccl-brandtext .pcsc-brandflag i.fa-yelp,
.penci-social-textcolored a i.fa-yelp{
	color: rgba(244,13,21,1) !important
}
.penci-social-textcolored a i.fa-line,
.penci-social-textcolored a i.penci-icon-line,
.penci-social-textcolored a i.penciicon-line,
.penci-social-textcolored a i.penciicon-line-1 {
	color: #01b901 !important
}
.penci-social-textcolored a i.fa-viber,
.penci-social-textcolored a i.penci-icon-viber,
.penci-social-textcolored a i.penciicon-viber,
.penci-social-textcolored a i.penciicon-viber-1 {
	color: #7d51a0 !important
}
.penci-social-textcolored a i.fa-discord,
.penci-social-textcolored a i.penci-icon-discord,
.penci-social-textcolored a i.penciicon-discord,
.penci-social-textcolored a i.penciicon-discord-1 {
	color: #7289da !important
}
.penci-social-textcolored a i.penciicon-douban-logo {
	color: #00b51d !important
}
.penci-social-textcolored a i.penciicon-qq-social-logo-of-a-penguin {
	color: #4292ff !important
}
.penci-social-textcolored a i.penciicon-letter-d {
	color: #000 !important
}
.penci-social-textcolored a i.penciicon-blogger,
.penci-social-textcolored a i.penciicon-blogger-1 {
	color: #ed7800 !important
}
.penci-social-textcolored a i.fa-delicious {
	color: #0078f0 !important
}
.penci-social-textcolored a i.penciicon-deviantart,
.penci-social-textcolored a i.penciicon-deviantart-1 {
	color: #01ca3a !important
}
.penci-social-textcolored a i.fa-digg {
	color: #005be2 !important
}
.penci-social-textcolored a i.penciicon-evernote,
.penci-social-textcolored a i.penciicon-evernote-1 {
	color: #00a32c !important
}
.penci-social-textcolored a i.penciicon-forrst,
.penci-social-textcolored a i.penciicon-forrst-1 {
	color: #054958 !important
}
.penci-social-textcolored a i.penciicon-grooveshark,
.penci-social-textcolored a i.penciicon-grooveshark-1 {
	color: #f75421 !important
}
.penci-social-textcolored a i.penciicon-lastfm {
	color: #e31b23 !important
}
.penci-social-textcolored a i.penciicon-myspace,
.penci-social-textcolored a i.penciicon-myspace-logo {
	color: #0037c1 !important
}
.penci-social-textcolored a i.fa-paypal,
.penci-social-textcolored a i.penciicon-brand {
	color: #0070ba !important
}
.penci-social-textcolored a i.fa-skype,
.penci-social-textcolored a i.penciicon-skype {
	color: #00aff0 !important
}
.penci-social-textcolored a i.fa-windows,
.penci-social-textcolored a i.penciicon-windows {
	color: #00adef !important
}
.penci-social-textcolored a i.fa-wordpress,
.penci-social-textcolored a i.penciicon-wordpress-logo {
	color: #21759b !important
}
.penci-social-textcolored a i.penciicon-yahoo-logo {
	color: #6001d2 !important
}
.penci-social-textcolored a i.penciicon-y {
	color: #fc401d !important
}
.penci-social-textcolored a i.fa-globe {
	color: var(--pcaccent-cl) !important
}
.penci-social-textcolored a i.fa-dribbble {
	color: #ea4c89 !important
}
#sidebar-nav .menu,
.pchgbel .menu,
.penci-menu-hbg .menu {
	margin: 0;
	list-style: none
}
#sidebar-nav .menu li,
.pchgbel .menu li,
.penci-menu-hbg .menu li {
	display: block;
	border-bottom: 1px solid #dedede;
	padding: 0;
	margin-bottom: 0
}
.pchgbel .menu li.penci-mega-menu .sub-menu a:empty,
.penci-menu-hbg .menu li.penci-mega-menu .sub-menu a:empty {
	padding: 0;
	display: none
}
.pchgbel.menu li.penci-mega-menu .sub-menu a:blank,
.penci-menu-hbg .menu li.penci-mega-menu .sub-menu a:blank {
	padding: 0;
	display: none
}
.pchgbel .menu li.penci-mega-menu .sub-menu .penci-megamenu a:not(.mega-cat-child),
.penci-menu-hbg .menu li.penci-mega-menu .sub-menu .penci-megamenu a:not(.mega-cat-child) {
	padding: 0;
	display: none
}
.pchgbel .menu li.penci-mega-menu .sub-menu .penci-megamenu a.mega-normal-child,
.penci-menu-hbg .menu li.penci-mega-menu .sub-menu .penci-megamenu a.mega-normal-child {
	padding: 10px 0;
	display: block
}
#sidebar-nav .menu ul>li:last-child,
#sidebar-nav .menu>li:last-child,
.pchgbel .menu ul>li:last-child,
.pchgbel .menu>li:last-child,
.penci-menu-hbg .menu ul>li:last-child,
.penci-menu-hbg .menu>li:last-child {
	border-bottom: none
}
#sidebar-nav .menu li a,
.pchgbel .menu li a,
.penci-menu-hbg .menu li a {
	font-size: 13px;
	font-weight: 400;
	letter-spacing: 0;
	text-transform: uppercase;
	color: #313131;
	margin: 0;
	position: relative;
	padding: 13px 0 13px 0;
	display: block;
	line-height: 1.3em;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.pchgbel .menu li a,
.penci-menu-hbg .menu li a {
	text-decoration: none
}
#sidebar-nav .menu li.menu-item-has-children a,
.pchgbel .menu li.menu-item-has-children a,
.penci-menu-hbg .menu li.menu-item-has-children a {
	padding-right: 17px
}
#sidebar-nav .menu li a:hover,
.pchgbel .menu li a:hover,
.penci-menu-hbg .menu li a:hover {
	color: var(--pcaccent-cl)
}
#sidebar-nav .menu li a>i,
.pchgbel .menu li a>i,
.penci-menu-hbg .menu li a>i {
	display: inline-block;
	margin-right: 5px
}
#sidebar-nav ul.sub-menu,
.pchgbel ul.sub-menu,
.penci-menu-hbg ul.sub-menu {
	border-top: 1px solid #dedede;
	display: none;
	padding: 10px 0 10px 12px
}
.pchgbel ul.sub-menu,
.penci-menu-hbg ul.sub-menu {
	margin: 0
}
#sidebar-nav ul.sub-menu ul.sub-menu,
.pchgbel ul.sub-menu ul.sub-menu,
.penci-menu-hbg ul.sub-menu ul.sub-menu {
	border: none;
	padding: 5px 0 5px 12px
}
#sidebar-nav ul.sub-menu ul.sub-menu,
.pchgbel ul.sub-menu ul.sub-menu,
.penci-menu-hbg ul.sub-menu ul.sub-menu {
	padding-right: 0
}
#sidebar-nav ul.sub-menu li,
.pchgbel ul.sub-menu li,
.penci-menu-hbg ul.sub-menu li {
	overflow: hidden;
	border: none
}
#sidebar-nav ul.sub-menu li a,
.pchgbel ul.sub-menu li a,
.penci-menu-hbg ul.sub-menu li a {
	margin: 0;
	padding: 10px 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
#sidebar-nav .menu li a .indicator,
.pchgbel .menu li a .indicator,
.penci-menu-hbg .menu li a .indicator {
	text-decoration: none;
	position: absolute;
	top: 0;
	right: 0;
	height: 100%;
	z-index: 20;
	font-size: 17px;
	font-style: normal;
	text-align: right;
	padding: 11px 0 11px 5px;
	line-height: 1;
	color: inherit !important;
	opacity: .85
}
.pchgbel .menu li a .indicator .fa-angle-up:before,
.menu li a .indicator .fa-angle-up:before {
	content: "\f106"
}
#sidebar-nav .menu .sub-menu li a .indicator,
.pchgbel .menu .sub-menu li a .indicator,
.penci-menu-hbg .menu .sub-menu li a .indicator {
	padding: 8px 0 8px 5px
}
#sidebar-nav .menu .sub-menu li a .indicator:hover,
.pchgbel .menu .sub-menu li a .indicator:hover,
.penci-menu-hbg .menu .sub-menu li a .indicator:hover,
#sidebar-nav .menu li a .indicator:hover,
.penci-menu-hbg .menu li a .indicator:hover {
	color: var(--pcaccent-cl)
}
#sidebar-nav ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu,
.pchgbel ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu,
.penci-menu-hbg ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu {
	display: block;
	padding: 0
}
#sidebar-nav ul.menu>li.megamenu>ul.sub-menu>li>a,
.pchgbel ul.menu>li.megamenu>ul.sub-menu>li>a,
.penci-menu-hbg ul.menu>li.megamenu>ul.sub-menu>li>a {
	display: none
}
.fa-angle-double-up:before {
	content: "\f102"
}
#close-sidebar-nav,
.penci-menu-hbg-overlay {
	position: fixed;
	visibility: hidden;
	opacity: 0;
	text-decoration: none;
	top: 0;
	left: 0;
	font-size: 1.4em;
	color: #313131;
	padding: 10px;
	height: 100%;
	background: rgba(0, 0, 0, .8);
	right: 0;
	z-index: 99996;
	cursor: pointer;
	transition: all .5s;
	-webkit-transition: all .5s;
	-moz-transition: all .5s
}
.penci-menuhbg-open .penci-menu-hbg-overlay {
	left: 0;
	opacity: 1;
	visibility: visible
}
.open-sidebar-nav #close-sidebar-nav {
	left: 270px;
	opacity: 1;
	visibility: visible
}
#close-sidebar-nav i {
	display: none;
	width: 24px;
	height: 24px;
	background-color: #fff;
	line-height: 24px;
	text-align: center;
	border-radius: 12px;
	font-size: 14px
}
.penci-menu-hbg {
	background-repeat: no-repeat;
	background-position: center center
}
.penci-menu-hbg #logo {
	display: none
}
.penci-menuhbg-wapper {
	float: right;
	width: 18px;
	margin-right: 12px;
	text-align: center
}
.penci-menuhbg-toggle {
	padding: 0;
	width: 18px;
	line-height: 20px;
	background-position: right top;
	background-repeat: no-repeat;
	box-sizing: content-box;
	-moz-box-sizing: content-box;
	display: flex;
	align-items: center;
	height: 58px;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	-ms-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s
}
.penci-menuhbg-toggle .penci-menuhbg-inner {
	transition: -webkit-transform .33s .3s ease-in;
	transition: transform .33s .3s ease-in;
	-webkit-transform-origin: center;
	transform-origin: center;
	display: block;
	height: 20px;
	position: relative;
	width: 100%;
	overflow: hidden
}
.penci-menuhbg-toggle .penci-lines {
	height: 2px;
	display: block;
	width: 18px;
	background-color: transparent;
	position: relative;
	transition: background .2s ease, opacity .2s ease
}
.penci-menuhbg-toggle .penci-lines:before {
	top: 5px;
	transition: transform .65s cubic-bezier(.3, 1, .3, 1) 0s, background-color .2s ease, opacity .2s ease
}
.penci-menuhbg-toggle .penci-lines:after {
	top: -5px;
	-webkit-transform-origin: 50% 50%;
	transform-origin: 50% 50%;
	transition: transform .65s cubic-bezier(.3, 1, .3, 1) 80ms, background-color .2s ease, opacity .2s ease
}
.penci-menuhbg-toggle .penci-lines:after,
.penci-menuhbg-toggle .penci-lines:before {
	display: block;
	width: 100%;
	height: 2px;
	position: absolute;
	left: 0;
	content: "";
	background-color: #313131
}
.penci-menuhbg-toggle .lines-button {
	cursor: pointer;
	line-height: 0 !important;
	top: 9px;
	position: relative;
	font-size: 0 !important;
	user-select: none;
	display: block
}
.penci-menuhbg-toggle .lines-button.penci-hover-effect {
	left: -30px;
	margin-top: -2px
}
.penci-menuhbg-toggle .lines-button:after {
	height: 2px;
	display: inline-block;
	width: 100%;
	position: absolute;
	left: 0;
	top: 0;
	content: "";
	background-color: #313131;
	transition: transform .65s cubic-bezier(.3, 1, .3, 1) 40ms, background-color .2s ease, opacity .2s ease
}
.penci-menuhbg-toggle.closed .penci-menuhbg-inner {
	transition: -webkit-transform .33s 0s ease;
	transition: transform .33s 0s ease
}
.penci-menuhbg-toggle:hover .lines-button:after,
.penci-menuhbg-toggle:hover .penci-lines:after,
.penci-menuhbg-toggle:hover .penci-lines:before {
	background: var(--pcaccent-cl)
}
.penci-menuhbg-toggle:hover .lines-button:after,
.penci-menuhbg-toggle:hover .penci-lines:after,
.penci-menuhbg-toggle:hover .penci-lines:before {
	transform: translateX(30px)
}
.penci-menu-hbg-inner #penci-close-hbg {
	position: absolute;
	top: 10px;
	left: 15px;
	cursor: pointer;
	z-index: 1;
	-webkit-transition: all .5s ease;
	-moz-transition: all .5s ease;
	-ms-transition: all .5s ease;
	-o-transition: all .5s ease;
	transition: all .5s ease;
	width: 20px;
	height: 20px;
	display: block;
	overflow: hidden
}
.penci-menu-hbg-inner #penci-close-hbg i {
	display: none
}
.admin-bar .penci-menu-hbg #penci-close-hbg {
	top: 40px
}
.penci-menu-hbg-inner #penci-close-hbg:after,
.penci-menu-hbg-inner #penci-close-hbg:before {
	content: "";
	height: 100%;
	width: 2px;
	backface-visibility: hidden;
	position: absolute;
	border-radius: 5px;
	background: #888;
	left: 9px;
	transition: opacity .2s ease, background-color .2s ease
}
.penci-menu-hbg-inner #penci-close-hbg:before {
	transform: rotate(45deg)
}
.penci-menu-hbg-inner #penci-close-hbg:after {
	transform: rotate(-45deg)
}
.penci-menu-hbg-inner #penci-close-hbg:hover {
	transform: rotate(180deg);
	-ms-transform: rotate(180deg);
	-webkit-transform: rotate(180deg);
	-o-transform: rotate(180deg);
	-moz-transform: rotate(180deg)
}
.penci-menu-hbg-inner #penci-close-hbg:hover:after,
.penci-menu-hbg-inner #penci-close-hbg:hover:before {
	background-color: #111
}
.penci-menu-hbg-inner .penci-hbg_sitetitle {
	font-size: 18px;
	margin-top: 15px;
	line-height: 1.3;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.penci-menu-hbg-inner .penci-hbg_desc {
	margin-top: 10px;
	line-height: 1.45;
	font-size: 14px
}
.penci-menu-hbg-inner .penci-hbg-header {
	text-align: center;
	margin-bottom: 30px
}
.penci-hbg-header .penci-lazy[src*=penci-holder] {
	width: auto;
	height: auto
}
.penci-hbg-header .penci-hbg-logo .penci-lazy[src*=penci-holder] {
	background: 0 0
}
.penci-menu-hbg-inner .menu-hamburger-navigation {
	margin-bottom: 30px
}
.penci-menu-hbg-widgets1 {
	margin-top: 40px
}
.penci-menu-hbg-widgets2 {
	margin-top: 40px
}
.penci-menu-hbg .penci-sidebar-content .widget {
	margin-bottom: 40px
}
.penci-menu-hbg-inner .header-social.sidebar-nav-social {
	text-align: left;
	padding-left: 0;
	padding-right: 0;
	margin: 26px -3px 0
}
.penci-menu-hbg-inner .penci-hbg-footer {
	margin-bottom: 0;
	margin-top: 30px
}
.penci_menu_hbg_ftext {
	line-height: 1.6
}
.penci-menu-hbg {
	padding-bottom: 30px
}
.penci-menu-hbg.penci-menu-hbg-left #penci-close-hbg {
	left: auto;
	right: 10px
}
.penci-menu-hbg-inner .penci-sidebar-content {
	width: 100% !important;
	float: none !important
}
.penci-menu-hbg.penci-menu-hbg-right {
	right: 0;
	left: auto;
	transform: translateX(330px);
	-webkit-transform: translateX(330px);
	-moz-transform: translateX(330px)
}
.penci-menuhbg-open .penci-menu-hbg.penci-menu-hbg-right {
	transform: translateX(0)
}
#navigation.header-4 .penci-menuhbg-wapper,
#navigation.header-5 .penci-menuhbg-wapper {
	float: none;
	vertical-align: top;
	display: inline-block
}
.wrap-social-search {
	display: inline-block;
	vertical-align: top
}
.pcheader-icon {
	float: right;
	width: 20px;
	text-align: center
}
.pcheader-icon.shoping-cart-icon {
	margin-right: 15px
}
#navigation.header-4 .pcheader-icon.shoping-cart-icon,
#navigation.header-5 .pcheader-icon.shoping-cart-icon,
#navigation.header-6 .pcheader-icon.shoping-cart-icon,
.pcheader-icon.shoping-cart-icon.clear-right {
	margin-right: 0
}
.pcheader-icon>a {
	height: 58px;
	font-size: 14px;
	line-height: 58px;
	color: #313131;
	cursor: pointer;
	background: 0 0;
	display: block;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	-ms-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s
}
.pcheader-icon.shoping-cart-icon>a {
	position: relative
}
.pcheader-icon.shoping-cart-icon>a>i {
	font-size: 17px
}
.pcheader-icon.shoping-cart-icon>a>span {
	position: absolute;
	z-index: 1;
	width: 14px;
	height: 14px;
	display: inline-block;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	top: calc(50% - 17px);
	right: -4px;
	background: var(--pcaccent-cl);
	color: #fff;
	text-align: center;
	white-space: nowrap;
	line-height: 14px;
	font-size: 8px;
	font-family: var(--pcbody-font);
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
body:not(.penci-fawesome-ver5) .shoping-cart-icon>a i.fas.fa-shopping-cart {
	display: inline-block;
	font: normal normal normal 14px/1 FontAwesome;
	font-size: inherit;
	text-rendering: auto;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale
}
#navigation.header-6 .pcheader-icon.shoping-cart-icon>a>span {
	top: 23px
}
.is-sticky #navigation.header-6 .pcheader-icon.shoping-cart-icon>a>span {
	top: 12px
}
.pcheader-icon .fa-shopping-bag:before {
	content: "\f07a";
	font-family: FontAwesome
}
.penci-fawesome-ver5 .pcheader-icon .fa-shopping-bag:before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900
}
.show-search {
	position: absolute;
	left: 0;
	width: 100%;
	top: 0;
	height: 58px;
	background: #fff;
	text-align: left;
	z-index: 200;
	display: none
}
.show-search form.pc-searchform input.search-input {
	padding: 15px 35px 15px 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	border: none;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	z-index: 3;
	color: #313131;
	height: 58px;
	line-height: 28px;
	box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	background: 0 0;
	font-weight: 400;
	letter-spacing: 0;
	font-size: 13px
}
.show-search form.pc-searchform i {
	display: none
}
.header-search-style-overlay .show-search form.pc-searchform i {
	display: block;
	font-size: 24px
}
.show-search a.close-search {
	position: absolute;
	width: 20px;
	height: 60px;
	display: inline-block;
	right: 0;
	top: 0;
	z-index: 5;
	text-align: center;
	line-height: 60px;
	font-size: 16px;
	cursor: pointer;
	color: #313131
}
.show-search a.close-search i {
	font-size: 70%
}
form.pc-searchform .searchsubmit {
	display: none
}
.penci-header-trans .show-search form.pc-searchform input.search-input {
	padding-left: 15px
}
.penci-header-trans .show-search a.close-search {
	right: 15px
}
.header-search-style-showup .penci-top-search {
	position: relative
}
.header-search-style-showup .show-search {
	left: auto;
	right: 0;
	width: 300px;
	top: 100%;
	padding: 20px;
	border-top: 4px solid var(--pcaccent-cl);
	height: auto !important;
	visibility: hidden;
	display: block;
	-webkit-transition: all .27s ease-in-out;
	-moz-transition: all .27s ease-in-out;
	-o-transition: all .27s ease-in-out;
	transition: all .27s ease-in-out;
	-webkit-transform-origin: 0 0;
	-moz-transform-origin: 0 0;
	-ms-transform-origin: 0 0;
	-o-transform-origin: 0 0;
	transform-origin: 0 0;
	-webkit-transform: rotateX(-90deg);
	-moz-transform: rotateX(-90deg);
	-ms-transform: rotateX(-90deg);
	-o-transform: rotateX(-90deg);
	transform: rotateX(-90deg);
	box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-webkit-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-moz-box-shadow: 0 3px 3px rgba(190, 190, 190, .6)
}
.header-search-style-showup .show-search,
.header-search-style-showup .sticky-wrapper.is-sticky .show-search,
.header-search-style-showup .sticky-wrapper:not(.is-sticky) #navigation .show-search,
.header-search-style-showup .sticky-wrapper:not(.is-sticky) .show-search {
	height: auto !important
}
.header-search-style-showup .show-search.active {
	-webkit-transform: rotateX(0);
	-moz-transform: rotateX(0);
	-ms-transform: rotateX(0);
	-o-transform: rotateX(0);
	transform: rotateX(0);
	visibility: visible
}
.header-search-style-showup .show-search:before {
	visibility: hidden;
	opacity: 0;
	content: "";
	display: block;
	position: absolute;
	top: -9px;
	right: 5px;
	margin: 0 auto;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 0 6px 6px 6px;
	-webkit-transform: translate3d(0, 5px, 0);
	transform: translate3d(0, 5px, 0);
	-webkit-transition: all .4s ease;
	transition: all .4s ease;
	border-color: transparent transparent var(--pcaccent-cl) transparent;
	border-bottom-color: var(--pcaccent-cl)
}
.header-search-style-showup .show-search.active:before {
	visibility: visible;
	opacity: 1;
	-webkit-transform: translate3d(0, 0, 0);
	transform: translate3d(0, 0, 0)
}
.header-search-style-showup .show-search form.pc-searchform input.search-input,
.header-search-style-showup .sticky-wrapper.is-sticky .show-search form.pc-searchform input.search-input,
.header-search-style-showup .sticky-wrapper:not(.is-sticky) .show-search form.pc-searchform input.search-input {
	border: 1px solid var(--pcborder-cl);
	border-right: 0;
	height: 40px !important;
	padding: 5px 12px !important;
	position: relative
}
.header-search-style-showup .show-search a.close-search {
	display: none
}
.header-search-style-showup .show-search form.pc-searchform .searchsubmit {
	display: block;
	border: 0;
	padding: 0 16px;
	font-size: 13px;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	background-color: var(--pcaccent-cl);
	color: #fff;
	text-transform: uppercase;
	transition: all .3s;
	cursor: pointer;
	white-space: nowrap
}
.widget.widget_search form.pc-searchform .searchsubmit {
	display: none
}
.header-search-style-showup .show-search .pc-searchform-inner {
	display: flex
}
.header-search-style-showup .search-results-wrapper .penci-dropdown-results {
	left: -20px;
	width: calc(100% + 40px)
}
.header-search-style-showup .penci-builder-element .search-results-wrapper .penci-dropdown-results {
	left: 0;
	width: 100%
}
.main-nav-social {
	display: inline-block;
	text-align: left;
	margin: 0 13px 0 0;
	float: right;
	line-height: 58px;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	-ms-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s
}
#navigation.header-4 .main-nav-social,
#navigation.header-5 .main-nav-social {
	float: none;
	vertical-align: top;
	margin: 0 0 0 30px
}
.main-nav-social .inner-header-social {
	display: inline-block;
	vertical-align: top;
	position: relative
}
.main-nav-social a {
	float: left;
	display: inline-block;
	vertical-align: top;
	margin-right: 10px;
	color: #313131;
	font-size: 14px
}
.main-nav-social a:last-child {
	margin-right: 0
}
.main-nav-social a:hover {
	color: var(--pcaccent-cl)
}
#navigation.header-6 .main-nav-social {
	line-height: 80px;
	margin: 0 0 0 30px
}
.button-menu-mobile i,
.main-nav-social a i,
.pcheader-icon a i {
	line-height: inherit;
	vertical-align: top
}
.is-sticky #navigation.header-6 .main-nav-social {
	line-height: 58px
}
@media only screen and (min-width:961px) {
	#navigation.header-10 .main-nav-social,
	#navigation.header-11 .main-nav-social,
	#navigation.header-9 .main-nav-social {
		line-height: 80px
	}
	.is-sticky #navigation.header-10 .main-nav-social,
	.is-sticky #navigation.header-11 .main-nav-social,
	.is-sticky #navigation.header-9 .main-nav-social {
		line-height: 58px
	}
}
#navigation.header-4 .pcheader-icon,
#navigation.header-4 .penci-menuhbg-toggle,
#navigation.header-4 .top-search-classes,
#navigation.header-5 .pcheader-icon,
#navigation.header-5 .penci-menuhbg-toggle,
#navigation.header-5 .top-search-classes,
#navigation.header-6 .pcheader-icon,
#navigation.header-6 .penci-menuhbg-toggle,
#navigation.header-6 .top-search-classes {
	margin-left: 15px
}
#header {
	margin-bottom: var(--pchd-mg);
	position: relative
}
.elementor-template-full-width #header,
.elementor-template-full-width .penci-page-header-wrap,
.page-template-page-fullwidth #header,
.page-template-page-fullwidth .penci-page-header-wrap,
.single.elementor-template-full-width .post {
	margin-bottom: 0
}
.elementor-template-full-width .clear-footer,
.page-template-page-fullwidth .clear-footer {
	height: 0;
	margin-bottom: 0
}
.header-header-1.has-bottom-line,
.header-header-4.has-bottom-line,
.header-header-7.has-bottom-line {
	border-bottom: 1px solid #ececec
}
.header-header-1.has-bottom-line.penci-vernav-hide-innerhead,
.header-header-4.has-bottom-line.penci-vernav-hide-innerhead,
.header-header-7.has-bottom-line.penci-vernav-hide-innerhead {
	border-bottom: none
}
#header .inner-header {
	width: 100%;
	background-size: cover;
	position: relative;
	background-position: center center;
	background-repeat: no-repeat;
	height: auto
}
.penci-header-trans #header .inner-header {
	background: 0 0 !important
}
#header .inner-header .container {
	padding: 40px 0;
	text-align: center;
	position: relative;
	overflow: hidden
}
.header-style-header-3 #header .inner-header .container {
	display: table
}
@media only screen and (max-width:767px) {
	.header-style-header-3 #header .inner-header .container {
		display: block
	}
}
#logo {
	text-align: center
}
.container.align-left-logo #logo {
	text-align: left
}
.container.has-banner #logo {
	display: table-cell;
	vertical-align: middle;
	width: 400px
}
.container.has-banner .header-banner {
	display: table-cell;
	vertical-align: middle;
	width: 770px;
	text-align: right
}
.penci-header-trans .penci-header-wrap {
	position: absolute;
	z-index: 10000;
	left: 0;
	right: 0
}
.penci-header-trans .penci-header-wrap #header {
	margin-bottom: 0
}
.penci-header-trans .penci-header-second {
	box-shadow: none;
	border: 0
}
.penci-header-trans .penci-header-signup-form {
	margin-top: 0
}
.penci-header-trans #logo .penci-logo-sticky,
.penci-header-trans .is-sticky #logo .penci-logo {
	display: none
}
.penci-header-trans .is-sticky #logo .penci-logo-sticky {
	display: block;
	position: static;
	visibility: visible;
	opacity: 1
}
.penci-header-trans #navigation.sticky.sticky-active #logo .penci-logo-sticky {
	display: inline
}
.penci-header-trans #navigation.sticky.sticky-active #logo .penci-logo {
	display: none
}
@media only screen and (min-width:961px) {
	#navigation.header-11 {
		background: 0 0 !important
	}
	#navigation.header-11>.container {
		background: #fff;
		box-shadow: 0 0 30px 0 rgba(0, 0, 0, .1);
		padding-left: 20px;
		padding-right: 20px
	}
	#navigation.header-11.header-layout-bottom {
		box-shadow: none;
		border: 0
	}
	.penci-header-trans .header-style-header-1 .penci-header-wrap>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-10 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-11 #header>#navigation:not(.sticky-active) .container,
	.penci-header-trans .header-style-header-2 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-3 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-4 .penci-header-wrap>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-5 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-6 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-7 .penci-header-wrap>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-8 #header>#navigation:not(.sticky-active),
	.penci-header-trans .header-style-header-9 #header>#navigation:not(.sticky-active) {
		background: 0 0 !important;
		border-top-color: transparent !important;
		border-bottom-color: transparent !important
	}
	.penci-header-trans .sticky-wrapper:not(.is-sticky) #navigation,
	.penci-header-trans .sticky-wrapper:not(.is-sticky) #navigation.header-11>.container {
		background: 0 0 !important;
		border-top-color: transparent !important;
		border-bottom-color: transparent !important
	}
	#navigation.header-10.penci-logo-overflow #logo,
	#navigation.header-11.penci-logo-overflow #logo {
		z-index: 199;
		position: relative;
		height: 80px !important;
		line-height: 1 !important
	}
	#navigation.header-10.penci-logo-overflow #logo a,
	#navigation.header-11.penci-logo-overflow #logo a {
		position: absolute;
		top: 0;
		width: 100%;
		left: 50%;
		transform: translateX(-50%);
		-webkit-transform: translateX(-50%)
	}
	#navigation.header-10.penci-logo-overflow #logo img,
	#navigation.header-11.penci-logo-overflow #logo img {
		height: auto !important;
		max-height: inherit;
		margin-top: 0 !important;
		z-index: 199
	}
}
@media only screen and (max-width:960px) {
	.penci-header-trans #navigation.penci-disable-sticky-nav #logo .penci-logo-sticky,
	.penci-header-trans #navigation.sticky #logo .penci-logo-sticky,
	.penci-header-trans .sticky-wrapper #navigation.header-6 #logo .penci-logo-sticky {
		display: inline
	}
	.penci-header-trans #navigation.penci-disable-sticky-nav #logo .penci-logo,
	.penci-header-trans #navigation.sticky #logo .penci-logo,
	.penci-header-trans .sticky-wrapper #navigation.header-6 #logo .penci-logo {
		display: none
	}
}
.header-slogan {
	margin: 17px 0 0 0;
	text-align: center;
	line-height: 1
}
.header-slogan .header-slogan-text {
	margin: 0;
	font-size: 14px;
	font-weight: 700;
	line-height: 1.5;
	font-style: italic;
	color: #313131;
	display: inline-block;
	position: relative;
	font-family: var(--pcbody-font);
	padding: 0 15px;
	vertical-align: top
}
.header-slogan .header-slogan-text:after,
.header-slogan .header-slogan-text:before {
	content: "";
	position: absolute;
	top: 50%;
	height: 1px;
	display: block;
	width: 60px;
	background: var(--pcborder-cl);
	left: 100%
}
.header-slogan .header-slogan-text:before {
	left: auto;
	right: 100%
}
.header-social {
	display: block;
	text-align: center;
	margin: 20px 0 0
}
.header-social .inner-header-social {
	display: inline-block;
	vertical-align: top;
	position: relative
}
.header-social a {
	align-items: center;
	display: inline-flex;
	vertical-align: middle;
	margin-right: 13px
}
.header-social a:last-child {
	margin-right: 0
}
.header-social a i {
	font-size: 14px;
	color: #313131;
	-webkit-transition: all .2s linear;
	-moz-transition: all .2s linear;
	-ms-transition: all .2s linear;
	-o-transition: all .2s linear;
	transition: all .2s linear;
	vertical-align: top
}
.header-social a:hover i {
	color: var(--pcaccent-cl)
}
.featured-area {
	margin-top: calc(var(--pchd-mg) * -1 + 4px);
	margin-bottom: var(--pchd-mg);
	position: relative
}
.penci-block-el.featured-area,
.penci-block-vc.featured-area {
	margin-top: 0 !important;
	margin-bottom: 0 !important
}
.featured-area:after,
.featured-area:before {
	content: "";
	display: table;
	clear: both
}
.featured-area.featured-style-2,
.featured-area.featured-style-6 {
	margin-top: calc(var(--pchd-mg) * -1 + 10px)
}
.penci-vernav-enable #header+.featured-area {
	margin-top: calc(var(--pchd-mg) * -1)
}
.penci-vernav-enable #header+.featured-area.featured-style-1,
.penci-vernav-enable #header+.featured-area.featured-style-10,
.penci-vernav-enable #header+.featured-area.featured-style-12,
.penci-vernav-enable #header+.featured-area.featured-style-14,
.penci-vernav-enable #header+.featured-area.featured-style-16,
.penci-vernav-enable #header+.featured-area.featured-style-18,
.penci-vernav-enable #header+.featured-area.featured-style-19,
.penci-vernav-enable #header+.featured-area.featured-style-20,
.penci-vernav-enable #header+.featured-area.featured-style-21,
.penci-vernav-enable #header+.featured-area.featured-style-22,
.penci-vernav-enable #header+.featured-area.featured-style-23,
.penci-vernav-enable #header+.featured-area.featured-style-24,
.penci-vernav-enable #header+.featured-area.featured-style-25,
.penci-vernav-enable #header+.featured-area.featured-style-26,
.penci-vernav-enable #header+.featured-area.featured-style-27,
.penci-vernav-enable #header+.featured-area.featured-style-29.style-30,
.penci-vernav-enable #header+.featured-area.featured-style-32,
.penci-vernav-enable #header+.featured-area.featured-style-35.style-36,
.penci-vernav-enable #header+.featured-area.featured-style-4:not(.style-5),.penci-vernav-enable #header+.featured-area.featured-style-8 {
	margin-top: calc(30px - var(--pchd-mg))
}
.penci-vernav-enable #header+.featured-area.featured-style-28,
.penci-vernav-enable #header+.featured-area.featured-style-38 {
	margin-top: calc(var(--pchd-mg) * -1 + 4px)
}
.penci-vernav-enable #header+.featured-area.featured-style-2,
.penci-vernav-enable #header+.featured-area.featured-style-37,
.penci-vernav-enable #header+.featured-area.featured-style-6 {
	margin-top: calc(var(--pchd-mg) * -1 + 10px)
}
.penci-vernav-enable #header+.penci-header-signup-form {
	margin-top: calc(var(--pchd-mg) * -1)
}
.single.penci-vernav-enable.penci-body-single-style-10.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form,
.single.penci-vernav-enable.penci-body-single-style-20.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form,
.single.penci-vernav-enable.penci-body-single-style-4.penci-body-title-bellow.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form,
.single.penci-vernav-enable.penci-body-single-style-5.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form,
.single.penci-vernav-enable.penci-body-single-style-7.penci-body-title-bellow.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form,
.single.penci-vernav-enable.penci-body-single-style-9.penci-body-title-bellow.penci-show-pthumb:not(.single-portfolio) #header+.penci-header-signup-form {
	margin-top: 0
}
.featured-area.featured-video {
	background: #fafafa url(images/loading.gif) no-repeat center center
}
.wrapper-boxed.penci-page-hide-header .featured-area {
	margin-top: 0
}
.dark-layout-enabled .featured-area.featured-video {
	background-color: #2d2d2d;
	background-image: url(images/loading2.gif)
}
.featured-area.featured-video>div {
	visibility: hidden
}
.featured-area.featured-video.loaded-wait>div {
	visibility: visible
}
.featured-area.featured-video.loaded-wait {
	background: 0 0
}
.penci-owl-carousel .owl-item .owl-lazy,
.penci-owl-carousel .owl-item .penci-lazy {
	opacity: 1;
	-webkit-transition: none;
	-moz-transition: none;
	-ms-transition: none;
	-o-transition: none;
	transition: none
}
.penci-owl-carousel .penci-owl-nav .owl-next,
.penci-owl-carousel .penci-owl-nav .owl-prev,
.penci-slick-carousel .slick-arrow {
	width: 34px;
	height: 34px;
	display: inline-block;
	vertical-align: top;
	background: #fff;
	color: #010101;
	font-size: 12px;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	position: absolute;
	z-index: 10;
	top: 50%;
	margin-top: -18px;
	left: 20px;
	line-height: 34px;
	text-align: center;
	opacity: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	border: none
}
.penci-slick-carousel .slick-arrow {
	padding: 0
}
.penci-owl-carousel .penci-owl-nav .owl-next i[class*=" penciicon-"],
.penci-owl-carousel .penci-owl-nav .owl-next i[class^=penciicon-],
.penci-owl-carousel .penci-owl-nav .owl-prev i[class*=" penciicon-"],
.penci-owl-carousel .penci-owl-nav .owl-prev i[class^=penciicon-],
.penci-slick-carousel .slick-arrow i {
	font-weight: 700 !important;
	vertical-align: top
}
.penci-owl-carousel .penci-owl-nav .owl-next i,
.penci-owl-carousel .penci-owl-nav .owl-prev i,
.penci-slick-carousel .slick-arrow i {
	line-height: inherit
}
.penci-nav-visible .penci-owl-nav .owl-next,
.penci-nav-visible .penci-owl-nav .owl-prev {
	opacity: .5
}
.penci-owl-carousel .penci-owl-nav.disabled {
	display: none
}
.penci-owl-carousel .penci-owl-nav.disabled .owl-next,
.penci-owl-carousel .penci-owl-nav.disabled .owl-prev {
	display: none !important
}
.penci-owl-carousel .penci-owl-nav .owl-next,
.penci-slick-carousel .slick-next {
	left: auto;
	right: 20px
}
.penci-owl-carousel:hover .penci-owl-nav .owl-next,
.penci-owl-carousel:hover .penci-owl-nav .owl-prev,
.penci-slick-carousel .slick-arrow {
	opacity: .8
}
.penci-owl-carousel .penci-owl-nav .owl-next:hover,
.penci-owl-carousel .penci-owl-nav .owl-prev:hover,
.penci-slick-carousel .slick-next:hover {
	opacity: 1
}
.penci-custom-slides .penci-owl-carousel .penci-owl-dots,
.penci-owl-carousel .penci-owl-dots {
	position: absolute;
	bottom: 15px !important;
	z-index: 10;
	width: 100%;
	text-align: center;
	left: 0
}
.penci-owl-carousel .penci-owl-dots.disabled {
	display: none !important
}
.penci-custom-slides .penci-owl-carousel .penci-owl-dot,
.penci-owl-carousel .penci-owl-dot {
	display: inline-block;
	margin: 0 3px;
	vertical-align: top;
	background: 0 0;
	border: none
}
.penci-owl-carousel .penci-owl-dot span {
	width: 10px;
	height: 10px;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	border: 2px solid #fff;
	background: rgba(0, 0, 0, .3);
	display: inline-block;
	vertical-align: top;
	transition: .3s all ease-in-out;
	transform: scale(.75)
}
.penci-owl-carousel .penci-owl-dot.active span {
	background: #fff
}
.penci-owl-carousel-slider .penci-owl-dot.active span {
	transform: scale(1)
}
.penci-enSticky .penci-sticky-ct.elementor-column,
.penci-enSticky .penci-sticky-sb.elementor-column {
	display: block !important
}
.penci-featured-content {
	position: absolute;
	display: block;
	top: 50%;
	width: 100%;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	padding: 0 25px;
	z-index: 9
}
.penci-featured-content .feat-text {
	max-width: 480px;
	width: 100%;
	display: block;
	margin: 0 auto;
	padding: 23px 10px 21px;
	position: relative;
	text-align: center;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s;
	animation-delay: .4s;
	-webkit-animation-delay: .4s;
	animation-delay: var(--pcfs-delay);
	-webkit-animation-delay: var(--pcfs-delay);
	opacity: 0
}
.penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .feat-text,
.penci-slick-carousel .slick-current .penci-featured-content .feat-text,
.penci-slick-carousel .swiper-slide-active .penci-featured-content .feat-text {
	-webkit-animation-name: pencitextslider;
	-moz-animation-name: pencitextslider;
	-o-animation-name: pencitextslider;
	animation-name: pencitextslider
}
@-webkit-keyframes pencifade {
	0% {
		opacity: 0
	}
	100% {
		opacity: 1
	}
}
@-moz-keyframes pencifade {
	0% {
		opacity: 0
	}
	100% {
		opacity: 1
	}
}
@-o-keyframes pencifade {
	0% {
		opacity: 0
	}
	100% {
		opacity: 1
	}
}
@keyframes pencifade {
	0% {
		opacity: 0
	}
	100% {
		opacity: 1
	}
}
@-webkit-keyframes pencitextslider {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-moz-keyframes pencitextslider {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-o-keyframes pencitextslider {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencitextslider {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-webkit-keyframes pencitextslide {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-moz-keyframes pencitextslide {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-o-keyframes pencitextslide {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencitextslide {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.penci-featured-content .featured-slider-overlay {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 1;
	background: #000;
	opacity: .7
}
.penci-featured-content .feat-text .featured-cat {
	z-index: 3;
	position: relative;
	margin-bottom: 5px;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s
}
.penci-featured-content .feat-text .featured-cat a {
	color: #fff;
	text-decoration: none !important
}
.penci-featured-content .feat-text h3 {
	z-index: 3;
	position: relative;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s
}
.penci-featured-content .feat-text h3 a {
	color: #fff;
	font-size: 24px;
	text-transform: uppercase;
	text-decoration: none
}
.penci-featured-content .feat-text .feat-meta {
	z-index: 3;
	position: relative;
	margin-top: 6px;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s
}
.penci-featured-content .feat-text>:nth-child(1) {
	animation-delay: var(--pcfs-delay)
}
.penci-featured-content .feat-text>:nth-child(2),
.penci-mag-featured-content .feat-text>:nth-child(1) {
	animation-delay: calc(var(--pcfs-delay) + .2s)
}
.penci-featured-content .feat-text>:nth-child(3),
.penci-mag-featured-content .feat-text>:nth-child(2) {
	animation-delay: calc(var(--pcfs-delay) + .4s)
}
.penci-featured-content .feat-text>:nth-child(4),
.penci-mag-featured-content .feat-text>:nth-child(3) {
	animation-delay: calc(var(--pcfs-delay) + .6s)
}
.penci-featured-content .feat-text .feat-meta span,
.penci-fslider-fmeta {
	color: #fff;
	font-size: 13px
}
.feat-meta span>time,
.penci-fslider-fmeta span>time,
span.date>time,
span.side-item-meta>time {
	font-size: inherit;
	color: inherit;
	text-decoration: inherit;
	font-weight: inherit;
	background: 0 0;
	font-style: inherit;
	font-family: inherit
}
.penci-featured-content .feat-text .feat-meta span a,
.penci-fslider-fmeta span a {
	color: #fff;
	font-size: inherit;
	text-decoration: none !important
}
.penci-featured-content .feat-text .feat-meta>span:after,
.penci-fslider-fmeta>span:after,
.popularpost_meta>span:after {
	content: "";
	display: inline-block;
	margin: 0 8px 0 12px;
	width: 0;
	height: 10px;
	border-left: 1px solid;
	opacity: .35;
	color: inherit
}
.penci-featured-content .feat-text .feat-meta>span:last-of-type:after,
.penci-fslider-fmeta>span:last-of-type:after,
.popularpost_meta>span:last-of-type:after {
	content: none;
	display: none
}
.penci-owl-carousel.penci-owl-loaded .active .feat-text .feat-meta,
.penci-owl-carousel.penci-owl-loaded .active .feat-text .featured-cat,
.penci-owl-carousel.penci-owl-loaded .active .feat-text .penci-featured-slider-button,
.penci-owl-carousel.penci-owl-loaded .active .feat-text h3 {
	-webkit-animation-name: pencitextslide;
	-moz-animation-name: pencitextslide;
	-o-animation-name: pencitextslide;
	animation-name: pencitextslide
}
.featured-style-1 .penci-owl-carousel .penci-image-holder:before {
	padding-top: 45%
}
.featured-style-2 .penci-owl-carousel .penci-image-holder:before {
	padding-top: 57%
}
.featured-style-2 .penci-owl-carousel .swiper-slide {
	width: 900px
}
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text .feat-meta,
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text .featured-cat,
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text h3,
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .feat-text {
	-webkit-animation-name: none;
	-moz-animation-name: none;
	-o-animation-name: none;
	animation-name: none
}
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .feat-text {
	-webkit-animation-name: pencitextslider;
	-moz-animation-name: pencitextslider;
	-o-animation-name: pencitextslider;
	animation-name: pencitextslider
}
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text .feat-meta,
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text .featured-cat,
.featured-style-2 .penci-owl-carousel.penci-owl-loaded .active .feat-text h3 {
	-webkit-animation-name: pencitextslide;
	-moz-animation-name: pencitextslide;
	-o-animation-name: pencitextslide;
	animation-name: pencitextslide
}
.featured-style-3 .penci-featured-content .feat-text {
	max-width: 500px
}
.featured-style-3 .penci-owl-carousel .penci-image-holder:before {
	padding-top: 0;
	height: 540px
}
.featured-style-4 .penci-owl-carousel .penci-image-holder {
	width: 67%
}
.featured-style-4 .penci-owl-carousel .penci-image-holder:before {
	height: 526px;
	padding-top: 0
}
.penci-slider4-overlay {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 2;
	background: -moz-linear-gradient(left, rgba(255, 255, 255, 0) 26%, #000 65%);
	background: -webkit-gradient(linear, left top, right top, color-stop(26%, #000), color-stop(65%, transparent));
	background: -webkit-linear-gradient(left, rgba(255, 255, 255, 0) 26%, #000 65%);
	background: -o-linear-gradient(left, rgba(255, 255, 255, 0) 26%, #000 65%);
	background: -ms-linear-gradient(left, rgba(255, 255, 255, 0) 26%, #000 65%);
	background: linear-gradient(to right, rgba(255, 255, 255, 0) 26%, #000 65%)
}
.featured-style-4 .penci-featured-content {
	width: 40%;
	padding: 0 20px;
	right: 0;
	z-index: 5
}
.featured-style-4 .penci-featured-content .featured-slider-overlay {
	background: 0 0
}
.featured-style-4 .penci-featured-content .feat-text h3 a {
	font-weight: inherit;
	letter-spacing: 0;
	font-size: 26px;
	transition: all .3s;
	-webkit-transition: all .3s;
	line-height: 1.3;
	font-family: inherit;
	text-transform: uppercase
}
.featured-style-4 .penci-featured-content .feat-text h3 a:hover {
	opacity: .8
}
.featured-style-4 .overlay-link {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 2
}
.featured-style-4 .penci-featured-content .feat-text .featured-cat {
	margin-bottom: 2px
}
.featured-style-37 .penci-image-holder:before,
.featured-style-6 .penci-image-holder:before {
	padding-top: 64%
}
.featured-area .wrapper-item-classess {
	width: 100%;
	position: relative;
	display: inline-block;
	vertical-align: top
}
.penci-item-mag {
	position: relative
}
.featured-style-37 .penci-featured-items-left,
.featured-style-37 .penci-featured-items-right,
.featured-style-6 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 32.6%;
	position: relative
}
.featured-style-37 .penci-featured-items-left,
.featured-style-6 .wrapper-item .penci-item-1 {
	width: 67.4%;
	border-right: 10px solid transparent
}
.featured-style-6 .wrapper-item .penci-item-2 {
	border-bottom: 5px solid transparent
}
.featured-style-6 .wrapper-item .penci-item-0 {
	border-top: 5px solid transparent
}
.penci-slide-overlay {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0
}
.penci-slide-overlay .overlay-link {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 1;
	background: -moz-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: -webkit-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: -o-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: -ms-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	-webkit-transition: opacity .4s ease 0s;
	-moz-transition: opacity .4s ease 0s;
	-o-transition: opacity .4s ease 0s;
	transition: opacity .4s ease 0s;
	opacity: .7
}
.penci-item-mag:hover .penci-slide-overlay .overlay-link {
	opacity: .9
}
.penci-slide-overlay .penci-mag-featured-content {
	position: absolute;
	bottom: 16px;
	left: 20px;
	padding-right: 20px;
	z-index: 5;
	opacity: 0;
	transition: opacity .4s;
	-webkit-transition: opacity .4s;
	-moz-transition: opacity .4s;
	transition-delay: .3s;
	-webkit-transition-delay: .3s;
	-moz-transition-delay: .3s;
	width: calc(100% - 20px)
}
.featured-area .active .penci-mag-featured-content,
.featured-area .swiper-slide-visible .penci-mag-featured-content,
.featured-style-7 .penci-mag-featured-content,
.featured-style-8 .penci-mag-featured-content {
	opacity: 1
}
.penci-mag-featured-content h3 {
	line-height: 1.3
}
.penci-mag-featured-content h3 a {
	text-decoration: none;
	text-transform: uppercase;
	color: #fff;
	font-size: 16px
}
.penci-mag-featured-content h3 a:hover {
	text-decoration: none
}
.featured-style-37 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-6 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 24px
}
.penci-mag-featured-content .cat>a.penci-cat-name {
	color: #fff
}
.penci-mag-featured-content .cat {
	margin-bottom: 2px
}
.penci-mag-featured-content .feat-meta>span:after {
	content: "";
	display: inline-block;
	margin: 0 8px 0 12px;
	width: 0;
	height: 8px;
	border-left: 1px solid;
	opacity: .5
}
.penci-mag-featured-content .feat-meta {
	margin-top: 6px
}
.penci-mag-featured-content .feat-meta>span:last-child:after {
	content: none
}
.penci-mag-featured-content .feat-meta a,
.penci-mag-featured-content .feat-meta span {
	color: #fff;
	font-size: 13px
}
.featured-style-7 .penci-image-holder:before {
	padding-top: 100%
}
.featured-area.featured-style-14 .wrapper-item-classess,
.featured-area.featured-style-20 .wrapper-item-classess,
.featured-area.featured-style-21 .wrapper-item-classess,
.featured-area.featured-style-22 .wrapper-item-classess,
.featured-area.featured-style-23 .wrapper-item-classess,
.featured-area.featured-style-25 .wrapper-item-classess,
.featured-area.featured-style-26 .wrapper-item-classess,
.featured-area.featured-style-27 .wrapper-item-classess {
	width: calc(100% + 4px);
	margin-left: -2px
}
.featured-style-8 .penci-image-holder:before {
	padding-top: 135.416%
}
.featured-style-8 .wrapper-item .penci-item-mag {
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-9 .penci-image-holder:before {
	padding-top: 80%
}
.featured-style-9 .penci-mag-featured-content h3 a {
	font-size: 18px
}
.featured-style-9 .wrapper-item .penci-item-mag {
	position: relative
}
.featured-style-10 .penci-image-holder:before {
	padding-top: 120%
}
.featured-style-10 .wrapper-item .penci-item-mag {
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-11 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-15 .penci-slide-overlay .penci-mag-featured-content {
	left: 0;
	padding: 0 20px;
	text-align: center;
	width: 100%
}
.featured-style-11 .penci-image-holder:before {
	padding-top: 56%
}
.featured-style-11 .penci-mag-featured-content h3 a {
	font-size: 24px
}
.featured-style-11 .wrapper-item .penci-item-mag {
	position: relative
}
.featured-style-12 .penci-mag-featured-content h3 a {
	font-size: 18px
}
.featured-style-12 .wrapper-item .penci-item-mag {
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-10 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-12 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-7 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-8 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-9 .penci-slide-overlay .penci-mag-featured-content {
	text-align: center
}
.featured-style-12 .penci-image-holder:before {
	padding-top: 66.6667%
}
.featured-style-13 .wrapper-item .penci-item-mag,
.featured-style-15 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative
}
.featured-style-13 .wrapper-item .penci-item-1,
.featured-style-15 .wrapper-item .penci-item-2 {
	width: 50%
}
.featured-style-13 .penci-image-holder:before,
.featured-style-15 .penci-image-holder:before {
	padding-top: 0;
	height: 500px
}
.featured-style-13 .penci-mag-featured-content h3 a,
.featured-style-15 .penci-mag-featured-content h3 a {
	font-size: 18px
}
.featured-style-13 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-15 .penci-item-2 .penci-mag-featured-content h3 a {
	font-size: 24px
}
.featured-style-14 .wrapper-item .penci-item-mag,
.featured-style-16 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-14 .wrapper-item .penci-item-1,
.featured-style-16 .wrapper-item .penci-item-2 {
	width: 50%
}
.featured-style-14 .penci-image-holder:before,
.featured-style-16 .penci-image-holder:before {
	padding-top: 0;
	height: 380px
}
.featured-style-16 .penci-item-2 .penci-mag-featured-content {
	left: 0;
	padding: 0 20px;
	text-align: center;
	width: 100%
}
.featured-style-14 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-16 .penci-item-2 .penci-mag-featured-content h3 a {
	font-size: 20px
}
.featured-style-17 .wrapper-item .penci-slider17-mag-item {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative
}
.featured-style-17 .wrapper-item .penci-slide17-item-2 {
	width: 50%;
	border-left: 4px solid transparent;
	border-right: 4px solid transparent
}
.featured-style-17 .penci-image-holder:before {
	padding: 0;
	height: 273px
}
.featured-style-17 .penci-slide17-item-2 .penci-image-holder:before {
	height: 550px
}
.featured-style-17 .wrapper-item .penci-item-1,
.featured-style-17 .wrapper-item .penci-item-4 {
	margin-bottom: 4px
}
.featured-style-17 .penci-slide-overlay .penci-mag-featured-content {
	text-align: center
}
.featured-style-17 .penci-item-3 .penci-mag-featured-content h3 a {
	font-size: 24px
}
.featured-style-18 .wrapper-item .penci-slider17-mag-item {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative
}
.featured-style-18 .wrapper-item .penci-slide17-item-2 {
	width: 50%;
	border-left: 4px solid transparent;
	border-right: 4px solid transparent
}
.featured-style-18 .penci-image-holder:before {
	padding: 0;
	height: 198px
}
.featured-style-18 .penci-slide17-item-2 .penci-image-holder:before {
	height: 400px
}
.featured-style-18 .wrapper-item .penci-item-1,
.featured-style-18 .wrapper-item .penci-item-4 {
	margin-bottom: 4px
}
.featured-style-18 .penci-item-3 .penci-mag-featured-content {
	text-align: center
}
.featured-style-18 .penci-mag-featured-content h3 a {
	font-size: 14px
}
.featured-style-18 .penci-item-3 .penci-mag-featured-content h3 a {
	font-size: 20px
}
.featured-style-19 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 55%;
	position: relative
}
.featured-style-19 .wrapper-item .penci-item-2,
.featured-style-19 .wrapper-item .penci-item-3 {
	width: 45%
}
.featured-style-19 .wrapper-item .penci-item-0,
.featured-style-19 .wrapper-item .penci-item-2 {
	border-left: 4px solid transparent
}
.featured-style-19 .wrapper-item .penci-item-1,
.featured-style-19 .wrapper-item .penci-item-2 {
	border-bottom: 4px solid transparent
}
.featured-style-19 .penci-image-holder:before {
	height: 275px;
	padding-top: 0
}
.featured-style-19 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-19 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 20px
}
.featured-style-20 .wrapper-item .penci-item-mag,
.featured-style-21 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 33.33333%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-22 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 20%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-20 .wrapper-item .penci-item-1,
.featured-style-20 .wrapper-item .penci-item-2,
.featured-style-22 .wrapper-item .penci-item-1,
.featured-style-22 .wrapper-item .penci-item-2 {
	width: 50%;
	border-bottom: 4px solid transparent
}
.featured-style-20 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-20 .penci-item-2 .penci-mag-featured-content h3 a,
.featured-style-21 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-21 .penci-item-4 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-2 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-1 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-2 .penci-mag-featured-content h3 a {
	font-size: 20px
}
.featured-style-20 .penci-image-holder:before,
.featured-style-21 .penci-image-holder:before {
	padding-top: 60%
}
.featured-style-20 .penci-mag-featured-content,
.featured-style-21 .penci-mag-featured-content {
	text-align: center
}
.featured-style-22 .penci-image-holder:before {
	padding-top: 66.6667%
}
.featured-style-21 .wrapper-item .penci-item-0,
.featured-style-21 .wrapper-item .penci-item-4 {
	border-top: 4px solid transparent;
	width: 50%
}
.featured-style-22 .penci-item-1 .penci-mag-featured-content,
.featured-style-22 .penci-item-2 .penci-mag-featured-content,
.featured-style-23 .penci-item-1 .penci-mag-featured-content,
.featured-style-23 .penci-item-2 .penci-mag-featured-content {
	text-align: center
}
.featured-style-22 .penci-item-0 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22 .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22 .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22 .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22 .penci-item-6 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23 .penci-item-0 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23 .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23 .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23 .penci-item-5 .penci-slide-overlay .penci-mag-featured-content {
	bottom: 12px;
	left: 0;
	width: 100%;
	padding: 0 15px;
	text-align: center
}
.featured-style-22 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-3 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-4 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-5 .penci-mag-featured-content h3 a,
.featured-style-22 .penci-item-6 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-3 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-4 .penci-mag-featured-content h3 a,
.featured-style-23 .penci-item-5 .penci-mag-featured-content h3 a {
	font-size: 14px;
	text-transform: none;
	letter-spacing: 0
}
.featured-style-23 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-23 .wrapper-item .penci-item-1,
.featured-style-23 .wrapper-item .penci-item-2 {
	width: 50%;
	border-bottom: 4px solid transparent
}
.featured-style-23 .penci-image-holder:before {
	padding-top: 66.6667%
}
.featured-style-23 .penci-item-1 .penci-image-holder:before,
.featured-style-23 .penci-item-2 .penci-image-holder:before {
	padding-top: 60%
}
.featured-style-24 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-24 .wrapper-item .penci-item-1,
.featured-style-24 .wrapper-item .penci-item-2 {
	width: 50%;
	border-bottom: 4px solid transparent
}
.featured-style-24 .wrapper-item .penci-item-2 {
	border-bottom: 4px solid transparent
}
.featured-style-24 .penci-image-holder:before {
	padding: 0;
	height: 192px
}
.featured-style-24 .penci-item-1 .penci-image-holder:before {
	height: 456px
}
.featured-style-24 .penci-item-2 .penci-image-holder:before {
	height: 260px
}
.featured-style-24 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-24 .penci-item-3 .penci-mag-featured-content h3 a {
	font-size: 14px;
	letter-spacing: 0
}
.featured-style-24 .penci-item-2 .penci-mag-featured-content h3 a {
	font-size: 20px
}
.featured-style-24 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 22px
}
.featured-style-25 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 33.33333%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-25 .wrapper-item .penci-item-1 {
	width: 66.66666%
}
.featured-style-25 .wrapper-item .penci-item-2,
.featured-style-25 .wrapper-item .penci-item-3 {
	border-bottom: 4px solid transparent
}
.featured-style-25 .penci-image-holder:before {
	padding: 0;
	height: 170px
}
.featured-style-25 .penci-item-1 .penci-image-holder:before {
	height: 518px
}
.featured-style-25 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 24px
}
.featured-style-26 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 25%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-26 .wrapper-item .penci-item-1 {
	width: 50%
}
.featured-style-26 .wrapper-item .penci-item-2,
.featured-style-26 .wrapper-item .penci-item-3 {
	border-bottom: 4px solid transparent
}
.featured-style-26 .penci-image-holder:before {
	padding: 0;
	height: 238px
}
.featured-style-26 .penci-item-1 .penci-image-holder:before {
	height: 480px
}
.featured-style-26 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 22px
}
.featured-style-26 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-26 .penci-item-2 .penci-mag-featured-content h3 a,
.featured-style-26 .penci-item-3 .penci-mag-featured-content h3 a,
.featured-style-26 .penci-item-4 .penci-mag-featured-content h3 a {
	text-transform: none;
	letter-spacing: 0
}
.featured-style-27 .wrapper-item .penci-item-mag {
	float: left;
	display: inline-block;
	width: 33.33333%;
	position: relative;
	border-left: 2px solid transparent;
	border-right: 2px solid transparent
}
.featured-style-27 .wrapper-item .penci-item-1 {
	width: 66.66666%
}
.featured-style-27 .wrapper-item .penci-item-1,
.featured-style-27 .wrapper-item .penci-item-2 {
	border-bottom: 4px solid transparent
}
.featured-style-27 .penci-image-holder:before {
	padding: 0;
	height: 260px
}
.featured-style-27 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 22px
}
.featured-style-28 .wrapper-item {
	padding-left: 2px;
	padding-right: 2px
}
.featured-style-28 .wrapper-item .penci-item-mag {
	width: 300px
}
.featured-style-28 .penci-image-holder:before {
	padding-top: 66.6667%
}
.featured-style-28 .wrapper-item .penci-item-1 {
	width: 606px
}
.featured-style-28 .penci-slide-overlay .penci-mag-featured-content {
	opacity: 1
}
.featured-style-28 .wrapper-item .penci-item-2,
.featured-style-28 .wrapper-item .penci-item-4,
.featured-style-28 .wrapper-item .penci-item-6 {
	border-bottom: 4px solid transparent
}
.featured-style-28 .penci-item-0 .penci-mag-featured-content h3 a,
.featured-style-28 .penci-item-2 .penci-mag-featured-content h3 a,
.featured-style-28 .penci-item-3 .penci-mag-featured-content h3 a,
.featured-style-28 .penci-item-4 .penci-mag-featured-content h3 a,
.featured-style-28 .penci-item-5 .penci-mag-featured-content h3 a,
.featured-style-28 .penci-item-6 .penci-mag-featured-content h3 a {
	text-transform: none;
	letter-spacing: 0
}
.featured-style-28 .penci-item-1 .penci-mag-featured-content h3 a {
	font-size: 22px
}
.overlay-icon-format {
	position: absolute;
	text-align: center;
	display: inline-block;
	width: 36px;
	height: 36px;
	line-height: 32px;
	top: 50%;
	left: 50%;
	margin: -18px 0 0 -18px;
	font-size: 14px;
	opacity: 0;
	color: rgba(255, 255, 255, .9);
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	border: 2px solid rgba(255, 255, 255, .9);
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5);
	z-index: 3;
	background: rgba(0, 0, 0, .3)
}
.overlay-icon-format.lager-size-icon {
	width: 42px;
	height: 42px;
	line-height: 38px;
	margin: -21px 0 0 -21px;
	font-size: 16px
}
.penci-item-mag:hover .overlay-icon-format {
	opacity: 1;
	transform: scale(1);
	-webkit-transform: scale(1);
	-moz-transform: scale(1)
}
.overlay-icon-format i.fa-music {
	margin-right: 3px
}
.overlay-icon-format i.fa-play {
	margin-left: 2px
}
.featured-style-17 .penci-item-0 .overlay-icon-format,
.featured-style-17 .penci-item-1 .overlay-icon-format,
.featured-style-17 .penci-item-2 .overlay-icon-format,
.featured-style-17 .penci-item-4 .overlay-icon-format,
.featured-style-18 .penci-item-0 .overlay-icon-format,
.featured-style-18 .penci-item-1 .overlay-icon-format,
.featured-style-18 .penci-item-2 .overlay-icon-format,
.featured-style-18 .penci-item-4 .overlay-icon-format,
.featured-style-19 .penci-item-mag .overlay-icon-format,
.featured-style-20 .penci-item-0 .overlay-icon-format,
.featured-style-20 .penci-item-3 .overlay-icon-format,
.featured-style-20 .penci-item-4 .overlay-icon-format,
.featured-style-21 .penci-item-1 .overlay-icon-format,
.featured-style-21 .penci-item-2 .overlay-icon-format,
.featured-style-21 .penci-item-3 .overlay-icon-format,
.featured-style-22 .penci-item-0 .overlay-icon-format,
.featured-style-22 .penci-item-3 .overlay-icon-format,
.featured-style-22 .penci-item-4 .overlay-icon-format,
.featured-style-22 .penci-item-5 .overlay-icon-format,
.featured-style-22 .penci-item-6 .overlay-icon-format,
.featured-style-23 .penci-item-0 .overlay-icon-format,
.featured-style-23 .penci-item-3 .overlay-icon-format,
.featured-style-23 .penci-item-4 .overlay-icon-format,
.featured-style-23 .penci-item-5 .overlay-icon-format,
.featured-style-24 .penci-item-0 .overlay-icon-format,
.featured-style-24 .penci-item-2 .overlay-icon-format,
.featured-style-24 .penci-item-3 .overlay-icon-format,
.featured-style-25 .penci-item-0 .overlay-icon-format,
.featured-style-25 .penci-item-2 .overlay-icon-format,
.featured-style-25 .penci-item-3 .overlay-icon-format,
.featured-style-26 .penci-item-0 .overlay-icon-format,
.featured-style-26 .penci-item-2 .overlay-icon-format,
.featured-style-26 .penci-item-3 .overlay-icon-format,
.featured-style-26 .penci-item-4 .overlay-icon-format,
.featured-style-27 .penci-item-mag .overlay-icon-format,
.featured-style-6 .penci-item-0 .overlay-icon-format,
.featured-style-6 .penci-item-2 .overlay-icon-format {
	top: 20px;
	left: auto;
	right: 20px;
	margin: 0
}
.featured-style-29 .penci-image-holder:before {
	height: 550px;
	padding: 0
}
.featured-style-35 .penci-image-holder:before {
	height: 600px;
	padding: 0
}
.featured-style-29 .featured-slider-overlay {
	position: absolute;
	background: #000;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	opacity: .3;
	z-index: 1
}
.featured-style-29 .penci-featured-content {
	z-index: 5
}
.featured-style-29 .penci-featured-content .feat-text {
	width: 100%;
	max-width: var(--pcctain);
	margin: 0 auto;
	padding: 0
}
.featured-style-29 .penci-featured-content .feat-text h3 {
	position: relative;
	padding-bottom: 15px
}
.featured-style-29 .penci-featured-content .feat-text h3:before {
	width: 60px;
	height: 0;
	border-top: 1px solid #fff;
	left: 50%;
	margin-left: -30px;
	bottom: 0;
	content: "";
	position: absolute
}
.featured-style-29 .penci-featured-content .feat-text h3 a {
	font-size: 28px
}
.featured-style-29 .penci-featured-slider-button,
.featured-style-38 .penci-featured-slider-button,
.featured-style-39 .penci-featured-slider-button,
.featured-style-40 .penci-featured-slider-button,
.featured-style-41 .penci-featured-slider-button,
.featured-style-42 .penci-featured-slider-button,
.featured-style-44 .penci-featured-slider-button {
	margin-top: 20px;
	animation-delay: 1s;
	-webkit-animation-delay: 1s;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both
}
.featured-style-29 .penci-featured-slider-button a,
.featured-style-35 .penci-featured-slider-button a,
.featured-style-38 .penci-featured-slider-button a,
.featured-style-39 .penci-featured-slider-button a,
.featured-style-40 .penci-featured-slider-button a,
.featured-style-41 .penci-featured-slider-button a,
.featured-style-42 .penci-featured-slider-button a,
.featured-style-44 .penci-featured-slider-button a {
	height: 36px;
	line-height: 34px;
	padding: 0 15px;
	border: 1px solid #fff;
	color: #fff;
	font-family: var(--pchead-font);
	font-size: 12px;
	text-transform: uppercase;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	display: inline-block;
	vertical-align: top;
	font-weight: var(--pchead-wei);
	text-decoration: none !important
}
.featured-style-29 .penci-featured-slider-button a:hover,
.featured-style-35 .penci-featured-slider-button a:hover,
.featured-style-38 .penci-featured-slider-button a:hover,
.featured-style-39 .penci-featured-slider-button a:hover,
.featured-style-40 .penci-featured-slider-button a:hover,
.featured-style-41 .penci-featured-slider-button a:hover,
.featured-style-42 .penci-featured-slider-button a:hover,
.featured-style-44 .penci-featured-slider-button a:hover {
	background: #fff;
	color: #010101;
	text-decoration: none
}
.featured-style-29 .penci-featured-content .feat-text .featured-cat a {
	font-size: 14px
}
.featured-style-29 .penci-featured-content .feat-text {
	opacity: 1;
	animation-delay: 0s;
	-webkit-animation-delay: 0s
}
.featured-style-29 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .feat-text {
	-webkit-animation-name: none;
	-moz-animation-name: none;
	-o-animation-name: none;
	animation-name: none
}
.featured-style-29 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .feat-text h3,
.featured-style-29 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content .featured-cat,
.featured-style-29 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-slider-button {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp
}
.penci-featured-content-right {
	position: absolute;
	right: 0;
	width: 450px;
	top: 0;
	bottom: 0;
	height: 100%;
	display: block;
	padding-top: 20px;
	padding-bottom: 20px
}
.penci-featured-content-right:before {
	background: #000;
	opacity: 0;
	content: "";
	position: absolute;
	left: 0;
	bottom: 0;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%;
	display: block;
	z-index: 1;
	animation-delay: var(--pcfs-delay);
	-webkit-animation-delay: var(--pcfs-delay);
	-webkit-animation-duration: .6s;
	-moz-animation-duration: .6s;
	-ms-animation-duration: .6s;
	-o-animation-duration: .6s;
	animation-duration: .6s;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both
}
.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-content-right:before {
	-webkit-animation-name: pencifadeInUpDiv;
	-moz-animation-name: pencifadeInUpDiv;
	-o-animation-name: pencifadeInUpDiv;
	animation-name: pencifadeInUpDiv
}
@-webkit-keyframes pencifadeInUpDiv {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 450px, 0);
		transform: translate3d(0, 450px, 0)
	}
	100% {
		opacity: .7;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInUpDiv {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 450px, 0);
		transform: translate3d(0, 450px, 0)
	}
	100% {
		opacity: .7;
		-webkit-transform: none;
		transform: none
	}
}
.feat-text-right {
	position: absolute;
	display: block;
	top: 50%;
	width: 100%;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	z-index: 3;
	left: 0;
	padding-left: 20px;
	padding-right: 20px
}
.featured-style-35 .penci-featured-content-right {
	z-index: 5
}
.featured-style-35 .feat-text-right h3 a {
	font-size: 28px;
	color: #fff;
	text-transform: uppercase;
	text-decoration: none
}
.featured-style-35 .featured-cat {
	margin-bottom: 5px
}
.featured-style-35 .cat>a.penci-cat-name {
	color: #fff
}
.featured-style-35 .featured-content-excerpt {
	margin-top: 7px
}
.featured-content-excerpt .sd-sharing-enabled {
	display: none
}
.featured-style-35 .featured-content-excerpt p {
	color: #fff;
	line-height: 1.6;
	opacity: .85;
	margin-top: 10px;
	font-size: 14px
}
.featured-style-35 .penci-featured-slider-button {
	margin-top: 25px
}
.featured-style-35 .feat-text-right h3,
.featured-style-35 .featured-cat,
.featured-style-35 .featured-content-excerpt,
.featured-style-35 .penci-featured-slider-button,
.featured-style-37 .penci-item-1 .feat-meta,
.featured-style-37 .penci-item-1 .feat-text h3,
.featured-style-37 .penci-item-1 .featured-cat {
	-webkit-animation-duration: .5s;
	-moz-animation-duration: .5s;
	-ms-animation-duration: .5s;
	-o-animation-duration: .5s;
	animation-duration: .5s;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both
}
.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .feat-text-right h3,
.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .featured-cat,
.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .featured-content-excerpt,
.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-slider-button,
.featured-style-37 .penci-owl-carousel.penci-owl-loaded .active .feat-text .feat-meta,
.featured-style-37 .penci-owl-carousel.penci-owl-loaded .active .feat-text h3,
.featured-style-37 .penci-owl-carousel.penci-owl-loaded .active .featured-cat {
	-webkit-animation-name: pencifadeInUpSmall;
	-moz-animation-name: pencifadeInUpSmall;
	-o-animation-name: pencifadeInUpSmall;
	animation-name: pencifadeInUpSmall
}
.feat-text-right>:nth-child(1) {
	animation-delay: calc(var(--pcfs-delay) + .4s)
}
.feat-text-right>:nth-child(2) {
	animation-delay: calc(var(--pcfs-delay) + .6s)
}
.feat-text-right>:nth-child(3) {
	animation-delay: calc(var(--pcfs-delay) + .8s)
}
.feat-text-right>:nth-child(4) {
	animation-delay: calc(var(--pcfs-delay) + 1s)
}
.feat-text-right>:nth-child(5) {
	animation-delay: calc(var(--pcfs-delay) + 1.2s)
}
.featured-style-35 .featured-content-excerpt .feat-meta span {
	color: #fff;
	font-size: 13px
}
.featured-style-35 .featured-content-excerpt .feat-meta>span:after {
	content: "";
	display: inline-block;
	margin: 0 8px 0 12px;
	width: 0;
	height: 10px;
	border-left: 1px solid;
	opacity: .35;
	color: inherit
}
.featured-style-35 .featured-content-excerpt .feat-meta>span:last-child:after {
	content: none
}
.featured-style-35 .featured-content-excerpt .feat-meta span a {
	color: #fff;
	font-size: inherit;
	text-decoration: none !important
}
.featured-style-35.style-36 .penci-image-holder:before {
	height: 550px;
	padding: 0
}
.featured-style-35.style-36 .penci-featured-content-right {
	width: 420px
}
.featured-style-37 .penci-featured-items-right>.item:first-child {
	margin-bottom: 11px
}
.featured-style-37 .penci-slide-overlay .penci-mag-featured-content {
	opacity: 1;
	text-align: center
}
.featured-style-37 .penci-owl-carousel .penci-owl-dots {
	bottom: 11px
}
.featured-style-37 .penci-item-1 .penci-slide-overlay .penci-mag-featured-content {
	bottom: 46px
}
.featured-style-37 .penci-owl-carousel[data-dots=false] .penci-item-1 .penci-slide-overlay .penci-mag-featured-content {
	bottom: 16px
}
.featured-style-37 .penci-item-1 .feat-meta,
.featured-style-37 .penci-item-1 .feat-text h3,
.featured-style-37 .penci-item-1 .featured-cat {
	opacity: 0
}
.featured-style-38 .penci-owl-carousel .item {
	width: 450px;
	width: 25vw
}
.featured-style-38 .penci-image-holder:before {
	padding-top: 120%
}
.penci-slider38-overlay {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	width: 100%;
	height: 100%;
	background: #000;
	opacity: .4;
	z-index: 1;
	transition: opacity .3s;
	-webkit-transition: opacity .3s
}
.featured-style-38 .item:hover .penci-slider38-overlay {
	opacity: .7
}
.featured-style-38 .penci-featured-content {
	z-index: 5
}
.featured-style-38 .penci-featured-slider-button {
	margin-top: 24px
}
.featured-slider-excerpt {
	margin-top: 7px
}
.featured-slider-excerpt p {
	color: #fff;
	line-height: 1.6
}
.featured-style-38 .penci-featured-content .feat-text,
.featured-style-38 .penci-owl-carousel .feat-text .feat-meta,
.featured-style-38 .penci-owl-carousel .feat-text .featured-cat,
.featured-style-38 .penci-owl-carousel .feat-text h3 {
	-webkit-animation-delay: 0 !important;
	-moz-animation-delay: 0 !important;
	-o-animation-delay: 0 !important;
	animation-delay: 0 !important;
	-webkit-animation-name: none !important;
	-moz-animation-name: none !important;
	-o-animation-name: none !important;
	animation-name: none !important;
	opacity: 1 !important
}
.post-entry .penci-featured-content .feat-text .feat-meta,
.post-entry .penci-featured-content .feat-text .featured-cat,
.post-entry .penci-mag-featured-content .cat,
.post-entry .penci-mag-featured-content .feat-meta,
.post-entry .penci-widget-slide-detail .slide-item-date {
	line-height: 1
}
.post-entry .featured-style-35 .feat-text-right h3,
.post-entry .penci-featured-content .feat-text h3,
.post-entry .penci-mag-featured-content h3,
.post-entry .penci-owl-featured-area .feat-text h3,
.post-entry .penci-widget-slider h4 {
	margin-bottom: 0
}
.post-entry .penci-widget-slider h4 a:hover {
	text-decoration: none
}
.penci-image-holder {
	position: relative;
	width: 100%;
	background: #f5f5f5;
	display: inline-block;
	vertical-align: top;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover;
	overflow: hidden
}
.swiper-slide .penci-image-holder,
.swiper-slide a.penci-image-holder {
	display: block
}
.penci-image-holder:before {
	display: block;
	content: "";
	width: 100%;
	padding-top: 66.6667%;
	background: 0 0 !important;
	box-shadow: none !important
}
.penci-image-holder.penci-list-nocrop-thumb:before {
	content: none;
	padding-top: 0
}
.owl-lazy[src*="20xmlns='http://www.w3.org/2000/svg'"],
.penci-holder-load:not([style*=background-image]),
.penci-image-holder:not([style*=background-image]),
.penci-lazy:not(.lazyloaded),.penci-lazy[src*="20xmlns='http://www.w3.org/2000/svg'"],.penci-lazy[src*=penci-holder] {
	background-image: linear-gradient(to left, #f5f5f5 0, #efefef 15%, #f5f5f5 40%, #f5f5f5 100%);
	background-repeat: no-repeat !important;
	background-color: #f5f5f5;
	background-size: 900px 1700px !important;
	animation: pencipreload .6s infinite linear forwards;
	-webkit-animation: pencipreload .6s infinite linear forwards
}
.penci-image-holder img {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	width: 100% !important;
	height: 100% !important;
	object-fit: cover
}
.penci-lazy[src*=penci-holder] {
	width: 100%;
	height: auto
}
.holder-square.penci-lazy[src*=penci-holder] {
	height: 0;
	padding-bottom: 100%
}
.about-widget img.penci-lazy[src*=penci-holder] {
	opacity: 0
}
.instagram-square-lazy.penci-lazy[src*=penci-holder] {
	height: 0 !important;
	padding-bottom: 100% !important
}
.footer-widget-wrapper .thumbnails.no-border .instagram-square-lazy.penci-lazy[src*=penci-holder],
.penci-sidebar-content .thumbnails.no-border .instagram-square-lazy.penci-lazy[src*=penci-holder] {
	margin: 5px !important;
	width: calc(100% - 10px) !important
}
@-webkit-keyframes pencipreload {
	from {
		background-position: -800px 0
	}
	to {
		background-position: 100px 0
	}
}
@keyframes pencipreload {
	from {
		background-position: -800px 0
	}
	to {
		background-position: 100px 0
	}
}
.penci-image-holder.small-fix-size {
	width: 120px
}
.penci-image-holder.square-fix-size:before {
	padding-top: 100%
}
.penci-image-holder.rectangle-fix-size:before {
	padding-top: 128%
}
.penci-image-holder.slider-style-1-fix {
	height: 600px
}
.penci-image-holder.slider-style-2-fix {
	width: 900px
}
.penci-image-holder.slider-style-2-fix:before {
	padding-top: 56.7%
}
.penci-image-holder.slider-style-7-fix:before {
	padding-top: 56.6667%
}
.penci-image-holder.slider-style-3-fix {
	height: 560px
}
.featured-style-31 .penci-image-holder:before,
.featured-style-32 .penci-image-holder:before {
	content: none
}
.pencislider-item .penci-image-holder {
	position: relative
}
.pencislider-item .penci-image-holder a {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	display: block;
	z-index: 1
}
.pencislider-container {
	position: absolute;
	display: block;
	top: 50%;
	width: 100%;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	padding: 0 40px;
	z-index: 5
}
.pencislider-container .pencislider-content {
	display: block;
	margin: 0 auto;
	max-width: var(--pcctain)
}
.pencislider-container .pencislider-content .pencislider-title {
	font-family: var(--pchead-font);
	font-size: 30px;
	line-height: 1.2em;
	text-transform: uppercase;
	margin: 0;
	font-weight: var(--pchead-wei)
}
.pencislider-container .pencislider-content .pencislider-title a {
	color: inherit;
	font-size: inherit
}
.pencislider-container .pencislider-content .pencislider-title span {
	display: inline-block;
	vertical-align: top;
	padding: 5px 12px;
	color: inherit;
	font-size: inherit;
	background-color: rgba(0, 0, 0, .4)
}
.pencislider-container .pencislider-content .pencislider-caption {
	font-size: 16px;
	line-height: 1.3em;
	margin: 15px 0 0
}
.pencislider-container .pencislider-content .pencislider-caption span {
	display: inline-block;
	vertical-align: top;
	padding: 5px 12px;
	color: inherit;
	font-size: inherit;
	background-color: rgba(0, 0, 0, .4)
}
.pencislider-container .pencislider-content .penci-button {
	margin: 25px 0 0;
	background: 0 0;
	padding: 0;
	vertical-align: top;
	max-width: 100%
}
.pencislider-container .pencislider-content .pencislider-button {
	text-decoration: none;
	display: inline-block;
	padding: 11px 20px 11px;
	text-transform: uppercase;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	font-family: var(--pchead-font);
	cursor: pointer;
	font-size: 14px;
	line-height: 1.3;
	border: none;
	position: relative;
	font-weight: var(--pchead-wei)
}
.pencislider-container .pencislider-content .pencislider-button:hover {
	opacity: .9
}
.pencislider-container .pencislider-caption,
.pencislider-container .pencislider-content .penci-button,
.pencislider-container .pencislider-title {
	text-align: left;
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: 1s;
	-moz-animation-duration: 1s;
	-ms-animation-duration: 1s;
	-o-animation-duration: 1s;
	animation-duration: 1s
}
.pencislider-container.align-center .penci-button,
.pencislider-container.align-center .pencislider-caption,
.pencislider-container.align-center .pencislider-title {
	text-align: center
}
.pencislider-container.align-right .penci-button,
.pencislider-container.align-right .pencislider-caption,
.pencislider-container.align-right .pencislider-title {
	text-align: right
}
.pencislider-container .pencislider-content>:nth-child(1) {
	animation-delay: var(--pcfs-delay)
}
.pencislider-container .pencislider-content>:nth-child(2) {
	animation-delay: calc(var(--pcfs-delay) + .2s)
}
.pencislider-container .pencislider-content>:nth-child(3) {
	animation-delay: calc(var(--pcfs-delay) + .4s)
}
@-webkit-keyframes pencifadeInDown {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -40px, 0);
		transform: translate3d(0, -40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInDown {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -40px, 0);
		transform: translate3d(0, -40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.featured-area .active .pencislider-container.penci-fadeInDown .pencislider-caption,
.featured-area .active .pencislider-container.penci-fadeInDown .pencislider-content .penci-button,
.featured-area .active .pencislider-container.penci-fadeInDown .pencislider-title {
	-webkit-animation-name: pencifadeInDown;
	-moz-animation-name: pencifadeInDown;
	-o-animation-name: pencifadeInDown;
	animation-name: pencifadeInDown
}
@-webkit-keyframes pencifadeInUp {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInUp {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-webkit-keyframes pencifadeInUpSmall {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInUpSmall {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 20px, 0);
		transform: translate3d(0, 20px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.featured-area .active .pencislider-container.penci-fadeInUp .pencislider-caption,
.featured-area .active .pencislider-container.penci-fadeInUp .pencislider-content .penci-button,
.featured-area .active .pencislider-container.penci-fadeInUp .pencislider-title {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp
}
@-webkit-keyframes pencifadeInLeft {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-50px, 0, 0);
		transform: translate3d(-50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInLeft {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-50px, 0, 0);
		transform: translate3d(-50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.featured-area .active .pencislider-container.penci-fadeInLeft .pencislider-caption,
.featured-area .active .pencislider-container.penci-fadeInLeft .pencislider-content .penci-button,
.featured-area .active .pencislider-container.penci-fadeInLeft .pencislider-title {
	-webkit-animation-name: pencifadeInLeft;
	-moz-animation-name: pencifadeInLeft;
	-o-animation-name: pencifadeInLeft;
	animation-name: pencifadeInLeft
}
@-webkit-keyframes pencifadeInRight {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(50px, 0, 0);
		transform: translate3d(50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInRight {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(50px, 0, 0);
		transform: translate3d(50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.featured-area .active .pencislider-container.penci-fadeInRight .pencislider-caption,
.featured-area .active .pencislider-container.penci-fadeInRight .pencislider-content .penci-button,
.featured-area .active .pencislider-container.penci-fadeInRight .pencislider-title {
	-webkit-animation-name: pencifadeInRight;
	-moz-animation-name: pencifadeInRight;
	-o-animation-name: pencifadeInRight;
	animation-name: pencifadeInRight
}
.penci-flat-overlay .penci-slide-overlay .overlay-link {
	background: 0 0 !important;
	opacity: 0 !important
}
.penci-flat-overlay .penci-slide-overlay .penci-mag-featured-content {
	bottom: 0;
	left: 0;
	right: 0;
	padding: 17px 20px;
	width: 100%
}
.penci-flat-overlay .penci-slide-overlay .penci-mag-featured-content:before {
	position: absolute;
	left: 0;
	right: 0;
	bottom: 0;
	top: 0;
	background: #000;
	opacity: .5;
	content: "";
	z-index: 1;
	-webkit-transition: opacity .4s ease 0s;
	-moz-transition: opacity .4s ease 0s;
	-o-transition: opacity .4s ease 0s;
	transition: opacity .4s ease 0s
}
.penci-flat-overlay .penci-item-mag:hover .penci-slide-overlay .penci-mag-featured-content:before {
	opacity: .7
}
.penci-flat-overlay .feat-text,
.penci-flat-overlay .penci-mag-featured-content .cat {
	position: relative;
	z-index: 5
}
.featured-style-22.penci-flat-overlay .penci-item-0 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22.penci-flat-overlay .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22.penci-flat-overlay .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22.penci-flat-overlay .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-22.penci-flat-overlay .penci-item-6 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23.penci-flat-overlay .penci-item-0 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23.penci-flat-overlay .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23.penci-flat-overlay .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
.featured-style-23.penci-flat-overlay .penci-item-5 .penci-slide-overlay .penci-mag-featured-content {
	bottom: 0;
	padding: 10px 5px
}
.featured-style-28.penci-flat-overlay .penci-slide-overlay .penci-mag-featured-content {
	padding: 12px 15px
}
.featured-style-28.penci-flat-overlay .penci-item-1 .penci-slide-overlay .penci-mag-featured-content {
	padding: 17px 20px
}
.penci-owl-carousel:not(.penci-owl-loaded) {
	display: block
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-featured-content-right,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>div,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>figure,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>img,
.penci-owl-carousel:not(.penci-owl-loaded)>div {
	display: none
}
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>div:first-child,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>figure:first-child,
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper>img:first-child {
	display: block
}
.penci-owl-carousel:not(.penci-owl-loaded)>.swiper-wrapper {
	overflow: hidden
}
.featured-style-2 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
	width: 900px;
	margin-left: auto;
	margin-right: auto
}
.featured-style-38 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
	width: 450px;
	width: 25vw;
	margin-left: auto;
	margin-right: auto;
	position: relative
}
@media only screen and (max-width:1200px) {
	.featured-style-38 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
		width: 400px
	}
}
@media only screen and (max-width:960px) {
	.featured-style-2 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
		width: 760px
	}
}
@media only screen and (max-width:767px) {
	.featured-style-2 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
		width: 480px
	}
}
@media only screen and (max-width:479px) {
	.featured-style-2 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item,
	.featured-style-38 .penci-owl-carousel:not(.penci-owl-loaded) .swiper-wrapper>.item {
		width: 360px
	}
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-featured-content {
	display: none
}
.penci-owl-carousel:not(.penci-owl-loaded):after,
.penci-owl-carousel:not(.penci-owl-loaded):before {
	content: "";
	clear: both;
	display: table
}
.penci-owl-carousel.penci-headline-posts:not(.penci-owl-loaded):after,
.penci-owl-carousel.penci-headline-posts:not(.penci-owl-loaded):before {
	content: none;
	clear: none;
	display: none
}
@media only screen and (min-width:1170px) {
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div {
		width: 16.666666%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="5"] .swiper-wrapper>div {
		width: 20%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="4"] .swiper-wrapper>div {
		width: 25%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="3"] .swiper-wrapper>div {
		width: 33.3333%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="2"] .swiper-wrapper>div {
		width: 50%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="2"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="3"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="3"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="4"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="4"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="4"] .swiper-wrapper>div:nth-child(4),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="5"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="5"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="5"] .swiper-wrapper>div:nth-child(4),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="5"] .swiper-wrapper>div:nth-child(5),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div:nth-child(4),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div:nth-child(5),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-item="6"] .swiper-wrapper>div:nth-child(6) {
		display: block
	}
}
@media only screen and (max-width:1169px) and (min-width:768px) {
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="4"] .swiper-wrapper>div {
		width: 25%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="4"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="4"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="4"] .swiper-wrapper>div:nth-child(4) {
		display: block
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="3"] .swiper-wrapper>div {
		width: 33.3333%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="3"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="3"] .swiper-wrapper>div:nth-child(3) {
		display: block
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="2"] .swiper-wrapper>div {
		width: 50%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tablet="2"] .swiper-wrapper>div:nth-child(2) {
		display: block
	}
}
@media only screen and (max-width:767px) and (min-width:481px) {
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="4"] .swiper-wrapper>div {
		width: 25%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="4"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="4"] .swiper-wrapper>div:nth-child(3),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="4"] .swiper-wrapper>div:nth-child(4) {
		display: block
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="3"] .swiper-wrapper>div {
		width: 33.3333%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="3"] .swiper-wrapper>div:nth-child(2),
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="3"] .swiper-wrapper>div:nth-child(3) {
		display: block
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="2"] .swiper-wrapper>div {
		width: 50%;
		float: left
	}
	.penci-owl-carousel:not(.penci-owl-loaded)[data-tabsmall="2"] .swiper-wrapper>div:nth-child(2) {
		display: block
	}
}
.pc-wrapbuilder-header {
	--pchb-socialw: 28px;
	--pchb-m-socialw: 28px
}
.pc-wrapbuilder-header .container {
	max-width: 100%;
}
.pc-wrapbuilder-header .container.container-1400 {
	max-width: var(--pcctain2);
}
.penci_nav_row {
	position: relative;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-flex-flow: row nowrap;
	flex-flow: row nowrap;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-justify-content: space-between;
	-ms-flex-pack: justify;
	justify-content: space-between;
	height: 100%;
	margin-left: -10px;
	margin-right: -10px
}
.pchb-boxed-layout .penci_nav_row {
	margin-left: 10px;
	margin-right: 10px
}
.penci_nav_normal {
	flex: 0 0 auto
}
.pcmiddle-center .penci_nav_center,
.pcmiddle-center .penci_nav_left,
.pcmiddle-center .penci_nav_right {
	display: flex;
	flex-direction: row;
	align-items: center
}
.pcmiddle-center .penci_nav_left,
.pcmiddle-center .penci_nav_right {
	flex: 1 1 0
}
.pcmiddle-center .penci_nav_left,
.pcmiddle-normal .penci_nav_alignleft {
	justify-content: flex-start
}
.pcmiddle-center .penci_nav_right,
.pcmiddle-normal .penci_nav_alignright {
	justify-content: flex-end
}
.pcmiddle-center .penci_nav_aligncenter,
.pcmiddle-normal .penci_nav_aligncenter {
	justify-content: center
}
.pcmiddle-normal .penci_nav_center {
	flex: 1 1 0
}
.pc-builder-menu .navigation {
	background-color: transparent;
	border: 0;
	height: auto
}
.penci-desktop-bottombar,
.penci-desktop-midbar,
.penci-desktop-sticky-bottom,
.penci-desktop-sticky-mid,
.penci-desktop-sticky-top,
.penci-desktop-topbar,
.penci-mobile-bottombar,
.penci-mobile-midbar,
.penci-mobile-topbar {
	padding-top: 10px;
	padding-bottom: 10px;
	background-size: cover;
	background-repeat: no-repeat;
	background-attachment: scroll
}
.penci-desktop-bottombar.pc-noel,
.penci-desktop-midbar.pc-noel,
.penci-desktop-sticky-bottom.pc-noel,
.penci-desktop-sticky-mid.pc-noel,
.penci-desktop-sticky-top.pc-noel,
.penci-desktop-topbar.pc-noel,
.penci-mobile-bottombar.pc-noel,
.penci-mobile-midbar.pc-noel,
.penci-mobile-topbar.pc-noel {
	padding-top: 0;
	padding-bottom: 0
}
.penci-desktop-bottombar,
.penci-desktop-bottomblock,
.penci-desktop-midbar,
.penci-desktop-topbar,
.penci-desktop-topblock {
	background-color: #fff
}
.penci-header-trans .penci-desktop-bottombar,
.penci-header-trans .penci-desktop-bottomblock,
.penci-header-trans .penci-desktop-midbar,
.penci-header-trans .penci-desktop-topbar,
.penci-header-trans .penci-desktop-topblock {
	background-color: transparent
}
.penci_header_overlap .penci-desktop-bottombar,
.penci_header_overlap .penci-desktop-bottomblock,
.penci_header_overlap .penci-desktop-midbar,
.penci_header_overlap .penci-desktop-topbar,
.penci_header_overlap .penci-desktop-topblock {
	background-color: transparent
}
.penci-desktop-bottombar.bg-transparent,
.penci-desktop-bottomblock.bg-transparent,
.penci-desktop-midbar.bg-transparent,
.penci-desktop-topbar.bg-transparent,
.penci-desktop-topblock.bg-transparent {
	background-color: transparent !important
}
.pc-wrapbuilder-header {
	margin-bottom: var(--pchd-mg)
}
.elementor-template-full-width .pc-wrapbuilder-header,
.page-template-page-fullwidth .pc-wrapbuilder-header {
	margin-bottom: 0
}
.pc-wrapbuilder-header .header-social .inner-header-social {
	display: flex;
	position: relative
}
.pc-wrapbuilder-header #penci_off_canvas .header-social .inner-header-social {
	display: inline-block
}
@media only screen and (max-width:479px) {
	#penci_off_canvas .penci-builder-element.header-social a {
		margin-bottom: 10px
	}
}
.pc-wrapbuilder-header .header-social.mobile-social .inner-header-social {
	justify-content: center
}
.single.penci-body-single-style-10 #header,
.single.penci-body-single-style-10 .pc-wrapbuilder-header,
.single.penci-body-single-style-5 #header,
.single.penci-body-single-style-5 .pc-wrapbuilder-header,
.single.penci-body-single-style-6 #header,
.single.penci-body-single-style-6 .pc-wrapbuilder-header {
	--pchd-mg: 40px
}
.navigation {
	background: #fff;
	height: 60px;
	z-index: 9999;
	width: 100%;
	-webkit-backface-visibility: hidden;
	border-bottom: 1px solid #ececec;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.navigation.pc-elehd-menu,
.navigation.mobile-menu {
	background-color: transparent;
	height: unset
}
.navigation.pc-elehd-menu {
	border: 0;
	display: flex;
}
.post-entry .navigation.pc-elehd-menu > ul {
	padding: 0;
	list-style: none;
}
.post-entry .navigation.pc-elehd-menu > ul li {
	list-style: none;
}
.navigation.pchdvertical-enabled .menu .sub-menu {
	top: 0;
	left: 100%;
}
.navigation.pchdvertical-enabled ul.menu > li.menu-item-has-children > a:after {
	content: '\f105';
}
.navigation.pchdvertical-enabled ul.menu > li {
	float: none; 
	display: block;
}
.wrapper-boxed.enable-boxed .navigation {
	transition: height .3s, box-shadow .3s;
	-webkit-transition: height .3s, box-shadow .3s;
	-moz-transition: height .3s, box-shadow .3s
}
.navigation.sticky-active {
	z-index: 99999
}
.navigation.header-layout-bottom {
	box-shadow: 0 0 0 transparent;
	-webkit-box-shadow: 0 0 0 transparent;
	-moz-box-shadow: 0 0 0 transparent;
	border-top: 1px solid #ececec
}
.is-sticky .navigation {
	box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-webkit-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-moz-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	border-color: transparent !important
}
.wrapper-boxed.enable-boxed .is-sticky .navigation {
	margin: 0 auto;
	left: 0;
	right: 0;
	width: 100%;
	max-width: calc(var(--pcctain) + 60px)
}
.penci-body-boxed.penci-two-sidebar .wrapper-boxed.enable-boxed .is-sticky .navigation {
	max-width: calc(var(--pcctain2) + 30px)
}
.slicknav_menu {
	display: none
}
.navigation .container {
	position: relative;
	display: table;
	text-align: center
}
.navigation .container .inner-top-navigation {
	display: inline-block;
	vertical-align: top
}
.navigation .menu {
	float: left
}
.navigation .menu>ul>li,
.navigation ul.menu>li {
	display: inline-block;
	position: relative;
	float: left;
	margin-right: 30px
}
.navigation .menu>li:last-child,
.navigation .menu>ul>li:last-child {
	margin-right: 0
}
.navigation .menu>li>a,
.navigation .sub-menu>li>a {
	font-family: var(--pchead-font);
	font-size: 12px;
	color: #313131;
	text-transform: uppercase;
	display: inline-block;
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	position: relative;
	font-weight: var(--pchead-wei);
	text-decoration: none
}
.navigation .menu>li>a {
	line-height: 58px
}
.navigation .menu>li>a>i,
.navigation .sub-menu li>a>i {
	font-size: 13px;
	margin-right: 5px
}
.navigation .menu>ul.sub-menu>li>a:before,
.navigation ul.menu>li>a:before {
	content: "";
	position: absolute;
	bottom: calc(50% - 12px);
	transition: all .2s;
	-webkit-transition: all .2s;
	-moz-transition: all .2s;
	left: 50%;
	height: 2px;
	width: 0;
	background: var(--pcaccent-cl)
}
.navigation .menu>ul>li:hover>a:before,
.navigation .menu>ul>li>a:hover:before,
.navigation ul.menu>li:hover>a:before,
.navigation ul.menu>li>a:hover:before {
	left: 0;
	width: 100%
}
.navigation .menu li.current-menu-item>a,
.navigation .menu li:hover>a,
.navigation .menu li>a:hover,
.navigation .menu>li.current-menu-ancestor>a,
.navigation .menu>li.current-menu-item>a,
.navigation .menu>li.current_page_item>a {
	color: var(--pcaccent-cl)
}
.navigation .menu>ul>li>a>img,
.navigation ul.menu>li>a>img {
	vertical-align: middle
}
.navigation .button-menu-mobile {
	display: none;
	float: left;
	text-align: center;
	color: #313131;
	font-size: 21px;
	cursor: pointer;
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s
}
@media only screen and (max-width:960px) {
	.penci-hlogo-center .penci-mobile-hlogo {
		float: none;
		margin: 0;
		position: absolute;
		left: 50%;
		top: 0;
		transform: translateX(-50%);
		-webkit-transform: translateX(-50%);
		z-index: 10
	}
	.penci-mobile-hlogo {
		display: inline-block
	}
}
.pb-logo-sidebar-mobile {
	text-align: center
}
.navigation .menu .children,
.navigation .menu .sub-menu {
	visibility: hidden;
	opacity: 0;
	position: absolute;
	left: 0;
	z-index: 9999;
	box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-webkit-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-moz-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	border-top: 1px solid #ececec;
	margin-top: 0;
	background: #fff
}
body.penci-hsubmenu-overlay .navigation .menu .children,
body.penci-hsubmenu-overlay .navigation .menu .sub-menu {
	box-shadow: 0 3px 3px rgba(34, 33, 33, 0.6);
	-webkit-box-shadow: 0 3px 3px rgba(34, 33, 33, 0.6);
	-moz-box-shadow: 0 3px 3px rgba(34, 33, 33, 0.6);
}
.navigation ul.menu ul.sub-menu li a {
	margin: 0 20px;
	padding: 12px 0;
	font-size: 12px;
	min-width: 200px;
	line-height: 1.4;
	-moz-transition: color .3s, background-color .3s;
	-webkit-transition: color .3s, background-color .3s;
	transition: color .3s, background-color .3s;
	border-bottom: 1px solid #e0e0e0;
	text-align: left;
	border-left: none !important;
	position: relative;
	overflow: hidden;
	vertical-align: top
}
.navigation ul.menu ul ul.sub-menu li,
.navigation ul.menu ul.sub-menu li {
	padding-right: 0;
	margin-right: 0;
	float: none;
	position: relative;
	width: 100%
}
.navigation .menu ul.sub-menu>li:last-child>a {
	border-bottom: none
}
.navigation .menu .children ul,
.navigation .menu .sub-menu ul {
	left: 100%;
	top: 0
}
.navigation .menu li.penci-mega-menu {
	position: static !important
}
#navigation .menu li.penci-block-mega.penci-megapos-center,
#navigation .menu li.penci-block-mega.penci-megapos-flexible,
.navigation .menu li.penci-block-mega.penci-megapos-center,
.navigation .menu li.penci-block-mega.penci-megapos-flexible {
	position: relative !important
}
li.penci-mega-menu>ul.sub-menu {
	display: none
}
#sidebar-nav li.penci-mega-menu .penci-content-megamenu,
.penci-menu-hbg li.penci-mega-menu .penci-content-megamenu {
	display: none !important
}
.navigation .menu li.penci-mega-menu>ul.sub-menu {
	width: 100%;
	padding: 0 !important;
	clear: both;
	display: block
}
.navigation .menu li.penci-block-mega.penci-mg-fullwidth {
	position: static !important;
	--pcctnspc: 0;
}
.navigation .menu li.penci-block-mega.penci-mg-fullwidth>.penci-dropdown-menu {
	width: 100vw !important;
	left: calc((100vw - var(--pcctain))/ 2 * -1 + 10px - var(--pcctnspc)) !important
}
.navigation .menu li.penci-block-mega.penci-mg-fullwidth>.penci-dropdown-menu>.container {
	width: 100%
}
.navigation .penci-megamenu {
	width: 100%;
	display: table
}
.navigation .penci-megamenu .penci-mega-child-categories {
	width: 230px;
	display: table-cell;
	vertical-align: top;
	background: #fff;
	padding: 20px 0;
	position: relative
}
.navigation .penci-megamenu .penci-mega-child-categories.pcmit-bottom {
	display: table-footer-group;
	width: 100%;
	text-align: center
}
.navigation .penci-megamenu .penci-mega-child-categories.pcmit-top {
	display: table-row;
	width: 100%;
	text-align: center
}
.navigation .penci-megamenu .penci-mega-child-categories:after {
	content: "";
	width: 1px;
	height: 100%;
	position: absolute;
	top: 0;
	right: 0;
	background-color: #ececec
}
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
	min-width: 0;
	display: block;
	font-size: 12px;
	text-align: right;
	line-height: 1.4em;
	margin: 0;
	padding: 12px 20px;
	border-top: 1px solid transparent;
	border-bottom: 1px solid transparent;
	position: relative
}
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	display: inline-block
}
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a.cat-active {
	border-top-color: #ececec;
	border-bottom-color: #ececec;
	background: #fff;
	color: var(--pcaccent-cl);
	z-index: 10;
	position: relative
}
#navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a.cat-active,
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a.cat-active {
	border-bottom-color: transparent
}
#navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a.cat-active,
.navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a.cat-active {
	border-top-color: transparent
}
.navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before {
	content: "";
	width: 1px;
	height: 100%;
	position: absolute;
	top: 0;
	right: 0;
	background: #fff;
	z-index: 1;
	transition: none;
	-webkit-transition: none;
	-moz-transition: none
}
.navigation .penci-megamenu .penci-content-megamenu {
	display: table-cell
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts {
	padding: 20px 10px 0 10px
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-row {
	width: 100%;
	display: none;
	vertical-align: top
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
	width: 20%;
	padding: 0 10px;
	float: left;
	margin-bottom: 15px;
	position: relative
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
	width: 25%
}
.navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(4n+1),
.navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(5n+1) {
	clear: both
}
.navigation .penci-megamenu .pcmit-side+.penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(4n+1),
.navigation .penci-megamenu .pcmit-side+.penci-content-megamenu .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(5n+1) {
	clear: both /* fix issue */
}
.penci-megamenu .penci-image-holder:before {
	padding-top: 66.6667%
}
@media only screen and (min-width:1800px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 14.2857%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 16.66666%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(6n+1),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(7n+1) {
		clear: both
	}
}
@media only screen and (max-width:1799px) and (min-width:1500px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 16.66666%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 20%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(5n+1),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(6n+1) {
		clear: both
	}
	.navigation .penci-megamenu .penci-content-megamenu.pcmis-5 .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(5n+1) {
		clear: none
	}
}
@media only screen and (max-width:1799px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(6),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(11),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(12),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(16),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(17),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(18),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(7),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(13),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(14),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(19),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(20),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(21) {
		display: none
	}
}
@media only screen and (max-width:1499px) and (min-width:1170px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 20%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 25%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(4n+1),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(5n+1) {
		clear: both
	}
}
@media only screen and (max-width:1499px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(5),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(10),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(9),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(13),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(14),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(15),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(6),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(11),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(12),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(16),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(17),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(18) {
		display: none
	}
}
@media only screen and (max-width:1169px) {
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post {
		width: 25%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post {
		width: 33.33333%
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6 .penci-mega-post:nth-child(3n+1),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7 .penci-mega-post:nth-child(4n+1) {
		clear: both
	}
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-1 .penci-mega-post:nth-child(4),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(7),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-2 .penci-mega-post:nth-child(8),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(10),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(11),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-6.mega-row-3 .penci-mega-post:nth-child(12),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-1 .penci-mega-post:nth-child(5),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(10),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-2 .penci-mega-post:nth-child(9),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(13),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(14),
	.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-7.mega-row-3 .penci-mega-post:nth-child(15) {
		display: none
	}
}
.navigation .penci-megamenu .penci-mega-thumbnail {
	display: block;
	margin: 0 0 17px 0;
	position: relative
}
.navigation .penci-megamenu .penci-mega-thumbnail a {
	width: 100%
}
.navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
	font-size: 10px;
	background: var(--pcaccent-cl);
	text-transform: uppercase;
	position: absolute;
	display: inline-block;
	padding: 0 6px;
	color: #fff;
	top: 0;
	left: 0;
	z-index: 3;
	height: 18px;
	font-weight: 400;
	text-align: center;
	line-height: 18px
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post a {
	margin: 0;
	padding: 0;
	min-width: 0;
	border-bottom: none;
	position: relative
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail a {
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail a:hover {
	opacity: .8
}
.navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-thumbnail .mega-cat-name a {
	font-size: inherit !important;
	font-family: inherit !important;
	font-weight: inherit !important;
	line-height: inherit !important;
	color: inherit !important;
	opacity: 1;
	padding: 0;
	margin: 0;
	text-transform: none;
	letter-spacing: 0
}
.navigation .penci-megamenu .penci-mega-thumbnail img {
	width: 100%;
	height: auto
}
.navigation .penci-megamenu .post-mega-title {
	text-align: center;
	margin: 0
}
.navigation .penci-megamenu .post-mega-title a {
	text-align: center
}
.navigation .penci-megamenu .penci-mega-date {
	line-height: 1;
	font-size: 12px;
	color: #999;
	text-align: center;
	margin-top: 6px
}
.navigation ul.menu>li.megamenu {
	position: static
}
.navigation ul.menu>li.megamenu>ul.sub-menu {
	width: var(--pcctain);
	padding: 15px 0;
	display: table;
	table-layout: fixed;
	background: #fff;
	left: 0
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li {
	min-width: 200px;
	max-width: 300px;
	display: table-cell;
	vertical-align: top;
	padding: 0 5px;
	margin: 0;
	position: relative
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li:before {
	left: 0;
	content: "";
	position: absolute;
	top: 15px;
	bottom: 15px;
	width: 1px;
	display: block;
	background: #e0e0e0
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li:first-child:before {
	content: none;
	display: none
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li>a {
	margin: 0 20px;
	border-bottom: 1px solid #e0e0e0;
	display: none
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu {
	visibility: visible;
	opacity: 1;
	transform: none;
	-webkit-transform: none;
	-moz-transform: none;
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	position: static;
	border: none
}
.navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu li,
.navigation ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu li a {
	display: block
}
.navigation.menu-style-2 .menu>ul>li>a:before,
.navigation.menu-style-2 ul.menu>li>a:before {
	content: none;
	display: none
}
.navigation .menu>ul.sub-menu>li.menu-item-has-children>a:after,
.navigation .menu>ul.sub-menu>li.penci-mega-menu>a:after,
.navigation ul.menu>li.menu-item-has-children>a:after,
.navigation ul.menu>li.penci-mega-menu>a:after {
	font-family: FontAwesome;
	content: "\f107";
	margin-left: 5px;
	color: inherit;
	font-size: 13px;
	font-weight: 400;
	width: auto;
	display: inline-block;
	vertical-align: top;
	line-height: inherit
}
.penci-fawesome-ver5 .navigation .menu>ul>li.menu-item-has-children>a:after,
.penci-fawesome-ver5 .navigation .menu>ul>li.penci-mega-menu>a:after,
.penci-fawesome-ver5 .navigation ul.menu>li.menu-item-has-children>a:after,
.penci-fawesome-ver5 .navigation ul.menu>li.penci-mega-menu>a:after {
	font-family: "Font Awesome 5 Free";
	content: "\f107";
	font-weight: 900
}
.navigation.menu-style-2 .menu .children,
.navigation.menu-style-2 .menu .sub-menu {
	border-top: 4px solid #e0e0e0;
	padding: 8px 0
}
.navigation.menu-style-2 ul.menu ul.sub-menu:before {
	width: 0;
	height: 4px;
	top: -4px;
	position: absolute;
	background: var(--pcaccent-cl);
	left: 0;
	-webkit-transition: width .4s cubic-bezier(.87, .02, .23, 1);
	-webkit-transition: width .4s cubic-bezier(.87, .02, .23, 1.005);
	-moz-transition: width .4s cubic-bezier(.87, .02, .23, 1.005);
	-o-transition: width .5s cubic-bezier(.87, .02, .23, 1.005);
	transition: width .5s cubic-bezier(.87, .02, .23, 1.005);
	content: "";
	transition-delay: .3s;
	-webkit-transition-delay: .3s;
	-moz-transition-delay: .3s
}
.navigation.menu-style-2 .menu ul li:hover>ul.sub-menu:before,
.navigation.menu-style-2 ul.menu li:hover>ul.sub-menu:before {
	width: 100%
}
.navigation.menu-style-2 ul.menu ul.sub-menu a {
	padding: 8px 0;
	border: none !important
}
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts {
	padding: 0
}
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
	margin: 0;
	position: relative;
	z-index: 5
}
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu.pcmis-1 .penci-mega-latest-posts .penci-mega-post {
	padding: 0 0 15px;
}
#navigation.menu-style-2 .penci-megamenu .penci-content-megamenu:not(.pcmis-1) .penci-mega-latest-posts .penci-mega-post,
.navigation.menu-style-2 .penci-megamenu .penci-content-megamenu:not(.pcmis-1) .penci-mega-latest-posts .penci-mega-post {
	padding-top: 15px;
	padding-bottom: 15px;
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-thumbnail {
	position: relative;
	z-index: 5
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-meta {
	padding: 0 5px
}
.navigation.menu-style-2 .penci-megamenu .post-mega-title {
	line-height: 1
}
.menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post:before {
	position: absolute;
	content: "";
	right: 0;
	top: 0;
	bottom: 0;
	width: 1px;
	background: #f1f1f2;
	z-index: 1
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
	bottom: 0;
	top: auto
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories {
	padding: 12px 0
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories:after {
	background-color: #f1f1f2
}
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
	min-width: 0;
	display: block;
	text-align: left;
	line-height: 1.4em;
	margin: 0;
	padding: 6px 0 6px 20px;
	position: relative;
	border: none;
	background-color: inherit;
	z-index: 0
}
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	padding-top: 20px;
	padding-bottom: 20px
}
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-bottom a,
.navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories.pcmit-top a {
	display: inline-block
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after {
	content: "";
	display: block;
	position: absolute;
	top: 50%;
	margin-top: -.5px;
	-webkit-transition: width .4s ease-in-out;
	-o-transition: width .4s ease-in-out;
	transition: width .4s ease-in-out;
	border-bottom: 1px solid;
	width: 0;
	opacity: .3;
	left: 20px;
	z-index: 1;
	box-shadow: none;
	-webkit-box-shadow: none;
	color: inherit
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:hover:after {
	width: calc(100% + 20px)
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span {
	position: relative;
	z-index: 2;
	background-color: inherit;
	padding-right: 20px;
	display: inline-block
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.all-style:before {
	content: "";
	background: #f1f1f2;
	width: 24px;
	display: block;
	height: 1px;
	margin: 4px 0 17px;
	opacity: 1;
	position: static;
	box-shadow: none;
	-webkit-box-shadow: none
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-bottom a.all-style:before,
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories.pcmit-top a.all-style:before {
	display: none
}
.navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.all-style:after {
	content: none;
	display: none
}
.navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu {
	padding: 5px 0
}
.navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu>li>ul.sub-menu:before {
	display: none;
	content: none
}
.penci-megamenu[data-number="1"] {
	min-height: 279px
}
.penci-megamenu[data-number="2"] {
	min-height: 558px
}
.penci-megamenu[data-number="3"] {
	min-height: 837px
}
.penci-megamenu[data-style="3"] {
	min-height: 190px
}
.penci-megamenu[data-style="3"][data-number="2"] {
	min-height: 380px
}
.penci-megamenu[data-style="3"][data-number="3"] {
	min-height: 570px
}
.penci-megamenu[data-style="4"] {
	min-height: 130px
}
.penci-megamenu[data-style="4"][data-number="2"] {
	min-height: 260px
}
.penci-megamenu[data-style="4"][data-number="3"] {
	min-height: 390px
}
.penci-megamenu.loaded {
	min-height: unset
}
.penci-mega-default-width {
	min-width: var(--pcctain)
}
.penci-mega-default-width .container {
	width: 100%
}
.navigation.menu-item-padding .menu>ul>li,
.navigation.menu-item-padding ul.menu>li {
	margin: 0
}
.navigation.menu-item-padding .menu>ul>li>a,
.navigation.menu-item-padding ul.menu>li>a {
	padding: 0 15px
}
.navigation.menu-item-padding .menu>li.current-menu-ancestor>a,
.navigation.menu-item-padding .menu>li.current-menu-item>a,
.navigation.menu-item-padding .menu>li.current_page_item>a,
.navigation.menu-item-padding .menu>li:hover>a,
.navigation.menu-item-padding .menu>li>a:hover {
	background-color: #ececec
}
.navigation.menu-item-padding .menu>ul>li>a:before,
.navigation.menu-item-padding ul.menu>li>a:before {
	content: none;
	display: none
}
@media only screen and (min-width:961px) {
	.is-sticky .navigation.menu-item-padding {
		height: 58px;
		border: none !important
	}
	.navigation-sticky-wrapper:not(.is-sticky) .menu .children,
	.navigation-sticky-wrapper:not(.is-sticky) .menu .sub-menu {
		margin-top: -1px
	}
}
@-moz-document url-prefix() {
	.navigation.menu-style-2 ul.menu>li.megamenu>ul.sub-menu:before {
		top: 0
	}
}
.penci-header-image-logo,
.penci-header-text-logo {
	--pchb-logo-title-size: 40px;
	--pchb-logo-title-font: var(--pchead-font);
	--pchb-logo-title-fw: "400";
	--pchb-logo-title-fs: "normal";
	--pchb-logo-slogan-size: 14px;
	--pchb-logo-slogan-font: "inherit";
	--pchb-logo-slogan-fw: "400";
	--pchb-logo-slogan-fs: "normal";
	--pchb-logo-title-color: "inherit";
	--pchb-logo-slogan-color: var(--pctext-cl)
}
.penci-header-text-logo .site-name {
	font-size: var(--pchb-logo-title-size);
	font-family: var(--pchb-logo-title-font);
	font-weight: var(--pchb-logo-title-fw);
	font-style: var(--pchb-logo-title-fs);
	color: var(--pchb-logo-title-color);
	line-height: 1
}
.penci-header-image-logo .site-slogan,
.penci-header-text-logo .site-slogan {
	font-size: var(--pchb-logo-slogan-size);
	font-family: var(--pchb-logo-slogan-font);
	font-weight: var(--pchb-logo-slogan-fw);
	font-style: var(--pchb-logo-slogan-fs);
	color: var(--pchb-logo-slogan-color);
	line-height: 1.3;
	margin-top: 12px
}
.penci_navbar_mobile .penci-header-text-logo {
	--pchb-m-logo-title-size: 20px;
	--pchb-m-logo-title-m-size: 20px;
	--pchb-m-logo-title-font: var(--pchead-font);
	--pchb-m-logo-title-fw: "400";
	--pchb-m-logo-title-fs: "normal";
	--pchb-m-logo-slogan-size: 14px;
	--pchb-m-logo-slogan-m-size: 14px;
	--pchb-m-logo-slogan-font: "inherit";
	--pchb-m-logo-slogan-fw: "400";
	--pchb-m-logo-slogan-fs: "normal";
	--pchb-m-logo-title-color: "inherit";
	--pchb-m-logo-slogan-color: "inherit"
}
.penci_navbar_mobile .penci-header-text-logo .site-name {
	font-size: var(--pchb-m-logo-title-size);
	font-family: var(--pchb-m-logo-title-font);
	font-weight: var(--pchb-m-logo-title-fw);
	font-style: var(--pchb-m-logo-title-fs);
	color: var(--pchb-m-logo-title-color);
	line-height: 1
}
.penci_navbar_mobile .site-slogan {
	font-size: var(--pchb-m-logo-slogan-size);
	font-family: var(--pchb-m-logo-slogan-font);
	font-weight: var(--pchb-m-logo-slogan-fw);
	font-style: var(--pchb-m-logo-slogan-fs);
	color: var(--pchb-m-logo-slogan-color);
	line-height: 1.3;
	margin-top: 12px
}
.pc-logo-sticky {
	--pchb-logo-s-title-size: 40px;
	--pchb-logo-s-title-font: var(--pchead-font);
	--pchb-logo-s-title-fw: "400";
	--pchb-logo-s-title-fs: "normal";
	--pchb-logo-s-slogan-size: 14px;
	--pchb-logo-s-slogan-font: "inherit";
	--pchb-logo-s-slogan-fw: "400";
	--pchb-logo-s-slogan-fs: "normal";
	--pchb-logo-s-title-color: "inherit";
	--pchb-logo-s-slogan-color: "inherit"
}
.pc-logo-sticky.penci-header-text-logo .site-name {
	font-size: var(--pchb-logo-s-title-size);
	font-family: var(--pchb-logo-s-title-font);
	font-weight: var(--pchb-logo-s-title-fw);
	font-style: var(--pchb-logo-s-title-fs);
	color: var(--pchb-logo-s-title-color);
	line-height: 1
}
.pc-logo-sticky.penci-header-image-logo .site-slogan,
.pc-logo-sticky.penci-header-text-logo .site-slogan {
	font-size: var(--pchb-logo-s-slogan-size);
	font-family: var(--pchb-logo-s-slogan-font);
	font-weight: var(--pchb-logo-s-slogan-fw);
	font-style: var(--pchb-logo-s-slogan-fs);
	color: var(--pchb-logo-s-slogan-color);
	line-height: 1.3;
	margin-top: 12px
}
.pb-logo-sidebar-mobile {
	--pchb-logo-sm-title-size: 40px;
	--pchb-logo-sm-title-font: var(--pchead-font);
	--pchb-logo-sm-title-fw: "400";
	--pchb-logo-sm-title-fs: "normal";
	--pchb-logo-sm-slogan-size: 14px;
	--pchb-logo-sm-slogan-font: "inherit";
	--pchb-logo-sm-slogan-fw: "400";
	--pchb-logo-sm-slogan-fs: "normal";
	--pchb-logo-sm-title-color: "inherit";
	--pchb-logo-sm-slogan-color: "inherit"
}
.pb-logo-sidebar-mobile.penci-header-text-logo .site-name {
	font-size: var(--pchb-logo-sm-title-size);
	font-family: var(--pchb-logo-sm-title-font);
	font-weight: var(--pchb-logo-sm-title-fw);
	font-style: var(--pchb-logo-sm-title-fs);
	color: var(--pchb-logo-sm-title-color);
	line-height: 1
}
.pb-logo-sidebar-mobile.penci-header-image-logo .site-slogan,
.pb-logo-sidebar-mobile.penci-header-text-logo .site-slogan {
	font-size: var(--pchb-logo-sm-slogan-size);
	font-family: var(--pchb-logo-sm-slogan-font);
	font-weight: var(--pchb-logo-sm-slogan-fw);
	font-style: var(--pchb-logo-sm-slogan-fs);
	color: var(--pchb-logo-sm-slogan-color);
	line-height: 1.3;
	margin-top: 12px
}
.penci-builder-element.penci-data-time-format {
	white-space: nowrap
}
.penci-builder-element.header-social a i {
	width: var(--pchb-socialw);
	height: var(--pchb-socialw);
	line-height: calc(var(--pchb-socialw) - 2px);
	background: 0 0;
	border: 1px solid #e0e0e0;
	margin: 0;
	display: inline-block;
	text-align: center;
	color: var(--pctext-cl)
}
.penci-builder-element.header-social.mobile-social a i {
	width: var(--pchb-m-socialw);
	height: var(--pchb-m-socialw);
	line-height: calc(var(--pchb-m-socialw) - 2px)
}
.penci-builder-element.header-social a:hover i {
	color: var(--pcaccent-cl)
}
.penci-builder-element.header-social a {
	margin-right: 10px
}
body:not(.rtl) .penci-builder-element.header-social a:last-child {
	margin-right: 0 !important
}
.penci-builder-element.header-social .penci-social-colored a {
	transition: opacity .3s
}
.penci-builder-element.header-social .penci-social-colored a:hover {
	opacity: .85
}
.penci-builder-element.header-social .penci-social-colored a i {
	border: none !important;
	color: #fff !important;
	line-height: var(--pchb-socialw)
}
.penci-builder-element.header-social.mobile-social .penci-social-colored a i {
	border: none !important;
	color: #fff !important;
	line-height: var(--pchb-m-socialw)
}
.penci-builder-element.header-social .penci-social-simple a i {
	line-height: 1;
	width: auto !important;
	height: auto !important;
	border-color: transparent !important;
	background-color: transparent !important
}
.penci-builder-element.header-social .penci-social-bordered a i {
	background-color: transparent
}
.penci-builder-element.header-social {
	margin-top: 0
}
.penci-vertical-line {
	display: inline-block;
	width: 1px;
	height: 20px;
	background-color: var(--pcborder-cl)
}
.penci-builder-element.header-social .penci-social-circle a i {
	border-radius: 50%
}
.pc-builder-element.pc-main-menu {
	--pchb-main-menu-font: var(--pchead-font);
	--pchb-main-menu-fs: 12px;
	--pchb-main-menu-lh: 58px;
	--pchb-main-menu-fs_l2:var(--pchb-main-menu-fs);
	--pchb-main-menu-cl: #313131;
	--pchb-main-menu-fw: bold;
	--pchb-main-menu-tt: uppercase;
	--pchb-main-menu-mg: 30px;
	--pchb-main-menu-mgi: 0;
	--pchb-mainm-linect: ""
}
.pc-builder-element.pc-main-menu .navigation .menu ul.sub-menu li a,
.pc-builder-element.pc-main-menu .navigation .menu>li>a {
	font-family: var(--pchb-main-menu-font);
	font-size: var(--pchb-main-menu-fs);
	font-weight: var(--pchb-main-menu-fw);
	color: var(--pchb-main-menu-cl);
	letter-spacing: 0;
	text-transform: var(--pchb-main-menu-tt)
}
.pc-builder-element.pc-main-menu .navigation .menu li.current-menu-item>a,
.pc-builder-element.pc-main-menu .navigation .menu li>a:hover,
.pc-builder-element.pc-main-menu .navigation .menu>li.current-menu-ancestor>a,
.pc-builder-element.pc-main-menu .navigation .menu>li.current-menu-item>a,
.pc-builder-element.pc-main-menu .navigation .menu>li.current_page_item>a {
	color: var(--pcaccent-cl)
}
.pc-builder-element.pc-main-menu .navigation ul.menu ul.sub-menu li a {
	font-size: var(--pchb-main-menu-fs_l2)
}
.pc-builder-element.pc-main-menu .navigation .menu>ul>li,
.pc-builder-element.pc-main-menu .navigation ul.menu>li {
	margin-right: var(--pchb-main-menu-mg)
}
.pc-builder-element.pc-main-menu .navigation ul.menu>li:last-child {
	margin-right: 0
}
.pc-builder-element.pc-main-menu .navigation .menu>li>a {
	line-height: var(--pchb-main-menu-lh)
}
.pc-builder-element.pc-main-menu .navigation.menu-item-padding .menu>ul>li>a,
.pc-builder-element.pc-main-menu .navigation.menu-item-padding ul.menu>li>a {
	padding-left: calc(var(--pchb-main-menu-mg)/ 2);
	padding-right: calc(var(--pchb-main-menu-mg)/ 2)
}
.pc-builder-element.pc-main-menu .navigation.menu-item-padding .menu>ul>li:not(:last-child),
.pc-builder-element.pc-main-menu .navigation.menu-item-padding ul.menu>li:not(:last-child) {
	margin-right: var(--pchb-main-menu-mgi)
}
.pc-builder-element.pc-second-menu {
	--pchb-second-menu-font: var(--pchead-font);
	--pchb-second-menu-fs: 12px;
	--pchb-second-menu-lh: 58px;
	--pchb-second-menu-fs_l2:var(--pchb-second-menu-fs);
	--pchb-second-menu-cl: #313131;
	--pchb-second-menu-fw: bold;
	--pchb-second-menu-tt: uppercase;
	--pchb-second-menu-mg: 30px;
	--pchb-second-menu-mgi: 0;
	--pchb-secondm-linect: ""
}
.pc-builder-element.pc-second-menu .navigation .menu ul.sub-menu li a,
.pc-builder-element.pc-second-menu .navigation .menu>li>a {
	font-family: var(--pchb-second-menu-font);
	font-size: var(--pchb-second-menu-fs);
	font-weight: var(--pchb-second-menu-fw);
	color: var(--pchb-second-menu-cl);
	text-transform: var(--pchb-second-menu-tt)
}
.pc-builder-element.pc-second-menu .navigation .menu li.current-menu-item>a,
.pc-builder-element.pc-second-menu .navigation .menu li>a:hover,
.pc-builder-element.pc-second-menu .navigation .menu>li.current-menu-ancestor>a,
.pc-builder-element.pc-second-menu .navigation .menu>li.current-menu-item>a,
.pc-builder-element.pc-second-menu .navigation .menu>li.current_page_item>a {
	color: var(--pcaccent-cl)
}
.pc-builder-element.pc-second-menu .navigation ul.menu ul.sub-menu li a {
	font-size: var(--pchb-second-menu-fs_l2)
}
.pc-builder-element.pc-second-menu .navigation .menu>ul>li,
.pc-builder-element.pc-second-menu .navigation ul.menu>li {
	margin-right: var(--pchb-second-menu-mg)
}
.pc-builder-element.pc-second-menu .navigation .menu>ul>li:last-child,
.pc-builder-element.pc-second-menu .navigation ul.menu>li:last-child {
	margin-right: 0
}
.pc-builder-element.pc-second-menu .navigation .menu>li>a {
	line-height: var(--pchb-second-menu-lh)
}
.pc-builder-element.pc-second-menu .navigation.menu-item-padding .menu>ul>li>a,
.pc-builder-element.pc-second-menu .navigation.menu-item-padding ul.menu>li>a {
	padding-left: calc(var(--pchb-second-menu-mg)/ 2);
	padding-right: calc(var(--pchb-second-menu-mg)/ 2)
}
.pc-builder-element.pc-second-menu .navigation.menu-item-padding .menu>ul>li:not(:last-child),
.pc-builder-element.pc-second-menu .navigation.menu-item-padding ul.menu>li:not(:last-child) {
	margin-right: var(--pchb-second-menu-mgi)
}
.pc-builder-element.pc-third-menu {
	--pchb-third-menu-font: var(--pchead-font);
	--pchb-third-menu-fs: 12px;
	--pchb-third-menu-lh: 58px;
	--pchb-third-menu-fs_l2:var(--pchb-third-menu-fs);
	--pchb-third-menu-cl: #313131;
	--pchb-third-menu-fw: bold;
	--pchb-third-menu-tt: uppercase;
	--pchb-third-menu-mg: 30px;
	--pchb-third-menu-mgi: 0;
	--pchb-thirdm-linect: ""
}
.pc-builder-element.pc-third-menu .navigation .menu ul.sub-menu li a,
.pc-builder-element.pc-third-menu .navigation .menu>li>a {
	font-family: var(--pchb-third-menu-font);
	font-size: var(--pchb-third-menu-fs);
	font-weight: var(--pchb-third-menu-fw);
	color: var(--pchb-third-menu-cl);
	text-transform: var(--pchb-third-menu-tt)
}
.pc-builder-element.pc-third-menu .navigation .menu li.current-menu-item>a,
.pc-builder-element.pc-third-menu .navigation .menu li>a:hover,
.pc-builder-element.pc-third-menu .navigation .menu>li.current-menu-ancestor>a,
.pc-builder-element.pc-third-menu .navigation .menu>li.current-menu-item>a,
.pc-builder-element.pc-third-menu .navigation .menu>li.current_page_item>a {
	color: var(--pcaccent-cl)
}
.pc-builder-element.pc-third-menu .navigation ul.menu ul.sub-menu li a {
	font-size: var(--pchb-third-menu-fs_l2)
}
.pc-builder-element.pc-third-menu .navigation .menu>ul>li,
.pc-builder-element.pc-third-menu .navigation ul.menu>li {
	margin-right: var(--pchb-third-menu-mg)
}
.pc-builder-element.pc-third-menu .navigation .menu>ul>li:last-child,
.pc-builder-element.pc-third-menu .navigation ul.menu>li:last-child {
	margin-right: 0
}
.pc-builder-element.pc-third-menu .navigation .menu>li>a {
	line-height: var(--pchb-third-menu-lh)
}
.pc-builder-element.pc-builder-menu .pcremove-lineh ul.menu>li>a:before {
	content: none
}
.pc-builder-element.pc-third-menu .navigation.menu-item-padding .menu>ul>li>a,
.pc-builder-element.pc-third-menu .navigation.menu-item-padding ul.menu>li>a {
	padding-left: calc(var(--pchb-third-menu-mg)/ 2);
	padding-right: calc(var(--pchb-third-menu-mg)/ 2)
}
.pc-builder-element.pc-third-menu .navigation.menu-item-padding .menu>ul>li:not(:last-child),
.pc-builder-element.pc-third-menu .navigation.menu-item-padding ul.menu>li:not(:last-child) {
	margin-right: var(--pchb-third-menu-mgi)
}
.penci-builder-element.penci-topbar-trending .penci-owl-carousel .swiper-slide {
	background-color: transparent
}
.penci-builder-element.penci-topbar-trending a.penci-topbar-post-title {
	color: var(--pcheading-cl)
}
@keyframes Penci-FadeDown {
	from {
		transform: translate3d(0, -100%, 0)
	}
	to {
		transform: none
	}
}
@keyframes Penci-FadeUp {
	from {
		transform: none
	}
	to {
		transform: translate3d(0, -100%, 0)
	}
}
.penci_header.penci_builder_sticky_header_desktop {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	z-index: 9998;
	opacity: 0;
	visibility: hidden;
	transition: visibility .1s ease, opacity .1s ease, transform .3s ease;
	transform: translate3d(0, -100%, 0);
	background-color: #fff;
	border-style: solid;
	border-width: 0
}
.penci_header.main-builder-header {
	border-width: 0
}
body.admin-bar .penci_header.penci_builder_sticky_header_desktop {
	top: 32px
}
.penci_header.penci_builder_sticky_header_desktop.sticky-apply {
	opacity: 1;
	visibility: visible;
	transform: translate3d(0, 0, 0)
}
.penci_header.main-builder-header.ns-apply .navigation .menu .penci-dropdown,
.penci_header.main-builder-header.ns-apply .navigation .menu .sub-menu {
	display: none
}
.penci_navbar_mobile {
	background: var(--pcbg-cl)
}
.penci_navbar_mobile.mobile-overlap {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	z-index: 9996;
	background: 0 0
}
body.admin-bar .penci_navbar_mobile.mobile-overlap {
	top: 46px
}
body.admin-bar .penci_navbar_mobile.mobile-overlap.mobile-sticky {
	top: 0
}
.penci_header.penci_builder_sticky_header_desktop.sticky-apply.hide-scroll-down.scrolldown,
.penci_navbar_mobile.mobile-sticky.hide-scroll-down,
.penci_navbar_mobile.mobile-sticky.hide-scroll-down.scrolldown {
	opacity: 0;
	visibility: hidden;
	transform: translate3d(0, -100%, 0)
}
.penci_header.penci_builder_sticky_header_desktop.sticky-apply.hide-scroll-down.scrollup,
.penci_navbar_mobile.mobile-sticky.hide-scroll-down.scrollup {
	opacity: 1;
	visibility: visible;
	display: block;
	transform: translate3d(0, 0, 0)
}
.penci-header-image-logo img,
.penci_builder_sticky_header_desktop .penci-header-image-logo img {
	width: auto;
	height: auto
}
.pc-builder-element .search-click,
.pc-builder-element.penci-top-search .search-click {
	height: unset;
	line-height: unset;
	display: inline-block
}
.pchd-elcart,
.pc-elehdbd-search {
	display: flex;
	min-height: 1px;
}
.pchd-elcompare.top-search-classes,
.pchd-elwishlist.top-search-classes,
.pchd-elcart .top-search-classes,
.pc-elehdbd-search.top-search-classes {
	float: none;
}
.pchd-elcart .top-search-classes,
.pchd-elcart .top-search-classes a.cart-contents,
.pchd-elwishlist.top-search-classes > a,
.pchd-elcompare.top-search-classes > a {
	width: 58px;
}
.pchd-elcart a.cart-contents, 
.pchd-elcart.top-search-classes > a {
	line-height: unset;
	height: unset;
}
@media only screen and (min-width:961px) {
	.penci_navbar_mobile,
	.penci_navbar_mobile.mobile-sticky,
	.penci_navbar_mobile.mobile-sticky.hide-scroll-down.scrollup {
		display: none
	}
}
@media only screen and (max-width:960px) {
	.penci_builder_sticky_header_desktop,
	.penci_header.penci-header-builder.main-builder-header,
	.penci_header.penci_builder_sticky_header_desktop,
	.penci_header.penci_builder_sticky_header_desktop.sticky-apply {
		display: none !important
	}
}
.penci_header.penci-header-builder.penci_header_overlap {
	position: absolute;
	top: 0;
	right: 0;
	left: 0;
	z-index: 9996
}
@media only screen and (max-width:479px) {
	.penci_navbar_mobile .container {
		padding-left: 10px;
		padding-right: 10px
	}
}
.penci_navbar_mobile .navigation {
	border: 0
}
.penci_navbar_mobile .navigation .button-menu-mobile {
	display: block
}
.penci-header-builder.shadow-enable,
.penci_builder_sticky_header_desktop.shadow-enable,
.penci_navbar_mobile.mobile-sticky.shadow-enable {
	box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-webkit-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	-moz-box-shadow: 0 1px 5px rgba(190, 190, 190, .46);
	border-color: transparent;
	border-width: 0
}
.penci-builder.penci-builder-button,
[class^=pc-button-define-style-] {
	display: inline-block;
	transition: .3s all ease-in-out;
	border-style: solid;
	border-width: 0
}
.pc-button-define-style-1,
.penci-builder.penci-builder-button.button-define-style-1,
.top-search-classes>.pc-button-define-style-1 {
	padding: 10px;
	border: 2px solid var(--pcaccent-cl);
	color: var(--pcaccent-cl)
}
.penci-builder.penci-builder-button.button-define-style-1 {
	padding: 5px 15px
}
.penci-top-search.pc-builder-element {
	width: auto
}
.penci-top-search.pc-builder-element .penci-search-form form.penci-ajax-search {
	display: block
}
.pc-button-define-style-2,
.penci-builder.penci-builder-button.button-define-style-2,
.top-search-classes>.pc-button-define-style-2 {
	color: var(--pcaccent-cl);
	border-bottom: 1px solid var(--pcaccent-cl);
	padding: 0 0 4px;
	padding-top: 0 !important;
	background-color: transparent !important
}
.pc-button-define-style-3,
.penci-builder.penci-builder-button.button-define-style-3,
.top-search-classes>.pc-button-define-style-3 {
	padding: 10px;
	background-color: #f2f2f2;
	color: var(--pcheading-cl);
	border-bottom: 2px solid #dedede
}
.penci-builder.penci-builder-button.button-define-style-3 {
	padding: 7px 15px
}
.pc-button-define-style-4,
.penci-builder.penci-builder-button.button-define-style-4,
.top-search-classes>.pc-button-define-style-4 {
	padding: 10px;
	background-color: #f2f2f2;
	color: var(--pcheading-cl)
}
.penci-builder.penci-builder-button.button-define-style-4 {
	padding: 7px 12px
}
.penci-builder.penci-builder-button.button-shape-rectangle {
	border-radius: 0
}
.penci-builder.penci-builder-button.button-shape-circle {
	border-radius: 400px
}
.penci-builder.penci-builder-button.button-shape-round {
	border-radius: 10px
}
.pb-header-builder.cart-icon:not(.pc-button-define-customize) .top-search-classes.shoping-cart-icon {
	margin-right: 0;
	margin-left: 0
}
.top-search-classes.penci-builder-element,
.top-search-classes.penci-builder-elements {
	width: auto
}
.penci_navbar_mobile .navigation.mobile-menu {
	width: auto;
	float: none
}
.penci-builder-mobile-sidebar-nav {
	position: fixed;
	top: 0;
	height: 100%;
	z-index: 100001;
	width: 330px;
	overflow-y: auto;
	padding: 30px 20px 20px;
	background: #fff;
	left: 0;
	transition: all .5s;
	-webkit-transition: all .5s;
	-moz-transition: all .5s;
	transform: translateX(-330px);
	-webkit-transform: translateX(-330px);
	-moz-transform: translateX(-330px)
}
.open-mobile-builder-sidebar-nav .penci-builder-mobile-sidebar-nav {
	left: 330px
}
.penci-builder-mobile-sidebar-nav.mpos-right {
	left: auto;
	right: 0;
	transform: translateX(330px);
	-webkit-transform: translateX(330px);
	-moz-transform: translateX(330px)
}
.open-mobile-builder-sidebar-nav .penci-builder-mobile-sidebar-nav.mpos-right {
	right: 330px;
	left: auto
}
.close-mobile-menu-builder {
	position: fixed;
	visibility: hidden;
	opacity: 0;
	text-decoration: none;
	top: 0;
	left: 0;
	font-size: 1.4em;
	color: #313131;
	padding: 10px;
	height: 100%;
	background: rgba(0, 0, 0, .8);
	right: 0;
	z-index: 100000;
	cursor: pointer;
	transition: all .5s;
	-webkit-transition: all .5s;
	-moz-transition: all .5s
}
.close-mobile-menu-builder.mpos-right {
	left: auto;
	right: 0
}
.close-mobile-menu-builder i {
	display: inline-block;
	width: 24px;
	height: 24px;
	background-color: #fff;
	line-height: 24px;
	text-align: center;
	border-radius: 12px;
	font-size: 14px
}
.open-mobile-builder-sidebar-nav .close-mobile-menu-builder {
	left: 330px;
	opacity: 1;
	visibility: visible
}
.close-mobile-menu-builder.mpos-right {
	right: 0;
	left: 0;
	text-align: right
}
.open-mobile-builder-sidebar-nav .close-mobile-menu-builder.mpos-right {
	right: 330px;
	left: 0
}
.pc-builder-menu.pc-dropdown-menu {
	--pchb-dd-fn: var(--pchead-font);
	--pchb-dd-fw: var(--pchead-wei);
	--pchb-dd-lv1:13px;
	--pchb-dd-lv2:13px;
	--pchb-dd-tt: uppercase
}
.pc-builder-menu.pc-dropdown-menu .menu li a {
	font-family: var(--pchb-dd-fn);
	font-weight: var(--pchb-dd-fw);
	font-size: var(--pchb-dd-lv1);
	text-transform: var(--pchb-dd-tt)
}
.pc-builder-menu.pc-dropdown-menu .menu li li a {
	font-size: var(--pchb-dd-lv2)
}
.penci_navbar_mobile.mobile-sticky {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	z-index: 9999;
	transition: visibility .1s ease, opacity .1s ease, transform .3s ease;
	background-color: var(--pcbg-cl)
}
.penci_navbar_mobile.mobile-sticky .penci_container {
	display: none;
	transition: .3s all ease-in-out
}
.penci_navbar_mobile.mobile-sticky .penci_container.sticky-enable {
	display: block;
	opacity: 1
}
.pc-header-element.pc-login-register {
	position: relative
}
.widget .pc-widget-searchform button[type=submit] {
	width: auto
}
.widget .pc-widget-searchform.search-style-default button[type=submit] {
	display: none
}
.penci-builder-element.pc-search-form {
	max-width: 300px;
	width: 100%
}
.pcwg-widget.penci-builder-element.pc-search-form,
.penci-builder-element.pc-search-form-sidebar {
	max-width: 100%;
	width: 100%
}
.pc-search-form.search-style-icon-button,
.pc-search-form.search-style-text-button {
	position: relative
}
.pc-search-form.search-style-icon-button .search-input,
.pc-search-form.search-style-text-button .search-input {
	line-height: 36px;
	padding-top: 0;
	padding-bottom: 0;
	padding-right: 20px;
	border-right-width: 0
}
.penci-builder-element.pc-search-form-desktop {
	--pcs-d-txt-cl: var(--pctext-cl)
}
.penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input {
	color: var(--pcs-d-txt-cl)
}
.penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input::placeholder {
	color: var(--pcs-d-txt-cl)
}
.penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input:-ms-input-placeholder {
	color: var(--pcs-d-txt-cl)
}
.penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input::-ms-input-placeholder {
	color: var(--pcs-d-txt-cl)
}
.penci-builder-element.pc-search-form-sidebar {
	--pcs-s-txt-cl: var(--pctext-cl)
}
.penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input {
	color: var(--pcs-s-txt-cl)
}
.penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input::placeholder {
	color: var(--pcs-s-txt-cl)
}
.penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input:-ms-input-placeholder {
	color: var(--pcs-s-txt-cl)
}
.penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input::-ms-input-placeholder {
	color: var(--pcs-s-txt-cl)
}
.pc-search-form.search-style-icon-button .searchsubmit,
.pc-search-form.search-style-text-button .searchsubmit {
	display: block;
	height: 100%;
	padding: 0 15px;
	background-color: var(--pcaccent-cl);
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	color: #fff;
	border: 0;
	transition: .3s all ease-in-out;
	position: absolute;
	top: 0;
	right: 0;
	z-index: 9;
	cursor: pointer
}
.pc-wrapbuilder-header .pc-search-form.search-style-text-button .searchsubmit {
	text-transform: uppercase
}
body.rtl .pc-search-form.search-style-icon-button .searchsubmit,
body.rtl .pc-search-form.search-style-text-button .searchsubmit {
	right: auto;
	left: 0
}
.pc-search-form.search-style-text-button .search-input {
	padding-right: 100px
}
body.rtl .pc-search-form.search-style-text-button .search-input {
	padding-right: 20px;
	padding-left: 100px;
	border-right-width: 1px;
	border-left-width: 0
}
.pc-search-form.search-style-icon-button .search-input {
	padding-right: 66px
}
body.rtl .pc-search-form.search-style-text-button .search-input {
	padding-left: 66px;
	padding-right: 20px;
	border-right-width: 1px;
	border-left-width: 0
}
.pc-search-form.search-style-icon-button .searchsubmit {
	font-size: 0;
	line-height: 0
}
.pc-search-form.search-style-icon-button .searchsubmit:before {
	font-size: 16px;
	line-height: 38px;
	content: "\f108";
	font-family: penciicon, serif;
	font-style: normal;
	font-weight: 400;
	font-variant: normal;
	text-transform: none;
	-moz-osx-font-smoothing: grayscale
}
.pc-search-form.search-style-icon-button .penciicon-magnifiying-glass,
.pc-search-form.search-style-text-button .penciicon-magnifiying-glass {
	display: none
}
.penci-header-block {
	width: 100%
}
.pc-header-element.penci-topbar-social a,
.pc-header-element.penci-topbar-social-mobile a {
	color: inherit
}
.pc-header-element.penci-topbar-social .pclogin-item>a,
.pc-header-element.penci-topbar-social-mobile .pclogin-item>a {
	line-height: unset;
	display: inline-flex;
	align-items: center;
	justify-content: center
}
.pc-header-element.penci-topbar-social .pclogin-item>a img,
.pc-header-element.penci-topbar-social-mobile .pclogin-item>a img {
	top: auto
}
.pc-header-element .pctopbar-login-btn .pclogin-sub li a {
	color: #fff
}
.pc-header-element .pctopbar-login-btn .pclogin-sub {
	top: 100%
}
.pc-header-element .pctopbar-login-btn .pclogin-sub li a:hover {
	color: var(--pcaccent-cl)
}
.penci_nav_col {
	display: flex;
	align-items: center;
	flex-direction: row;
	padding-left: 10px;
	padding-right: 10px
}
.penci_nav_col.penci_nav_flexcolumn {
	flex-direction: column;
	align-items: initial;
}
.penci_nav_col.penci_nav_flexcolumn.penci_nav_alignleft {
	align-items: flex-start;
}
.penci_nav_col.penci_nav_flexcolumn.penci_nav_aligncenter {
	align-items: center;
}
.penci_nav_col.penci_nav_flexcolumn.penci_nav_alignright {
	align-items: flex-end;
}
.penci_nav_col.penci_content_columns {
	flex-direction: column
}
.penci_nav_col>:not(:first-child) {
	margin-left: 10px
}
.penci-header-builder .pcheader-icon>a,
.penci-header-builder .penci-menuhbg-toggle,
.penci-header-builder .top-search-classes a.cart-contents,
.penci-header-builder .top-search-classes>a {
	height: auto;
	line-height: unset
}
.header-search-style-showup .penci-header-builder .show-search,
.header-search-style-showup .penci_navbar_mobile .show-search {
	top: calc(100% + 10px)
}
.header-search-style-showup .penci_nav_left .show-search {
	left: 0;
	right: auto
}
.header-search-style-showup .penci_nav_left .show-search:before {
	left: 5px;
	right: auto
}
.container.container-custom {
	margin-left: auto;
	margin-right: auto
}
.admin-bar .penci-builder-mobile-sidebar-nav.penci-menu-hbg {
	padding-top: 30px
}
.penci-builder-item-wrap>div:not(:last-child) {
	margin-bottom: 20px
}
.penci-header-builder.pchb-boxed-layout.container-1400 .container,
.penci-header-builder.pchb-boxed-layout.container-custom .container,
.penci-header-builder.pchb-boxed-layout.container-fullwidth .container,
.penci-header-builder.pchb-boxed-layout.container-normal .container {
	max-width: 100%
}
.penci-header-builder.pchb-boxed-layout.container-1400,
.penci-header-builder.pchb-boxed-layout.container-custom,
.penci-header-builder.pchb-boxed-layout.container-fullwidth,
.penci-header-builder.pchb-boxed-layout.container-normal {
	width: 100%;
	padding-left: 0;
	padding-right: 0
}
.penci-header-builder.pchb-boxed-layout.container-normal {
	max-width: var(--pcctain)
}
.penci-header-builder.pchb-boxed-layout.container-fullwidth {
	max-width: 100%
}
.penci-header-builder.pchb-boxed-layout.container-1400 {
	max-width: var(--pcctain2)
}
.pc-builder-element .pc-logo img,
.pc-builder-element.pc-logo img {
	max-height: 60px
}
.penci-disable-uppercase {
	text-transform: none !important
}
.penci-enable-uppercase {
	text-transform: uppercase !important
}
.penci-header-builder .pc-builder-element.penci-menuhbg-wapper {
	width: auto
}
.penci-elhb-hbg.penci-menuhbg-wapper {
	width: auto;
	float: none;
	margin: 0;
}
.penci-menuhbg-toggle.builder {
	--pcbd-menuhbg-size: 18px;
	height: auto
}
.penci-menuhbg-toggle.builder {
	width: var(--pcbd-menuhbg-size)
}
.penci-menuhbg-toggle.builder .penci-menuhbg-inner {
	height: var(--pcbd-menuhbg-size)
}
.penci-menuhbg-toggle.builder .penci-lines,
.penci-menuhbg-wapper {
	width: var(--pcbd-menuhbg-size)
}
.penci-menuhbg-toggle.builder .lines-button {
	top: calc((var(--pcbd-menuhbg-size) - 2px)/ 2)
}
.penci-menuhbg-toggle.builder .penci-lines:before {
	top: calc(var(--pcbd-menuhbg-size)/ 2 - 4px)
}
.penci-menuhbg-toggle.builder .penci-lines:after {
	top: calc((var(--pcbd-menuhbg-size)/ 2 - 4px) * -1)
}
.penci-menuhbg-toggle.builder:hover .lines-button:after,
.penci-menuhbg-toggle.builder:hover .penci-lines:after,
.penci-menuhbg-toggle.builder:hover .penci-lines:before {
	transform: translateX(calc(var(--pcbd-menuhbg-size) + 10px))
}
.penci-menuhbg-toggle.builder .lines-button.penci-hover-effect {
	left: calc((var(--pcbd-menuhbg-size) + 10px) * -1)
}
.pc-wrapbuilder-header {
	--pchd-sinput-txt: var(--pctext-cl)
}
.header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input {
	color: var(--pchd-sinput-txt)
}
.header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input::placeholder {
	color: var(--pchd-sinput-txt);
	opacity: 1
}
.header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input:-ms-input-placeholder {
	color: var(--pchd-sinput-txt)
}
.header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input::-ms-input-placeholder {
	color: var(--pchd-sinput-txt)
}
#penci-featured-video-bg {
	height: 600px
}
.overlay-video-click,
.penci-video-bg-overlay,
.penci-video-overlay-background {
	position: absolute;
	z-index: 5;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background-repeat: no-repeat;
	background-size: cover;
	background-position: center center;
	display: none
}
.overlay-video-click {
	display: block;
	z-index: 20
}
.penci-placeholder-videobg,
.penci-video-bg-overlay {
	z-index: 2;
	display: block
}
.penci-video-overlay {
	position: absolute;
	top: 50%;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	-moz-transform: translateY(-50%);
	text-align: center;
	left: 20px;
	right: 20px;
	z-index: 10
}
.penci-video-custom-img,
h2.penci-heading-video,
p.penci-sub-heading-video {
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: 1s;
	-moz-animation-duration: 1s;
	-ms-animation-duration: 1s;
	-o-animation-duration: 1s;
	animation-duration: 1s;
	-webkit-animation-delay: 1.5s;
	-moz-animation-delay: 1.5s;
	-o-animation-delay: 1.5s;
	animation-delay: 1.5s
}
.penci-video-custom-img {
	margin: 0 0 24px 0
}
.penci-video-custom-img.no-margin-bottom {
	margin: 0
}
h2.penci-heading-video {
	color: #fff;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 30px;
	line-height: 1.2em;
	text-transform: uppercase;
	margin: 0;
	-webkit-animation-delay: 1.8s;
	-moz-animation-delay: 1.8s;
	-o-animation-delay: 1.8s;
	animation-delay: 1.8s
}
p.penci-sub-heading-video {
	font-size: 16px;
	line-height: 1.3em;
	margin: 15px 0 0;
	font-style: italic;
	color: #fff;
	-webkit-animation-delay: 2.1s;
	-moz-animation-delay: 2.1s;
	-o-animation-delay: 2.1s;
	animation-delay: 2.1s
}
.featured-area.loaded-animation .penci-video-custom-img,
.featured-area.loaded-animation h2.penci-heading-video,
.featured-area.loaded-animation p.penci-sub-heading-video {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp
}
.featured-area.magazine-slider {
	width: var(--pcctain);
	margin-left: auto;
	margin-right: auto
}
.penci-magazine-slider.penci-loading {
	background: #fafafa url(images/loading.gif) no-repeat center center;
	min-height: 506px
}
.featured-area.loaded-wait .penci-magazine-slider.penci-loading {
	background: 0 0;
	min-height: 0 !important
}
.penci-magazine-slider {
	margin: 0;
	padding: 0;
	position: relative
}
.penci-magazine-slider .penci-mag-item {
	display: none
}
.penci-magazine-slider ul.mag-wrap {
	list-style: none;
	margin: 0;
	display: inline-block;
	width: 100%;
	vertical-align: top;
	bottom: 0;
	left: 0
}
.penci-magazine-slider ul.mag-wrap li {
	overflow: hidden;
	display: block;
	float: left;
	position: relative;
	width: 380px;
	height: 253px
}
.penci-magazine-slider ul.mag-wrap li.mag-item-1 {
	width: 790px;
	height: 506px;
	border-right: 10px solid transparent
}
.penci-magazine-slider ul.mag-wrap li.mag-item-2 {
	border-bottom: 10px solid transparent
}
.penci-magazine-slider .mag-meta {
	position: absolute;
	padding: 20px;
	width: 100%;
	z-index: 10;
	left: 0;
	bottom: 0
}
.penci-magazine-slider .mag-item-1 .mag-meta {
	padding: 30px
}
.penci-magazine-slider .mag-cat {
	margin-bottom: 4px
}
.penci-magazine-slider .mag-cat a.penci-cat-name {
	border-color: #fff;
	color: #fff
}
.penci-magazine-slider .mag-cat a.penci-cat-name:after {
	border-color: #fff
}
.penci-magazine-slider .mag-cat a.penci-cat-name:hover {
	text-decoration: none;
	color: var(--pcaccent-cl)
}
.penci-magazine-slider .mag-meta h3 {
	line-height: 1.3
}
.penci-magazine-slider .mag-meta h3 a {
	color: #fff;
	font-size: 16px;
	text-transform: uppercase;
	letter-spacing: 0
}
.penci-magazine-slider .mag-item-1 .mag-meta h3 a {
	font-size: 24px
}
.penci-magazine-slider .mag-meta-child {
	margin-top: 6px
}
.penci-magazine-slider .mag-item-1 .mag-meta-child {
	margin-top: 7px
}
.penci-magazine-slider .mag-meta-child span {
	color: #fff;
	font-size: 12px
}
.penci-magazine-slider .mag-item-1 .mag-meta-child span {
	font-size: 14px
}
.penci-magazine-slider .mag-meta-child span:after {
	content: "";
	display: inline-block;
	margin: 0 7px 0 10px;
	width: 0;
	height: 8px;
	border-left: 1px solid #fff;
	opacity: .5
}
.penci-magazine-slider .mag-item-1 .mag-meta-child span:after {
	margin: 0 8px 0 12px;
	height: 10px
}
.penci-magazine-slider .mag-meta-child span:last-child:after {
	content: none;
	display: none
}
.penci-magazine-slider .penci-direction-nav a {
	position: absolute;
	width: 36px;
	height: 36px;
	display: inline-block;
	top: 50%;
	margin-top: -18px;
	font-size: 20px;
	cursor: pointer;
	outline: 0;
	opacity: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	text-align: center;
	line-height: 36px;
	background: #fff;
	z-index: 12;
	border-radius: 100%;
	-webkit-border-radius: 100%;
	-moz-border-radius: 100%;
	color: #313131;
	border: none
}
.penci-magazine-slider .penci-direction-nav a.penci-prev {
	left: 30px
}
.penci-magazine-slider .penci-direction-nav a.penci-next {
	right: 30px
}
.penci-magazine-slider:hover .penci-direction-nav a {
	opacity: 1
}
.penci-magazine-slider .penci-direction-nav a:hover {
	background: var(--pcaccent-cl);
	color: #fff
}
.penci-magazine-slider .penci-direction-nav a:before {
	content: none;
	display: none
}
.penci-magazine-slider .mag-overlay {
	background: #000;
	opacity: .6;
	position: absolute;
	left: 0;
	right: 0;
	width: 100%;
	height: 100%;
	z-index: 2;
	background: -moz-linear-gradient(top, transparent 0, #000 100%);
	background: -webkit-linear-gradient(top, transparent 0, #000 100%);
	background: -o-linear-gradient(top, transparent 0, #000 100%);
	background: -ms-linear-gradient(top, transparent 0, #000 100%);
	background: linear-gradient(to bottom, transparent 0, #000 100%);
	-webkit-transition: opacity .4s ease 0s;
	-moz-transition: opacity .4s ease 0s;
	-o-transition: opacity .4s ease 0s;
	transition: opacity .4s ease 0s
}
.penci-magazine-slider ul.mag-wrap .mag-content:hover .mag-overlay {
	opacity: .8
}
.penci-magazine-slider.penci-mag3-slider.penci-loading {
	min-height: 387px
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1,
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 {
	border: none
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li,
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 {
	width: 287px;
	height: auto
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content,
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content {
	height: 191px;
	position: relative
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content {
	height: 387px;
	position: relative
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 {
	width: 586px
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 {
	margin: 0 5px
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content:first-child,
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content:first-child {
	margin-bottom: 5px
}
.penci-magazine-slider ul.mag-wrap li .mag-content .mag-img,
.penci-magazine-slider.penci-mag1-slider ul.mag-wrap li .mag-content {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 1;
	width: 100%;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content h3 a {
	font-size: 14px;
	letter-spacing: 0
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content h3 {
	text-align: center
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content h3 a {
	font-size: 16px
}
.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content .mag-meta {
	padding: 10px;
	width: 100%
}
.penci-magazine-slider.penci-mag3-slider .mag-cat {
	text-align: center
}
.penci-mag2-carousel {
	overflow: hidden
}
.featured-area.magazine-slider-2 {
	height: 463px;
	overflow: hidden
}
.featured-area.magazine-slider-2.loaded-wait {
	height: auto;
	overflow: visible
}
.penci-mag2-carousel .mag2-item {
	display: block;
	float: left;
	margin: 0 1px 0 0;
	width: 700px;
	height: 463px;
	position: relative
}
.penci-mag2-carousel .penci-mag2-carousel-content>.mag2-item {
	margin-right: 1px !important
}
.penci-mag2-carousel .mag2-item.mag2-even {
	width: 346px
}
.penci-mag2-carousel .mag2-item .mag2-item {
	width: 346px;
	height: 231px;
	margin: 0;
	position: relative
}
.penci-mag2-carousel .mag2-item>.mag2-item:first-child {
	margin-bottom: 1px
}
.mag2-thumbnail,
.mag2-thumbnail .mag-img {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 1;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover
}
.mag2slider-overlay {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.mag2slider-overlay i {
	display: block;
	width: 50px;
	height: 50px;
	position: absolute;
	top: 50%;
	left: 50%;
	margin: -25px 0 0 -25px;
	border-radius: 50%;
	background: 0 0;
	text-align: center;
	font: 14px/40px FontAwesome;
	color: rgba(255, 255, 255, .9);
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	border: 2px solid rgba(255, 255, 255, .9);
	opacity: 0;
	font-size: 18px;
	z-index: 3;
	line-height: 48px
}
.mag2slider-overlay i.fa-play:before {
	margin-left: 2px
}
.mag2slider-overlay i.fa-music:before {
	margin-right: 2px
}
.penci-mag2-carousel .mag2-item .mag2-item .mag2slider-overlay i {
	width: 44px;
	height: 44px;
	line-height: 40px;
	font-size: 17px;
	margin: -22px 0 0 -22px
}
.mag2slider-overlay:after {
	background: #000;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 1;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	opacity: .05;
	content: ""
}
.mag2-thumbnail:hover .mag2slider-overlay i {
	opacity: 1
}
.mag2-thumbnail:hover .mag2slider-overlay:after {
	opacity: .7
}
.penci-mag2-carousel .mag2-header {
	position: absolute;
	padding: 17px 20px;
	width: 100%;
	z-index: 8;
	left: 0;
	bottom: 0;
	text-align: center
}
.penci-mag2-carousel .mag2-item .mag2-item .mag2-header {
	padding: 17px 20px !important
}
.penci-mag2-carousel .mag2-header h3 a {
	font-size: 24px;
	text-transform: uppercase;
	color: #fff
}
.penci-mag2-carousel .mag2-item .mag2-item .mag2-header {
	text-align: left
}
.penci-mag2-carousel .mag2-item .mag2-item .mag2-header h3 a {
	font-size: 16px;
	letter-spacing: 0
}
.penci-mag2-carousel .cat>a.penci-cat-name {
	color: #fff
}
.penci-mag2-carousel .cat>a.penci-cat-name:after {
	border-color: #fff
}
@media only screen and (min-width:779px) {
	.penci-mag2-carousel .mag2-thumbnail img {
		transform: none !important;
		-webkit-transform: none !important
	}
	.penci-mag2-carousel .mag2-header {
		width: 100% !important
	}
}
@media only screen and (max-width:778px) {
	.mag2slider-overlay i {
		display: none
	}
	.penci-mag2-carousel .cat.mag-cat {
		display: none
	}
	.penci-mag2-carousel .mag2-header h3 a {
		font-size: 18px
	}
	.penci-mag2-carousel .mag2-header {
		padding-right: 15px;
		text-align: left
	}
}
.container.home-featured-boxes {
	display: table;
	margin-top: calc(30px - var(--pchd-mg));
	margin-bottom: 30px
}
.container.home-featured-boxes-vc {
	width: 100%
}
.home-featured-boxes .penci-image-holder:before {
	padding-top: 66.75%
}
@media only screen and (min-width:961px) {
	.boxes-size-horizontal .homepage-featured-boxes.boxes-4-columns .penci-image-holder:before {
		padding-top: 70.37%
	}
}
.home-featured-boxes.boxes-size-square .penci-image-holder:before {
	padding-top: 100%
}
.home-featured-boxes.boxes-size-vertical .penci-image-holder:before {
	padding-top: 135.4%
}
.home-featured-boxes-vc {
	overflow: hidden
}
ul.homepage-featured-boxes {
	list-style: none;
	margin-left: -15px;
	margin-right: -15px;
	padding: 0 !important
}
.post-entry ul.homepage-featured-boxes li,
ul.homepage-featured-boxes li {
	width: 33.3333%;
	float: left;
	display: inline-block;
	padding: 0 15px;
	margin-bottom: 30px
}
ul.homepage-featured-boxes li .penci-fea-in {
	position: relative;
	overflow: hidden
}
ul.homepage-featured-boxes li .penci-fea-in:after,
ul.homepage-featured-boxes li .penci-fea-in:before {
	position: absolute;
	left: 5px;
	right: 5px;
	top: 5px;
	bottom: 5px;
	content: "";
	opacity: 0;
	-webkit-transition: opacity .3s, -webkit-transform .4s;
	transition: opacity .3s, transform .4s;
	z-index: 5
}
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-2:after,
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-2:before {
	content: none !important;
	display: none !important
}
ul.homepage-featured-boxes li .penci-fea-in:before {
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transform: scale(0, 1);
	transform: scale(0, 1)
}
ul.homepage-featured-boxes li .penci-fea-in:after {
	border-right: 1px solid #fff;
	border-left: 1px solid #fff;
	-webkit-transform: scale(1, 0);
	transform: scale(1, 0)
}
ul.homepage-featured-boxes li .penci-fea-in:hover:after,
ul.homepage-featured-boxes li .penci-fea-in:hover:before {
	opacity: 1;
	-webkit-transform: scale(1);
	transform: scale(1)
}
ul.homepage-featured-boxes .penci-fea-in .fea-box-img {
	position: static;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	display: block;
	z-index: 1;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: center center
}
ul.homepage-featured-boxes .penci-fea-in .fea-box-img:after {
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	position: absolute;
	z-index: 2;
	content: "";
	background: #000;
	transition: opacity .25s;
	-webkit-transition: opacity .25s;
	-moz-transition: opacity .25s;
	opacity: 0
}
ul.homepage-featured-boxes .penci-fea-in:hover .fea-box-img:after {
	opacity: .3
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 .fea-box-img {
	right: 0;
	bottom: 0
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 .fea-box-img:after {
	content: none !important;
	display: none !important
}
ul.homepage-featured-boxes .penci-fea-in h4 {
	position: absolute;
	width: 100%;
	left: 0;
	top: 50%;
	text-align: center;
	z-index: 5;
	font-style: italic;
	letter-spacing: 0;
	font-family: var(--pcbody-font);
	font-weight: 400;
	padding: 5px 20px;
	margin-top: -25px
}
ul.homepage-featured-boxes .penci-fea-in h4>span {
	display: inline-block;
	position: relative
}
ul.homepage-featured-boxes .penci-fea-in h4 span span {
	display: inline-block;
	background: #fff;
	color: #313131;
	padding: 0 15px;
	position: relative;
	min-width: 120px;
	height: 40px;
	line-height: 40px;
	white-space: nowrap;
	-webkit-transition: all .3s ease 0s;
	-moz-transition: all .3s ease 0s;
	-o-transition: all .3s ease 0s;
	transition: all .3s ease 0s;
	font-style: normal;
	font-size: 14px;
	font-weight: 400
}
ul.homepage-featured-boxes .penci-fea-in h4 span span:before {
	top: -5px;
	left: -5px;
	right: -5px;
	bottom: -5px;
	content: "";
	display: block;
	background: 0 0;
	position: absolute;
	border: 1px solid #fff
}
ul.homepage-featured-boxes .penci-fea-in:hover h4 span {
	color: var(--pcaccent-cl)
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4 {
	background: #fff;
	padding: 0 20px;
	margin-top: -20px
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4:before {
	top: -5px;
	left: 0;
	right: 0;
	width: 100%;
	bottom: -5px;
	content: "";
	display: block;
	background: 0 0;
	position: absolute;
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transition: all .3s ease 0s;
	-moz-transition: all .3s ease 0s;
	-o-transition: all .3s ease 0s;
	transition: all .3s ease 0s
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4 span {
	background: 0 0
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4 span:before {
	content: none;
	display: none
}
.home-featured-boxes-sc .penci-fea-in.boxes-style-4 .fea-box-img:after,
.home-featured-boxes-sc .penci-fea-in.boxes-style-4 h4 span span:before,
ul.homepage-featured-boxes .penci-fea-in.boxes-style-3 .fea-box-img:after,
ul.homepage-featured-boxes .penci-fea-in.boxes-style-3 h4 span span:before {
	content: none
}
.home-featured-boxes-sc li .penci-fea-in.boxes-style-4:after,
.home-featured-boxes-sc li .penci-fea-in.boxes-style-4:before,
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-3:after,
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-3:before {
	opacity: .4;
	-webkit-transition: all .4s;
	transition: all .4s;
	z-index: 5;
	transform: none;
	-webkit-transform: none;
	left: 10px;
	right: 10px;
	top: 10px;
	bottom: 10px
}
.home-featured-boxes-sc li .penci-fea-in.boxes-style-4:hover:after,
.home-featured-boxes-sc li .penci-fea-in.boxes-style-4:hover:before,
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-3:hover:after,
ul.homepage-featured-boxes li .penci-fea-in.boxes-style-3:hover:before {
	opacity: 1
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-3 .fea-box-img {
	transition: all .4s ease-in-out;
	-webkit-transition: all .4s ease-in-out;
	-moz-transition: all .4s ease-in-out
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-3:hover .fea-box-img {
	transform: scale(1.05);
	-webkit-transform: scale(1.05);
	-moz-transform: scale(1.05)
}
ul.homepage-featured-boxes .penci-fea-in.boxes-style-3 h4 span span {
	text-transform: uppercase;
	font-size: 12px;
	font-family: var(--pchead-font)
}
.boxes-weight-bold ul.homepage-featured-boxes .penci-fea-in h4 span span {
	font-weight: 700
}
.home-featured-boxes-sc .penci-fea-in.boxes-style-4:hover .fea-box-img:after {
	opacity: 0
}
.home-featured-boxes-sc li.boxes-no-text .penci-fea-in.boxes-style-4:after,
.home-featured-boxes-sc li.boxes-no-text .penci-fea-in.boxes-style-4:before {
	border: 0
}
ul.homepage-featured-boxes.boxes-4-columns li {
	width: 25%
}
.home-featured-boxes-sc ul.homepage-featured-boxes.boxes-2-columns li {
	width: 50%
}
.home-featured-boxes-sc ul.homepage-featured-boxes.boxes-1-column li {
	width: 100%;
	margin-bottom: 20px
}
.penci-biggrid {
	--pcgap: 4px
}
.penci-biggrid-wrapper {
	margin-bottom: 20px
}
.biggrid-archive-wrapper.penci-biggrid-wrapper {
	margin-bottom: 35px
}
.penci-biggrid-inner {
	overflow: hidden;
	display: block
}
.penci-biggrid-wrapper .pcbg-content-inner {
	z-index: 5
}
.biggrid-archive-wrapper.container.two-sidebar {
	display: block
}
.penci-dflex {
	display: flex;
	display: -webkit-flex;
	display: -ms-flexbox;
	-webkit-flex-flow: row wrap;
	-ms-flex-flow: row wrap;
	flex-flow: row wrap;
	align-items: flex-start
}
.penci-bgstyle-1 .penci-dflex {
	margin-left: -10px;
	margin-right: -10px;
	width: calc(100% + 20px)
}
.penci-bgstyle-1 .penci-dflex .penci-bgitem {
	padding: 0 10px;
	margin-bottom: 20px
}
.pcsl-col-1 .pcsl-item,
.penci-grid-col-1 .penci-dflex .penci-bgitem {
	flex: 0 0 100%
}
.pcsl-col-2 .pcsl-item,
.penci-grid-col-2 .penci-dflex .penci-bgitem {
	flex: 0 0 50%
}
.pcsl-col-3 .pcsl-item,
.penci-grid-col-3 .penci-dflex .penci-bgitem {
	flex: 0 0 33.33333%
}
.pcsl-col-4 .pcsl-item,
.penci-grid-col-4 .penci-dflex .penci-bgitem {
	flex: 0 0 25%
}
.pcsl-col-5 .pcsl-item,
.penci-grid-col-5 .penci-dflex .penci-bgitem {
	flex: 0 0 20%
}
.pcsl-col-6 .pcsl-item,
.penci-grid-col-6 .penci-dflex .penci-bgitem {
	flex: 0 0 16.66667%
}
.pcbg-thumb,
.penci-bgitin {
	position: relative;
	overflow: hidden
}
.pcbg-thumb .pcbg-bgoverlay.active-overlay {
	z-index: 2
}
.pcbg-bgoverlay.active-overlay {
	background: -webkit-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: -o-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: -ms-linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	background: linear-gradient(to bottom, rgba(255, 255, 255, 0) 60%, #000 100%);
	opacity: .7
}
.penci-bgitem:hover .pcbg-bgoverlay.active-overlay {
	opacity: .9
}
.penci-bgmain {
	display: flex;
	flex-direction: column;
	position: relative
}
.pcbg-bgoverlay,
.pcbg-bgoverlaytext,
.pcbg-cbgoverlap,
.pcbg-content {
	position: absolute;
	left: 0;
	right: 0;
	top: 0;
	bottom: 0;
	width: 100%;
	height: 100%;
	display: block
}
.pcbg-cbgoverlap {
	z-index: 100
}
.penci-bgrid-content-above .pcbg-content,
.penci-bgrid-content-below .pcbg-content {
	position: static
}
.penci-bgrid-content-above .penci-bgmain {
	flex-direction: column-reverse
}
.pcbg-bgoverlay,
.pcbg-bgoverlaytext {
	transition: opacity .3s
}
.pcbg-bgoverlaytext {
	z-index: -1
}
.pcbg-mask-title .pcbg-content-inner .pcbg-above {
	margin-bottom: 5px
}
.penci-bgrid-based-custom.pcbg-mask-title .pcbg-content-inner .pcbg-above {
	margin-bottom: 9px
}
.pcbg-mask-title .pcbg-content-inner .pcbg-meta,
.post-entry .pcbg-mask-title .pcbg-content-inner .pcbg-meta {
	margin-top: 13px
}
.pcbg-mask-subtitle .cat>a.penci-cat-name:after {
	content: none;
	display: none
}
.penci-bgrid-based-post.pcbg-mask-subtitle .cat>a.penci-cat-name {
	display: inline-block;
	padding: 1px 5px !important;
	background: #a2d4af;
	box-decoration-break: clone;
	-webkit-box-decoration-break: clone;
	margin-right: 5px
}
.penci-bgrid-based-post.pcbg-mask-subtitle .cat>a.penci-cat-name:last-child {
	margin-right: 0
}
.pcbg-mask-meta .pcbg-meta-desc,
.pcbg-mask-title .pcbg-title,
.penci-bgrid-based-custom.pcbg-mask-subtitle .pcbg-sub-title {
	display: inline;
	background: #a2d4af;
	border: none;
	padding: 0 4px;
	box-decoration-break: clone;
	-webkit-box-decoration-break: clone;
	max-width: 99%;
	transition: background-color .3s, border-color .3s
}
.pcbg-mask-title .pcbg-title {
	border-width: 3px 10px
}
.pcbg-mask-meta .pcbg-meta-desc {
	border-width: 2px 8px
}
.pcbg-content-flex {
	display: flex;
	height: 100%;
	width: 100%;
	z-index: 1;
	align-items: flex-end
}
.pcbg-content-inner {
	padding: 20px;
	position: relative;
	z-index: 1;
	display: block;
	width: 100%
}
.pcbg-content-inner.bgcontent-inline-block {
	display: inline-block;
	width: auto
}
.pcbg-content-inner .pcbg-above {
	line-height: 1;
	margin-bottom: 2px
}
.pcbg-content-inner .cat>a.penci-cat-name,
.pcbg-content-inner .cat>a.penci-cat-name:hover {
	color: inherit
}
.penci-bgrid-content-on .pcbg-content-inner .pcbg-sub-title {
	color: #fff
}
.penci-biggrid-data .pcbg-content-inner .pcbg-title {
	font-size: 18px
}
.penci-biggrid-data .pcbg-content-inner .pcbg-title a {
	font-size: inherit
}
.penci-biggrid-data.penci-fixh .pcbg-content-inner .pcbg-title {
	font-size: 16px
}
.penci-biggrid-data.penci-fixh .pcbg-big-item .pcbg-content-inner .pcbg-title {
	font-size: 24px
}
.penci-biggrid-data .pcbg-content-inner .pcbg-title,
.penci-biggrid-data .pcbg-content-inner .pcbg-title a,
.penci-biggrid-data .pcbg-content-inner .pcbg-title a:hover {
	letter-spacing: 0;
	text-decoration: none;
	margin: 0
}
.penci-bgrid-content-on .pcbg-content-inner .pcbg-title,
.penci-bgrid-content-on .pcbg-content-inner .pcbg-title a,
.penci-bgrid-content-on .pcbg-content-inner .pcbg-title a:hover {
	color: #fff
}
.pcbg-content-inner .pcbg-meta,
.post-entry .pcbg-content-inner .pcbg-meta {
	margin-top: 6px;
	line-height: 1.3;
	font-size: 14px
}
.penci-bgrid-content-on .pcbg-meta,
.penci-bgrid-content-on .pcbg-meta span,
.penci-bgrid-content-on .pcbg-meta span a {
	color: #fff
}
.pcbg-above,
.penci-bgrid-based-custom .pcbg-meta {
	font-size: 14px
}
.penci-bgitem .pcbg-pexcerpt p {
	color: inherit;
	line-height: 1.5;
	text-align: inherit
}
.penci-bgitem .pcbg-pexcerpt p:last-child {
	margin-bottom: 0 !important
}
.pcbg-content-inner .pcbg-meta>div,
.post-entry .pcbg-content-inner .pcbg-meta>div {
	margin-top: 10px
}
.pcbg-content-inner .pcbg-meta>div:first-child,
.post-entry .pcbg-content-inner .pcbg-meta>div:first-child {
	margin-top: 0
}
.penci-bgrid-based-custom .pcbg-sub-title {
	line-height: 1.2;
	margin-bottom: 7px
}
.penci-bgrid-based-custom .pcbg-sub-title a {
	color: inherit
}
.penci-biggrid-data .pcbg-readmore-sec {
	margin-top: 15px
}
.pcbg-readmore-sec .pcbg-readmorebtn,
.pcsl-readmore .pcsl-readmorebtn {
	padding: 10px 15px;
	font-size: 13px;
	line-height: 1;
	background-color: #efefef;
	color: #111;
	position: relative;
	display: inline-flex;
	align-items: center;
	justify-content: center;
	outline: 0;
	border-width: 0;
	border-style: solid;
	border-color: transparent;
	border-radius: 0;
	box-shadow: none;
	vertical-align: middle;
	text-align: center;
	text-decoration: none;
	text-transform: uppercase;
	text-shadow: none;
	letter-spacing: .3px;
	cursor: pointer;
	text-decoration: none !important;
	transition: color .3s ease, background-color .3s ease, border-color .3s ease, box-shadow .3s ease, opacity .3s ease
}
.pcbg-readmore-sec .pcbg-readmorebtn.pcreadmore-icon-right {
	flex-direction: row
}
.pcbg-readmore-sec .pcbg-readmorebtn.pcreadmore-icon-left {
	flex-direction: row-reverse
}
.penci-biggrid-data .pcbg-readmore-sec span {
	color: inherit;
	font: inherit
}
.penci-biggrid-data .pcbg-readmore-sec i {
	font-size: inherit;
	color: inherit
}
.pcbg-readmore-sec .pcrm-text {
	line-height: 1
}
.pcbg-readmore-sec .pcreadmore-icon-right i,
.pcbg-readmore-sec .pcreadmore-icon-right svg {
	margin-left: 5px
}
.pcbg-readmore-sec .pcreadmore-icon-left i,
.pcbg-readmore-sec .pcreadmore-icon-left svg {
	margin-right: 5px
}
.pcbg-thumb .icon-post-format {
	position: absolute;
	z-index: 2;
	text-align: center;
	display: inline-block;
	width: 36px;
	height: 36px;
	line-height: 32px;
	margin: 0;
	font-size: 15px;
	opacity: 1;
	color: rgba(255, 255, 255, .9);
	background: #fff;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	background: rgba(0, 0, 0, .4);
	border: 2px solid rgba(255, 255, 255, .9)
}
.pcbg-thumb .icon-post-format .fa-play {
	margin-left: 2px
}
.pcbg-thumb .penci-piechart {
	right: auto;
	top: auto
}
.pcbg-ficonpo-top-right .pcbg-thumb .icon-post-format,
.pcbg-reiconpo-top-right .pcbg-thumb .penci-piechart {
	top: 20px;
	right: 20px
}
.pcbg-ficonpo-top-left .pcbg-thumb .icon-post-format,
.pcbg-reiconpo-top-left .pcbg-thumb .penci-piechart {
	top: 20px;
	left: 20px
}
.pcbg-ficonpo-bottom-right .pcbg-thumb .icon-post-format,
.pcbg-reiconpo-bottom-right .pcbg-thumb .penci-piechart {
	bottom: 20px;
	right: 20px
}
.pcbg-ficonpo-bottom-left .pcbg-thumb .icon-post-format,
.pcbg-reiconpo-bottom-left .pcbg-thumb .penci-piechart {
	bottom: 20px;
	left: 20px
}
.pcbg-ficonpo-center .pcbg-thumb .icon-post-format,
.pcbg-reiconpo-center .pcbg-thumb .penci-piechart {
	top: 50%;
	left: 50%;
	margin: -20px 0 0 -20px
}
.pcbg-reiconpo-center .pcbg-thumb .penci-piechart {
	margin: -25px 0 0 -25px
}
.penci-bgitem:hover .icon-post-format {
	opacity: 0;
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5)
}
@media only screen and (max-width:767px) {
	.penci-biggrid-wrapper.hide-mdesc .pcbg-content-inner .pcbg-meta,
	.penci-biggrid-wrapper.hide-mexcerpt .pcbg-content-inner .pcbg-pexcerpt,
	.penci-biggrid-wrapper.hide-mreadmorebt .pcbg-content-inner .pcbg-readmore-sec,
	.penci-biggrid-wrapper.hide-msubtitle .pcbg-content-inner .pcbg-above,
	.penci-biggrid-wrapper.hide-msubtitle .pcbg-content-inner .pcbg-below {
		display: none
	}
	.pcbg-ficonpo-top-right .pcbg-thumb .icon-post-format,
	.pcbg-reiconpo-top-right .pcbg-thumb .penci-piechart {
		top: 15px;
		right: 15px
	}
	.pcbg-ficonpo-top-left .pcbg-thumb .icon-post-format,
	.pcbg-reiconpo-top-left .pcbg-thumb .penci-piechart {
		top: 15px;
		left: 15px
	}
	.pcbg-ficonpo-bottom-right .pcbg-thumb .icon-post-format,
	.pcbg-reiconpo-bottom-right .pcbg-thumb .penci-piechart {
		bottom: 15px;
		right: 15px
	}
	.pcbg-ficonpo-bottom-left .pcbg-thumb .icon-post-format,
	.pcbg-reiconpo-bottom-left .pcbg-thumb .penci-piechart {
		bottom: 15px;
		left: 15px
	}
}
.penci-biggrid .penci-pagination {
	margin-bottom: 0;
	margin-top: 20px
}
.penci-bgstyle-1 .penci-pagination,
.penci-bgstyle-2 .penci-pagination {
	margin-top: 0
}
.penci-biggrid .penci-pagination a i {
	font-size: inherit
}
.pcbg-thumbin {
	display: block;
	margin: -1px;
	transition: -webkit-transform .5s cubic-bezier(0, 0, .42, 1.21);
	transition: transform .5s cubic-bezier(0, 0, .42, 1.21)
}
.pencibg-imageh-move-bottom .penci-bgitem .pcbg-thumbin,
.pencibg-imageh-move-left .penci-bgitem .pcbg-thumbin,
.pencibg-imageh-move-right .penci-bgitem .pcbg-thumbin,
.pencibg-imageh-move-top .penci-bgitem .pcbg-thumbin,
.pencibg-imageh-zoom-in .penci-bgitem:hover .pcbg-thumbin,
.pencibg-imageh-zoom-out .penci-bgitem .pcbg-thumbin {
	-webkit-transform: scale(1.09);
	transform: scale(1.09)
}
.pencibg-imageh-zoom-out .penci-bgitem:hover .pcbg-thumbin {
	-webkit-transform: scale3d(1, 1, 1);
	transform: scale3d(1, 1, 1)
}
.pencibg-imageh-move-left .penci-bgitem .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateX(4%);
	transform: scale3d(1.1, 1.1, 1) translateX(4%)
}
.pencibg-imageh-move-left .penci-bgitem:hover .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateX(-4%);
	transform: scale3d(1.1, 1.1, 1) translateX(-4%)
}
.pencibg-imageh-move-right .penci-bgitem .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateX(-4%);
	transform: scale3d(1.1, 1.1, 1) translateX(-4%)
}
.pencibg-imageh-move-right .penci-bgitem:hover .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateX(4%);
	transform: scale3d(1.1, 1.1, 1) translateX(4%)
}
.pencibg-imageh-move-top .penci-bgitem .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateY(4%);
	transform: scale3d(1.1, 1.1, 1) translateY(4%)
}
.pencibg-imageh-move-top .penci-bgitem:hover .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateY(-4%);
	transform: scale3d(1.1, 1.1, 1) translateY(-4%)
}
.pencibg-imageh-move-bottom .penci-bgitem .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateY(-4%);
	transform: scale3d(1.1, 1.1, 1) translateY(-4%)
}
.pencibg-imageh-move-bottom .penci-bgitem:hover .pcbg-thumbin {
	-webkit-transform: scale3d(1.1, 1.1, 1) translateY(4%);
	transform: scale3d(1.1, 1.1, 1) translateY(4%)
}
.textop .pcbg-content-inner>div:nth-of-type(1) {
	transition-delay: 50ms
}
.textop .pcbg-content-inner>div:nth-of-type(2) {
	transition-delay: .1s
}
.textop .pcbg-content-inner>div:nth-of-type(3) {
	transition-delay: .15s
}
.textop .pcbg-content-inner>div:nth-of-type(4) {
	transition-delay: .2s
}
.pencibg-texth-show-in.textop .item-hover {
	opacity: 0;
	visibility: hidden;
	transition: transform .2s ease-in-out, opacity .2s ease-in-out
}
.pencibg-texth-show-in.textop.pencibg-textani-movetop .item-hover {
	transform: translateY(15px);
	-webkit-transform: translateY(15px)
}
.pencibg-texth-show-in.textop.pencibg-textani-movebottom .item-hover {
	transform: translateY(-15px);
	-webkit-transform: translateY(-15px)
}
.pencibg-texth-show-in.textop.pencibg-textani-moveleft .item-hover {
	transform: translateX(15px);
	-webkit-transform: translateX(15px)
}
.pencibg-texth-show-in.textop.pencibg-textani-moveright .item-hover {
	transform: translateX(-15px);
	-webkit-transform: translateX(-15px)
}
.pencibg-texth-show-in.textop .penci-bgitem:hover .item-hover {
	opacity: 1;
	visibility: visible;
	transform: translate(0, 0);
	-webkit-transform: translate(0, 0)
}
.pencibg-texth-hide-in.textop .item-hover {
	opacity: 1;
	transition: transform .2s ease-in-out, opacity .2s ease-in-out, visibility .2s ease-in-out;
	transform: translate(0, 0);
	-webkit-transform: translate(0, 0);
	visibility: visible
}
.pencibg-texth-hide-in.textop.pencibg-textani-movetop .penci-bgitem:hover .item-hover {
	transform: translateY(-15px);
	-webkit-transform: translateY(-15px)
}
.pencibg-texth-hide-in.textop.pencibg-textani-movebottom .penci-bgitem:hover .item-hover {
	transform: translateY(15px);
	-webkit-transform: translateY(15px)
}
.pencibg-texth-hide-in.textop.pencibg-textani-moveleft .penci-bgitem:hover .item-hover {
	transform: translateX(-15px);
	-webkit-transform: translateX(-15px)
}
.pencibg-texth-hide-in.textop.pencibg-textani-moveright .penci-bgitem:hover .item-hover {
	transform: translateX(15px);
	-webkit-transform: translateX(15px)
}
.pencibg-texth-hide-in.textop .penci-bgitem:hover .item-hover {
	opacity: 0;
	visibility: hidden
}
.pencibg-texth-show-in.notextop .pcbg-content-inner {
	opacity: 0;
	transition: opacity .2s ease-in-out, transform .2s ease-in-out
}
.pencibg-texth-show-in.pencibg-textani-zoomin .pcbg-content-inner {
	transform: scale(.8);
	-webkit-transform: scale(.8)
}
.pencibg-texth-show-in.pencibg-textani-zoomout .pcbg-content-inner {
	transform: scale(1.2);
	-webkit-transform: scale(1.2)
}
.pencibg-texth-show-in.notextop .penci-bgitem:hover .pcbg-content-inner {
	opacity: 1;
	transform: scale(1);
	-webkit-transform: scale(1)
}
.pencibg-texth-hide-in.notextop .pcbg-content-inner {
	opacity: 1;
	transition: opacity .2s ease-in-out, transform .2s ease-in-out;
	transform: scale(1);
	-webkit-transform: scale(1)
}
.pencibg-texth-hide-in.pencibg-textani-zoomin .penci-bgitem:hover .pcbg-content-inner {
	opacity: 0;
	transform: scale(1.2);
	-webkit-transform: scale(1.2)
}
.pencibg-texth-hide-in.pencibg-textani-zoomout .penci-bgitem:hover .pcbg-content-inner {
	opacity: 0;
	transform: scale(.8);
	-webkit-transform: scale(.8)
}
.pencibg-texth-hide-in.pencibg-textani-fade .penci-bgitem:hover .pcbg-content-inner {
	opacity: 0
}
.penci-biggrid-wrapper.pcbg-titles-visible .pcbg-heading.item-hover {
	opacity: 1 !important;
	visibility: visible !important
}
.penci-bgstyle-2 .penci-biggrid-data {
	margin-left: -10px;
	margin-right: -10px
}
.penci-bgstyle-2 .item-masonry {
	width: 33.3333%;
	float: left;
	display: block;
	padding-left: 10px;
	padding-right: 10px;
	margin-bottom: 20px
}
.penci-bgstyle-2 .penci-image-holder:before {
	content: none
}
.penci-grid-col-1 .penci-bgstyle-2 .item-masonry {
	width: 100%
}
.penci-grid-col-2 .penci-bgstyle-2 .item-masonry {
	width: 50%
}
.penci-grid-col-4 .penci-bgstyle-2 .item-masonry {
	width: 25%
}
.penci-grid-col-5 .penci-bgstyle-2 .item-masonry {
	width: 20%
}
.penci-grid-col-6 .penci-bgstyle-2 .item-masonry {
	width: 16.666666%
}
.penci-fixh {
	display: block
}
.penci-fixh .pcbg-thumb,
.penci-fixh .pcbg-thumbin,
.penci-fixh .penci-bgitin,
.penci-fixh .penci-bgmain,
.penci-fixh .penci-image-holder {
	height: 100%
}
.penci-fixh .penci-image-holder:before {
	content: none;
	padding-top: 0
}
.penci-fixh .penci-bgitem {
	margin-right: var(--pcgap);
	margin-bottom: var(--pcgap);
	float: left
}
.penci-pagination.pcbg-paging-align-center.penci-ajax-more a.penci-ajax-more-button {
	margin-right: auto;
	margin-left: auto
}
.penci-pagination.pcbg-paging-align-right.penci-ajax-more a.penci-ajax-more-button {
	margin-left: auto;
	margin-right: 0
}
.penci-pagination.pcbg-paging-align-left.penci-ajax-more a.penci-ajax-more-button {
	margin-right: auto;
	margin-left: 0
}
.penci-bgstyle-3 .penci-fixh {
	--bgh: 500px
}
.penci-bgstyle-3 .penci-fixh .penci-bgitem {
	width: 33.33333%;
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2);
	margin-right: 0
}
.penci-bgstyle-3 .penci-fixh .bgitem-1 {
	width: calc(66.66667% - var(--pcgap));
	height: var(--bgh);
	margin-right: var(--pcgap)
}
.penci-bgstyle-4 .penci-fixh {
	--bgh: 460px
}
.penci-bgstyle-4 .penci-fixh .penci-bgitem {
	width: calc(25% - var(--pcgap)/ 2);
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2)
}
.penci-bgstyle-4 .penci-fixh .bgitem-1 {
	width: calc(50% - var(--pcgap));
	height: var(--bgh)
}
.penci-bgstyle-4 .penci-fixh .bgitem-0,
.penci-bgstyle-4 .penci-fixh .bgitem-3 {
	margin-right: 0
}
.penci-bgstyle-5 .penci-fixh {
	--bgh: 400px
}
.penci-bgstyle-5 .penci-fixh .penci-bgitem {
	width: calc(25% - var(--pcgap)/ 2);
	height: var(--bgh)
}
.penci-bgstyle-5 .penci-fixh .bgitem-1 {
	width: calc(50% - var(--pcgap))
}
.penci-bgstyle-5 .penci-fixh .bgitem-0 {
	margin-right: 0
}
.penci-bgstyle-6 .penci-fixh {
	--bgh: 460px;
	display: flex;
	-webkit-flex-flow: column wrap;
	-ms-flex-flow: column wrap;
	flex-flow: column wrap;
	-webkit-align-content: flex-start;
	-ms-flex-line-pack: start;
	align-content: flex-start;
	max-height: var(--bgh)
}
.penci-bgstyle-6 .penci-fixh:after,
.penci-bgstyle-6 .penci-fixh:before {
	content: none
}
.penci-bgstyle-6 .penci-fixh .penci-bgitem {
	height: calc(var(--bgh)/ 2 - var(--pcgap));
	width: calc(25% - var(--pcgap));
	order: 1
}
.penci-bgstyle-6 .penci-fixh .bgitem-1 {
	width: 50%;
	height: var(--bgh);
	order: 2
}
.penci-bgstyle-6 .penci-fixh .bgitem-0,
.penci-bgstyle-6 .penci-fixh .bgitem-4 {
	margin-right: 0
}
.penci-bgstyle-6 .penci-fixh .bgitem-0,
.penci-bgstyle-6 .penci-fixh .bgitem-4 {
	order: 3
}
.penci-bgstyle-7 .penci-fixh {
	--bgh: 460px
}
.penci-bgstyle-7 .penci-fixh .penci-bgitem {
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2);
	width: calc(25% - var(--pcgap)/ 2)
}
.penci-bgstyle-7 .penci-fixh .bgitem-1 {
	width: calc(50% - var(--pcgap));
	height: var(--bgh)
}
.penci-bgstyle-7 .penci-fixh .bgitem-2 {
	width: 50%
}
.penci-bgstyle-7 .penci-fixh .bgitem-0,
.penci-bgstyle-7 .penci-fixh .bgitem-2 {
	margin-right: 0
}
.penci-bgstyle-8 .penci-fixh {
	--bgh: 460px
}
.penci-bgstyle-8 .penci-fixh .penci-bgitem {
	width: calc(38% - var(--pcgap)/ 2);
	height: calc(var(--bgh)/ 3 - var(--pcgap));
	margin-right: 0
}
.penci-bgstyle-8 .penci-fixh .bgitem-1 {
	width: calc(62% - var(--pcgap)/ 2);
	height: var(--bgh);
	margin-right: var(--pcgap)
}
.penci-bgstyle-8 .penci-fixh .bgitem-2 {
	height: calc(var(--bgh)/ 3)
}
.penci-bgstyle-10 .penci-fixh,
.penci-bgstyle-9 .penci-fixh {
	--bgh: 250px
}
.penci-bgstyle-10 .penci-fixh .penci-bgitem,
.penci-bgstyle-9 .penci-fixh .penci-bgitem {
	width: calc((100% - 2 * var(--pcgap))/ 3);
	height: var(--bgh)
}
.penci-bgstyle-10 .penci-fixh .bgitem-0,
.penci-bgstyle-10 .penci-fixh .bgitem-4,
.penci-bgstyle-9 .penci-fixh .bgitem-1,
.penci-bgstyle-9 .penci-fixh .bgitem-2 {
	width: calc(50% - var(--pcgap)/ 2);
	height: calc(var(--bgh) * 1.5)
}
.penci-bgstyle-10 .penci-fixh .bgitem-0,
.penci-bgstyle-10 .penci-fixh .bgitem-3,
.penci-bgstyle-9 .penci-fixh .bgitem-0,
.penci-bgstyle-9 .penci-fixh .bgitem-2 {
	margin-right: 0
}
.penci-bgstyle-11 .penci-fixh {
	--bgh: 400px
}
.penci-bgstyle-11 .penci-fixh .penci-bgitem {
	width: 40%;
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2)
}
.penci-bgstyle-11 .penci-fixh .bgitem-1,
.penci-bgstyle-11 .penci-fixh .bgitem-2 {
	width: calc(30% - var(--pcgap));
	height: var(--bgh)
}
.penci-bgstyle-11 .penci-fixh .bgitem-0,
.penci-bgstyle-11 .penci-fixh .bgitem-3 {
	margin-right: 0
}
.penci-bgstyle-12 .penci-fixh {
	--bgh: 400px
}
.penci-bgstyle-12 .penci-fixh .penci-bgitem {
	width: calc(25% - var(--pcgap));
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2)
}
.penci-bgstyle-12 .penci-fixh .bgitem-1 {
	width: 50%;
	height: var(--bgh)
}
.penci-bgstyle-12 .penci-fixh .bgitem-2 {
	height: var(--bgh)
}
.penci-bgstyle-12 .penci-fixh .bgitem-0,
.penci-bgstyle-12 .penci-fixh .bgitem-3 {
	margin-right: 0
}
.penci-bgstyle-13 .penci-fixh {
	--bgh: 600px
}
.penci-bgstyle-13 .penci-fixh .penci-bgitem {
	width: calc(50% - var(--pcgap)/ 2);
	height: calc(var(--bgh)/ 2);
	margin-right: 0
}
.penci-bgstyle-13 .penci-fixh .bgitem-1 {
	width: 100%;
	height: var(--bgh)
}
.penci-bgstyle-13 .penci-fixh .bgitem-2 {
	margin-right: var(--pcgap)
}
.penci-bgstyle-14 .penci-fixh {
	--bgh: 660px
}
.penci-bgstyle-14 .penci-fixh .penci-bgitem {
	width: calc((100% - 2 * var(--pcgap))/ 3);
	height: calc(var(--bgh)/ 3)
}
.penci-bgstyle-14 .penci-fixh .bgitem-1 {
	width: 100%;
	height: var(--bgh)
}
.penci-bgstyle-14 .penci-fixh .bgitem-0,
.penci-bgstyle-14 .penci-fixh .bgitem-1 {
	margin-right: 0
}
.penci-bgstyle-15 .penci-fixh {
	--bgh: 500px
}
.penci-bgstyle-15 .penci-fixh .penci-bgitem {
	width: calc((100% - 2 * var(--pcgap))/ 3);
	height: calc(var(--bgh)/ 2 - var(--pcgap)/ 2)
}
.penci-bgstyle-15 .penci-fixh .bgitem-1 {
	width: calc(100% - (100% - 2 * var(--pcgap))/ 3 - var(--pcgap));
	height: var(--bgh)
}
.penci-bgstyle-15 .penci-fixh .bgitem-0,
.penci-bgstyle-15 .penci-fixh .bgitem-2,
.penci-bgstyle-15 .penci-fixh .bgitem-3 {
	margin-right: 0
}
.penci-bgstyle-16 .penci-fixh {
	--bgh: 300px
}
.penci-bgstyle-16 .penci-fixh .penci-bgitem {
	width: calc(44% - var(--pcgap)/ 2);
	height: var(--bgh)
}
.penci-bgstyle-16 .penci-fixh .bgitem-0,
.penci-bgstyle-16 .penci-fixh .bgitem-1 {
	width: calc(56% - var(--pcgap)/ 2)
}
.penci-bgstyle-16 .penci-fixh .bgitem-0,
.penci-bgstyle-16 .penci-fixh .bgitem-2 {
	margin-right: 0
}
.penci-bgstyle-17 .penci-fixh {
	--bgh: 400px;
	display: flex;
	-webkit-align-content: flex-start;
	-ms-flex-line-pack: start;
	align-content: flex-start;
	margin-right: 0
}
.penci-bgstyle-17 .penci-fixh {
	--bgh: 400px
}
.penci-bgstyle-17 .penci-fixh .penci-bgitem {
	width: calc(25% - var(--pcgap)/ 2);
	height: var(--bgh);
	order: 2
}
.penci-bgstyle-17 .penci-fixh .bgitem-1 {
	width: calc(50% - var(--pcgap));
	order: 3
}
.penci-bgstyle-17 .penci-fixh .bgitem-0 {
	margin-right: 0;
	order: 4
}
.penci-bgstyle-18 .penci-fixh {
	--bgh: 560px
}
.penci-bgstyle-18 .penci-fixh .penci-bgitem {
	width: calc(35% - var(--pcgap)/ 2);
	height: var(--bgh)
}
.penci-bgstyle-18 .penci-fixh .bgitem-0,
.penci-bgstyle-18 .penci-fixh .bgitem-1 {
	width: calc(65% - var(--pcgap)/ 2)
}
.penci-bgstyle-18 .penci-fixh .bgitem-0,
.penci-bgstyle-18 .penci-fixh .bgitem-3 {
	height: calc(var(--bgh) * .6)
}
.penci-bgstyle-18 .penci-fixh .bgitem-0,
.penci-bgstyle-18 .penci-fixh .bgitem-2 {
	margin-right: 0
}
.penci-bgstyle-19 .penci-fixh,
.penci-bgstyle-20 .penci-fixh,
.penci-bgstyle-21 .penci-fixh,
.penci-bgstyle-22 .penci-fixh {
	--bgh: 250px;
	margin-left: calc(var(--pcgap) * -1 / 2);
	margin-right: calc(var(--pcgap) * -1 / 2)
}
.penci-bgstyle-19 .penci-fixh .penci-bgitem,
.penci-bgstyle-20 .penci-fixh .penci-bgitem {
	width: calc(33.3333% - var(--pcgap));
	height: var(--bgh);
	margin-left: calc(var(--pcgap)/ 2);
	margin-right: calc(var(--pcgap)/ 2)
}
.penci-bgstyle-19 .penci-fixh .bgitem-3,
.penci-bgstyle-20 .penci-fixh .bgitem-1 {
	height: calc(2 * var(--bgh) + var(--pcgap));
	float: right
}
.penci-bgstyle-19 .penci-fixh .bgitem-0,
.penci-bgstyle-20 .penci-fixh .bgitem-6 {
	width: calc(66.6667% - var(--pcgap))
}
.penci-bgstyle-20 .penci-fixh .bgitem-1 {
	float: left
}
.penci-bgstyle-21 .penci-fixh .penci-bgitem,
.penci-bgstyle-22 .penci-fixh .penci-bgitem {
	float: left;
	width: calc(25% - var(--pcgap));
	height: calc(var(--bgh) * 3 / 4);
	margin-left: calc(var(--pcgap)/ 2);
	margin-right: calc(var(--pcgap)/ 2)
}
.penci-bgstyle-21 .penci-fixh .pcbg-big-item,
.penci-bgstyle-22 .penci-fixh .pcbg-big-item {
	width: calc(33.3333% - var(--pcgap));
	height: var(--bgh)
}
@media screen and (max-width:960px) {
	.penci-bgstyle-3 .penci-fixh {
		--bgh: 460px
	}
	.penci-bgstyle-3 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-3 .penci-fixh .bgitem-0 {
		margin-right: 0
	}
	.penci-bgstyle-3 .penci-fixh .bgitem-1 {
		width: 100%;
		margin-right: 0
	}
	.penci-bgstyle-4 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2)
	}
	.penci-bgstyle-4 .penci-fixh .bgitem-1 {
		width: 100%
	}
	.penci-bgstyle-5 .penci-fixh {
		--bgh: 500px
	}
	.penci-bgstyle-5 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		height: calc(var(--bgh) * .8)
	}
	.penci-bgstyle-5 .penci-fixh .bgitem-1 {
		width: 100%;
		height: var(--bgh)
	}
	.penci-bgstyle-6 .penci-fixh {
		--bgh: 500px;
		-webkit-flex-flow: row wrap;
		-ms-flex-flow: row wrap;
		flex-flow: row wrap;
		max-height: none
	}
	.penci-bgstyle-6 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		height: calc(var(--bgh)/ 2)
	}
	.penci-bgstyle-6 .penci-fixh .bgitem-1 {
		width: 100%;
		height: var(--bgh);
		margin-right: 0
	}
	.penci-bgstyle-6 .penci-fixh .bgitem-4 {
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-6 .penci-fixh .bgitem-0,
	.penci-bgstyle-6 .penci-fixh .bgitem-3 {
		margin-right: 0
	}
	.penci-bgstyle-7 .penci-fixh .penci-bgitem {
		height: calc(var(--bgh)/ 2);
		width: calc(50% - var(--pcgap)/ 2);
		margin-right: 0
	}
	.penci-bgstyle-7 .penci-fixh .bgitem-1 {
		width: 100%;
		height: var(--bgh)
	}
	.penci-bgstyle-7 .penci-fixh .bgitem-2 {
		width: 100%
	}
	.penci-bgstyle-7 .penci-fixh .bgitem-3 {
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-8 .penci-fixh {
		--bgh: 460px
	}
	.penci-bgstyle-8 .penci-fixh .penci-bgitem {
		width: 100%;
		height: calc(var(--bgh)/ 2)
	}
	.penci-bgstyle-8 .penci-fixh .bgitem-1 {
		width: 100%;
		margin-right: 0;
		height: var(--bgh)
	}
	.penci-bgstyle-10 .penci-fixh,
	.penci-bgstyle-9 .penci-fixh {
		--bgh: 460px
	}
	.penci-bgstyle-10 .penci-fixh .penci-bgitem,
	.penci-bgstyle-9 .penci-fixh .penci-bgitem {
		width: 100%;
		height: var(--bgh);
		margin-right: 0
	}
	.penci-bgstyle-10 .penci-fixh .bgitem-0,
	.penci-bgstyle-10 .penci-fixh .bgitem-4,
	.penci-bgstyle-9 .penci-fixh .bgitem-1,
	.penci-bgstyle-9 .penci-fixh .bgitem-2 {
		width: calc(50% - var(--pcgap)/ 2);
		height: calc(var(--bgh)/ 2)
	}
	.penci-bgstyle-10 .penci-fixh .bgitem-4,
	.penci-bgstyle-9 .penci-fixh .bgitem-1 {
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-11 .penci-fixh,
	.penci-bgstyle-14 .penci-fixh,
	.penci-bgstyle-15 .penci-fixh {
		--bgh: 250px
	}
	.penci-bgstyle-11 .penci-fixh .penci-bgitem,
	.penci-bgstyle-14 .penci-fixh .penci-bgitem,
	.penci-bgstyle-15 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		height: var(--bgh);
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-11 .penci-fixh .bgitem-0,
	.penci-bgstyle-11 .penci-fixh .bgitem-2,
	.penci-bgstyle-14 .penci-fixh .bgitem-0,
	.penci-bgstyle-14 .penci-fixh .bgitem-2,
	.penci-bgstyle-15 .penci-fixh .bgitem-0,
	.penci-bgstyle-15 .penci-fixh .bgitem-2,
	.penci-bgstyle-15 .penci-fixh .bgitem-4 {
		margin-right: 0
	}
	.penci-bgstyle-12 .penci-fixh {
		--bgh: 460px
	}
	.penci-bgstyle-12 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		margin-right: 0
	}
	.penci-bgstyle-12 .penci-fixh .bgitem-1 {
		width: 100%
	}
	.penci-bgstyle-12 .penci-fixh .bgitem-2 {
		margin-right: var(--pcgap)
	}
	.penci-bgstyle-12 .penci-fixh .bgitem-0,
	.penci-bgstyle-12 .penci-fixh .bgitem-3 {
		margin-right: 0
	}
	.penci-bgstyle-13 .penci-fixh {
		--bgh: 460px
	}
	.penci-bgstyle-16 .penci-fixh {
		--bgh: 200px
	}
	.penci-bgstyle-17 .penci-fixh {
		--bgh: 500px;
		display: flex;
		-webkit-flex-flow: row wrap;
		-ms-flex-flow: row wrap;
		flex-flow: row wrap;
		margin-right: 0
	}
	.penci-bgstyle-17 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap)/ 2);
		height: calc(var(--bgh) * .8)
	}
	.penci-bgstyle-17 .penci-fixh .bgitem-1 {
		width: 100%;
		height: var(--bgh);
		margin-right: 0;
		order: 1
	}
	.penci-bgstyle-18 .penci-fixh .penci-bgitem {
		width: calc(45% - var(--pcgap)/ 2)
	}
	.penci-bgstyle-18 .penci-fixh .bgitem-0,
	.penci-bgstyle-18 .penci-fixh .bgitem-1 {
		width: calc(55% - var(--pcgap)/ 2)
	}
	.penci-bgstyle-18 .penci-fixh .bgitem-0,
	.penci-bgstyle-18 .penci-fixh .bgitem-3 {
		height: calc(var(--bgh) * .8)
	}
	.penci-bgstyle-18 .penci-fixh {
		--bgh: 300px
	}
	.penci-bgstyle-19 .penci-fixh .bgitem-0,
	.penci-bgstyle-19 .penci-fixh .penci-bgitem,
	.penci-bgstyle-20 .penci-fixh .bgitem-6,
	.penci-bgstyle-20 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap))
	}
	.penci-bgstyle-19 .penci-fixh .bgitem-3,
	.penci-bgstyle-20 .penci-fixh .bgitem-1 {
		width: calc(100% + var(--pcgap))
	}
	.penci-bgstyle-21 .penci-fixh .penci-bgitem,
	.penci-bgstyle-22 .penci-fixh .penci-bgitem {
		width: calc(50% - var(--pcgap));
		height: var(--bgh)
	}
	.penci-bgstyle-21 .penci-fixh .bgitem-1,
	.penci-bgstyle-22 .penci-fixh .bgitem-1 {
		height: calc(var(--bgh) * 2);
		width: calc(100% + var(--pcgap))
	}
}
@media screen and (max-width:767px) {
	.penci-bgstyle-3 .penci-fixh,
	.penci-bgstyle-8 .penci-fixh {
		--bgh: 320px
	}
	.penci-bgstyle-4 .penci-fixh,
	.penci-bgstyle-6 .penci-fixh {
		--bgh: 380px
	}
	.penci-bgstyle-7 .penci-fixh {
		--bgh: 400px
	}
	.penci-bgstyle-11 .penci-fixh,
	.penci-bgstyle-14 .penci-fixh,
	.penci-bgstyle-15 .penci-fixh,
	.penci-bgstyle-16 .penci-fixh,
	.penci-bgstyle-19 .penci-fixh,
	.penci-bgstyle-20 .penci-fixh,
	.penci-bgstyle-21 .penci-fixh,
	.penci-bgstyle-22 .penci-fixh {
		--bgh: 190px
	}
	.penci-bgstyle-10 .penci-fixh,
	.penci-bgstyle-12 .penci-fixh,
	.penci-bgstyle-13 .penci-fixh,
	.penci-bgstyle-17 .penci-fixh,
	.penci-bgstyle-5 .penci-fixh,
	.penci-bgstyle-9 .penci-fixh {
		--bgh: 300px
	}
	.penci-bgstyle-10 .penci-fixh .bgitem-0,
	.penci-bgstyle-10 .penci-fixh .bgitem-4,
	.penci-bgstyle-9 .penci-fixh .bgitem-1,
	.penci-bgstyle-9 .penci-fixh .bgitem-2 {
		width: 100%;
		height: var(--bgh);
		margin-right: 0
	}
	.penci-bgstyle-18 .penci-fixh {
		--bgh: 240px
	}
	.penci-bgrid-monecol .penci-fixh .penci-bgitem {
		margin-right: 0 !important;
		margin-left: 0 !important;
		width: 100% !important
	}
	.penci-bgrid-monecol .penci-fixh {
		margin-left: 0 !important;
		margin-right: 0 !important
	}
	.penci-bgrid-monecol .penci-bgstyle-11 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-13 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-14 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-15 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-3 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-4 .penci-fixh .penci-bgitem,
	.penci-bgrid-monecol .penci-bgstyle-6 .penci-fixh .penci-bgitem {
		height: var(--bgh)
	}
	.penci-bgrid-msameh .penci-fixh .penci-bgitem {
		height: var(--bgh) !important
	}
	.pcbg-content-inner {
		padding: 15px
	}
}
.pcbg-verbd .penci-dflex .penci-bgitem,
.pcsl-verbd .pcsl-item {
	border-right: 1px solid var(--pcborder-cl)
}
.pcbg-verbd .penci-dflex .penci-bgitem:last-child,
.pcsl-verbd:not(.pcsl-crs) .pcsl-item:last-child {
	border-right: none !important
}
@media screen and (max-width:767px) {
	.pcbg-verbd .penci-dflex .penci-bgitem,
	.pcsl-verbd .pcsl-item {
		border-right: none !important
	}
}
@media screen and (max-width:1169px) {
	.pcsl-col-5 .pcsl-item,
	.pcsl-col-6 .pcsl-item,
	.penci-grid-col-5 .penci-dflex .penci-bgitem,
	.penci-grid-col-6 .penci-dflex .penci-bgitem {
		flex: 0 0 33.33333%
	}
	.penci-grid-col-5 .penci-bgstyle-2 .item-masonry,
	.penci-grid-col-6 .penci-bgstyle-2 .item-masonry {
		width: 33.33333%
	}
}
@media screen and (max-width:960px) {
	.pcsl-col-4 .pcsl-item,
	.penci-grid-col-4 .penci-bgitem {
		flex: 0 0 50%
	}
	.penci-grid-col-4 .penci-bgstyle-2 .item-masonry {
		width: 50%
	}
}
@media screen and (max-width:1169px) {
	.pcsl-tabcol-1 .pcsl-item,
	.penci-grid-tcol-1 .penci-dflex .penci-bgitem {
		flex: 0 0 100%
	}
	.pcsl-tabcol-2 .pcsl-item,
	.penci-grid-tcol-2 .penci-dflex .penci-bgitem {
		flex: 0 0 50%
	}
	.pcsl-tabcol-3 .pcsl-item,
	.penci-grid-tcol-3 .penci-dflex .penci-bgitem {
		flex: 0 0 33.33333%
	}
	.pcsl-tabcol-4 .pcsl-item,
	.penci-grid-tcol-4 .penci-dflex .penci-bgitem {
		flex: 0 0 25%
	}
	.penci-grid-tcol-1 .penci-bgstyle-2 .item-masonry {
		width: 100%
	}
	.penci-grid-tcol-2 .penci-bgstyle-2 .item-masonry {
		width: 50%
	}
	.penci-grid-tcol-3 .penci-bgstyle-2 .item-masonry {
		width: 33.33333%
	}
	.penci-grid-tcol-4 .penci-bgstyle-2 .item-masonry {
		width: 25%
	}
}
@media screen and (max-width:767px) {
	.pcsl-col-2 .pcsl-item,
	.pcsl-col-3 .pcsl-item,
	.pcsl-col-4 .pcsl-item,
	.pcsl-col-5 .pcsl-item,
	.pcsl-col-6 .pcsl-item,
	.pcsl-mobcol-1 .pcsl-item,
	.penci-dflex .penci-bgitem,
	.penci-grid-col-2 .penci-dflex .penci-bgitem,
	.penci-grid-col-3 .penci-dflex .penci-bgitem,
	.penci-grid-col-4 .penci-dflex .penci-bgitem,
	.penci-grid-col-5 .penci-dflex .penci-bgitem,
	.penci-grid-col-6 .penci-dflex .penci-bgitem,
	.penci-grid-mcol-1 .penci-dflex .penci-bgitem {
		flex: 0 0 100%
	}
	.pcsl-mobcol-2 .pcsl-item,
	.penci-grid-mcol-2 .penci-dflex .penci-bgitem {
		flex: 0 0 50%
	}
	.pcsl-mobcol-3 .pcsl-item,
	.penci-grid-mcol-3 .penci-dflex .penci-bgitem {
		flex: 0 0 33.33333%
	}
	.penci-grid-col-2 .penci-bgstyle-2 .item-masonry,
	.penci-grid-col-3 .penci-bgstyle-2 .item-masonry,
	.penci-grid-col-4 .penci-bgstyle-2 .item-masonry,
	.penci-grid-col-5 .penci-bgstyle-2 .item-masonry,
	.penci-grid-col-6 .penci-bgstyle-2 .item-masonry,
	.penci-grid-mcol-1 .penci-bgstyle-2 .item-masonry {
		width: 100%
	}
	.penci-grid-mcol-2 .penci-bgstyle-2 .item-masonry {
		width: 50%
	}
	.penci-grid-mcol-3 .penci-bgstyle-2 .item-masonry {
		width: 33.33333%
	}
}
.pcfooter-navmenu {
	--pcfnmn-space: 30px;
	--pcfnmn-spea-height: 12px;
	--pcfnmn-cirspea-h: 4px
}
.pcfooter-navmenu {
	display: block;
	clear: both
}
.pcfooter-navmenu .pcfoot-navmenu {
	padding: 0;
	list-style: none;
	margin: 0;
	vertical-align: top;
	line-height: 1.6
}
.pcfoot-navmenu:after,
.pcfoot-navmenu:before {
	content: "";
	display: table;
	clear: both
}
.pcfooter-navmenu .pcfoot-navmenu .sub-menu,
.pcfooter-navmenu .pcfoot-navmenu>li ul {
	display: none !important
}
.pcfooter-navmenu .pcfoot-navmenu>li {
	display: inline-block;
	vertical-align: top;
	margin-right: var(--pcfnmn-space);
	margin-bottom: 0;
	line-height: unset;
	position: relative
}
.pcfooter-navmenu .pcfoot-navmenu>li:last-child {
	margin-right: 0
}
.pcfooter-navmenu .pcfoot-navmenu li a {
	color: var(--pctext-cl);
	text-decoration: none;
	transition: all .3s;
	display: block;
	line-height: 1.5
}
.pcfooter-navmenu.pcfnm-bgitems .pcfoot-navmenu li a {
	background: #e5e5e5;
	padding: 5px 15px;
	line-height: 1.3
}
.pcfooter-navmenu.pcfnm-bditems .pcfoot-navmenu li a {
	padding: 5px 15px;
	line-height: 1.3;
	border: 1px solid var(--pcborder-cl)
}
.pcfooter-navmenu .pcfoot-navmenu li a:hover,
.pcfooter-navmenu .pcfoot-navmenu li.current-menu-item a {
	color: var(--pcaccent-cl)
}
.pcfooter-navmenu.pcfnm-bgitems .pcfoot-navmenu li a:hover {
	background: #ddd
}
.pcfooter-navmenu .pcfoot-navmenu>li:after {
	content: "";
	display: block;
	width: 0;
	border: 0 solid var(--pcborder-cl);
	border-left-width: 1px;
	height: var(--pcfnmn-spea-height);
	position: absolute;
	right: calc(var(--pcfnmn-space) * -1 / 2 - 2px);
	top: 50%;
	margin-top: calc(var(--pcfnmn-spea-height) * -1 / 2)
}
.pcfnm-sepa-slash .pcfoot-navmenu>li:after {
	transform: skewX(-20deg);
	-webkit-transform: skewX(-20deg);
	right: calc(var(--pcfnmn-space) * -1 / 2 - 3px)
}
.pcfnm-sepa-dslash .pcfoot-navmenu>li:after {
	transform: skewX(-20deg);
	-webkit-transform: skewX(-20deg);
	border-right-width: 1px;
	width: 4px;
	right: calc(var(--pcfnmn-space) * -1 / 2 - 5px)
}
.pcfnm-sepa-circle .pcfoot-navmenu>li:after {
	width: var(--pcfnmn-cirspea-h);
	height: var(--pcfnmn-cirspea-h);
	border: none;
	border-radius: 50%;
	background: var(--pcborder-cl);
	transform: none;
	margin-top: calc(var(--pcfnmn-cirspea-h) * -1 / 2);
	right: calc(var(--pcfnmn-space) * -1 / 2 - var(--pcfnmn-cirspea-h)/ 2 - 2px)
}
.pcfooter-navmenu.pcfnm-sepa-none .pcfoot-navmenu>li:after,
body.rtl .pcfooter-navmenu .pcfoot-navmenu>li:first-child:after,
body:not(.rtl) .pcfooter-navmenu .pcfoot-navmenu>li:last-child:after {
	content: none;
	display: none
}
.penci-smalllist {
	display: block;
	width: 100%;
	clear: both;
	--pcsl-hgap: 20px;
	--pcsl-bgap: 20px;
	--pcsl-between: 20px;
	--pcsl-dwidth: 15%;
	overflow: hidden
}
.pcsl-inner,
.swiper.pcsl-inner {
	margin-left: calc(var(--pcsl-hgap) * -1 / 2);
	margin-right: calc(var(--pcsl-hgap) * -1 / 2);
	width: calc(100% + var(--pcsl-hgap));
	display: flex;
	display: -webkit-flex;
	display: -ms-flexbox;
	-webkit-flex-flow: row wrap;
	-ms-flex-flow: row wrap;
	flex-flow: row wrap;
	align-items: flex-start
}
.pcsl-inner .pcsl-item {
	padding: 0 calc(var(--pcsl-hgap)/ 2);
	width: 100%;
	margin-bottom: var(--pcsl-bgap)
}
.pcsl-inner .pcsl-iteminer {
	display: flex;
	display: -webkit-flex;
	display: -ms-flexbox;
	-webkit-flex-flow: row wrap;
	-ms-flex-flow: row wrap;
	flex-flow: row wrap;
	align-items: flex-start
}
.pcsl-inner.pcsl-imgpos-top .pcsl-iteminer {
	flex-direction: column
}
.sl-date {
	color: var(--pcmeta-cl)
}
.pcsl-crs.pcsl-inner .pcsl-item {
	margin-bottom: 0 !important
}
.pcsl-inner .pcsl-thumb {
	width: 32%;
	order: 2;
	transition: opacity .3s;
	position: relative
}
.pcsl-inner .pcsl-thumb:hover {
	opacity: .85
}
.pcsl-inner .pcsl-content {
	width: 68%;
	padding: 0 var(--pcsl-between);
	order: 3
}
.pcsl-inner.pcsl-hdate .pcsl-date {
	width: var(--pcsl-dwidth);
	order: 1;
	padding: 0 var(--pcsl-between)
}
.pcsl-inner.pcsl-hdate .pcsl-date.pcsl-dpos-left {
	padding-left: 0;
	order: 0
}
.pcsl-inner.pcsl-hdate .pcsl-date.pcsl-dpos-right {
	padding-right: 0;
	order: 5
}
.pcsl-inner.pcsl-hdate .pcsl-thumb {
	width: 20%
}
.pcsl-inner.pcsl-hdate .pcsl-content {
	width: 65%;
	width: calc(80% - var(--pcsl-dwidth))
}
.pcsl-inner .pcsl-content ins {
	text-decoration: none
}
.pcsl-inner.pcsl-imgpos-top .pcsl-thumb {
	margin-bottom: var(--pcsl-between);
	width: 100%
}
.pcsl-imgpos-left .pcsl-content {
	padding-right: 0
}
.pcsl-imgpos-right .pcsl-content {
	padding-left: 0;
	order: 1
}
.pcsl-imgpos-top .pcsl-content,
.pcsl-inner .pcsl-nothumb .pcsl-content {
	padding-left: 0 !important;
	padding-right: 0 !important;
	width: 100% !important
}
.pcsl-inner .pcsl-content .pcsl-title {
	font-size: 16px;
	color: var(--pcheading-cl);
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	line-height: 1.4;
	display: block
}
.pcsl-inner .pcsl-content .pcsl-title a {
	font-size: inherit;
	color: inherit;
	font-family: inherit;
	font-weight: inherit;
	text-decoration: none
}
.pcsl-inner .pcsl-content .pcsl-title a:hover {
	color: var(--pcaccent-cl)
}
.pcsl-inner .pcsl-content .cat {
	line-height: 1.3;
	margin-bottom: 4px
}
.pcsl-inner .pcsl-content .cat .penci-product-cats,
.pcsl-inner .pcsl-content .cat .penci-product-cats a {
	text-decoration: none;
	color: var(--pcaccent-cl)
}
.pcsl-inner .grid-post-box-meta,
.post-entry .pcsl-inner .grid-post-box-meta {
	margin-top: 8px;
	line-height: 1.3;
	font-size: 14px
}
.pcsl-nocrop .penci-image-holder:before {
	padding-top: 0;
	content: none
}
.pcsl-flex-full {
	width: 100%;
	order: 10
}
.pcsl-pexcerpt {
	margin-top: 15px
}
.pcsl-inner .pcsl-pexcerpt p {
	line-height: 1.5
}
.pcsl-inner .pcsl-pexcerpt p:last-child {
	margin-bottom: 0
}
.pcsl-readmore {
	margin-top: 15px;
	display: block
}
.pcsl-readmore .pcsl-readmorebtn.pcsl-btns-bordered {
	border: 1px solid var(--pcborder-cl);
	background: 0 0
}
.pcsl-readmore .pcsl-readmorebtn.pcsl-btns-underline {
	border: 0 solid var(--pcborder-cl);
	border-bottom-width: 2px;
	background: 0 0 !important;
	padding: 0 0 3px 0 !important
}
.pcsl-readmore .pcsl-readmorebtn.pcsl-btns-text {
	padding: 0 !important;
	border: none !important;
	background: 0 0 !important
}
@media screen and (min-width:1025px) {
	.pcsl-grid.pcsl-col-2 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-col-3 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-col-3 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-col-4 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-col-4 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-col-4 .pcsl-item:nth-last-child(4),
	.pcsl-grid.pcsl-col-5 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-col-5 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-col-5 .pcsl-item:nth-last-child(4),
	.pcsl-grid.pcsl-col-5 .pcsl-item:nth-last-child(5),
	.pcsl-grid.pcsl-col-6 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-col-6 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-col-6 .pcsl-item:nth-last-child(4),
	.pcsl-grid.pcsl-col-6 .pcsl-item:nth-last-child(5),
	.pcsl-grid.pcsl-col-6 .pcsl-item:nth-last-child(6) {
		margin-bottom: 0 !important
	}
}
@media screen and (max-width:1024px) and (min-width:768px) {
	.pcsl-grid.pcsl-tabcol-2 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-tabcol-3 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-tabcol-3 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-tabcol-4 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-tabcol-4 .pcsl-item:nth-last-child(3),
	.pcsl-grid.pcsl-tabcol-4 .pcsl-item:nth-last-child(4) {
		margin-bottom: 0 !important
	}
}
@media screen and (max-width:767px) {
	.pcsl-grid.pcsl-mobcol-2 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-mobcol-3 .pcsl-item:nth-last-child(2),
	.pcsl-grid.pcsl-mobcol-3 .pcsl-item:nth-last-child(3) {
		margin-bottom: 0 !important
	}
	.pcsl-inner.pcsl-cat-mhide .pcsl-content .cat,
	.pcsl-inner.pcsl-excerpt-mhide .pcsl-pexcerpt,
	.pcsl-inner.pcsl-meta-mhide .pcsl-meta,
	.pcsl-inner.pcsl-rm-mhide .pcsl-readmore {
		display: none
	}
	.pcsl-inner.pcsl-imgtopmobile .pcsl-thumb {
		margin-bottom: var(--pcsl-between);
		width: 100%;
		order: 1
	}
	.pcsl-inner.pcsl-hdate .pcsl-content,
	.pcsl-inner.pcsl-hdate .pcsl-date,
	.pcsl-inner.pcsl-hdate .pcsl-thumb,
	.pcsl-inner.pcsl-imgtopmobile .pcsl-content {
		padding-left: 0 !important;
		padding-right: 0 !important;
		width: 100% !important
	}
	.pcsl-inner.pcsl-hdate .pcsl-thumb {
		order: 1 !important;
		margin-bottom: 15px
	}
	.pcsl-inner.pcsl-hdate .pcsl-date {
		order: 2 !important;
		margin-bottom: 8px
	}
	.pcsl-inner.pcsl-hdate .pcsl-content {
		order: 3 !important
	}
}
.pcsl-grid .pcsl-item:last-child,
.pcsl-nlist .pcsl-item:last-child {
	margin-bottom: 0 !important
}
.penci-homepage-title {
	position: relative;
	margin-bottom: 30px;
	text-align: center;
	clear: both;
	background: 0 0;
	margin-top: 5px
}
.penci-border-arrow {
	position: relative;
	line-height: 1.3;
	margin-left: 5px;
	margin-right: 5px;
	margin-top: 5px
}
.post-entry .penci-border-arrow a,
.post-entry .penci-border-arrow a:hover {
	text-decoration: none
}
.penci-border-arrow .inner-arrow {
	border: 1px solid #313131;
	background: #fff;
	position: relative;
	display: block;
	text-transform: uppercase;
	padding: 8px 12px 7px;
	z-index: 3;
	font-size: 14px
}
.penci-border-arrow .inner-arrow a {
	text-decoration: none !important;
	font-size: inherit;
	font-weight: inherit;
	color: inherit !important
}
.penci-border-arrow .inner-arrow .pcbh-extrabtn {
	font-size: 70%;
	display: inline-block
}
.penci-border-arrow .inner-arrow .pcbh-btns-underline {
	position: relative;
	padding-bottom: 3px;
	line-height: 1;
	transform: translateY(-2px);
	transition: all .3s
}
.penci-border-arrow .inner-arrow .pcbh-btns-underline:after {
	content: "";
	width: 100%;
	height: 1px;
	position: absolute;
	bottom: 0;
	left: 0;
	background: red;
	transition: all .3s
}
@media only screen and (max-width:479px) {
	.penci-border-arrow .inner-arrow .pcbh-extrabtn.pcbtn-etrhm {
		display: none
	}
}
.penci-border-arrow .inner-arrow .pcbh-extrabtn.pcbh-btnp-left {
	margin-right: 10px
}
.penci-border-arrow .inner-arrow .pcbh-extrabtn.pcbh-btnp-right {
	margin-left: 10px
}
.penci-border-arrow .inner-arrow .pcbh-extrabtn.pcbh-btni-right i {
	margin-left: 5px;
	margin-right: 0
}
.penci-border-arrow .inner-arrow .pcbh-extrabtn.pcbh-btni-left i {
	margin-right: 5px;
	margin-left: 0
}
.penci-homepage-title {
	--extrabtn: 0;
}
.penci-border-arrow.block-tbtnpos-left .inner-arrow .pcbh-extrabtn,
.penci-border-arrow.block-tbtnpos-right .inner-arrow .pcbh-extrabtn {
	position: absolute;
	right: 0;
	top: 50%;
	transform: translateY(-50%);
	margin-left: 0;
	margin-right: 0;
}
.penci-border-arrow.block-tbtnpos-left .inner-arrow .pcbh-extrabtn {
	left: 0;
	right: auto;
}
.pcalign-right.block-tbtnpos-left .pcnav-lgroup {
	left: calc( var(--extrabtn) + 15px );
}
.block-tbtnpos-right .pcnav-lgroup,
.pcalign-right.block-tbtnpos-right .pcnav-lgroup {
	right: calc( var(--extrabtn) + 15px );
}
.penci-border-arrow:after,
.penci-border-arrow:before {
	content: "";
	position: absolute
}
.penci-border-arrow:before {
	width: 0;
	height: 0;
	border-style: solid;
	border-color: transparent;
	bottom: -5px;
	left: 50%;
	border-top-color: #313131;
	border-width: 6px;
	border-bottom: 0;
	margin-left: -6px;
	z-index: 5
}
.penci-border-arrow:after {
	border: 1px solid #313131;
	left: -5px;
	right: -5px;
	bottom: 3px;
	display: block;
	z-index: 1;
	height: 100%
}
.penci-homepage-title h3 {
	font-size: 14px;
	color: #313131;
	text-transform: uppercase;
	position: relative;
	z-index: 1
}
.penci-simplelist,
.penci-simplelist li,
.post-entry ul.penci-simplelist {
	margin: 0;
	padding: 0;
	list-style: none
}
.penci-simplelist li,
.post-entry ul.penci-simplelist li {
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-wrap: wrap;
	width: 100%;
	margin-bottom: 10px;
	line-height: 1.4
}
.penci-simplelist>li:last-child,
.post-entry ul.penci-simplelist>li:last-child {
	margin-bottom: 0 !important
}
.penci-simplelist li .list-icon {
	display: inline-block;
	margin-right: 5px;
	transition: all .3s;
	order: 0
}
.penci-simplelist li .list-icon svg {
	width: 15px;
	height: auto;
	vertical-align: middle
}
.penci-iconp-right li .list-icon {
	order: 2;
	margin-right: 0;
	margin-left: 5px
}
.penci-simplelist.penci-justify-center li {
	justify-content: center
}
.penci-simplelist.penci-justify-right li {
	justify-content: flex-end
}
.penci-simplelist li a {
	color: inherit;
	font-family: inherit;
	font-size: inherit
}
.penci-simplelist li a:hover {
	text-transform: none
}
.penci-simplelist-shape-icon li .list-icon {
	line-height: 25px;
	display: inline-flex;
	align-items: center;
	justify-content: center;
	min-width: 25px;
	min-height: 25px;
	text-align: center;
	padding: 4px
}
.list-icon img {
	width: auto;
	max-height: 50px
}
.penci-simplelist-style-rounded .list-icon {
	border-radius: 50%
}
.penci-simplelist.penci-simplelist-type-ordered {
	counter-reset: section
}
.penci-simplelist.penci-simplelist-type-ordered li:before {
	content: counter(section) ". ";
	counter-increment: section;
	background-color: transparent
}
.penci-simplelist.penci-simplelist-type-unordered li:before {
	display: inline-block;
	content: "\25B8";
	background-color: transparent;
	line-height: 1;
	margin-right: 5px;
	transition: color .3s
}
.penci-simplelist.penci-iconp-right.penci-simplelist-type-unordered li:before {
	order: 3;
	margin-left: 5px;
	margin-right: 0
}
.mega-menu-list,
.mega-menu-list ul,
.post-entry ul.mega-menu-list,
.post-entry ul.mega-menu-list ul {
	margin: 0;
	padding: 0;
	list-style: none
}
.mega-menu-list {
	--pcmega-colspace: 20px
}
.mega-menu-list ul,
.post-entry ul.mega-menu-list ul {
	margin-top: 15px
}
.post-entry ul.mega-menu-list a:hover,
ul.mega-menu-list a {
	text-decoration: none
}
.post-entry ul.mega-menu-list a:hover,
ul.mega-menu-list a:hover {
	color: var(--pcaccent-cl)
}
.post-entry ul.mega-menu-list li,
ul.mega-menu-list li {
	position: relative;
	margin: 0;
	padding: 0;
	list-style: none;
	line-height: 1;
	margin-bottom: 15px
}
.post-entry ul.mega-menu-list li:last-child,
ul.mega-menu-list li:last-child {
	margin-bottom: 0 !important
}
.mega-menu-list>li>a {
	font-family: var(--pchead-font);
	font-weight: 700;
	text-transform: uppercase;
	position: relative
}
.mega-menu-list>li.heading-style-style-2>a {
	border-bottom: 3px solid var(--pctext-cl);
	padding: 0 0 8px;
	display: block
}
.mega-menu-list>li.heading-style-style-2>a:after {
	content: "";
	position: absolute;
	width: 40px;
	height: 3px;
	background-color: var(--pcaccent-cl);
	left: 0;
	bottom: -3px
}
.mega-menu-list>li.heading-style-style-3 {
	overflow: hidden
}
.mega-menu-list>li.heading-style-style-3>a {
	padding-right: 12px
}
.mega-menu-list>li.heading-style-style-3>a:after {
	position: absolute;
	content: "";
	width: 2000px;
	height: 0;
	top: 50%;
	left: 100%;
	border-bottom: 1px solid var(--pcborder-cl);
	z-index: 1
}
.mega-menu-list li a {
	position: relative;
	display: inline-block;
	padding: 0;
	margin: 0;
	text-decoration: none;
	color: var(--pctext-cl);
	line-height: unset
}
.mega-menu-list li a img {
	display: inline-block;
	width: auto;
	max-height: 20px
}
.mega-menu-list .menu-label {
	font-size: 9px;
	font-weight: 600;
	line-height: 12px;
	position: absolute;
	z-index: 1;
	top: calc(50% - 24px);
	left: 100%;
	display: inline-block;
	margin-left: -20px;
	padding: 3px 4px;
	vertical-align: middle;
	white-space: nowrap;
	letter-spacing: .3px;
	text-transform: uppercase;
	color: #fff;
	line-height: 1;
	background-color: var(--pcaccent-cl)
}
.mega-menu-list .menu-label.label-style-1:before,
.mega-menu-list .menu-label.label-style-2:before {
	position: absolute;
	top: 100%;
	left: 10px;
	content: "";
	border: 4px solid;
	border-color: var(--pcaccent-cl);
	border-right-width: 7px;
	border-right-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-width: 0
}
.mega-menu-list .menu-label.label-style-2:before {
	left: 0;
	border-right-width: 5px
}
.mega-menu-list .menu-label.label-style-3 {
	top: calc(50% - 8px);
	left: 100%;
	margin-left: 5px;
	border-color: var(--pcaccent-cl)
}
.mega-menu-list .menu-label.label-style-3:before {
	position: absolute;
	top: calc(50% - 4px);
	left: -4px;
	content: "";
	border-width: 4px 4px 4px 0;
	border-style: solid;
	border-color: var(--pcaccent-cl);
	border-top-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-color: transparent !important
}
.mega-menu-list .menu-label.label-style-4:before {
	position: absolute;
	right: 50%;
	bottom: -4px;
	left: 50%;
	margin-left: -3px;
	content: "";
	border-width: 4px 3px 0 3px;
	border-style: solid;
	border-color: var(--pcaccent-cl);
	border-right-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-color: transparent !important
}
ul.pcmg-subcol-2>li {
	display: block;
	float: left;
	width: calc(50% - var(--pcmega-colspace)/ 2);
	margin-right: var(--pcmega-colspace)
}
ul.pcmg-subcol-3>li {
	display: block;
	float: left;
	width: calc(33.3333% - var(--pcmega-colspace)/ 3 * 2);
	margin-right: var(--pcmega-colspace)
}
ul.pcmg-subcol-2>li:nth-child(2n+2),
ul.pcmg-subcol-3>li:nth-child(3n+3) {
	margin-right: 0
}
ul.pcmg-subcol-2>li:nth-child(2n+1),
ul.pcmg-subcol-3>li:nth-child(3n+1) {
	clear: both
}
ul.pcmg-subcol-2>li:nth-last-child(2),
ul.pcmg-subcol-3>li:nth-last-child(2),
ul.pcmg-subcol-3>li:nth-last-child(3) {
	margin-bottom: 0 !important
}
.standard-post-special {
	position: relative;
	margin: 0 0 26px 0
}
.standard-content-special {
	padding: 0;
	text-align: center;
	background: #fff;
	display: block;
	box-shadow: 0 0 10px 3px rgba(0, 0, 0, .2);
	-webkit-box-shadow: 0 0 10px 3px rgba(0, 0, 0, .2);
	-moz-box-shadow: 0 0 10px 3px rgba(0, 0, 0, .2)
}
.standard-post-special.no-thumbnail .standard-content-special {
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	border: 1px solid #ececec
}
.format-post-box {
	display: block;
	padding: 52px 30px 21px 30px;
	position: relative
}
.format-post-box.penci-format-link {
	padding-top: 19px
}
.format-post-box .post-format-icon {
	position: absolute;
	width: 100%;
	text-align: center;
	display: block;
	top: 16px;
	margin-left: -30px
}
.format-post-box.penci-format-link .post-format-icon {
	display: none
}
.format-post-box .post-format-icon i {
	font-size: 35px;
	padding: 0 20px;
	display: inline-block;
	color: var(--pcaccent-cl)
}
.format-post-box .post-format-icon i.fa-quote-left:before {
	content: "\f101";
	font-family: penciicon;
	font-size: 26px;
	font-weight: 400
}
.format-post-box .dt-special,
.format-post-box .dt-special a {
	color: #888;
	font-size: 112.5%;
	font-style: italic
}
.format-post-box.penci-format-quote .dt-special {
	text-align: center;
	font-style: italic;
	font-size: 18px
}
.format-post-box .dt-special a:hover {
	color: var(--pcaccent-cl)
}
.author-quote {
	margin: 15px 0 5px;
	text-align: center;
	display: block;
	overflow: hidden
}
.author-quote span {
	display: inline-block;
	font-size: 12px;
	padding: 0 11px;
	position: relative;
	color: var(--pcaccent-cl);
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-transform: uppercase
}
.author-quote span:after,
.author-quote span:before {
	position: absolute;
	content: "";
	width: 60px;
	height: 1px;
	top: 50%;
	left: 100%;
	background: var(--pcaccent-cl)
}
.author-quote span:before {
	left: auto;
	right: 100%
}
.standard-post-image {
	margin: 0 0 26px 0;
	text-align: center;
	display: block;
	position: relative
}
.standard-content-special,
.standard-post-image .audio-iframe {
	position: absolute;
	left: 30px;
	right: 30px;
	bottom: 30px;
	display: block
}
.standard-post-image.no-thumbnail .audio-iframe,
.standard-post-special.no-thumbnail .standard-content-special {
	position: static
}
.standard-post-image img {
	vertical-align: top;
	max-width: 100%;
	height: auto
}
.header-standard {
	text-align: center;
	padding-bottom: 17px;
	position: relative;
	margin: 0 0 19px 0
}
.header-standard:after {
	content: "";
	position: absolute;
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	display: block;
	bottom: 0;
	left: 50%;
	margin-left: -30px
}
.header-standard-wrapper {
	display: flex;
	flex-wrap: wrap;
	justify-content: center;
	align-items: center;
	column-gap: 30px;
	margin-bottom: 6px;
}
.header-standard-wrapper > div {
	margin: 0;
}
.header-standard-wrapper > div .cat > a.penci-cat-name {
	margin-bottom: 0;
	font-size: 14px;
}
.penci-standard-cat {
	overflow: hidden;
	display: block;
	margin-bottom: 6px
}
.header-standard .cat {
	display: inline-block;
	position: relative
}
.pc_titlebig_standard,
.pc_titlebig_standard a,
.header-standard .post-title,
.header-standard h2,
.header-standard h2 a {
	color: #313131;
	font-size: 24px;
	text-transform: uppercase
}
.container-single .header-standard h2.penci-psub-title,
.container-single h2.penci-psub-title,
.pcsb-subtt .penci-psub-title {
	letter-spacing: 0;
	text-transform: none;
	font-size: 18px;
	line-height: 1.3;
	margin: 8px 0;
	color: #777
}
.pcsb-subtt .penci-psub-title {
	margin: 0
}
@media only screen and (min-width:768px) {
	.penci-header-text-white .header-standard h2.penci-psub-title,
	.penci-single-style-10.penci-header-text-white .header-standard h2.penci-psub-title,
	.penci-single-style-20.penci-header-text-white .header-standard h2.penci-psub-title,
	.penci-single-style-13.penci-header-text-white .header-standard h2.penci-psub-title {
		color: #ccc
	}
}
@media only screen and (max-width:767px) {
	.container-single .header-standard h2.penci-psub-title,
	.container-single h2.penci-psub-title {
		font-size: 16px
	}
}
.pc_titlebig_standard a:hover,
.header-standard h2 a:hover {
	color: #888
}
.header-standard .author-post > span {
	color: #888
}
.header-standard .author-post {
	margin: 6px 0 0;
	font-size: 14px
}
.header-standard .author-post span,
.header-standard .author-post span a {
	font-size: inherit
}
.header-standard .author-post span a:not(.penci-cat-name) {
	color: #313131;
	text-transform: capitalize
}
.header-standard .author-post span a:hover {
	color: var(--pcaccent-cl)
}
.header-standard .author-post span a.penci-cat-name {
	margin-bottom: 0;
  	line-height: inherit;
}
.standard-content {
	position: relative
}
.standard-main-content {
	text-align: left
}
.penci-more-link {
	text-align: center;
	overflow: hidden;
	clear: both
}
.penci-more-link a.more-link {
	font-family: var(--pchead-font);
	color: var(--pcaccent-cl);
	text-transform: uppercase;
	font-size: 12px;
	display: inline-block;
	margin-top: 5px;
	font-weight: var(--pchead-wei);
	position: relative;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.standard-post-entry a.more-link:hover {
	text-decoration: none
}
.penci-more-link a.more-link:after,
.penci-more-link a.more-link:before {
	position: absolute;
	content: "";
	width: 60px;
	height: 0;
	top: 50%;
	left: 100%;
	margin: 0 10px;
	margin-top: -1px;
	border-top: 1px solid var(--pcaccent-cl);
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.penci-more-link a.more-link:before {
	left: auto;
	right: 100%
}
.penci-more-link a.more-link:hover:before {
	right: 50%;
	margin-right: -10px;
	width: 90px
}
.penci-more-link a.more-link:hover:after {
	left: 50%;
	margin-left: -10px;
	width: 90px
}
.penci-more-link.penci-more-link-button {
	margin-top: 17px
}
.penci-more-link.penci-more-link-button a.more-link:after,
.penci-more-link.penci-more-link-button a.more-link:before {
	content: none;
	display: none
}
.penci-more-link.penci-more-link-button a.more-link {
	line-height: 1;
	color: #fff;
	background: var(--pcaccent-cl);
	padding: 14px 16px;
	margin-top: 0
}
.penci-more-link.penci-more-link-button a.more-link:hover {
	opacity: .8
}
.penci-post-box-meta {
	padding: 15px 0;
	clear: both;
	display: block;
	border-top: 1px solid var(--pcborder-cl);
	border-bottom: 1px solid var(--pcborder-cl);
	margin: 30px 0 0
}
.penci-post-box-meta.center-inner {
	text-align: center
}
.penci-post-box-meta.center-inner .penci-post-share-box {
	float: none
}
.penci-post-box-meta .penci-box-meta {
	display: inline-block;
	font-size: 14px
}
.penci-hide-tagupdated {
	display: none !important
}
.penci-post-box-meta .penci-box-meta a,
.penci-post-box-meta .penci-box-meta span {
	color: #888
}
.grid-post-box-meta i,
.penci-post-box-meta .penci-box-meta i {
	margin-right: 5px
}
.penci-post-box-meta .penci-box-meta a:hover {
	color: var(--pcaccent-cl)
}
.penci-post-box-meta .penci-box-meta span:after {
	content: "";
	width: 0;
	height: 10px;
	margin: 0 16px 0 20px;
	display: inline-block;
	background: 0 0 !important;
	border-right: 1px solid;
	opacity: .7
}
.penci-post-box-meta .penci-box-meta span:last-child:after {
	content: none;
	display: none
}
.penci-post-box-meta .penci-post-share-box {
	display: inline-block;
	float: right
}
.penci-post-box-meta .penci-post-share-box a {
	display: inline-block;
	position: relative;
	color: #313131;
	margin-left: 10px;
	font-size: 14px
}
.penci-post-box-meta .penci-post-share-box a:first-child {
	margin-left: 0
}
.penci-post-share-box a.liked,
.penci-post-share-box a:hover {
	color: var(--pcaccent-cl)
}
.penci-post-share-box .dt-share {
	position: absolute;
	display: inline-block;
	font-size: 9px;
	font-family: var(--pchead-font);
	font-weight: 400;
	background: #313131;
	color: #fff;
	height: 20px;
	line-height: 20px;
	white-space: nowrap;
	text-align: center;
	bottom: -45px;
	width: 60px;
	left: 50%;
	margin-left: -30px;
	opacity: 0;
	visibility: hidden;
	transition: all .2s ease-in-out;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	z-index: 5
}
.penci-post-share-box a:hover .dt-share {
	opacity: 1;
	bottom: -30px;
	visibility: visible
}
.penci-post-share-box .dt-share:before {
	position: absolute;
	width: 0;
	height: 0;
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-bottom: 7px solid #313131;
	content: "";
	top: -7px;
	left: 50%;
	margin-left: -4px
}
.penci-post-like.liked i:before {
	content: "\f004"
}
.penci-fawesome-ver5 .penci-post-like.liked i:before {
	font-weight: 900
}
.list-posts-share .penci-svg-line,
.penci-post-share-box .penci-svg-line {
	vertical-align: top;
	transform: translateY(2px);
	-webkit-transform: translateY(2px)
}
.list-posts-share .penci-svg-viber,
.penci-post-share-box .penci-svg-viber {
	vertical-align: top;
	transform: translateY(4px);
	-webkit-transform: translateY(4px)
}
.penci-svg-discord,
.penci-svg-goodreads,
.penci-svg-line,
.penci-svg-messenger,
.penci-svg-tiktok,
.penci-svg-viber {
	width: 14px;
	vertical-align: middle
}
.post-share-item.show-on-mobile {
	display: none
}
@media only screen and (max-width:960px) {
	.post-share-item.show-on-desktop {
		display: none
	}
}
.header-standard.header-classic {
	margin: 0 0 26px 0;
	padding: 0
}
.header-standard.header-classic:after {
	content: none;
	display: none
}
.header-standard.header-classic.penci-title-bellow {
	margin-bottom: 40px
}
ul.penci-grid {
	display: flex;
	flex-wrap: wrap;
	row-gap: 0;
	--pcrgap: 30px;
	column-gap: var(--pcrgap);
	padding: 0 !important;
	margin: 0
}
@media only screen and (min-width: 768px) {
	ul.penci-grid[data-layout="boxed-2"] {
		row-gap: var(--pcrgap);
	}
}
.penci-grid>li {
	width: calc((100% - var(--pcrgap) * 2)/ 3);
	margin-bottom: 51px;
	list-style: none !important
}
.sd-content ul li {
	clear: none !important;
	width: auto !important
}
.penci-grid>li.grid-style {
	text-align: center
}
.container.penci_sidebar .penci-grid>li,
.penci-grid>li.grid-2-style {
	width: calc((100% - var(--pcrgap))/ 2)
}
.penci-lposts-ctcol.pencisc-grid-1 .penci-grid>li,
.penci-lposts-ctcol.pencisc-grid-2 .penci-grid>li,
.penci-lposts-ctcol.pencisc-grid-3 .penci-grid>li,
.penci-lposts-ctcol.pencisc-grid-4 .penci-grid>li,
.penci-lposts-ctcol.pencisc-grid-5 .penci-grid>li,
.penci-lposts-ctcol.pencisc-grid-6 .penci-grid>li {
	width: 100%;
	margin-bottom: 0;
	margin-right: 0
}
.penci-grid li .item>.thumbnail,
.penci-masonry .item-masonry>.thumbnail {
	display: inline-block;
	position: relative;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	margin-bottom: 28px;
	width: 100%
}
.grid-mixed .thumbnail .icon-post-format,
.pcsl-thumb .icon-post-format,
.penci-grid li .item .thumbnail .icon-post-format,
.penci-masonry .item-masonry>.thumbnail .icon-post-format {
	position: absolute;
	z-index: 2;
	text-align: center;
	display: inline-block;
	width: 42px;
	height: 42px;
	line-height: 38px;
	top: 50%;
	left: 50%;
	margin: -21px 0 0 -21px;
	font-size: 16px;
	opacity: 1;
	color: rgba(255, 255, 255, .9);
	background: #fff;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	background: rgba(0, 0, 0, .4);
	border: 2px solid rgba(255, 255, 255, .9)
}
.pcsl-thumb .icon-post-format {
	width: 34px;
	height: 34px;
	line-height: 30px;
	margin: -17px 0 0 -17px;
	font-size: 14px
}
.pcsl-thumb .icon-post-format i.fa-play,
.penci-grid li .item .thumbnail .icon-post-format i.fa-play,
.penci-masonry .item-masonry>.thumbnail .icon-post-format i.fa-play {
	margin-left: 3px
}
.grid-mixed .thumbnail:hover .icon-post-format,
.pcsl-thumb:hover .icon-post-format,
.penci-grid li .item>.thumbnail:hover .icon-post-format,
.penci-masonry .item-masonry>.thumbnail:hover .icon-post-format {
	opacity: 0;
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5)
}
.grid-mixed .thumbnail:hover,
.penci-grid li .item>.thumbnail:hover,
.penci-masonry .item-masonry>.thumbnail:hover {
	opacity: .85
}
.penci-grid li .item img,
.penci-masonry .item-masonry a img {
	width: 100%;
	height: auto;
	vertical-align: top;
	margin: 0
}
.penci-grid li .item .cat,
.penci-masonry .item-masonry .cat {
	color: var(--pcaccent-cl);
	display: block;
	margin-bottom: 8px
}
.penci-masonry .item-masonry .grid-post-box-meta .cat,
.penci-grid li .item .grid-post-box-meta .cat {
	display: inline-block;
	margin-bottom: 0;
}
.penci-masonry .item-masonry .grid-post-box-meta .cat > a.penci-cat-name,
.penci-grid li .item .grid-post-box-meta .cat > a.penci-cat-name {
	margin-bottom: 0;
	line-height: inherit;
	font-size: inherit;
}
.penci_grid_title a,
.penci-grid li .item h2 a,
.penci-masonry .item-masonry h2 a {
	font-size: 18px;
	color: var(--pcheading-cl);
	text-transform: uppercase;
	transition: .3s;
}
.penci_grid_title a:hover,
.penci-grid li .item h2 a:hover,
.penci-masonry .item-masonry h2 a:hover {
	color: #888
}
.penci-grid li .item p,
.penci-masonry .item-masonry p {
	margin-bottom: 0
}
.penci-grid .mixed-detail .item-content,
.penci-grid li .item .item-content,
.penci-masonry .item-masonry .item-content {
	margin-top: 18px;
	text-align: left
}
.penci-post-box-meta.penci-post-box-grid {
	border: none !important;
	padding: 0;
	text-align: center;
	position: relative;
	margin-top: 16px;
	clear: none
}
.penci-post-box-meta.penci-post-box-grid:before {
	content: "";
	position: absolute;
	width: 100%;
	left: 0;
	height: 1px;
	background: #dedede;
	display: block;
	top: 49%;
	z-index: 1
}
.penci-post-box-meta.penci-post-box-grid .penci-post-share-box {
	float: none !important;
	padding: 0 10px;
	position: relative;
	z-index: 5;
	background: #fff;
	display: inline-block;
	margin-top: 0
}
.grid-header-box {
	padding-bottom: 17px;
	position: relative
}
.grid-header-box:after {
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	margin-left: -30px;
	position: absolute;
	left: 50%;
	bottom: 0;
	content: ""
}
.grid-boxed-4-item .grid-header-box::after {
	display: none;
}
.penci-grid li.grid-overlay-meta .item>.thumbnail,
.penci-masonry .item-masonry.grid-overlay-meta>.thumbnail {
	margin-bottom: 0;
	vertical-align: top
}
.grid-overlay-meta .grid-header-box {
	margin: -30px 25px 0;
	background: #fff;
	padding-top: 25px;
	padding-left: 5px;
	padding-right: 5px;
	z-index: 10;
	position: relative
}
.penci-featured-cat-seemore,
.penci-readmore-btn {
	margin-top: 10px;
	display: block;
	text-align: left
}
.penci-featured-cat-seemore {
	clear: both;
	margin: -40px 0 60px;
	line-height: 1
}
.penci-seemore-style-8 {
	margin-top: -20px
}
.penci-featured-cat-seemore a,
.penci-readmore-btn a {
	transition: .3s;
	-webkit-transition: .3s;
	-moz-transition: .3s;
	line-height: inherit
}
.penci-featured-cat-seemore a:hover,
.penci-readmore-btn a:hover {
	opacity: .7
}
.penci-featured-cat-seemore i,
.penci-readmore-btn i {
	margin-left: 5px;
	font-size: inherit;
	color: inherit
}
.penci-readmore-btn.penci-btn-make-button {
	margin-top: 21px
}
.penci-featured-cat-seemore.penci-btn-remove-arrow i,
.penci-readmore-btn.penci-btn-remove-arrow i {
	display: none
}
.penci-featured-cat-seemore.penci-btn-make-button a,
.penci-readmore-btn.penci-btn-make-button a {
	line-height: 1;
	color: #fff;
	background: var(--pcaccent-cl);
	padding: 10px 15px;
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 12px;
	display: inline-block
}
.penci-featured-cat-seemore.penci-btn-align-center,
.penci-readmore-btn.penci-btn-align-center {
	text-align: center
}
.penci-featured-cat-seemore.penci-btn-align-left,
.penci-readmore-btn.penci-btn-align-left {
	text-align: left
}
.penci-featured-cat-seemore.penci-btn-align-right,
.penci-readmore-btn.penci-btn-align-right {
	text-align: right
}
.penci-wrap-masonry {
	margin-left: -15px;
	margin-right: -15px
}
.penci-masonry {
	width: 100%;
	display: inline-block;
	vertical-align: top
}
.penci-masonry .item-masonry {
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	width: 33.3333%;
	display: inline-block;
	padding: 0 15px;
	float: left;
	margin-bottom: 51px;
	text-align: center
}
.penci-isotope-padding {
	display: block !important;
	overflow: hidden;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover
}
.item-link-relative,
.penci-post-gallery-container .item-link-relative {
	position: relative;
	display: block;
	vertical-align: top
}
.item-link-relative>img,
.item-masonry a img,
.penci-post-gallery-container .item-link-relative img {
	position: absolute;
	left: 0;
	right: 0;
	top: 0;
	bottom: 0;
	display: block;
	z-index: 1;
	width: 100%
}
.container.penci_sidebar .penci-masonry .item-masonry,
.container.penci_sidebar .penci-masonry[data-cols="2"] .item-masonry,
.penci-masonry .item-masonry.grid-masonry-2,
.penci-masonry[data-cols="2"] .item-masonry {
	width: 50%
}
.penci-masonry .item-masonry .thumbnail>a {
	display: inline-block;
	vertical-align: top;
	width: 100%
}
.container.penci_sidebar .penci-masonry[data-cols="6"] .item-masonry,
.penci-masonry[data-cols="6"] .item-masonry,
.pencisc-grid-6 .penci-masonry .item-masonry {
	width: 16.6666667%
}
.container.penci_sidebar .penci-masonry[data-cols="5"] .item-masonry,
.penci-masonry[data-cols="5"] .item-masonry,
.pencisc-grid-5 .penci-masonry .item-masonry {
	width: 20%
}
.container.penci_sidebar .penci-masonry[data-cols="4"] .item-masonry,
.penci-masonry[data-cols="4"] .item-masonry,
.pencisc-grid-4 .penci-masonry .item-masonry {
	width: 25%
}
.container.penci_sidebar .penci-masonry[data-cols="3"] .item-masonry,
.penci-masonry[data-cols="3"] .item-masonry,
.pencisc-grid-3 .penci-masonry .item-masonry {
	width: 33.3333%
}
.container.penci_sidebar .penci-masonry[data-cols="2"] .item-masonry,
.penci-masonry[data-cols="2"] .item-masonry,
.pencisc-grid-2 .penci-masonry .item-masonry {
	width: 50%
}
.container.penci_sidebar .penci-masonry[data-cols="1"] .item-masonry,
.penci-masonry[data-cols="1"] .item-masonry,
.pencisc-grid-1 .penci-masonry .item-masonry {
	width: 100%
}
.penci-masonry .standard-masonry {
	width: 50%
}
.standard-masonry .standard-main-content>h2 {
	font-size: 20px
}
.standard-masonry .standard-main-content>h2:before {
	height: 18px;
	top: 3px
}
.penci-masonry .item-masonry.standard-masonry .cat a {
	margin-bottom: 13px
}
.standard-masonry .post-box-meta {
	margin-top: 14px
}
.cat>a.penci-cat-name {
	font-size: 13px;
	color: var(--pcaccent-cl);
	line-height: 1.2;
	margin: 0 15px 0 0;
	padding-right: 10px;
	display: inline-block;
	vertical-align: top;
	background: 0 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	font-weight: 400;
	margin-bottom: 5px;
	position: relative;
	text-decoration: none
}
.cat>a.penci-cat-name:after {
	content: "";
	display: inline-block;
	border: 1px solid;
	font-size: 12px;
	margin-left: 10px;
	position: absolute;
	top: 50%;
	margin-top: -3px;
	width: 3px;
	height: 3px;
	transform: rotate(45deg);
	-moz-transform: rotate(45deg);
	-webkit-transform: rotate(45deg);
	box-sizing: unset;
	-webkit-box-sizing: unset;
	opacity: .65
}
.cat>a.penci-cat-name:first-child {
	margin-left: 0
}
.cat>a.penci-cat-name:last-child {
	margin-right: 0;
	padding: 0
}
.cat>a.penci-cat-name:last-child:after {
	content: none;
	display: none
}
.penci-grid li.list-post {
	width: 100% !important;
	margin-right: 0 !important;
	padding-bottom: 40px;
	margin-bottom: 40px;
	border-bottom: 1px solid #dedede
}
.penci-grid li.list-post .item {
	width: 100%
}
.penci-grid li.list-post:last-child {
	margin-bottom: 40px;
	padding-bottom: 0;
	border-bottom: none
}
.penci-grid li.list-post .item>.thumbnail {
	margin: 0;
	width: 46.25%;
	float: left;
	max-width: 100%
}
.pc-has-thumb.pc-list-imgright article {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row-reverse;
}
.pc-has-thumb.pc-list-imgright article .thumbnail {
	align-self: start;
}
.penci-grid li.pclist-layout.pc-has-thumb.pc-list-imgright .item .content-list-right {
	padding-left: 0;
	padding-right: 30px;
}
.penci-latest-posts-sc .penci-grid li.list-post .item>.thumbnail {
	max-width: 100%
}
.penci-grid li.list-post .item .content-list-right {
	margin: 0;
	padding-left: 30px;
	width: 53.75%;
	float: left
}
.penci-grid li.list-post .item .content-list-right.fullwidth {
	padding: 0 !important;
	width: 100% !important
}
.penci-grid[data-layout=list-boxed] li.list-post.pc-nothumb .item {
	border-left: 1px solid var(--pcborder-cl);
	padding-left: 20px
}
.penci-grid[data-layout=list-boxed-2] li.list-post.pc-nothumb .item {
	border-right: 1px solid var(--pcborder-cl);
	padding-right: 20px
}
.list-post .header-list-style {
	position: relative;
	padding-bottom: 17px
}
.list-post .header-list-style:after {
	content: "";
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	display: block;
	bottom: 0;
	left: 0;
	position: absolute
}
.content-special-list {
	width: 100%;
	display: block;
	padding: 30px;
	background-size: cover;
	background-position: center center;
	position: relative
}
.content-special-list.no-thumbnail {
	padding: 0
}
.content-special-list .standard-content-special {
	position: relative;
	left: auto;
	top: auto;
	bottom: auto;
	right: auto
}
.content-special-list.no-thumbnail .standard-content-special {
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	border: 1px solid #ececec
}
.list-post.penci-slistp .header-list-style {
	padding-bottom: 5px
}
.penci-grid li.list-post.penci-slistp .item>.thumbnail {
	width: 160px;
	max-width: 100%;
	margin-right: 16px;
	float: left
}
.penci-grid li.list-post.penci-slistp .item .content-list-right {
	display: block;
	float: none !important;
	overflow: hidden;
	width: auto !important;
	padding-left: 0 !important;
	padding-right: 0 !important
}
.list-post.penci-slistp .header-list-style:after {
	content: none;
	display: none
}
.penci-grid li.list-post.penci-slistp {
	padding-bottom: 15px;
	margin-bottom: 15px
}
.penci-latest-posts-small-list li.penci-slistp:last-child {
	padding-bottom: 0 !important
}
.penci-latest-posts-mixed-3 .penci-grid li.penci-slistp,
.penci-latest-posts-mixed-4 .penci-grid li.penci-slistp,
.penci-layout-mixed-3 .penci-grid li.penci-slistp,
.penci-layout-mixed-4 .penci-grid li.penci-slistp {
	padding-bottom: 0;
	margin-bottom: 0;
	padding-top: 15px;
	border-bottom: none;
	border-top: 1px solid var(--pcborder-cl)
}
.penci-latest-posts-mixed-3 .penci-grid li.penci-slistp~.penci-slistp,
.penci-latest-posts-mixed-4 .penci-grid li.penci-slistp~.penci-slistp,
.penci-layout-mixed-3 .penci-grid li.penci-slistp~.penci-slistp,
.penci-layout-mixed-4 .penci-grid li.penci-slistp~.penci-slistp {
	margin-top: 15px
}
.penci-latest-posts-mixed-3 .penci-grid li.list-post.penci-slistp:last-child,
.penci-latest-posts-mixed-4 .penci-grid li.list-post.penci-slistp:last-child,
.penci-layout-mixed-3 .penci-grid li.list-post.penci-slistp:last-child,
.penci-layout-mixed-4 .penci-grid li.list-post.penci-slistp:last-child {
	margin-bottom: 30px
}
.post-entry li.penci-slistp .grid-post-box-meta {
	line-height: 1.3;
	margin-top: 10px
}
.penci-grid li.penci-slistp .item .thumbnail .icon-post-format {
	width: 32px;
	height: 32px;
	line-height: 30px;
	margin: -16px 0 0 -16px;
	font-size: 14px;
	left: 50%;
	right: auto
}
.grid-mixed {
	display: table;
	width: 100%;
	vertical-align: top;
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 60px
}
.grid-mixed>article {
	width: 100%;
	display: table
}
.grid-mixed .mixed-detail,
.grid-mixed .thumbnail {
	display: table-cell;
	vertical-align: top
}
.grid-mixed .thumbnail.thumb-right {
	display: none
}
.penci-grid>.grid-mixed:nth-of-type(2n) .thumbnail.thumb-right {
	display: table-cell
}
.penci-grid>.grid-mixed:nth-of-type(2n) .thumbnail.thumb-left {
	display: none
}
.grid-mixed .thumbnail {
	width: 65.812%;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	position: relative
}
.grid-mixed .mixed-detail {
	width: 34.188%;
	padding: 30px;
	padding-bottom: 115px;
	position: relative
}
.grid-mixed .mixed-detail .cat {
	margin-bottom: 8px;
	display: block
}
.grid-mixed .mixed-detail h2 a {
	font-size: 18px;
	text-transform: uppercase;
	color: #313131
}
.grid-mixed .mixed-detail h2 a:hover {
	color: #888
}
.grid-mixed .grid-header-box:after {
	left: 0;
	margin: 0
}
.grid-mixed .penci-post-box-meta {
	margin: 0 0 4px 0;
	position: absolute;
	left: 30px;
	bottom: 30px;
	right: 30px;
	display: block
}
.penci-el-mixed-s2 .grid-mixed .mixed-detail,
.penci-el-mixed-s2 .grid-mixed .thumbnail.thumb-left,
.penci-latest-posts-sc .grid-mixed .mixed-detail,
.penci-latest-posts-sc .grid-mixed .thumbnail.thumb-left,
.penci_sidebar .grid-mixed .mixed-detail,
.penci_sidebar .grid-mixed .thumbnail.thumb-left {
	display: block !important;
	width: 100%
}
@media only screen and (min-width:961px) {
	.penci-latest-posts-mixed-larger .grid-mixed .thumbnail.thumb-left {
		width: 65.812%
	}
	.penci-latest-posts-mixed-larger .grid-mixed .mixed-detail {
		width: 34.188%
	}
	.penci-latest-posts-mixed-larger .grid-mixed .mixed-detail,
	.penci-latest-posts-mixed-larger .grid-mixed .thumbnail.thumb-left {
		display: table-cell !important;
		vertical-align: top
	}
	.penci-latest-posts-mixed-larger .grid-mixed.pcmx-hide-share .mixed-detail {
		padding-bottom: 30px;
		vertical-align: middle;
	}
}
.penci_sidebar .grid-mixed .mixed-detail {
	padding: 30px
}
.penci_sidebar .grid-mixed .penci-post-box-meta {
	position: relative;
	margin: 31px 0 4px;
	left: auto;
	right: auto;
	bottom: auto
}
.penci-el-mixed-s2 .grid-mixed .thumbnail.thumb-right,
.penci-latest-posts-sc .grid-mixed .thumbnail.thumb-right,
.penci_sidebar .grid-mixed .thumbnail.thumb-right {
	display: none !important
}
.penci-el-mixed-s2 .penci-grid>li {
	width: calc((100% - var(--pcrgap))/ 2)
}
.penci-grid .list-post.list-boxed-post {
	position: relative;
	padding-bottom: 0;
	border: 1px solid #dedede !important;
	margin-bottom: 60px
}
.penci-post-box-meta.post-box-boxed-1 {
	margin: 31px 0 0;
	text-align: left
}
.list-post.list-boxed-post .header-list-style:after,
.penci-layout-boxed-1 .list-boxed-post .header-list-style:after,
.penci-layout-classic-boxed-1 .list-boxed-post .header-list-style:after,
.penci-layout-standard-boxed-1 .list-boxed-post .header-list-style:after {
	left: 50%;
	margin-left: -30px
}
.grid-post-box-meta {
	margin: 12px 0 0;
	font-size: 14px
}
.grid-post-box-meta > span:not(.cat) {
	color: #888
}
.grid-post-box-meta a,
.grid-post-box-meta span {
	font-size: inherit
}
.grid-post-box-meta span:after {
	content: "";
	width: 1px;
	height: 10px;
	background: #dedede;
	margin: 0 8px 0 10px;
	border-right: 1px solid;
	background: 0 0 !important;
	opacity: .6;
	display: inline-block
}
.grid-post-box-meta span:last-child:after {
	content: none;
	display: none
}
.grid-post-box-meta span a {
	color: #313131
}
.grid-post-box-meta span a.comment-link {
	color: #888;
	font-style: normal
}
.grid-post-box-meta span a.comment-link:hover,
.grid-post-box-meta span a:hover {
	color: var(--pcaccent-cl)
}
.list-boxed-post .grid-post-share-box .inner-grid-post-share-box {
	background: #fff
}
.penci-grid .list-post.list-boxed-post .item>.thumbnail {
	width: 50%;
	max-width: none;
	position: relative;
	float: none
}
.penci-grid .list-post.list-boxed-post .item>.content-list-right {
	float: right
}
.penci-grid li.list-boxed-post:nth-of-type(2n+2) .item>.content-list-right {
	float: left
}
.penci-grid .list-post.list-boxed-post .item>.thumbnail:before {
	content: "";
	width: 0;
	height: 0;
	border-top: 20px solid transparent;
	border-right: 20px solid #fff;
	border-bottom: 20px solid transparent;
	position: absolute;
	right: 0;
	top: 50%;
	margin-top: -20px;
	z-index: 5
}
.penci-grid .list-post.list-boxed-post:nth-of-type(2n+2) .item>.thumbnail:before {
	border-right: none;
	border-left: 20px solid #fff;
	right: auto;
	left: 0
}
.penci-grid .list-post.list-boxed-post .item .content-list-right {
	padding: 20px 60px;
	display: table;
	width: 50%;
	min-height: 389px;
	height: 389px;
	text-align: center
}
.list-boxed-post .inner-content-list-right {
	vertical-align: middle;
	display: table-cell
}
.penci_sidebar .penci-grid .list-post.list-boxed-post .item .content-list-right {
	padding: 20px 30px;
	min-height: 0;
	height: auto
}
.penci-grid .list-post.list-boxed-post .item .content-list-right.fullwidth {
	width: 100%;
	max-width: none
}
.list-boxed-post .fullwidth .inner-content-list-right {
	min-height: 0;
	padding-left: 0;
	padding-right: 0
}
.grid-featured.penci-infeed-data,
.penci-grid .list-post.list-boxed-post.penci-infeed-data {
	border: none !important
}
.penci-infeed-data {
	overflow: hidden;
	text-align: center !important
}
.penci-infeed-data .penci-inner-infeed-data {
	display: block
}
.penci-infeed-data.penci-infeed-fullwidth-ads {
	width: 100% !important;
	min-width: 100% !important;
	max-width: 100% !important;
	margin-left: 0 !important;
	margin-right: 0 !important;
	margin-bottom: 40px
}
.grid-overlay {
	margin-bottom: 60px;
	position: relative;
	display: block;
	clear: both
}
.grid-style.grid-overlay {
	width: 100%
}
.penci-overlay-over {
	position: relative
}
.penci-overlay-over:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	opacity: .3;
	z-index: 1;
	transition: opacity .3s ease;
	-webkit-transition: opacity .3s ease;
	-moz-transition: opacity .3s ease
}
.penci-overlay-over:hover:before {
	opacity: .5
}
.penci-overlay-over .overlay-header-box {
	position: absolute;
	text-align: center;
	left: 20px;
	right: 20px;
	top: 50%;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	-moz-transform: translateY(-50%);
	z-index: 10;
	padding-bottom: 18px
}
.penci-overlay-over .overlay-header-box:after {
	content: "";
	height: 1px;
	background: #fff;
	display: block;
	position: absolute;
	bottom: 0;
	width: 60px;
	left: 50%;
	margin-left: -30px
}
.penci-overlay-over:hover .overlay-header-box:after {
	width: 60px;
	left: 50%;
	margin-left: -30px
}
.overlay-header-box .cat {
	display: block;
	margin-bottom: 6px
}
.overlay-header-box .cat>a.penci-cat-name {
	color: #fff
}
.overlay-header-box .cat>a.penci-cat-name:hover {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.overlay-header-box .cat>a.penci-cat-name:after {
	border-color: #fff
}
.overlay-header-box .overlay-author {
	margin-top: 6px;
	font-size: 14px
}
.overlay-header-box .overlay-title a {
	text-transform: uppercase;
	color: #fff;
	font-size: 24px
}
.overlay-author a,
.overlay-author span {
	color: #fff;
	font-style: italic
}
.overlay-author a:hover {
	color: var(--pcaccent-cl)
}
.penci-overlay-over .overlay-border {
	position: absolute;
	top: 5px;
	left: 5px;
	right: 5px;
	bottom: 5px;
	display: block;
	border: 1px solid #fff;
	z-index: 5
}
.overlay-post-box-meta {
	position: absolute;
	bottom: -1px;
	left: 30px;
	right: 30px;
	text-align: center;
	margin: 0;
	background: #fff;
	z-index: 7;
	border: none;
	padding: 21px 10px 0
}
.overlay-post-box-meta>div {
	display: inline-block;
	vertical-align: bottom;
	line-height: 1;
	float: none !important
}
.overlay-post-box-meta>div:after {
	content: "";
	width: 0;
	height: 10px;
	margin: 0 13px 0 16px;
	display: inline-block;
	border-right: 1px solid;
	background: 0 0 !important;
	opacity: .7
}
.overlay-post-box-meta > span.cat {
	display: inline-block;
	vertical-align: bottom;
	line-height: 1;
	float: none !important;
}
.overlay-post-box-meta > span.cat a {
	margin: 0;
}
.overlay-post-box-meta>div:last-child:after {
	content: none;
	display: none
}
.overlay-post-box-meta,
.overlay-post-box-meta .overlay-share a,
.overlay-post-box-meta .overlay-share span {
	color: #888
}
.overlay-post-box-meta .overlay-share a:hover {
	color: var(--pcaccent-cl)
}
.overlay-post-box-meta .overlay-share i {
	color: inherit;
	margin-right: 5px
}
.grid-featured {
	margin-bottom: 60px;
	border: 1px solid var(--pcborder-cl);
	overflow: hidden;
	width: 100%;
}
.grid-featured .thumbnail {
	position: relative;
	margin: -1px -1px 0 -1px
}
.penci-featured-infor {
	padding: 20px;
	text-align: center
}
.penci-featured-infor .cat {
	display: block;
	margin-bottom: 8px
}
.penci-featured-infor .grid-post-box-meta .cat {
	margin: initial;
	display: inline-block;
}
.penci-featured-infor .penci-entry-title {
	text-transform: uppercase;
	font-size: 24px
}
.penci-featured-infor .penci-entry-title a {
	color: var(--pcheading-cl);
	text-decoration: none;
	font-size: inherit
}
.penci-featured-infor .penci-entry-title a:hover {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.penci-featured-infor .item-content {
	margin-top: 18px;
	text-align: left
}
.penci-featured-infor .item-content>p:last-child {
	margin-bottom: 0 !important
}
.grid-featured .penci-featured-share-box a {
	color: inherit;
	line-height: inherit
}
.grid-featured .penci-featured-share-box a i {
	line-height: inherit
}
.grid-featured .penci-featured-share-box .penci-shareso a {
	margin-right: 10px
}
.grid-featured .penci-featured-share-box .penci-shareso a.penci-post-like {
	margin-right: 6px
}
.grid-featured .penci-featured-share-box .penci-shareso a:last-child {
	margin-right: 0
}
.grid-featured .penci-featured-share-box a:hover {
	color: var(--pcaccent-cl)
}
.penci-featured-share-box .dt-share {
	display: none !important
}
.penci-featured-share-box .penci-shareso {
	opacity: 0;
	visibility: hidden;
	transform: translateX(40px);
	-webkit-transform: translateX(40px);
	z-index: 2
}
.penci-featured-share-box .penci-shareic,
.penci-featured-share-box .penci-shareso {
	transition: opacity .3s, transform .3s;
	-webkit-transition: opacity .3s, transform .3s;
	padding: 0 15px;
	height: 40px;
	line-height: 40px;
	background: var(--pctext-cl);
	color: var(--pcbg-cl);
	display: inline-block;
	vertical-align: top;
	position: absolute;
	left: 0;
	bottom: 0;
	z-index: 10
}
.penci-featured-share-box .penci-shareic {
	padding: 0;
	width: 40px;
	text-align: center
}
.grid-featured .thumbnail:hover .penci-shareso {
	opacity: 1;
	transform: none;
	-webkit-transform: none;
	display: inline-block;
	visibility: visible
}
.grid-featured .thumbnail:hover .penci-shareic {
	transform: translateX(-40px);
	-webkit-transform: translateX(-40px)
}
.penci-grid li.list-boxed-post-2 {
	margin: 0 !important;
	width: 33.3333%
}
.penci-grid li.list-boxed-post-2:last-child {
	margin-bottom: 60px !important
}
.penci_sidebar .penci-grid li.list-boxed-post-2 {
	width: calc((100% - var(--pcrgap))/ 2);
}
.penci-grid li.list-boxed-post-2 .item>.thumbnail {
	margin: 0
}
.penci-grid li.list-boxed-post-2 .item>.thumbnail:before {
	position: absolute;
	content: "";
	width: 0;
	height: 0;
	border-left: 18px solid transparent;
	border-right: 18px solid transparent;
	border-bottom: 18px solid #fff;
	left: 50%;
	margin-left: -18px;
	bottom: 0
}
.penci-grid li.list-boxed-post-2 .item>.thumbnail.arrow-top:before {
	border-bottom: none;
	border-top: 18px solid #fff;
	bottom: auto;
	top: 0
}
.penci-grid li.list-boxed-post-2 .content-boxed-2 {
	border: 1px solid #efefef
}
.penci-grid li.list-boxed-post-2 .content-boxed-2.show-bottom {
	border-top: none
}
.penci-grid li.list-boxed-post-2 .content-boxed-2.show-top {
	border-bottom: none
}
.penci-grid li.list-boxed-post-2 .content-boxed-2.boxed-none {
	display: none
}
.penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
	height: 258px;
	display: table;
	text-align: center;
	padding: 20px;
	width: 100%
}
.penci_sidebar .penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
	height: 256px
}
.penci-grid li.list-boxed-post-2 .inner-boxed-2 {
	display: table-cell;
	vertical-align: middle;
	max-width: 100%
}
.typography-style .content-typography {
	position: absolute;
	left: 20px;
	right: 20px;
	top: 20px;
	bottom: 20px;
	transition: opacity .4s;
	-webkit-transition: opacity .4s;
	-moz-transition: opacity .4s
}
.penci-grid li.typography-style {
	margin-bottom: 30px
}
.penci-grid li.typography-style:last-child {
	margin-bottom: 60px
}
.penci-grid li.typography-style .item>.thumbnail {
	margin-bottom: 0
}
.penci-grid li.typography-style .item>.thumbnail:hover {
	opacity: 1
}
.penci-grid .typography-style .thumbnail:hover .content-typography,
.typography-style .content-typography:hover {
	opacity: 1
}
.penci-grid li.typography-style .overlay-typography {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	background: #000;
	opacity: .3;
	transition: opacity .3s ease 0s;
	-webkit-transition: opacity .3s ease 0s;
	-moz-transition: opacity .3s ease 0s
}
.penci-grid li.typography-style:hover .overlay-typography {
	opacity: .7
}
.penci-grid li.typography-style .overlay-typography:after,
.penci-grid li.typography-style .overlay-typography:before {
	position: absolute;
	top: 5px;
	right: 5px;
	bottom: 5px;
	left: 5px;
	content: "";
	opacity: 0;
	-webkit-transition: opacity .35s, -webkit-transform .35s;
	transition: opacity .35s, transform .35s
}
.penci-grid li.typography-style .overlay-typography:before {
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transform: scale(0, 1);
	transform: scale(0, 1)
}
.penci-grid li.typography-style .overlay-typography:after {
	border-right: 1px solid #fff;
	border-left: 1px solid #fff;
	-webkit-transform: scale(1, 0);
	transform: scale(1, 0)
}
.penci-grid li.typography-style:hover .overlay-typography:after,
.penci-grid li.typography-style:hover .overlay-typography:before {
	opacity: 1;
	-webkit-transform: scale(1);
	transform: scale(1)
}
.typography-style .main-typography {
	position: absolute;
	z-index: 5;
	top: 50%;
	left: 0;
	width: 100%;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	-moz-transform: translateY(-50%)
}
.typography-style .main-typography a.penci-cat-name {
	color: #fff;
	border-color: #fff;
	text-decoration: none
}
.typography-style .main-typography a.penci-cat-name:after {
	border-color: #fff
}
.penci-grid li.typography-style .item .main-typography h2 a {
	color: #fff
}
.penci-grid li.typography-style .grid-post-box-meta span,
.penci-grid li.typography-style .grid-post-box-meta span a {
	color: #fff
}
.penci-grid li.typography-style .grid-post-box-meta span a:hover,
.penci-grid li.typography-style .item .main-typography h2 a:hover {
	color: var(--pcaccent-cl)
}
.penci-grid>li.photography-2 {
	margin-bottom: 30px
}
.penci-grid>li.photography-2:last-child {
	margin-bottom: 60px
}
.penci-photo-2-effect {
	position: relative;
	overflow: hidden;
	background: #000;
	text-align: center;
	cursor: pointer
}
.penci-photo-2-effect img {
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden;
	transform: scale(1.2);
	-webkit-transform: scale(1.2);
	-moz-transform: scale(1.2);
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	opacity: .7;
	display: block;
	position: relative
}
.penci-photo-2-effect:hover img {
	opacity: .4;
	transform: scale(1);
	-webkit-transform: scale(1);
	-moz-transform: scale(1)
}
.penci-photo-2-effect figcaption,
.penci-photo-2-effect figcaption a.photo-2-overlay {
	padding: 60px;
	text-align: center;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.penci-photo-2-effect figcaption {
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden
}
.penci-photo-2-effect a.photo-2-overlay {
	z-index: 100;
	text-indent: 200%;
	white-space: nowrap;
	font-size: 0;
	opacity: 0
}
.penci-photo-2-effect figcaption h2,
.penci-photo-2-effect figcaption p {
	color: #fff;
	position: absolute;
	top: 50%;
	left: 0;
	width: 100%;
	transition: all .3s;
	-webkit-transition: all .3s
}
.penci-photo-2-effect figcaption h2 {
	font-size: 24px;
	padding: 0 60px;
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	top: 50%;
	transform: translateY(-100%);
	-webkit-transform: translateY(-100%);
	padding-bottom: 30px
}
.penci-photo-2-effect:hover figcaption h2 {
	padding-bottom: 15px
}
.penci-photo-2-effect figcaption p {
	padding: 0 60px;
	top: 50%;
	margin-top: 30px;
	line-height: 1.8
}
.penci-photo-2-effect:hover figcaption p {
	margin-top: 15px
}
.penci-photo-2-effect figcaption:after,
.penci-photo-2-effect figcaption:before {
	position: absolute;
	top: 50%;
	left: 50%;
	width: 80%;
	height: 1px;
	background: #fff;
	content: "";
	-webkit-transition: opacity .35s, -webkit-transform .35s;
	transition: opacity .35s, transform .35s;
	-webkit-transform: translate3d(-50%, -50%, 0);
	transform: translate3d(-50%, -50%, 0)
}
.penci-photo-2-effect:hover figcaption:after {
	opacity: .5;
	-webkit-transform: translate3d(-50%, -50%, 0) rotate(-45deg);
	transform: translate3d(-50%, -50%, 0) rotate(-45deg)
}
.penci-photo-2-effect:hover figcaption:before {
	opacity: .5;
	-webkit-transform: translate3d(-50%, -50%, 0) rotate(45deg);
	transform: translate3d(-50%, -50%, 0) rotate(45deg)
}
.penci_sidebar .penci-photo-2-effect figcaption {
	padding: 20px
}
.penci_sidebar .penci-photo-2-effect figcaption h2 {
	padding: 0 20px 20px;
	font-size: 18px
}
.penci_sidebar .penci-photo-2-effect figcaption p {
	margin-top: 20px;
	padding: 0 20px;
	font-size: 93%
}
.penci_sidebar .penci-photo-2-effect:hover figcaption h2 {
	padding-bottom: 10px
}
.penci_sidebar .penci-photo-2-effect:hover figcaption p {
	margin-top: 10px
}
section.home-featured-cat {
	clear: both;
	display: block;
	width: 100%
}
.home-featured-cat.mag-cat-style-2 {
	display: inline-block;
	width: 48.05%;
	margin-right: 3.9%;
	float: left
}
.penci-featured-cat-sc .home-featured-cat.mag-cat-style-2,
.vc_row .home-featured-cat.mag-cat-style-2 {
	width: 100%;
	float: none;
	margin-right: 0;
	vertical-align: top
}
#main .theiaStickySidebar>div.mag-cat-style-2:nth-of-type(2n+2),
#main>div.mag-cat-style-2:nth-of-type(2n+2) {
	margin-right: 0
}
.penci-grid li.magazine-layout .item h2 a {
	text-transform: none;
	letter-spacing: 0
}
.container.penci_sidebar .penci-grid > li.list-post-3,
.penci-grid > li.list-post-3,
.list-post-3 {
	width: 100%;
}
.list-post-3 .item {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
}
.list-post-3 + .list-post-3 {
	margin-top: 30px;
}
.penci-grid li.list-post-3 .item > .thumbnail {
	width: 45%;
	align-items: stretch;
	display: flex;
	margin: 0;
}
.list-post-3 .content-list-right {
	background: #fff;
	box-shadow: rgba(0, 0, 0, 0.07) 0px 0px 20px 0px;
	padding: 30px;
	width: calc(55% + 20px);
	margin: 20px 20px 20px -40px;
	position: relative;
	z-index: 2;
	border-radius: 5px;
	overflow: hidden;
}
.list-post-3 .grid-post-box-meta {
	padding: 25px 30px;
	background: var(--pcaccent-cl);
	margin: 20px -30px -30px -30px;
}
.list-post-3 .entry-content {
	margin-top: 20px;
}
.list-post-3 .grid-post-box-meta span,
.list-post-3 .grid-post-box-meta span a {
	color: #fff;
}
.list-post-3 .thumbnail {
	position: relative;
}
.list-post-3 .penci-post-box-meta {
	background: transparent;
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	margin: 0;
	backdrop-filter: blur(30px) brightness(90%);
	display: flex;
	flex-wrap: wrap;
	justify-content: center;
	align-items: center;
	opacity: 0;
	transition: 0.3s all ease-in-out;
}
.list-post-3 .penci-post-box-meta.active {
	opacity: 1;
}
.list-post-3 .penci-post-box-meta:before,
.list-post-3 .penci-post-box-meta:after {
	display: none;
}
.list-post-3 .penci-post-box-meta .penci-post-share-box {
	background: transparent;
}
.list-post-3 .penci-post-box-meta .penci-post-share-box a,
.list-post-3 .penci-post-box-meta .penci-post-share-box span {
	color: #fff;
}
.list-post-3.pc-nothumb .content-list-right {
	width: 100%;
	margin: 0;
}
.penci-post-share-box-btn {
	position: absolute;
	width: 32px;
	height: 32px;
	z-index: 99;
	background: var(--pcbg-cl);
	border-radius: 50%;
	display: flex;
	justify-content: center;
	align-items: center;
	bottom: 10px;
	left: 10px;
	font-size: 16px;
	box-shadow: 0px 0px 4px 0px rgba(0, 0, 0, 0.2);
}
.penci-post-share-box-btn a {
	color: var(--pcheading-cl);
}
@media only screen and (min-width:961px) {
	.penci-featured-cat-sc .mag-cat-style-7 .penci-grid>li {
		width: calc((100% - var(--pcrgap))/ 2)
	}
}
.penci-homepage-title.penci-magazine-title {
	text-align: left
}
.penci-homepage-title.penci-magazine-title:before {
	left: 30px
}
.penci-homepage-title.penci-magazine-title h3 a {
	color: #313131
}
.penci-homepage-title.pcalign-left {
	text-align: left
}
.penci-homepage-title.pcalign-center {
	text-align: center
}
.penci-homepage-title.pcalign-right {
	text-align: right
}
.home-featured-cat-content {
	display: inline-block;
	width: 100%;
	vertical-align: top;
	margin-bottom: 60px
}
.elementor-widget-penci-featured-cat .penci-featured-cat-seemore.penci-seemore-style-13 {
	margin-top: 0;
	margin-bottom: 0
}
.elementor-widget-penci-featured-cat .penci-featured-cat-seemore,
.elementor-widget-penci-featured-cat .penci-featured-cat-seemore.penci-seemore-style-8 {
	margin-top: 20px;
	margin-bottom: 0
}
.elementor-widget-penci-featured-cat .home-featured-cat-content {
	margin-bottom: 0 !important
}
.home-featured-cat-content.style-1 {
	display: table;
	width: 100%;
	width: calc(100% + 30px);
	margin-left: -15px;
	margin-right: -15px
}
.home-featured-cat-content.style-11,
.home-featured-cat-content.style-3 {
	display: table;
	width: 100%;
	width: calc(100% + 10px);
	margin-left: -5px;
	margin-right: -5px;
	margin-bottom: 50px
}
.penci-featured-cat-ctcol .home-featured-cat-content.style-11,
.penci-featured-cat-ctcol .home-featured-cat-content.style-3 {
	width: 100%;
	margin-left: 0;
	margin-right: 0
}
.home-featured-cat-content.style-5 {
	overflow: hidden
}
.home-featured-cat-content.style-7 {
	margin-bottom: 34px
}
.home-featured-cat-content.style-8 {
	margin-bottom: 0
}
.home-featured-cat-content.style-13 {
	margin-bottom: 40px
}
.home-featured-cat-content .cat-left,
.home-featured-cat-content .cat-right {
	width: 50%;
	float: left;
	display: inline-block;
	padding: 0 15px
}
.home-featured-cat-content .mag-post-box {
	width: 100%;
	overflow: hidden;
	display: table;
	padding-bottom: 15px;
	margin-bottom: 15px;
	border-bottom: 1px solid var(--pcborder-cl)
}
.home-featured-cat-content .mag-post-box.first-post {
	border-bottom: none;
	padding-bottom: 0;
	margin-bottom: 0
}
.home-featured-cat-content .cat-right>.mag-post-box:last-child,
.home-featured-cat-content>.mag-post-box:last-child {
	padding-bottom: 0;
	margin-bottom: 0;
	border-bottom: none
}
.home-featured-cat-content.style-10 .mag-post-box.first-post,
.home-featured-cat-content.style-2 .mag-post-box.first-post {
	padding-bottom: 22px;
	margin-bottom: 30px;
	border-bottom: 1px solid #dedede
}
.home-featured-cat-content .mag-post-box .magcat-thumb {
	float: left;
	margin-right: 20px;
	position: relative;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
.cat-right .magcat-detail,
.home-featured-cat-content.style-10 .mag-post-box:not(.first-post) .magcat-detail,
.home-featured-cat-content.style-2 .mag-post-box:not(.first-post) .magcat-detail,.home-featured-cat-content.style-9 .magcat-detail {
	overflow: hidden
}
.home-featured-cat-content .magcat-thumb .icon-post-format,
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a.icon-post-format,
.widget ul.side-newsfeed li .side-item .side-image a.icon-post-format {
	width: 30px;
	height: 30px;
	position: absolute;
	display: inline-block;
	line-height: 26px;
	z-index: 10;
	top: 50%;
	left: 50%;
	text-align: center;
	margin: -15px 0 0 -15px;
	border-radius: 50%;
	font-size: 13px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	border: 2px solid rgba(255, 255, 255, .9);
	background: rgba(0, 0, 0, .4);
	color: rgba(255, 255, 255, .9)
}
.home-featured-cat-content .mag-post-box.first-post .magcat-thumb .icon-post-format,
.home-featured-cat-content.style-3 .magcat-thumb .icon-post-format,
.home-featured-cat-content.style-4 .magcat-thumb .icon-post-format,
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format,
.widget ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format {
	font-size: 18px;
	width: 42px;
	height: 42px;
	line-height: 38px;
	margin: -21px 0 0 -21px
}
.home-featured-cat-content.style-3 .magcat-thumb .icon-post-format {
	left: 20px;
	top: 20px;
	margin: 0
}
.home-featured-cat-content.style-4 .magcat-thumb .icon-post-format {
	left: auto;
	top: 20px;
	right: 20px;
	margin: 0
}
.home-featured-cat-content .magcat-thumb .icon-post-format i.fa-play,
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format i.fa-play,
.widget ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format i.fa-play {
	margin-left: 2px
}
.home-featured-cat-content .magcat-thumb .icon-post-format i.fa-music,
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format i.fa-music,
.widget ul.side-newsfeed li.featured-news .side-item .side-image a.icon-post-format i.fa-music {
	margin-right: 2px
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb {
	position: relative
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb i {
	position: absolute;
	z-index: 2;
	text-align: center;
	display: inline-block;
	width: 42px;
	height: 42px;
	line-height: 38px;
	background: 0 0;
	top: 50%;
	left: 50%;
	margin: -21px 0 0 -21px;
	font-size: 18px;
	opacity: 1;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	border: 2px solid rgba(255, 255, 255, .9);
	background: rgba(0, 0, 0, .4);
	color: rgba(255, 255, 255, .9)
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb i.fa-play:before {
	margin-left: 2px
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb i.fa-music:before {
	margin-right: 2px
}
.home-featured-cat-content .magcat-thumb:hover .icon-post-format,
.penci-magcat-carousel .magcat-thumb .mag-post-thumb:hover i,
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image:hover a.icon-post-format,
.widget ul.side-newsfeed li .side-item .side-image:hover a.icon-post-format {
	opacity: 0;
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5)
}
.home-featured-cat-content .mag-post-box .magcat-thumb img {
	width: 120px;
	height: auto
}
.home-featured-cat-content .mag-post-box.first-post .magcat-thumb {
	margin: 0 0 24px 0;
	float: none
}
.home-featured-cat-content .mag-post-box .magcat-thumb:hover {
	opacity: .8
}
.home-featured-cat-content .mag-post-box.first-post .magcat-thumb img {
	width: 100% !important
}
.home-featured-cat-content .first-post .magcat-detail .mag-header {
	padding-bottom: 17px;
	margin-bottom: 19px;
	position: relative
}
.home-featured-cat-content .first-post .magcat-detail .mag-header:after {
	content: "";
	position: absolute;
	bottom: 0;
	left: 0;
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	display: block
}
.home-featured-cat-content .magcat-detail h3 a {
	color: var(--pcheading-cl);
	display: inline-block;
	font-size: 14px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	letter-spacing: 0;
	line-height: 1.4
}
.home-featured-cat-content .first-post .magcat-detail h3 a {
	font-size: 18px
}
.home-featured-cat-content .magcat-detail h3 a:hover {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.home-featured-cat-content .magcat-detail .mag-meta {
	margin-top: 7px
}
.home-featured-cat-content .mag-photo {
	display: inline-block;
	width: 50%;
	float: left;
	margin-bottom: 10px;
	padding: 0 5px;
	overflow: hidden
}
.penci-featured-cat-ctcol.pencisc-grid-1 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-1 .style-3 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-2 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-2 .style-3 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-3 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-3 .style-3 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-4 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-4 .style-3 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-5 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-5 .style-3 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-6 .style-11 .mag-photo,
.penci-featured-cat-ctcol.pencisc-grid-6 .style-3 .mag-photo {
	width: 100%;
	margin: 0;
	padding: 0
}
.home-featured-cat-content.style-3>.mag-photo:nth-child(2n+3) {
	clear: both
}
.home-featured-cat-content .mag-photo .magcat-thumb {
	position: relative;
	overflow: hidden
}
.home-featured-cat-content .mag-photo .magcat-detail {
	position: absolute;
	padding: 20px;
	width: 100%;
	z-index: 5;
	left: 0;
	bottom: 0
}
.home-featured-cat-content .mag-photo .magcat-detail h3 a {
	color: #fff;
	font-size: 18px
}
.home-featured-cat-content .mag-photo .mag-overlay-photo {
	position: absolute;
	background: #000;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	opacity: .15;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	z-index: 2
}
.home-featured-cat-content .mag-photo:hover .mag-overlay-photo {
	opacity: .7
}
.home-featured-cat-content .mag-photo .grid-post-box-meta span,
.home-featured-cat-content .mag-photo .grid-post-box-meta span a {
	color: #fff
}
.home-featured-cat-content .mag-photo .grid-post-box-meta span:after {
	color: #fff
}
.container .penci-grid li.magazine-layout {
	text-align: left
}
.container .penci-grid li.magazine-layout .grid-header-box:after {
	left: 0;
	margin-left: 0
}
.penci-featured-cat-custom-ads {
	margin-top: -40px;
	margin-bottom: 60px;
	clear: both;
	display: block;
	overflow: hidden;
	width: 100%;
	text-align: center
}
.home-featured-cat-content.style-6 {
	margin-bottom: 50px
}
.home-featured-cat-content.style-6 .cat-left,
.home-featured-cat-content.style-6 .cat-right {
	width: 100%;
	float: none;
	padding: 0
}
.home-featured-cat-content.style-6 .cat-left {
	margin-bottom: 30px
}
.home-featured-cat-content.style-6 .mag-post-box.first-post {
	display: inline-block;
	vertical-align: top;
	margin: 0;
	width: 100%;
	float: none
}
.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-thumb {
	margin: 0;
	width: 46.25%;
	float: left
}
.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-detail {
	padding-left: 30px;
	width: 53.75%;
	float: left
}
.home-featured-cat-content.style-6 .mag-post-box.first-post.full-mag-cat .magcat-detail {
	padding: 0 !important
}
.home-featured-cat-content.style-6 .cat-right .mag-post-box {
	float: left;
	width: 48.5%;
	margin-right: 3%;
	display: inline-block;
	border: none;
	padding-bottom: 0;
	margin-bottom: 30px
}
.home-featured-cat-content.style-6 .cat-right .mag-post-box:nth-child(2n+2) {
	margin-right: 0
}
.home-featured-cat-content.style-6 .cat-right .mag-post-box:last-child {
	margin-bottom: 0
}
.mag-single-slider .penci-image-holder:before {
	padding-top: 66.6667%
}
section.home-featured-cat.mag-cat-style-4,
section.home-featured-cat.mag-cat-style-5 {
	display: block;
	clear: both
}
.elementor-widget-penci-featured-cat .home-featured-cat-wrapper {
	display: flex;
	flex-wrap: wrap;
}
.elementor-widget-penci-featured-cat .home-featured-cat-content {
	order: 1;
}
.elementor-widget-penci-featured-cat .penci-featured-cat-seemore {
	order: 2;
	width: 100%;
}
.penci-slider.penci-single-mag-slider .penci-control-nav {
	position: static;
	clear: both;
	margin-top: 20px !important
}
.penci-slider.penci-single-mag-slider ul.slides li:after,
.penci-slider.penci-single-mag-slider ul.slides li:before {
	content: none;
	display: none
}
.penci-single-mag-slider .magcat-thumb {
	position: relative
}
.penci-single-mag-slider .mag-single-slider-overlay {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	display: block;
	z-index: 1;
	background: -moz-linear-gradient(to bottom, transparent 50%, rgba(0, 0, 0, 1) 100%);
	background: -webkit-linear-gradient(to bottom, transparent 50%, rgba(0, 0, 0, 1) 100%);
	background: -o-linear-gradient(to bottom, transparent 50%, rgba(0, 0, 0, 1) 100%);
	background: -ms-linear-gradient(to bottom, transparent 50%, rgba(0, 0, 0, 1) 100%);
	background: linear-gradient(to bottom, transparent 50%, rgba(0, 0, 0, 1) 100%);
	transition: all .4s ease-in;
	-webkit-transition: all .4s ease-in;
	-moz-transition: all .4s ease-in;
	opacity: .7
}
.penci-single-mag-slider .magcat-thumb:hover .mag-single-slider-overlay {
	opacity: .85
}
.penci-single-mag-slider .magcat-detail {
	position: absolute;
	z-index: 3;
	left: 0;
	bottom: 0;
	width: 100%;
	padding: 25px 30px
}
.penci-single-mag-slider .magcat-detail .magcat-titlte {
	font-size: 24px;
	margin: 0;
	line-height: 1.3;
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: 1s;
	-moz-animation-duration: 1s;
	-ms-animation-duration: 1s;
	-o-animation-duration: 1s;
	animation-duration: 1s;
	-webkit-animation-delay: .5s;
	-moz-animation-delay: .5s;
	-o-animation-delay: .5s;
	animation-delay: .5s
}
.penci-single-mag-slider .magcat-detail .magcat-titlte a {
	font-size: inherit;
	color: #fff;
	line-height: inherit
}
.penci-single-mag-slider .magcat-detail .magcat-titlte a:hover {
	color: #fff
}
.home-featured-cat-content .penci-single-mag-slider .grid-post-box-meta {
	margin-top: 8px;
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: 1s;
	-moz-animation-duration: 1s;
	-ms-animation-duration: 1s;
	-o-animation-duration: 1s;
	animation-duration: 1s;
	-webkit-animation-delay: .7s;
	-moz-animation-delay: .7s;
	-o-animation-delay: .7s;
	animation-delay: .7s
}
.penci-single-mag-slider .active .grid-post-box-meta,
.penci-single-mag-slider .active .magcat-detail .magcat-titlte {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp
}
.penci-single-mag-slider .grid-post-box-meta span,
.penci-single-mag-slider .grid-post-box-meta span a {
	color: #fff
}
body .penci-slider.penci-single-mag-slider ol.penci-control-nav li {
	margin: 0 4px
}
.penci-magcat-carousel-wrapper {
	margin-left: -15px;
	margin-right: -15px
}
.home-featured-cat-content.style-12 .penci-magcat-carousel-wrapper {
	margin-left: -10px;
	margin-right: -10px
}
.penci-magcat-carousel .magcat-carousel {
	padding: 0 15px;
	transition: opacity .25s ease-in;
	-webkit-transition: opacity .25s ease-in;
	-moz-transition: opacity .25s ease-in
}
.home-featured-cat-content.style-12 .penci-magcat-carousel .magcat-carousel {
	padding: 0 10px
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb {
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	margin: 0 0 24px 0;
	float: none;
	display: inline-block;
	vertical-align: top;
	width: 100%
}
.penci-magcat-carousel .magcat-thumb .mag-post-thumb:hover {
	opacity: .9
}
.home-featured-cat-content .penci-magcat-carousel .magcat-detail h3 a {
	font-size: 18px
}
.home-featured-cat-content.style-7 .penci-grid>li {
	margin-bottom: 26px
}
.home-featured-cat-content.style-7 .grid-header-box {
	text-align: left
}
.home-featured-cat-content.style-7 .grid-overlay-meta .grid-header-box,
.magazine-layout.magazine-2 .grid-header-box {
	margin-left: 0;
	padding-left: 0
}
.home-featured-cat-content.style-7 .grid-header-box:after {
	margin: 0;
	left: 0
}
.home-featured-cat-content.style-7 .penci-grid li .item h2 a {
	text-transform: none;
	letter-spacing: 0
}
.home-featured-cat-content.style-10 .mag-post-box,
.home-featured-cat-content.style-9 .mag-post-box {
	width: 48.0745%;
	float: left;
	margin-right: 3.851%;
	border-bottom: none
}
.home-featured-cat-content.style-10 .mag-post-box:nth-child(2n+1),
.home-featured-cat-content.style-9 .mag-post-box:nth-child(2n+1) {
	clear: both
}
.home-featured-cat-content.style-10 .mag-post-box:nth-child(2n+2),
.home-featured-cat-content.style-9 .mag-post-box:nth-child(2n+2) {
	margin-right: 0
}
.home-featured-cat-content.style-9 .mag-post-box.first-post {
	border-bottom: none;
	padding-bottom: 0;
	margin-bottom: 0
}
.home-featured-cat-content.style-10 .mag-post-box.first-post {
	margin-bottom: 30px
}
@media only screen and (min-width:768px) {
	.home-featured-cat-content.style-10 .mag-post-box:nth-last-child(2),
	.home-featured-cat-content.style-6 .cat-right .mag-post-box:nth-last-child(2),
	.home-featured-cat-content.style-9 .mag-post-box:nth-last-child(2) {
		margin-bottom: 0;
		padding: 0;
		border-bottom: 0
	}
}
.home-featured-cat-content.style-11 .mag-photo .magcat-detail {
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	bottom: auto;
	top: 50%;
	text-align: center;
	padding: 10px 20px
}
.home-featured-cat-content.style-12 .penci-magcat-carousel .magcat-thumb .mag-post-thumb {
	margin-bottom: 18px
}
.home-featured-cat-content.style-12 .penci-magcat-carousel .magcat-detail h3 a {
	font-size: 15px
}
.home-featured-cat-content.style-12 .magcat-detail .mag-meta {
	font-size: 13px;
	margin-top: 5px
}
@media only screen and (min-width:1170px) {
	ul.penci-grid.penci-fea-cat-style-13 {
		--pcrgap: 20px;
		row-gap: 20px
	}
	.container.penci_sidebar .penci-grid.penci-fea-cat-style-13>li,
	.penci-grid.penci-fea-cat-style-13>li {
		margin-bottom: 0 !important
	}
}
.penci-grid.penci-fea-cat-style-13>li.grid-style {
	text-align: left
}
.penci-grid.penci-fea-cat-style-13 li .item>.thumbnail {
	margin-bottom: 18px
}
.penci-grid.penci-fea-cat-style-13 li .item h2 a {
	font-size: 15px;
	text-transform: none;
	letter-spacing: 0;
	line-height: 1.4
}
.penci-fea-cat-style-13 .grid-post-box-meta {
	font-size: 13px;
	margin-top: 5px
}
.penci-fea-cat-style-13 .grid-header-box {
	padding-bottom: 0
}
.penci-fea-cat-style-13 .grid-header-box:after {
	content: none
}
.home-featured-cat-content.style-14 .first-post .magcat-detail {
	position: absolute;
	bottom: 0;
	left: 0;
	width: 100%;
	padding: 0 17px;
	z-index: 10
}
.home-featured-cat-content.style-14 .first-post .magcat-detail .mag-header:after {
	content: none
}
.home-featured-cat-content.style-14 .mag-post-box {
	margin-bottom: 10px;
	padding-bottom: 10px
}
.home-featured-cat-content.style-14 .mag-post-box:last-child {
	margin: 0;
	padding: 0
}
.home-featured-cat-content.style-14 .first-post .magcat-detail .mag-header {
	margin-bottom: 14px;
	padding-bottom: 0
}
.home-featured-cat-content.style-14 .first-post .magcat-detail h3 a {
	font-size: 16px
}
.home-featured-cat-content.style-14 .first-post .magcat-detail h3 a,
.home-featured-cat-content.style-14 .first-post .magcat-detail h3 a:hover {
	color: #fff
}
.home-featured-cat-content.style-14 .mag-meta {
	color: #fff;
	font-size: 13px;
	margin-top: 5px
}
.home-featured-cat-content.style-14 .mag-meta span,
.home-featured-cat-content.style-14 .mag-meta span a {
	color: inherit
}
.home-featured-cat-content .magcat-detail .magcat-title-small a {
	font-size: 14px;
	font-weight: 400
}
.home-featured-cat-content.style-14 .mag-post-box.first-post .magcat-thumb {
	margin-bottom: 0
}
.home-featured-cat-content.style-14 .magcat-padding {
	padding-left: 17px;
	position: relative
}
.home-featured-cat-content.style-14 .magcat-padding:before {
	content: "";
	width: 4px;
	height: 4px;
	border: 1px solid var(--pcaccent-cl);
	position: absolute;
	left: 0;
	top: 6px
}
.home-featured-cat-content.style-14 .mag-post-box .magcat-thumb:hover {
	opacity: 1
}
.home-featured-cat-content.style-14 .penci-image-holder:after,
.home-featured-cat-content.style-15 .mag-post-box.first-post .penci-image-holder:after {
	bottom: 0;
	content: "";
	display: block;
	height: 90%;
	width: 100%;
	position: absolute;
	z-index: 1;
	background: -moz-linear-gradient(top, transparent 50%, #000 100%);
	background: -webkit-linear-gradient(top, transparent 50%, #000 100%);
	background: -o-linear-gradient(top, transparent 50%, #000 100%);
	background: -ms-linear-gradient(top, transparent 50%, #000 100%);
	background: linear-gradient(to bottom, transparent 50%, #000 100%);
	opacity: .5;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
.home-featured-cat-content.style-14 .magcat-thumb:hover .penci-image-holder:after,
.home-featured-cat-content.style-15 .mag-post-box.first-post:hover .penci-image-holder:after {
	opacity: .8
}
@media only screen and (min-width:768px) {
	.home-featured-cat-content.style-15 {
		display: -ms-flexbox;
		display: flex;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap;
		align-items: center
	}
	.home-featured-cat.mag-cat-style-15 .cat-left,
	.home-featured-cat.mag-cat-style-15 .cat-right {
		-ms-flex: 0 0 50%;
		flex: 0 0 50%;
		float: none;
		display: block;
		width: auto
	}
}
.home-featured-cat-content.style-15 {
	border: 1px solid var(--pcborder-cl)
}
.home-featured-cat.mag-cat-style-15 .cat-left {
	padding: 0;
	margin: -1px -1px 0 -1px;
	width: calc(100% + 2px)
}
@media only screen and (min-width:768px) {
	.home-featured-cat.mag-cat-style-15 .cat-left {
		margin: -1px 0 0 -1px;
		width: calc(100% + 1px)
	}
}
.home-featured-cat.mag-cat-style-15 .cat-right {
	padding: 20px
}
.home-featured-cat-content.style-15 .mag-post-box.first-post .magcat-thumb {
	margin: 0
}
.home-featured-cat.mag-cat-style-15 .mag-post-box {
	position: relative
}
.home-featured-cat-content.style-15 .first-post .magcat-thumb:hover {
	opacity: 1
}
.home-featured-cat-content.style-15 .first-post .magcat-detail .mag-header {
	padding: 20px;
	margin: 0;
	position: absolute;
	left: 0;
	bottom: 0;
	width: 100%;
	z-index: 5
}
.home-featured-cat-content.style-15 .first-post .magcat-detail .mag-header:after {
	content: none;
	display: none
}
.home-featured-cat-content.style-15 .first-post .grid-post-box-meta span,
.home-featured-cat-content.style-15 .first-post .grid-post-box-meta span a,
.home-featured-cat-content.style-15 .first-post .magcat-detail h3 a {
	color: #fff
}
.home-featured-cat-content.style-15 .penci-image-holder.small-fix-size {
	width: 100px
}
.penci-home-popular-posts {
	padding: 25px 0 0;
	border: none;
	border-top: 1px solid #dedede;
	position: relative;
	margin-bottom: 60px
}
.penci-popular-posts-sc.hide-heading .penci-home-popular-posts,
.penci-popular-posts-sc .penci-home-popular-posts:not(.use-heading-default) {
	border-top: 0;
	padding-top: 0
}
.penci-home-popular-post,
.swiper.penci-home-popular-post {
	margin-left: -10px;
	margin-right: -10px;
	width: 100%;
	width: calc(100% + 20px)
}
.penci-home-popular-post .item-related h3 a {
	text-transform: uppercase
}
.home-pupular-posts-title {
	position: absolute;
	left: 0;
	width: 100%;
	top: 0;
	transform: translateY(-55%);
	-webkit-transform: translateY(-55%);
	-moz-transform: translateY(-55%);
	text-align: center;
	font-size: 18px;
	color: #313131;
	text-transform: uppercase
}
.home-pupular-posts-title a,
.home-pupular-posts-title span {
	font-size: inherit;
	color: inherit;
	padding: 0 18px;
	line-height: 1;
	display: inline-block;
	background: #fff;
	text-decoration: none !important
}
.home-pupular-posts-title.pcalign-right {
	text-align: right
}
.home-pupular-posts-title.pcalign-left {
	text-align: left
}
.home-pupular-posts-title.pcalign-left a,
.home-pupular-posts-title.pcalign-left span {
	padding-left: 0
}
.home-pupular-posts-title.pcalign-right a,
.home-pupular-posts-title.pcalign-right span {
	padding-right: 0
}
article.portfolio,
article.post,
article.type-post {
	margin-bottom: 60px
}
.penci-layout-classic-boxed-1 article.post,
.penci-layout-classic-grid article.post,
.penci-layout-classic-list article.post,
.penci-layout-standard-boxed-1 article.post,
.penci-layout-standard-grid article.post,
.penci-layout-standard-list article.post {
	margin-bottom: 60px
}
.single .post {
	margin-bottom: 60px
}
.penci-jarallax {
	width: 100%;
	padding-top: 50%;
	position: relative;
	z-index: 0
}
.penci-jarallax>.jarallax-img {
	position: absolute;
	object-fit: cover;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: -1
}
.post-image .mejs-container,
.post-image .mejs-overlay.load,
.post-image .wp-video,
.post-image video.wp-video-shortcode {
	width: 100% !important;
	height: 100% !important
}
.post-image .mejs-container {
	padding-top: 56.25%
}
.post-image .wp-video,
.post-image video.wp-video-shortcode {
	max-width: 100% !important
}
.post-image video.wp-video-shortcode {
	position: relative
}
.post-image .mejs-mediaelement {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0
}
.post-image .mejs-controls {
	z-index: 0 !important
}
.post-image .mejs-overlay-play {
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	width: auto !important;
	height: auto !important
}
.post-image .mejs-container.wp-audio-shortcode {
	padding-top: 0 !important
}
.container-single-fullwidth.two-sidebar .post-image {
	display: block;
	width: 100%
}
.penci-single-style-3:not(.penci-single-pheader-noimg).penci_sidebar #main article.post,
.penci-single-style-7:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
	padding-left: 10px;
	padding-right: 10px
}
.penci-single-style-16:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
	padding-left: 40px;
	padding-right: 40px;
	margin-left: 40px;
}
@media only screen and (min-width:961px) {
	.penci-single-style-3:not(.penci-single-pheader-noimg).container.penci_sidebar #main,
	.penci-single-style-16:not(.penci-single-pheader-noimg).container.penci_sidebar #main,
	.penci-single-style-7:not(.penci-single-pheader-noimg).container.penci_sidebar #main {
		position: relative;
		z-index: 10;
		padding-right: 30px
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg).container.penci_sidebar.two-sidebar #main,
	.penci-single-style-16:not(.penci-single-pheader-noimg).container.penci_sidebar.two-sidebar #main,
	.penci-single-style-7:not(.penci-single-pheader-noimg).container.penci_sidebar.two-sidebar #main {
		padding-right: 50px
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg) #main article.post,
	.penci-single-style-7:not(.penci-single-pheader-noimg) #main article.post {
		margin-top: -80px
	}
	.penci-single-style-16:not(.penci-single-pheader-noimg) #main article.post {
		margin-top: -220px;
	}
	.penci-single-style-3.penci_is_nosidebar #main article.post,
	.penci-single-style-16.penci_is_nosidebar #main article.post,
	.penci-single-style-7.penci_is_nosidebar #main article.post {
		margin-top: 0
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg).container.penci_sidebar.left-sidebar #main,
	.penci-single-style-16:not(.penci-single-pheader-noimg).container.penci_sidebar.left-sidebar #main,
	.penci-single-style-7:not(.penci-single-pheader-noimg).container.penci_sidebar.left-sidebar #main {
		padding-left: 40px;
		padding-right: 0
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg).penci_sidebar #main article.post,
	.penci-single-style-7:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
		background: #fff;
		padding-top: 20px
	}
	.penci-single-style-16:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
		background: #fff;
		padding-top: 40px
	}
	.penci-single-style-14:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
		background: #fff;
		padding-top: 40px;
		margin-top: -80px;
		position: relative;
		margin-left: 40px;
		padding-left: 40px;
	}
	.penci-single-style-17:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
		padding-left: 40px;
	}
	.penci-single-style-16:not(.penci-single-pheader-noimg).right-sidebar #main article.post {
		padding-left: 40px;
	}
	.penci-single-style-7:not(.penci-single-pheader-noimg).right-sidebar #main article.post {
		padding-left: 20px
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg).right-sidebar #main article.post {
		padding-right: 20px;
		padding-left: 0
	}
	.penci-single-style-3:not(.penci-single-pheader-noimg).left-sidebar #main article.post,
	.penci-single-style-16:not(.penci-single-pheader-noimg).left-sidebar #main article.post,
	.penci-single-style-7:not(.penci-single-pheader-noimg).left-sidebar #main article.post {
		padding-left: 20px
	}
	.penci-single-style-3:not(.penci_is_nosidebar) .standard-content-special,
	.penci-single-style-3:not(.penci_is_nosidebar) .standard-post-image .audio-iframe {
		bottom: 70px
	}
}
@media only screen and (min-width:1200px) {
	.penci-single-style-17 .penci-sidebar-right {
	  border-left: 1px solid var(--pcborder-cl);
	  padding-left: 30px;
	}
	.penci-single-style-17 .penci-sidebar-left {
	  border-right: 1px solid var(--pcborder-cl);
	  padding-right: 30px;
	}
}
.penci-single-4 .standard-post-special img {
	width: 100%
}
.penci-body-single-style-13.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-13.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-21.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-21.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-18.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-18.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-16.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-16.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-15.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-15.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-12.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-12.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-11.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-11.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-10.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-10.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-20.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-20.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-4.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-4.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-5.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-5.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-7.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-7.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header,
.penci-body-single-style-9.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) #header,
.penci-body-single-style-9.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .pc-wrapbuilder-header {
	margin-bottom: 0
}
.penci-body-single-style-10.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-20.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-4.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-5.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-7.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-16.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form,
.penci-body-single-style-9.penci-body-title-bellow.penci-show-pthumb:not(.penci-port-product) .penci-header-signup-form {
	margin-top: 10px;
	margin-bottom: 10px
}
.penci-body-single-style-4.single-format-video .post-image iframe,
.penci-body-single-style-5.single-format-video .post-image iframe,
.penci-body-single-style-7.single-format-video .post-image iframe,
.penci-body-single-style-16.single-format-video .post-image iframe,
.penci-video-format-vimeo iframe,
.penci-video-format-youtube iframe,
.standard-post-image.video-post iframe {
	width: 100%
}
.penci-video-format-youtube iframe,
.standard-post-image.video-post iframe {
	aspect-ratio: 16/9;
	height: auto
}
.standard-post-image.video-post .fluid-width-video-wrapper iframe {
	height: 100%;
	aspect-ratio: unset
}
.penci-video-format-youtube .fluid-width-video-wrapper iframe {
	aspect-ratio: unset
}
.player .vp-player-layout {
	left: 0 !important;
	width: 100% !important
}
.penci-single-featured-img {
	position: relative;
	width: 100%;
	background-color: #f5f5f5;
	display: block;
	vertical-align: top;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover;
	padding-top: 66.6667%
}
.standard-post-special_wrapper {
	position: absolute;
	left: 30px;
	right: 30px;
	bottom: 0;
	display: block;
	z-index: 10
}
.penci-single-style-21 .post-image {
	position: relative;
}
.penci-single-style-21 .post-image:after {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: rgba(74, 76, 83, 0.79);
	z-index: 1;
	content: '';
	background-image: url('data:image/svg+xml,<%3Fxml version="1.0" encoding="UTF-8"%3F><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="150" height="1" viewBox="0 0 151 1"><defs><clipPath id="clip-Custom_Size_1"><rect width="150" height="1" transform="translate(150 1801)"/></clipPath></defs><g id="Custom_Size_1" data-name="Custom Size – 1" transform="translate(0 -1801)" clip-path="url(%23clip-Custom_Size_1)"><rect width="1" height="5000" transform="translate(150 900.466)" fill="%23ffffff" opacity=".05"/></g></svg>');
}
.penci-single-style-21 .standard-post-special_wrapper {
	z-index: 3;
}
.penci-single-style-21 .standard-post-special_wrapper {
	top: 50%;
	transform: translateY(-50%);
	bottom: auto;
}  
.penci-single-style-21 .header-standard.header-classic {
	margin-bottom: 0;
}
.penci-author-img-wrapper .author {
	display: flex;
	flex-wrap: wrap;
	align-items: center;
	column-gap: 10px;
	justify-content: center;
	margin-top: 20px;
}
.penci-author-img-wrapper .author img {
	border-radius: 50%;
	max-width: 60px;
	height: auto;
}
.penci-author-img-wrapper .author-name {
	color: #fff;
	font-size: 16px;
}
.standard-post-image .standard-post-special_wrapper .audio-iframe,
.standard-post-special_wrapper .standard-content-special {
	position: static;
	margin-bottom: 23px
}
.penci-body-single-style-7 .standard-post-image .standard-post-special_wrapper .audio-iframe,
.penci-body-single-style-7 .standard-post-special_wrapper .standard-content-special,
.penci-body-single-style-11 .standard-post-image .standard-post-special_wrapper .audio-iframe,
.penci-body-single-style-11 .standard-post-special_wrapper .standard-content-special {
	margin-bottom: 70px
}
.penci-body-single-style-12 .standard-post-image .standard-post-special_wrapper .audio-iframe {
	margin-left: -40px;
	margin-right: -40px;
}
@media only screen and (min-width: 961px) {
	.penci-body-single-style-14 .standard-post-special .standard-content-special,
	.penci-body-single-style-14 .standard-post-image .audio-iframe {
		bottom: 80px;
		left: 40px;
	}
	.penci-body-single-style-15 .standard-post-special_wrapper .standard-content-special,
	.penci-body-single-style-15 .standard-post-image .audio-iframe {
		max-width: calc(var(--pcctain) - 60px);
	}
	.penci-body-single-style-16 .standard-content-special,
	.penci-body-single-style-16 .standard-post-image .audio-iframe {
		bottom: 220px;
		left: 40px;
		right: 40px;
	}
}
.penci-body-single-style-7 .penci_is_nosidebar .standard-post-image .standard-post-special_wrapper .audio-iframe,
.penci-body-single-style-7 .penci_is_nosidebar .standard-post-special_wrapper .standard-content-special {
	margin-bottom: 30px
}
.penci-body-single-style-5 .container-single .post-image {
	position: relative
}
.penci-body-single-style-5 .penci-move-title-above:after,
.penci-body-single-style-6 .penci-move-title-above:after,
.penci-body-single-style-7 .penci-move-title-above:after,
.penci-body-single-style-8 .penci-move-title-above:after {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	z-index: 1;
	bottom: 0;
	right: 0;
	background: linear-gradient(to bottom, transparent 50%, #000 90%);
	opacity: .7;
	transition: .3s
}
.penci-single-style-3 .single-breadcrumb,
.penci-single-style-4 .single-breadcrumb,
.penci-single-style-5 .single-breadcrumb,
.penci-single-style-6 .single-breadcrumb,
.penci-single-style-7 .single-breadcrumb,
.penci-single-style-9 .single-breadcrumb {
	text-align: center
}
.penci-single-pheader .container.two-sidebar,
.penci-single-pheader.container.two-sidebar,
.penci-single-style-10.container-single-magazine .container.two-sidebar,
.penci-single-style-20.container-single-magazine .container.two-sidebar,
.penci-single-style-13.container-single-magazine .container.two-sidebar,
.penci-single-style-15.container-single-magazine .container.two-sidebar,
.penci-single-style-9.container-single-magazine .container.two-sidebar {
	display: block
}
.penci-single-style-13.container-single-magazine .two-sidebar .penci-sidebar-content,
.penci-single-style-15.container-single-magazine .two-sidebar .penci-sidebar-content,
.penci-single-style-10.container-single-magazine .two-sidebar .penci-sidebar-content,
.penci-single-style-20.container-single-magazine .two-sidebar .penci-sidebar-content {
	width: 29.06%
}
@media only screen and (min-width: 1170px){
	.penci-body-single-style-11 .post-image:after {
		content: "";
		position: absolute;
		top: 0;
		left: 0;
		width: 100%;
		height: 100%;
		background: var(--pcbg-cl);
		z-index: 1;
		bottom: 0;
		right: 0;
		background: linear-gradient(to bottom, transparent 20%, var(--pcbg-cl) 100%);
		transition: .3s;
	}
}
@media only screen and (max-width: 1169px){
	.penci-body-single-style-11 .container.penci-breadcrumb {
		margin-top: 0;
	}
}
.penci-body-single-style-18 .penci-post-content-wrapper {
	background: linear-gradient(to top, var(--pcaccent-cl) 0%, rgba(255,255,255, 0.8) 100%);
	padding-top: 120px;
}
.penci-body-single-style-18 .penci-post-content-wrapper-inner {
	background: #fff;
	padding: 40px 40px 10px 40px;
}
.container.penci-single-style-18 {
	background: #fff;
	padding: 40px;
	overflow: hidden;
	box-shadow: 0 15px 35px 0 rgba(175, 181, 204, 0.35);
}
.penci-body-single-style-18 .container-single-fullwidth .post-image {
	margin-bottom: 0;
}
.penci-body-single-style-19 .header-standard {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 30px;
	margin-bottom: 35px;
}
@media only screen and (min-width:768px) {
	.container-single.penci-header-text-white .header-standard .post-title,
	.penci-header-text-white .cat>a.penci-cat-name,
	.penci-header-text-white .container.penci-breadcrumb a,
	.penci-header-text-white .container.penci-breadcrumb i,
	.penci-header-text-white .container.penci-breadcrumb span,
	.penci-header-text-white .header-standard .author-post span a,
	.penci-header-text-white .header-standard .post-title,
	.penci-header-text-white .header-standard h2,
	.penci-header-text-white .header-standard h2 a,
	.penci-header-text-white .pc_titlebig_standard,
	.penci-header-text-white .pc_titlebig_standard a,
	.penci-header-text-white .post-box-meta-single span,
	.penci-single-style-5.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name,
	.penci-single-style-6.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name,
	.penci-single-style-8.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name,
	.penci-single-style-11.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name {
		color: #fff
	}
}
.penci-single-style-10.penci-header-text-white .header-standard .author-post span a,
.penci-single-style-10.penci-header-text-white .header-standard .post-title,
.penci-single-style-10.penci-header-text-white .header-standard h2,
.penci-single-style-10.penci-header-text-white .header-standard h2 a,
.penci-single-style-10.penci-header-text-white .pc_titlebig_standard,
.penci-single-style-10.penci-header-text-white .pc_titlebig_standard a,
.penci-single-style-10.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name,
.penci-single-style-13.penci-header-text-white .post-box-meta-single span,
.penci-single-style-13.penci-header-text-white .header-standard .author-post span a,
.penci-single-style-13.penci-header-text-white .header-standard .post-title,
.penci-single-style-13.penci-header-text-white .header-standard h2,
.penci-single-style-13.penci-header-text-white .header-standard h2 a,
.penci-single-style-13.penci-header-text-white .pc_titlebig_standard,
.penci-single-style-13.penci-header-text-white .pc_titlebig_standard a,
.penci-single-style-13.penci-header-text-white .penci-standard-cat .cat>a.penci-cat-name,
.penci-single-style-13.penci-header-text-white .post-box-meta-single span {
	color: #fff
}
i.penci-post-countview-number {
	font-style: normal;
	font-size: inherit;
	font-weight: inherit;
	color: inherit
}
@media only screen and (max-width:767px) {
	.standard-post-special_wrapper {
		position: static;
		background: #fff;
		margin-bottom: 0;
		padding-top: 20px
	}
	.penci-single-style-16 .standard-post-special_wrapper,
	.penci-single-style-7 .standard-post-special_wrapper {
		background: 0 0
	}
	.penci-header-text-white .standard-post-special_wrapper .header-standard.header-classic {
		margin-bottom: 0
	}
	.penci-header-text-white .penci-move-title-above:after,
	.penci-header-text-white .standard-post-special_wrapper .container-single .post-image:after {
		content: none
	}
	.standard-post-image .standard-post-special_wrapper .audio-iframe,
	.standard-post-special_wrapper .standard-content-special {
		margin-bottom: 20px
	}
	.penci-header-text-white .format-post-box {
		display: block;
		padding: 20px
	}
	.penci-header-text-white .standard-content-special {
		box-shadow: none;
		-webkit-box-shadow: none;
		-moz-box-shadow: none
	}
	.pcsb-ft-o .standard-post-special_wrapper {
		position: absolute;
		left: 15px;
		right: 15px;
		bottom: 0;
		display: block;
		z-index: 10;
		background: unset;
		padding: 0
	}
}
.penci-single-style-9 .penci-post-image-wrapper {
	background-color: #111;
	padding-top: 40px;
	padding-bottom: 40px;
	margin-bottom: 40px;
	max-height: inherit
}
.penci-single-style-13 .penci-post-image-wrapper .post-image,
.penci-single-style-15 .penci-post-image-wrapper .post-image,
.penci-single-style-20 .penci-post-image-wrapper .post-image,
.penci-single-style-10 .penci-post-image-wrapper .post-image,
.penci-single-style-9 .penci-post-image-wrapper .post-image {
	margin-bottom: 0
}
.penci-single-style-10 .post-format-entry-header:after,
.penci-single-style-10 .post-format-entry-header:before,
.penci-single-style-15 .post-format-entry-header:after,
.penci-single-style-15 .post-format-entry-header:before,
.penci-single-style-13 .post-format-entry-header:after,
.penci-single-style-13 .post-format-entry-header:before {
	content: "";
	display: table;
	clear: both
}
.penci-single-style-10 .penci-post-image-wrapper {
	background-color: #111;
	padding-top: 40px;
	padding-bottom: 40px;
	max-height: inherit;
	margin-bottom: 40px
}
.penci-single-style-20 .post-format-entry-header {
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
	align-items: center;
}
.penci-single-style-20 .penci-post-image-wrapper {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-top: 40px;
	padding-bottom: 40px;
	max-height: inherit;
	margin-bottom: 40px
}
.penci-single-style-15 .penci-post-image-wrapper,
.penci-single-style-13 .penci-post-image-wrapper {
	max-height: inherit;
	margin-bottom: 45px;
	background: var(--pcaccent-cl);
}
.penci-single-style-10 .header-standard,
.penci-single-style-10 .post-box-meta-single,
.penci-single-style-15 .header-standard,
.penci-single-style-15 .post-box-meta-single,
.penci-single-style-13 .header-standard,
.penci-single-style-13 .post-box-meta-single {
	text-align: left
}
.penci-body-single-style-10.penci-hide-pthumb .post-format-entry-header .penci-sidebar-content,
.penci-body-single-style-20.penci-hide-pthumb .post-format-entry-header .penci-sidebar-content,
.penci-body-single-style-15.penci-hide-pthumb .post-format-entry-header .penci-sidebar-content,
.penci-body-single-style-13.penci-hide-pthumb .post-format-entry-header .penci-sidebar-content {
	width: 100%;
	float: none
}
.penci-single-style-15 .post-format-entry-header {
	position: relative;
}
.penci-single-style-15 .container.two-sidebar .penci-sidebar-content,
.penci-single-style-15 .penci-post-image-wrapper .penci-sidebar-content {
	position: absolute;
	z-index: 99;
	left: 0;
	background: #fff;
	padding: 30px;
	top: 50%;
	transform: translateY(-50%);
	width: 40%;
}
.penci-single-style-15 .penci-single-s15-content {
	width: 100vw;
	padding-left: 20%;
}
.penci-single-style-15 .penci-container-inside {
	width: var(--pcctain);
  	margin: 0 auto;
}
.penci-single-style-15 .penci-container-inside.penci-breadcrumb {
	padding-top: 30px;
}
.penci-single-style-15 .penci-container-inside.penci-breadcrumb a, 
.penci-single-style-15 .penci-container-inside.penci-breadcrumb i,
.penci-single-style-15 .penci-container-inside.penci-breadcrumb span, 
.penci-single-style-15 .penci-container-inside.penci-breadcrumb span a {
	color: #fff;
}
.penci-body-single-style-22 .container.penci-breadcrumb {
	margin-top: 10px;
}
.penci-body-single-style-16 .container.penci-breadcrumb,
.penci-body-single-style-11 .penci-breadcrumb,
.penci-body-single-style-12 .penci-breadcrumb,
.penci-body-single-style-14 .penci-breadcrumb,
.penci-body-single-style-16 .penci-breadcrumb,
.penci-body-single-style-17 .penci-breadcrumb,
.penci-body-single-style-18 .penci-breadcrumb,
.penci-body-single-style-19 .penci-breadcrumb,
.penci-body-single-style-22 .container.penci-breadcrumb,
.penci-body-single-style-22 .container-single .header-standard, 
.penci-body-single-style-22 .container-single .post-box-meta-single {
	text-align: center;
}
.penci-body-single-style-22 .container-single .header-standard {
	margin-bottom: 40px;
	padding-bottom: 35px;
	position: relative;
}
.penci-body-single-style-22 .container-single .header-standard:after {
	content: '';
	position: absolute;
	display: block;
	justify-content: center;
	background: var(--pcmeta-cl);
	width: 100px;
	height: 4px;
	align-self: center;
	bottom: 0;
	left: 50%;
	margin-left: -50px;
	transform: unset;
}   
.penci-body-single-style-22 .container-single-fullwidth .post-image {
	position: relative;
	overflow: visible;
	margin-bottom: 80px;
}
.penci-body-single-style-22 .post-image .penci-author-wrapper {
	position: absolute;
	bottom: -50px;
	left: 50%;
	right: 50%;
	z-index: 10;
	width: 100px;
	height: 100px;
	border-radius: 50%;
	overflow: hidden;
	background: #fff;
	padding: 5px;
	transform: translateX(-50%);
	box-shadow: 0 0 30px rgba(0,0,0,.08);
}
.penci-body-single-style-22 .post-image .penci-author-wrapper img {
  	border-radius: 50%;
}
@media only screen and (max-width: 960px) {
	.penci-body-single-style-22 .post-image .penci-author-wrapper {
	  width: 60px;
	  height: 60px;
	  bottom: -30px;
	}
	.penci-body-single-style-22 .container-single-fullwidth .post-image {
	  margin-bottom: 40px;
	}
}
@media only screen and (max-width: 1169px) {
	.penci-single-style-13 .penci-container-inside.penci-breadcrumb,
	.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content .single-header {
		max-width: 100%;
		float: none;
	}
	.penci-single-style-15 .penci-post-image-wrapper,
	.penci-single-style-13 .penci-post-image-wrapper {
		margin-bottom: 40px;
	}
	.penci-body-single-style-14 .penci-single-smore .container {
		padding-left: 0;
		padding-right: 0;
	}
	.penci-single-style-15 .container.two-sidebar .penci-sidebar-content, 
	.penci-single-style-15 .penci-post-image-wrapper .penci-sidebar-content {
		transform: unset;
	}
	.penci-single-style-15 .penci-single-s15-content {
		padding-left: 10%;
	}
	.penci-single-style-15 .penci-container-inside {
		max-width: 100%;
	} 
	.penci-single-style-19 .container.penci-breadcrumb,
	.penci-single-style-17 .container.penci-breadcrumb {
		padding-left: 0;
		padding-right: 0;
	}
	.penci-body-single-style-18 .penci-post-content-wrapper-inner {
		padding: 20px;
	}
	.penci-body-single-style-18 .penci-post-content-wrapper {
		padding-top: 30px;
	}
	.penci-single-style-20 .post-format-entry-header {
		flex-direction: column;
	}
	.penci-single-style-20 .penci-post-image-wrapper .penci-sidebar-content,
	.penci-single-style-20 .penci-single-s20-content {
		width: 100%;
	}
}
@media only screen and (max-width: 960px) {
	.penci-single-style-13 .post-format-entry-header {
		flex-direction: column;
	}
	.penci-single-style-15 .penci-single-s15-content {
		padding-left: 0;
		width: 100%;
	}
	.penci-single-style-16:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
		padding-left: 0;
		padding-right: 0;
		margin-left: 0;
	}
}
@media only screen and (max-width: 767px) {
	.penci-single-style-13.penci-show-ft-caption .penci-post-image-wrapper .penci-sidebar-content:after,
	.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:before,
	.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content:after {
		display: none;
	}
	.penci-single-style-13 .penci-container-inside.penci-breadcrumb,
	.penci-single-style-13 .penci-post-image-wrapper .penci-sidebar-content .single-header {
		padding: 0;
	}
	.penci-single-style-21 .standard-post-special_wrapper {
		position: absolute;
		left: 0;
		right: 0;
		bottom: 0;
		padding: 0 30px;
		display: block;
		z-index: 10;
		background: transparent;
		margin-bottom: 0;
		padding-top: 0;
	}
	.penci-single-style-21 .post-image:after {
		content: '';
	}
	.penci-single-style-21.container-single.penci-header-text-white .header-standard .post-title,
	.penci-single-style-21.penci-header-text-white .cat>a.penci-cat-name,
	.penci-single-style-21.penci-header-text-white .container.penci-breadcrumb a,
	.penci-single-style-21.penci-header-text-white .container.penci-breadcrumb i,
	.penci-single-style-21.penci-header-text-white .container.penci-breadcrumb span,
	.penci-single-style-21.penci-header-text-white .header-standard .author-post span a,
	.penci-single-style-21.penci-header-text-white .header-standard .post-title,
	.penci-single-style-21.penci-header-text-white .header-standard h2,
	.penci-single-style-21.penci-header-text-white .header-standard h2 a,	
	.penci-single-style-21.penci-header-text-white .pc_titlebig_standard,
	.penci-single-style-21.penci-header-text-white .pc_titlebig_standard a,
	.penci-single-style-21.penci-header-text-white .post-box-meta-single span {
		color: #fff
	}
	.penci-author-img-wrapper .author img {
		max-width: 30px;
	}
	.penci-author-img-wrapper .author-name {
		font-size: 12px;
	}
}
@media only screen and (max-width:479px) {
	.penci-single-style-9 .penci-post-image-wrapper {
		padding-top: 20px;
		padding-bottom: 20px
	}
}
.post-box-meta-single {
	text-align: center;
	margin: 6px 0 0;
	font-size: 14px
}
.post-box-meta-single span {
	color: #888
}
.header-standard .post-box-meta-single .author-post,
.header-standard .post-box-meta-single .author-post span a,
.header-standard .post-box-meta-single span {
	font-size: inherit
}
.post-box-meta-single span strong,
.post-box-meta-single span time {
	font-size: inherit;
	font-family: inherit;
	color: inherit
}
.post-box-meta-single a {
	color: #313131
}
.post-box-meta-single a:hover {
	color: var(--pcaccent-cl)
}
.post-box-meta-single>span:before,
.standard-top-meta>span:before {
	content: "";
	width: 0;
	height: 10px;
	margin: 0 13px;
	display: inline-block;
	background: 0 0 !important;
	border-right: 1px solid;
	opacity: .7
}
.post-box-meta-single>span:first-child:before,
.standard-top-meta>span:first-child:before {
	content: none;
	display: block
}
#wpadminbar {
	z-index: 9999
}
#wpadminbar:hover {
	z-index: 99999
}
.post-image {
	margin-bottom: 26px;
	text-align: center;
	vertical-align: top;
	overflow: hidden;
	position: relative
}
body.single .post-image:hover {
	overflow: initial;
}
.container-single-fullwidth .post-image {
	margin-bottom: 40px
}
.post-image img {
	max-width: 100%;
	height: auto
}
.post-image.audio iframe,
.standard-post-image.audio iframe {
	height: 166px;
	width: 100%
}
.container-single a[data-rel=penci-gallery-bground-content],
.container-single a[data-rel=penci-gallery-image-content],
.container-single-page a[data-rel=penci-gallery-image-content] {
	cursor: zoom-in
}
.penci-slick-slider {
	position: relative;
	opacity: 0;
	transition: .4s;
	-webkit-transition: .4s;
	-moz-transition: .4s;
	max-height: 500px
}
.penci-grid .penci-slick-slider,
.penci-masonry .penci-slick-slider {
	max-height: 250px;
	overflow: hidden
}
.penci-slick-slider img {
	width: 100%
}
.penci-slick-slider.loaded {
	opacity: 1;
	overflow: visible !important;
	max-height: none !important
}
.penci-slick-slider>button.slick-next,
.penci-slick-slider>button.slick-prev {
	position: absolute;
	width: 36px;
	height: 36px;
	display: inline-block;
	top: 50%;
	margin-top: -18px;
	cursor: pointer;
	outline: 0;
	opacity: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	text-align: center;
	line-height: 36px;
	background: #fff;
	z-index: 12;
	border-radius: 100%;
	-webkit-border-radius: 100%;
	-moz-border-radius: 100%;
	color: #313131;
	border: none
}
.penci-slick-slider>button.slick-prev {
	left: 30px
}
.penci-grid .penci-slick-slider>button.slick-prev,
.penci-masonry .penci-slick-slider>button.slick-prev {
	left: 20px
}
.penci-slick-slider>button.slick-next {
	right: 30px
}
.penci-grid .penci-slick-slider>button.slick-next,
.penci-masonry .penci-slick-slider>button.slick-next {
	right: 20px
}
.penci-slick-slider.loaded>button.slick-next,
.penci-slick-slider.loaded>button.slick-prev {
	opacity: .8
}
.penci-slick-slider.loaded>button.slick-next:hover,
.penci-slick-slider.loaded>button.slick-prev:hover,
.penci-slick-slider>button.slick-next:hover,
.penci-slick-slider>button.slick-prev:hover {
	opacity: 1
}
.penci-slick-slider>button.slick-next i,
.penci-slick-slider>button.slick-prev i {
	font-size: 20px;
	display: inline-block;
	line-height: 36px
}
.penci-grid .penci-slick-slider>button.slick-next,
.penci-grid .penci-slick-slider>button.slick-prev {
	opacity: .8
}
.penci-grid .penci-slick-slider:hover>button.slick-next,
.penci-grid .penci-slick-slider:hover>button.slick-prev {
	opacity: .8
}
.penci-grid .penci-slick-slider>button.slick-next:hover,
.penci-grid .penci-slick-slider>button.slick-prev:hover {
	opacity: 1
}
.penci-single-smaller-width {
	max-width: 780px
}
.post-entry {
	margin-bottom: 33px;
	line-height: 28px
}
.penci-custom-html-inside-content {
	margin-bottom: 20px
}
.post-entry.standard-post-entry {
	margin-bottom: 0
}
.post-entry:before {
	content: " ";
	display: table
}
.post-entry .inner-post-entry:after {
	content: " ";
	display: table;
	clear: both
}
.post-entry.page-has-margin {
	margin-bottom: 60px
}
.post-entry img {
	max-width: 100%;
	height: auto
}
.wpb_text_column {
	line-height: 1.8
}
.post-entry a:hover,
.wpb_text_column a:hover {
	text-decoration: underline
}
.elementor-widget-text-editor h1,
.elementor-widget-text-editor h2,
.elementor-widget-text-editor h3,
.elementor-widget-text-editor h4,
.elementor-widget-text-editor h5,
.elementor-widget-text-editor h6,
.elementor-widget-text-editor hr,
.post-entry h1,
.post-entry h2,
.post-entry h3,
.post-entry h4,
.post-entry h5,
.post-entry h6,
.post-entry hr,
.woocommerce .page-description h1,
.woocommerce .page-description h2,
.woocommerce .page-description h3,
.woocommerce .page-description h4,
.woocommerce .page-description h5,
.woocommerce .page-description h6,
.woocommerce .page-description hr,
.wpb_text_column h1,
.wpb_text_column h2,
.wpb_text_column h3,
.wpb_text_column h4,
.wpb_text_column h5,
.wpb_text_column h6,
.wpb_text_column hr {
	margin-bottom: 17px
}
.elementor-widget-text-editor .widget ul li,
.elementor-widget-text-editor p,
.post-entry .elementor-widget-text-editor p {
	font-size: inherit;
	line-height: inherit;
	font-family: inherit;
	font-weight: inherit;
	color: inherit;
	text-align: inherit
}
.post-entry p,
.woocommerce .page-description p,
.wpb_text_column p {
	margin-bottom: 17px
}
.post-entry h1,
.post-entry h2,
.post-entry h3,
.post-entry h4,
.post-entry h5,
.post-entry h6,
.woocommerce .page-description h1,
.woocommerce .page-description h2,
.woocommerce .page-description h3,
.woocommerce .page-description h4,
.woocommerce .page-description h5,
.woocommerce .page-description h6,
.wpb_text_column h1,
.wpb_text_column h2,
.wpb_text_column h3,
.wpb_text_column h4,
.wpb_text_column h5,
.wpb_text_column h6 {
	color: var(--pcheading-cl);
	letter-spacing: 0;
	line-height: 1.3em
}
.elementor-widget-text-editor h1,
.post-entry h1,
.woocommerce .page-description h1,
.wpb_text_column h1 {
	font-size: 24px
}
.elementor-widget-text-editor h2,
.post-entry h2,
.woocommerce .page-description h2,
.wpb_text_column h2 {
	font-size: 22px
}
.elementor-widget-text-editor h3,
.post-entry h3,
.woocommerce .page-description h3,
.wpb_text_column h3 {
	font-size: 20px
}
.elementor-widget-text-editor h4,
.post-entry h4,
.woocommerce .page-description h4,
.wpb_text_column h4 {
	font-size: 18px
}
.elementor-widget-text-editor h5,
.post-entry h5,
.woocommerce .page-description h5,
.wpb_text_column h5 {
	font-size: 16px
}
.elementor-widget-text-editor h6,
.post-entry h6,
.woocommerce .page-description h6,
.wpb_text_column h6 {
	font-size: 14px
}
.elementor-widget-text-editor hr,
.post-entry hr,
.woocommerce .page-description hr,
.wpb_text_column hr {
	border: 0;
	height: 0;
	border-bottom: 1px solid #dedede;
	clear: both
}
.post-password-form input[type=email],
.post-password-form input[type=number],
.post-password-form input[type=password],
.post-password-form input[type=text] {
	padding: 9px 20px;
	border: 1px solid #dedede;
	margin-bottom: 28px;
	font-size: 12px;
	font-weight: 400;
	font-family: var(--pcbody-font);
	max-height: 50px;
	outline: 0;
	height: 36px;
	line-height: 36px
}
.post-password-form input[type=submit] {
	padding: 0 20px;
	border: none;
	background: #313131;
	color: #fff;
	cursor: pointer;
	outline: 0;
	text-transform: uppercase;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	height: 36px;
	line-height: 36px;
	margin-left: 5px
}
.post-password-form input[type=submit]:hover {
	opacity: .85
}
.post-entry blockquote,
.woocommerce .page-description blockquote,
.wpb_text_column blockquote {
	padding: 0;
	position: relative;
	margin: 0 0 20px 0
}
.post-entry blockquote,
.post-entry blockquote p,
.woocommerce .page-description blockquote,
.woocommerce .page-description blockquote p,
.wpb_text_column blockquote,
.wpb_text_column blockquote p {
	font-size: 16px;
	color: #888;
	font-style: italic;
	line-height: 1.7;
	text-align: left
}
.post-entry blockquote p,
.woocommerce .page-description blockquote p,
.wpb_text_column blockquote p {
	margin: 0
}
.post-entry blockquote,
.woocommerce .page-description blockquote,
.wpb_text_column blockquote {
	position: relative;
	padding: 0 0 0 40px;
	border: none;
	overflow: hidden
}
.post-entry .wp-block-quote,
.woocommerce .page-description .wp-block-quote,
.wpb_text_column .wp-block-quote {
	padding-left: 1em;
	border-left: 4px solid #000
}
.post-entry blockquote:before,
.woocommerce .page-description blockquote:before,
.wpb_text_column blockquote:before {
	color: var(--pcaccent-cl);
	content: "\f101";
	font-family: penciicon;
	font-size: 22px;
	font-weight: 400;
	line-height: 1;
	font-style: normal;
	position: absolute;
	top: 6px;
	left: 2px
}
.post-entry blockquote .author,
.post-entry blockquote cite,
.woocommerce .page-description blockquote .author,
.woocommerce .page-description blockquote cite,
.wpb_text_column blockquote .author,
.wpb_text_column blockquote cite {
	display: block;
	font-size: 12px;
	text-transform: uppercase;
	margin-top: 7px;
	color: var(--pcaccent-cl);
	font-style: normal;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	overflow: hidden;
	text-align: left;
	position: relative;
	z-index: 1
}
.post-entry blockquote .author span,
.woocommerce .page-description blockquote .author span,
.wpb_text_column blockquote .author span {
	position: relative;
	display: inline-block;
	padding: 0 10px 0 0
}
.post-entry blockquote .author span:after,
.woocommerce .page-description blockquote .author span:after,
.wpb_text_column blockquote .author span:after {
	content: "";
	position: absolute;
	top: 50%;
	width: 90px;
	height: 1px;
	background: var(--pcaccent-cl);
	left: 100%;
	opacity: .8
}
.penci-single-link-pages {
	display: block;
	width: 100%
}
.penci-single-link-pages:after,
.penci-single-link-pages:before {
	content: "";
	display: table;
	clear: both
}
.penci-single-link-pages a {
	display: inline-block;
	margin: 0 4px 5px 4px;
	padding: 4px 7px;
	line-height: 1;
	border: 1px solid;
	color: inherit;
	text-decoration: none !important;
	transition: all .3s;
	-webkit-transition: all .3s
}
.penci-single-link-pages a:hover {
	opacity: .7
}
.elementor-widget-table-of-contents .elementor-toc__header-title {
	margin-bottom: 0
}
.post-entry .elementor-widget-table-of-contents ol,
.post-entry .elementor-widget-table-of-contents ul {
	padding: 0;
	margin-bottom: 0
}
.post-entry .elementor-widget-table-of-contents ol li,
.post-entry .elementor-widget-table-of-contents ul li {
	list-style-type: none
}
.post-entry.blockquote-style-2 blockquote {
	background: #f5f5f5;
	padding: 10px 20px 10px 24px
}
.post-entry.blockquote-style-2 blockquote:before {
	content: "";
	left: 0;
	position: absolute;
	height: 100%;
	top: 0;
	width: 4px;
	background: var(--pcaccent-cl)
}
.post-entry.blockquote-style-2 .author span {
	padding: 0 0 0 30px
}
.post-entry.blockquote-style-2 .author span:after {
	width: 20px;
	left: 0
}
.penci-pullqoute.align-left {
	max-width: 460px;
	float: left;
	width: 100%;
	margin-right: 20px
}
.penci-pullqoute.align-right {
	max-width: 460px;
	float: right;
	width: 100%;
	margin-left: 20px
}
.elementor-widget-text-editor ol,
.elementor-widget-text-editor ul,
.post-entry ol,
.post-entry ul,
.woocommerce .page-description ol,
.woocommerce .page-description ul {
	padding-left: 36px;
	margin-bottom: 20px
}
.elementor-widget-text-editor .penci-sidebar-content ol,
.elementor-widget-text-editor .penci-sidebar-content ul,
.post-entry .penci-sidebar-content ol,
.post-entry .penci-sidebar-content ul,
.woocommerce .page-description .penci-sidebar-content ol,
.woocommerce .page-description .penci-sidebar-content ul {
	padding-left: 0;
	margin-bottom: 0
}
.woocommerce-error::before,
.woocommerce-info::before,
.woocommerce-message::before {
	background-color: transparent !important
}
.elementor-widget-text-editor ol ol,
.elementor-widget-text-editor ol ul,
.elementor-widget-text-editor ul ol,
.elementor-widget-text-editor ul ul,
.post-entry ol ol,
.post-entry ol ul,
.post-entry ul ol,
.post-entry ul ul,
.woocommerce .page-description ol ol,
.woocommerce .page-description ol ul,
.woocommerce .page-description ul ol,
.woocommerce .page-description ul ul {
	margin: 2px 0;
	padding-left: 22px
}
.elementor-widget-text-editor .penci-sidebar-content ol ol,
.elementor-widget-text-editor .penci-sidebar-content ol ul,
.elementor-widget-text-editor .penci-sidebar-content ul ol,
.elementor-widget-text-editor .penci-sidebar-content ul ul,
.post-entry .penci-sidebar-content ol ol,
.post-entry .penci-sidebar-content ol ul,
.post-entry .penci-sidebar-content ul ol,
.post-entry .penci-sidebar-content ul ul,
.woocommerce .page-description .penci-sidebar-content ol ol,
.woocommerce .page-description .penci-sidebar-content ol ul,
.woocommerce .page-description .penci-sidebar-content ul ol,
.woocommerce .page-description .penci-sidebar-content ul ul {
	margin: 0;
	padding-left: 0
}
.elementor-widget-text-editor ul li,
.post-entry ul li,
.woocommerce .page-description ul li {
	margin-bottom: 6px;
	position: relative;
	list-style-type: square;
	line-height: 1.7
}
.elementor-widget-text-editor ol li,
.post-entry ol li,
.woocommerce .page-description ol li {
	margin-bottom: 2px;
	list-style: decimal
}
.elementor-widget-text-editor .penci-sidebar-content ol li,
.elementor-widget-text-editor .penci-sidebar-content ul li,
.post-entry .penci-sidebar-content ol li,
.post-entry .penci-sidebar-content ul li,
.woocommerce .page-description .penci-sidebar-content ol li,
.woocommerce .page-description .penci-sidebar-content ul li {
	list-style-type: none
}
.post-entry ol.wp-block-gallery,
.post-entry ul.wp-block-gallery {
	padding: 0
}
.sticky.post .post-header {
	border: 1px dashed #ddd;
	padding: 20px 0
}
.post-entry table {
	width: 100%;
	margin-bottom: 22px;
	border-collapse: collapse;
	border-left: 1px solid var(--pcborder-cl);
	border-right: 1px solid var(--pcborder-cl);
	border-top: 1px solid var(--pcborder-cl)
}
.post-entry td,
.post-entry th {
	padding: 12px;
	border-bottom: 1px solid var(--pcborder-cl);
	border-color: var(--pcborder-cl)
}
.post-entry th {
	font-weight: 700
}
.post-entry em strong {
	font-style: italic
}
.pencisc-button,
.post-entry .pencisc-button,
.woocommerce-product-details__short-description .pencisc-button {
	border: none;
	border-radius: 0;
	background: var(--pcaccent-cl);
	color: #fff;
	line-height: 1.3;
	padding: 10px 20px;
	text-align: center;
	transition: all .25s;
	font-size: 14px;
	text-transform: uppercase;
	cursor: pointer;
	display: inline-block;
	text-decoration: none !important
}
.pencisc-button i {
	margin-right: 5px
}
.pencisc-button.pencisc-icon-right i {
	margin: 0 0 0 5px
}
.pencisc-align-right {
	float: right;
	margin: 5px 0 20px 20px
}
.pencisc-align-left {
	float: left;
	margin: 5px 20px 20px 0
}
.pencisc-button.pencisc-full,
.post-entry .pencisc-button.pencisc-full,
.woocommerce-product-details__short-description .pencisc-button.pencisc-full {
	display: block;
	width: 100%;
	margin-left: 0;
	margin-right: 0
}
.pencisc-button,
.post-entry .pencisc-button.pencisc-small,
.woocommerce-product-details__short-description .pencisc-button.pencisc-small {
	padding: 7px 12px;
	font-size: 12px
}
.pencisc-button,
.post-entry .pencisc-button.pencisc-large,
.woocommerce-product-details__short-description .pencisc-button.pencisc-large {
	padding: 15px 30px;
	font-size: 18px
}
ul.penci_list_shortcode {
	list-style: none !important;
	list-style-type: none !important
}
.elementor-widget-text-editor ul.penci_list_shortcode,
.post-entry ul.penci_list_shortcode,
.woocommerce .page-description ul.penci_list_shortcode {
	padding-left: 19px
}
.heading1-style-1 .entry-content>h1,
.heading1-style-2 .entry-content>h1,
.heading2-style-1 .entry-content>h2,
.heading2-style-2 .entry-content>h2,
.heading3-style-1 .entry-content>h3,
.heading3-style-2 .entry-content>h3,
.heading4-style-1 .entry-content>h4,
.heading4-style-2 .entry-content>h4,
.heading5-style-1 .entry-content>h5,
.heading5-style-2 .entry-content>h5 {
	padding-bottom: 8px;
	border-bottom: 1px solid var(--pcborder-cl);
	overflow: hidden
}
.heading1-style-2 .entry-content>h1,
.heading2-style-2 .entry-content>h2,
.heading3-style-2 .entry-content>h3,
.heading4-style-2 .entry-content>h4,
.heading5-style-2 .entry-content>h5 {
	border-bottom-width: 0;
	position: relative
}
.heading1-style-2 .entry-content>h1:before,
.heading2-style-2 .entry-content>h2:before,
.heading3-style-2 .entry-content>h3:before,
.heading4-style-2 .entry-content>h4:before,
.heading5-style-2 .entry-content>h5:before {
	content: "";
	width: 50px;
	height: 2px;
	bottom: 0;
	left: 0;
	z-index: 2;
	background: var(--pcaccent-cl);
	position: absolute
}
.heading1-style-2 .entry-content>h1:after,
.heading2-style-2 .entry-content>h2:after,
.heading3-style-2 .entry-content>h3:after,
.heading4-style-2 .entry-content>h4:after,
.heading5-style-2 .entry-content>h5:after {
	content: "";
	width: 100%;
	height: 2px;
	bottom: 0;
	left: 20px;
	z-index: 1;
	background: var(--pcborder-cl);
	position: absolute
}
.heading1-style-3 .entry-content>h1,
.heading1-style-4 .entry-content>h1,
.heading2-style-3 .entry-content>h2,
.heading2-style-4 .entry-content>h2,
.heading3-style-3 .entry-content>h3,
.heading3-style-4 .entry-content>h3,
.heading4-style-3 .entry-content>h4,
.heading4-style-4 .entry-content>h4,
.heading5-style-3 .entry-content>h5,
.heading5-style-4 .entry-content>h5 {
	position: relative;
	padding-left: 20px
}
.heading1-style-3 .entry-content>h1:before,
.heading1-style-4 .entry-content>h1:before,
.heading2-style-3 .entry-content>h2:before,
.heading2-style-4 .entry-content>h2:before,
.heading3-style-3 .entry-content>h3:before,
.heading3-style-4 .entry-content>h3:before,
.heading4-style-3 .entry-content>h4:before,
.heading4-style-4 .entry-content>h4:before,
.heading5-style-3 .entry-content>h5:before,
.heading5-style-4 .entry-content>h5:before {
	width: 10px;
	height: 100%;
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	background: var(--pcaccent-cl)
}
.heading1-style-4 .entry-content>h1,
.heading2-style-4 .entry-content>h2,
.heading3-style-4 .entry-content>h3,
.heading4-style-4 .entry-content>h4,
.heading5-style-4 .entry-content>h5 {
	padding: 10px 20px;
	background: #f1f1f1
}
.heading1-style-5 .entry-content>h1,
.heading2-style-5 .entry-content>h2,
.heading3-style-5 .entry-content>h3,
.heading4-style-5 .entry-content>h4,
.heading5-style-5 .entry-content>h5 {
	position: relative
}
.heading1-style-5 .entry-content>h1:before,
.heading2-style-5 .entry-content>h2:before,
.heading3-style-5 .entry-content>h3:before,
.heading4-style-5 .entry-content>h4:before,
.heading5-style-5 .entry-content>h5:before {
	content: "";
	position: absolute;
	left: 0;
	bottom: 0;
	width: 200px;
	height: 50%;
	transform: skew(-25deg) translateX(0);
	background: var(--pcaccent-cl);
	z-index: -1;
	opacity: .4
}
.heading1-style-6 .entry-content>h1,
.heading2-style-6 .entry-content>h2,
.heading3-style-6 .entry-content>h3,
.heading4-style-6 .entry-content>h4,
.heading5-style-6 .entry-content>h5 {
	text-decoration: underline;
	text-underline-offset: 2px;
	text-decoration-thickness: 4px;
	text-decoration-color: var(--pcaccent-cl)
}
.penci_list_shortcode li {
	position: relative;
	list-style: none !important;
	padding-left: 20px !important
}
.penci_list_shortcode li:before {
	color: var(--pcaccent-cl);
	content: "\f00c" !important;
	width: 20px !important;
	height: auto !important;
	margin-left: -20px;
	display: inline-block;
	font: normal normal normal 14px/1 FontAwesome;
	font-size: inherit;
	text-rendering: auto;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	transform: none;
	background: 0 0 !important;
	transform: none !important;
	opacity: 1 !important;
	position: static !important;
	border: none !important
}
.penci_list_shortcode.penci_list-starlist li:before {
	content: "\f005" !important
}
.penci_list_shortcode.penci_list-pluslist li:before {
	content: "\f0fe" !important
}
.penci_list_shortcode.penci_list-minuslist li:before {
	content: "\f146" !important
}
.penci_list_shortcode.penci_list-editlist li:before {
	content: "\f044" !important
}
.penci_list_shortcode.penci_list-asterisklist li:before {
	content: "\f069" !important
}
.penci_list_shortcode.penci_list-thumbuplist li:before {
	content: "\f164" !important
}
.penci_list_shortcode.penci_list-folderlist li:before {
	content: "\f07b" !important
}
.penci_list_shortcode.penci_list-thumbdownlist li:before {
	content: "\f165" !important
}
.penci_list_shortcode.penci_list-heartlist li:before {
	content: "\f004" !important
}
.penci-highlight-black {
	-webkit-transition: color .3s;
	-moz-transition: color .3s;
	-o-transition: color .3s;
	transition: color .3s;
	background-color: rgba(0, 0, 0, .8);
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 rgba(0, 0, 0, .8), -8px 0 0 rgba(0, 0, 0, .8);
	color: gray
}
.penci-highlight-black:hover {
	color: #fff
}
.penci-highlighted-black {
	background-color: rgba(0, 0, 0, .8);
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 rgba(0, 0, 0, .8), -8px 0 0 rgba(0, 0, 0, .8);
	color: #fff
}
.penci-highlighted-red {
	background-color: red;
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 red, -8px 0 0 red;
	color: #fff
}
.penci-highlighted-blue {
	background-color: #3f51b5;
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 #3f51b5, -8px 0 0 #3f51b5;
	color: #fff
}
.penci-highlighted-green {
	background-color: green;
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 green, -8px 0 0 green;
	color: #fff
}
.penci-highlighted-yellow {
	background-color: #ffcb00;
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 #ffcb00, -8px 0 0 #ffcb00;
	color: #fff
}
.penci-highlighted-pink {
	background-color: pink;
	padding: 2px 0;
	margin: 0 7px 0 8px;
	box-shadow: 6px 0 0 pink, -8px 0 0 pink;
	color: #fff
}
.penci-tpadding-0,
.penci-tpadding-1,
.penci-tpadding-2,
.penci-tpadding-3,
.penci-tpadding-4,
.penci-tpadding-5,
.penci-tpadding-6,
.penci-tpadding-7 {
	display: block;
	margin-bottom: 17px
}
.penci-tpadding-1 {
	padding-left: 0;
	padding-right: 5%
}
.penci-tpadding-2 {
	padding-left: 5%;
	padding-right: 0
}
.penci-tpadding-3 {
	padding-left: 5%;
	padding-right: 5%
}
.penci-tpadding-4 {
	padding-left: 5%;
	padding-right: 10%
}
.penci-tpadding-5 {
	padding-left: 10%;
	padding-right: 5%
}
.penci-tpadding-6 {
	padding-left: 10%;
	padding-right: 10%
}
.penci-tpadding-7 {
	padding-left: 15%;
	padding-right: 15%
}
@media (max-width:767px) {
	.penci-tpadding-0,
	.penci-tpadding-1,
	.penci-tpadding-2,
	.penci-tpadding-3,
	.penci-tpadding-4,
	.penci-tpadding-5,
	.penci-tpadding-6,
	.penci-tpadding-7 {
		padding-left: 3% !important;
		padding-right: 3% !important
	}
}
.penci-dropcap-box {
	float: left;
	display: block;
	background-color: var(--pcaccent-cl);
	color: #fff;
	text-align: center;
	text-transform: uppercase;
	min-width: 56px;
	font-size: 48px;
	line-height: 50px;
	margin: 6px 13px 0 0;
	padding: 3px 13px
}
.penci-dropcap-box-outline {
	float: left;
	display: block;
	background-color: transparent !important;
	text-align: center;
	text-transform: uppercase;
	border: 2px solid var(--pcaccent-cl);
	color: var(--pcaccent-cl);
	min-width: 56px;
	font-size: 48px;
	line-height: 50px;
	margin: 6px 13px 0 0;
	padding: 3px 13px
}
.penci-dropcap-circle {
	-webkit-border-radius: 100%;
	-moz-border-radius: 100%;
	border-radius: 100%;
	float: left;
	display: block;
	background-color: var(--pcaccent-cl);
	color: #fff;
	text-align: center;
	text-transform: uppercase;
	min-width: 56px;
	font-size: 48px;
	line-height: 50px;
	margin: 6px 13px 0 0;
	padding: 3px 13px
}
.penci-dropcap-circle-outline {
	float: left;
	display: block;
	background-color: transparent !important;
	text-align: center;
	text-transform: uppercase;
	border: 2px solid var(--pcaccent-cl);
	color: var(--pcaccent-cl);
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	border-radius: 50%;
	min-width: 56px;
	font-size: 48px;
	line-height: 50px;
	margin: 6px 13px 0 0;
	padding: 3px 13px
}
.penci-dropcap-regular {
	float: left;
	display: block;
	text-align: center;
	text-transform: uppercase;
	background-color: transparent !important;
	color: var(--pcaccent-cl);
	font-size: 68px;
	line-height: 68px;
	margin: 0 13px 0 0;
	padding: 0
}
.penci-dropcap-bold {
	float: left;
	display: block;
	text-align: center;
	text-transform: uppercase;
	background-color: transparent !important;
	color: var(--pcaccent-cl);
	font-weight: 700;
	font-size: 68px;
	line-height: 68px;
	margin: 0 13px 0 0;
	padding: 0
}
.penci-ilrelated-posts {
	margin: 20px 0;
	overflow: hidden;
	padding: 17px 20px;
	border: 1px solid var(--pcborder-cl);
	width: 100%
}
.penci-ilrelated-posts.pcilrt-left {
	float: left;
	margin: 5px 20px 20px 0;
	max-width: 360px;
	width: 100%
}
.penci-ilrelated-posts.pcilrt-right {
	float: right;
	margin: 5px 0 20px 20px;
	max-width: 360px;
	width: 100%
}
.pcilrp-heading {
	margin-bottom: 20px;
	text-align: left
}
.pcilrp-heading span {
	font-size: 18px;
	line-height: 1.3;
	display: block;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	color: var(--pcheading-cl);
	letter-spacing: 0;
	padding-bottom: 10px;
	position: relative
}
.pcilrp-heading span:after {
	content: "";
	width: 50px;
	border-top: 1px solid var(--pcaccent-cl);
	display: block;
	position: absolute;
	bottom: 0;
	left: 0
}
.pcilrph-align-center {
	text-align: center
}
.pcilrph-align-center span:after {
	left: 50%;
	margin-left: -25px
}
.pcilrph-align-right {
	text-align: right
}
.pcilrph-align-right span:after {
	left: auto;
	right: 0
}
.penci-ilrelated-posts ul.pcilrp-content {
	margin-bottom: 0 !important
}
.penci-ilrelated-posts.pcilrt-grid ul.pcilrp-content li {
	line-height: unset
}
.penci-ilrelated-posts.pcilrt-list ul.pcilrp-content {
	padding-left: 18px
}
.penci-ilrelated-posts.pcilrt-list ul.pcilrp-content li {
	line-height: 1.6
}
.penci-ilrelated-posts.pcilrt-list ul.pcilrp-content li:last-child {
	margin-bottom: 0
}
.penci-ilrelated-posts ul.pcilrp-content li.pcilrp-item-grid {
	list-style-type: none
}
.pcilrt-grid .pcilrp-content {
	padding: 0 !important;
	margin-left: -10px;
	margin-right: -10px;
	display: flex;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap
}
.pcilrt-grid .pcilrp-item-grid {
	-ms-flex: 0 0 100%;
	flex: 0 0 100%;
	padding: 0 10px;
	margin-bottom: 20px
}
.pcilrt-grid .pcilrp-item-hidethumb {
	margin-bottom: 8px
}
.pcilrt-grid.pcilrt-col-2 .pcilrp-item-grid {
	flex: 0 0 50%
}
.pcilrt-grid.pcilrt-col-3 .pcilrp-item-grid {
	flex: 0 0 33.3333%
}
.pcilrt-grid .pcilrp-content>.pcilrp-item-grid:last-child {
	margin-bottom: 0
}
@media only screen and (min-width:961px) {
	.pcilrt-col-3 .pcilrp-content>.pcilrp-item-grid:nth-last-of-type(2),
	.pcilrt-col-3 .pcilrp-content>.pcilrp-item-grid:nth-last-of-type(3) {
		margin-bottom: 0
	}
}
@media only screen and (min-width:768px) {
	.pcilrt-col-2 .pcilrp-content>.pcilrp-item-grid:nth-last-of-type(2) {
		margin-bottom: 0
	}
}
@media only screen and (max-width:960px) {
	.pcilrt-grid.pcilrt-col-3 .pcilrp-item-grid {
		flex: 0 0 100%
	}
}
@media only screen and (max-width:767px) {
	.pcilrt-grid.pcilrt-col-2 .pcilrp-item-grid {
		flex: 0 0 100%
	}
	.penci-ilrelated-posts.pcilrt-left,
	.penci-ilrelated-posts.pcilrt-right {
		max-width: 100%
	}
}
.pcilrt-grid .pcilrp-flex {
	display: flex;
	-ms-flex-wrap: wrap;
	align-items: center;
	width: 100%
}
.pcilrp-flex .pcilrp-thumb {
	flex: 0 0 90px;
	margin-right: 20px;
	transition: all .3s
}
.pcilrp-flex .pcilrp-body {
	flex: 0 0 calc(100% - 110px)
}
.pcilrp-item-hidethumb .pcilrp-flex .pcilrp-body {
	flex: 0 0 100%
}
.pcilrt-thumbright .pcilrp-flex .pcilrp-thumb {
	order: 2;
	margin: 0 0 0 20px
}
.pcilrp-flex .pcilrp-thumb:hover {
	opacity: .85
}
.pcilrp-item-grid .pcilrp-title {
	line-height: 1.35
}
.penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a {
	color: var(--pctext-cl);
	line-height: 1.4;
	text-decoration: none;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 14px
}
.penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a:hover {
	color: var(--pcaccent-cl)
}
.pcilrp-meta {
	margin-top: 5px;
	font-size: 13px;
	color: var(--pcmeta-cl);
	line-height: 1.3
}
.pcilrp-meta span {
	margin-right: 10px;
	font-size: inherit;
	color: inherit
}
.pcilrp-meta span:last-child {
	margin-right: 0
}
.pcilrp-meta i {
	margin-right: 5px;
	opacity: .8
}
.gird-post-share {
	margin-top: 9px;
	position: relative;
	text-align: center
}
.gird-list-posts-share {
	background: #fff;
	display: inline-block;
	padding-right: 11px;
	position: relative;
	padding-left: 11px
}
.gird-post-share:before {
	position: absolute;
	width: 100%;
	top: 9px;
	height: 1px;
	content: "";
	left: 0;
	border-top: 1px solid #e9e9e9;
	border-bottom: 1px solid #e9e9e9
}
.gird-post-share a {
	margin: 0 4px;
	font-size: 14px;
	color: #939393
}
.gird-post-share a:hover {
	color: var(--pcaccent-cl)
}
.gird-post-share .gird-list-posts-share a:first-child {
	margin-left: 0
}
.share-box-grid.share-box-comments i {
	font-size: 15px
}
.tags-share-box {
	display: table;
	width: 100%;
	margin: 0;
	position: relative;
	padding: 19px 160px 18px 0;
	clear: both;
	border-top: 1px solid #dedede;
	font-size: 14px
}
.tags-share-box.center-box {
	text-align: center;
	padding: 15px 0
}
.tags-share-box.hide-tags.page-share {
	text-align: center;
	padding: 16px 0;
	position: relative;
	border-bottom: 1px solid #dedede;
	margin-bottom: -1px
}
.tags-share-box.hide-tags.page-share.pcnew-share {
	border-bottom: none;
	margin-bottom: 0;
	padding: 0
}
.tags-share-box.hide-tags.page-share.tags-share-box-2_3 {
	padding: 6px 20px
}
.tags-share-box.hide-tags.page-share .list-posts-share {
	vertical-align: middle;
	line-height: 16px
}
.tags-share-box.share-box-border-bot {
	border-bottom: 1px solid var(--pcborder-cl)
}
.post-tags {
	display: block;
	position: relative;
	z-index: 10;
	color: #888;
	margin-bottom: 0;
	line-height: 1.4;
	margin-top: 31px
}
.post-tags>span {
	display: inline-block;
	text-transform: uppercase;
	margin: 0 12px 0 0;
	font-style: italic;
	color: #888
}
.post-tags>span i {
	vertical-align: bottom
}
.post-tags.penci-post-sources > span,
.pc-search-suggest-term > a,
.container-single .post-entry .post-tags a {
	text-transform: uppercase;
	color: #888;
	padding: 5px 12px;
	margin-right: 8px;
	margin-bottom: 8px;
	display: inline-block;
	font-size: 11px !important;
	background: 0 0;
	border: 1px solid #dedede;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	outline: 0;
	font-weight: 400;
	line-height: 1.2
}
.post-tags.penci-post-sources > span {
	background: #000;
	color: #fff;
	font-style: normal;
  	font-weight: bold;
}
.post-tags.penci-post-sources > span::before {
	content: '\f0c1';
	font-family: 'FontAwesome';
	display: inline-block;
	margin-right: 4px;
	transform: rotate(85deg);
}
.pc-search-suggest-term > a:hover,
.container-single .post-entry .post-tags a:hover {
	background: var(--pcaccent-cl);
	color: #fff;
	border-color: var(--pcaccent-cl);
	text-decoration: none
}
.post-share {
	display: inline-block;
	position: absolute;
	z-index: 10;
	right: 0;
	top: 20px
}
.nc_socialPanel .nc_tweetContainer a.nc_tweet,
.swp_social_panel .nc_tweetContainer a.nc_tweet {
	color: #fff
}
.tags-share-box.center-box .post-share,
.tags-share-box.hide-tags.page-share .post-share {
	position: static
}
.tags-share-box.hide-tags.page-share .share-title {
	font-size: 12px;
	text-transform: uppercase;
	color: #313131;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	margin-right: 5px
}
.post-share .count-number-like {
	font-weight: 700;
	font-style: italic;
	font-size: 13px;
	color: var(--pcaccent-cl);
	vertical-align: top
}
.post-share .list-posts-share {
	display: inline-block;
	vertical-align: top
}
.post-share a {
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	font-size: 14px;
	margin: 0 0 0 10px;
	color: #313131;
	display: inline-block;
	vertical-align: top;
	position: relative
}
.post-share.hide-like-count .list-posts-share a:first-child {
	margin-left: 0
}
.post-share a.liked,
.post-share a:hover {
	color: var(--pcaccent-cl)
}
.post-share a.penci-post-like {
	margin-left: 5px
}
.tags-share-box .single-comment-o {
	color: #888
}
.tags-share-box .single-comment-o i {
	margin-right: 5px
}
.post-share a.penci-post-like:after,
.tags-share-box .single-comment-o:after {
	content: "";
	display: inline-block;
	width: 1px;
	height: 12px;
	margin: 4px 6px 0 20px;
	vertical-align: top;
	border: none;
	background-color: #dedede
}
.no-social-enabled.tags-share-box .single-comment-o:after {
	display: none
}
.tags-share-box .single-comment-o:after {
	margin-right: 20px
}
.tags-share-box .single-comment-o.hide-comments-o:after {
	display: none;
	content: none
}
.post-share a .dt-share {
	position: absolute;
	display: inline-block;
	font-size: 9px;
	font-family: var(--pchead-font);
	font-weight: 400;
	background: #313131;
	color: #fff;
	height: 20px;
	white-space: nowrap;
	line-height: 20px;
	text-align: center;
	z-index: 20;
	bottom: -45px;
	width: 60px;
	left: 50%;
	margin-left: -30px;
	opacity: 0;
	visibility: hidden;
	transition: all .2s ease-in-out;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out
}
.post-share a:hover .dt-share {
	opacity: 1;
	bottom: -30px;
	visibility: visible
}
.post-share a .dt-share:before {
	position: absolute;
	width: 0;
	height: 0;
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-bottom: 7px solid #313131;
	content: "";
	top: -7px;
	left: 50%;
	margin-left: -4px
}
article.page.type-page {
	margin-bottom: 60px
}
.tags-share-box.tags-share-box-top {
	border-bottom: 1px solid #dedede;
	margin-bottom: 33px
}
.tags-share-box.tags-share-box-2_3 {
	border: 1px solid #dedede;
	padding: 6px 15px
}
.tags-share-box.tags-share-box-2_3 .post-share {
	display: inline;
	position: relative;
	top: 0
}
.tags-share-box.tags-share-box-2_3 .post-share .list-posts-share {
	display: inline;
	vertical-align: middle
}
.tags-share-box.tags-share-box-2_3 .post-share:after,
.tags-share-box.tags-share-box-2_3 .post-share:before {
	content: "";
	width: 100%;
	clear: both
}
.tags-share-box.tags-share-box-2_3+.post-author {
	border-top: 0
}
.tags-share-box.tags-share-box-2_3 .penci-social-share-text {
	text-transform: uppercase;
	font-weight: 700;
	margin-right: 15px;
	font-size: 14px;
	top: 2px;
	color: #111;
	position: relative
}
.tags-share-box.tags-share-box-2_3 a.penci-post-like:after {
	content: none
}
.tags-share-box.tags-share-box-2_3 .post-share .count-number-like,
.tags-share-box.tags-share-box-2_3 .post-share a {
	color: #fff
}
.tags-share-box.tags-share-box-2_3 .penci-svg-line {
	vertical-align: middle;
	transform: translateY(-1px);
	-webkit-transform: translateY(-1px)
}
.tags-share-box.tags-share-box-2_3 .post-share-item {
	display: inline-block;
	margin: 5px 9px 5px 0;
	font-weight: 400;
	line-height: 32px;
	text-align: left;
	color: #fff;
	text-transform: none;
	height: 32px;
	border: 0;
	background-color: #111;
	padding: 0 12px;
	transition: opacity .3s;
	border-radius: 2px;
	vertical-align: middle
}
.tags-share-box-s2 .post-share .count-number-like,
.tags-share-box-s2 .post-share a,
.tags-share-box-s2 .post-share-item {
	color: #fff !important
}
.tags-share-box.tags-share-box-2_3 .post-share-plike {
	vertical-align: bottom
}
.tags-share-box.page-share .penci-social-share-text {
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 12px;
	text-transform: uppercase;
	vertical-align: middle
}
.tags-share-box.social-align-left {
	text-align: left !important
}
.tags-share-box.social-align-right {
	text-align: right !important
}
.tags-share-box.social-align-center {
	text-align: center !important
}
.post-author {
	margin: 0;
	overflow: hidden;
	padding: 38px 0 37px 0;
	border-top: 1px solid var(--pcborder-cl)
}
.abio-style-2,
.abio-style-3,
.abio-style-4 {
	padding: 20px;
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 30px
}
body.author .post-author {
	padding: 20px 20px;
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 40px
}
.abio-style-3,
.abio-style-4 {
	text-align: center
}
.abio-style-4 {
	margin-top: 80px;
	overflow: visible
}
.author-img {
	float: left;
	margin-right: 20px;
	overflow: hidden
}
.abio-style-3 .author-img,
.abio-style-4 .author-img {
	display: block;
	margin: 0 0 15px;
	float: none !important
}
.abio-style-4 .author-img {
	margin-top: -70px
}
.post-author .author-img img {
	margin: 0;
	border-radius: 100%;
	-webkit-border-radius: 100%;
	-moz-border-radius: 100%
}
.abio-style-3 .author-img img,
.abio-style-4 .author-img img {
	display: inline-block;
	vertical-align: top;
	border: 2px solid var(--pcborder-cl);
	box-shadow: 0 1px 2px 0 rgb(0 0 0 / 15%)
}
.abio-style-4 .author-img img {
	background-color: var(--pcbg-cl)
}
.bioimg-square .author-img img {
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
.bioimg-sround .author-img img {
	border-radius: 15px;
	-webkit-border-radius: 15px;
	-moz-border-radius: 15px
}
.post-author .author-content {
	margin-left: 120px
}
.abio-style-3 .author-content,
.abio-style-4 .author-content {
	margin-left: 0
}
.author-content h5 {
	font-size: 14px;
	margin: 0 0 15px;
	color: #313131;
	display: block;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-transform: uppercase
}
.author-content h5 a {
	display: inline-block;
	margin: 0;
	color: #313131
}
.author-content h5 a:hover {
	color: var(--pcaccent-cl)
}
.author-content p {
	margin-bottom: 16px
}
.abio-style-4 .author-content p {
	text-align: center
}
.author-content .author-social {
	font-size: 14px;
	color: #313131;
	margin-right: 10px
}
.author-content .bio-social .author-social:last-child {
	margin-right: 0
}
.author-content .author-social:hover {
	color: var(--pcaccent-cl)
}
.author-content .author-social i {
	vertical-align: top
}
.post-pagination {
	overflow: hidden;
	margin: 0;
	padding: 15px 0 15px;
	border-top: 1px solid #dedede
}
.post-pagination .prev-post {
	float: left;
	width: 50%
}
.post-pagination .next-post {
	float: right;
	text-align: right;
	width: 50%
}
.post-pagination span {
	margin: 0;
	display: inline-block;
	color: #888
}
.post-pagination span i {
	font-size: 15px;
	margin-right: 8px
}
.post-pagination span i.fa-angle-double-right {
	margin: 0 0 0 8px
}
.post-pagination .arrow {
	font-size: 64px;
	color: #ddd;
	line-height: 64px
}
.post-pagination .prev-post .arrow {
	float: left;
	margin-right: 18px
}
.post-pagination .next-post .arrow {
	float: right;
	margin-left: 18px
}
.pagi-text {
	margin-top: 6px
}
.post-pagination h5 {
	font-size: 14px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	padding: 0 25px 0 0;
	position: relative;
	text-transform: uppercase;
	line-height: 1.4
}
.post-pagination h5.next-title {
	padding: 0 0 0 25px
}
.post-pagination a {
	color: #313131
}
.post-pagination a:hover {
	color: var(--pcaccent-cl)
}
.penci-post-nav-thumb {
	width: 56px;
	min-width: 56px;
	height: 56px;
	margin-right: 15px;
	background-size: cover;
	background-position: center center;
	background-repeat: no-repeat
}
.penci-post-nav-thumb.nav-thumb-next {
	float: right;
	margin: 0 0 0 15px
}
.pcsb-pnavi .penci-post-nav-thumb {
	flex-shrink: 0
}
.post-related {
	overflow: hidden;
	margin: 0;
	text-align: center;
	padding: 36px 0 36px;
	border-top: 1px solid #dedede
}
#respond h3.comment-reply-title,
.post-title-box {
	position: relative;
	padding: 0;
	margin-bottom: 30px;
	text-align: center
}
#respond h3.comment-reply-title span,
.post-box-title {
	font-size: 18px;
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	color: #313131;
	position: relative;
	z-index: 10;
	display: inline-block;
	padding: 0 10px
}
#respond h3.comment-reply-title span:after,
#respond h3.comment-reply-title span:before,
.post-box-title:after,
.post-box-title:before {
	content: "";
	position: absolute;
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	display: block;
	top: 50%;
	margin-top: -1px;
	left: 100%
}
#respond h3.comment-reply-title span:before,
.post-box-title:before {
	left: auto;
	right: 100%
}
.penci-carousel {
	margin-left: -15px;
	margin-right: -15px;
	max-height: 220px
}
.penci-carousel.loaded {
	max-height: none
}
.penci-carousel button.slick-next,
.penci-carousel button.slick-prev {
	position: absolute;
	width: 36px;
	height: 36px;
	display: inline-block;
	top: 50%;
	margin-top: -18px;
	cursor: pointer;
	outline: 0;
	opacity: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	text-align: center;
	line-height: 36px;
	background: #fff;
	z-index: 12;
	border-radius: 100%;
	-webkit-border-radius: 100%;
	-moz-border-radius: 100%;
	color: #313131;
	border: none;
	font-size: 20px
}
.penci-carousel.loaded:hover button.slick-next,
.penci-carousel.loaded:hover button.slick-prev {
	opacity: .8
}
.penci-carousel.loaded button.slick-next:hover,
.penci-carousel.loaded button.slick-prev:hover {
	opacity: 1
}
.penci-carousel>button.slick-prev {
	left: 25px
}
.penci-carousel>button.slick-next {
	right: 25px
}
.penci-carousel>button.slick-next.slick-disabled,
.penci-carousel>button.slick-prev.slick-disabled {
	cursor: auto
}
.item-related {
	padding: 0 10px;
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s;
	text-align: center;
	position: relative
}
.penci-posts-related-grid {
	padding-bottom: 16px
}
.penci-related-grid-display,
.post-related .swiper {
	margin-left: -10px;
	margin-right: -10px;
	width: 100%;
	width: calc(100% + 20px)
}
.penci-related-grid-display .item-related {
	opacity: 1;
	margin: 0 0 20px;
	padding: 0 10px;
	width: 33.333333%;
	float: left
}
.penci-owl-carousel.penci-owl-loaded .item-related {
	opacity: 1
}
.penci-related-carousel .item-related-thumb {
	position: relative
}
.post-related-wrapper {
	position: relative
}
.penci-related-thumb-carousel {
	position: absolute;
	bottom: 30px;
	left: 0;
	right: 0;
	z-index: 9;
	padding: 0 30px
}
.penci-related-thumb-carousel.pcrl-style-8 {
	background: rgba(0, 0, 0, .5);
	bottom: 0
}
.penci-related-thumb-carousel .item-related-thumb {
	padding-left: 5px;
	padding-right: 5px;
	cursor: pointer;
	opacity: .8;
	transition: .3s all ease-in-out
}
.penci-related-thumb-carousel.pcrl-style-8 .item-related-thumb {
	padding-left: 10px;
	padding-right: 10px
}
.penci-related-thumb-carousel.pcrl-style-8 .item-related-thumb {
	padding-top: 30px;
	padding-bottom: 30px;
	border-bottom: 5px solid transparent;
	text-align: left
}
.penci-related-thumb-carousel.pcrl-style-8 h3 {
	color: #fff;
	font-size: 14px;
	overflow: hidden;
	display: -webkit-box;
	-webkit-line-clamp: 2;
	line-clamp: 2;
	-webkit-box-orient: vertical
}
.penci-related-thumb-carousel.pcrl-style-8 .swiper-slide-thumb-active .item-related-thumb {
	border-bottom-color: var(--pcaccent-cl)
}
.penci-related-thumb-carousel.pcrl-style-8 .swiper-slide-thumb-active h3 {
	color: var(--pcaccent-cl)
}
.penci-related-thumb-carousel.pcrl-style-8 span {
	color: rgba(255, 255, 255, .7);
	font-size: 12px;
	display: block;
	margin-bottom: 10px
}
.penci-related-thumb-carousel.pcrl-style-8 .swiper-slide-thumb-active span {
	color: #fff
}
.penci-related-thumb-carousel .item-related-thumb span.related-thumb {
	border: 3px solid rgba(255, 255, 255, .7)
}
.penci-related-thumb-carousel .item-related-thumb:hover,
.penci-related-thumb-carousel .swiper-slide-thumb-active .item-related-thumb {
	opacity: 1
}
.penci-related-thumb-carousel .swiper-slide-thumb-active .item-related-thumb span.related-thumb {
	border-color: var(--pcaccent-cl)
}
.penci-owl-carousel-slider .penci-owl-dots {
	position: static;
	height: 10px;
	clear: both;
	margin-top: 16px;
	text-align: center;
	margin-left: auto;
	margin-right: auto;
	transform: none !important
}
.penci-owl-carousel-slider .penci-owl-dots.disabled,
.penci-owl-carousel-slider .penci-owl-nav.disabled {
	display: none
}
.penci-related-carousel .penci-owl-dot span {
	width: 10px;
	height: 10px;
	display: inline-block;
	border-radius: 6px;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	font-size: 0;
	background: #fff;
	margin: 0 2px;
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	outline: 0;
	vertical-align: top;
	cursor: pointer;
	transition: all .2s ease-in-out;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	border: 2px solid var(--pcborder-cl)
}
.penci-owl-carousel-slider .penci-owl-dot.active span,
.penci-related-carousel .penci-owl-dot.active span {
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl)
}
.item-related img {
	width: 100%;
	height: auto
}
.item-related .item-related-inner>a {
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s;
	display: inline-block;
	margin-bottom: 17px;
	width: 100%;
	position: relative
}
.item-related .item-related-inner>a:hover {
	opacity: .85
}
#navigation .penci-megamenu .penci-mega-post a i,
.home-featured-cat-content.style-12 .penci-magcat-carousel .magcat-thumb .mag-post-thumb i,
.item-related .item-related-inner>a i,
.navigation .penci-megamenu .penci-mega-post a i,
.penci-grid.penci-fea-cat-style-13 li .item .thumbnail .icon-post-format {
	position: absolute;
	width: 36px;
	height: 36px;
	line-height: 32px;
	left: 50%;
	top: 50%;
	margin: -15px 0 0 -15px;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	font-size: 14px;
	transition: all .25s;
	-webkit-transition: all .25s;
	-moz-transition: all .25s;
	border: 2px solid rgba(255, 255, 255, .9);
	background: rgba(0, 0, 0, .4);
	color: rgba(255, 255, 255, .9);
	text-align: center
}
#navigation .penci-megamenu .penci-mega-post a i.fa-music:before,
.item-related>a i.fa-music:before,
.navigation .penci-megamenu .penci-mega-post a i.fa-music:before {
	margin-right: 2px
}
#navigation .penci-megamenu .penci-mega-post a i.fa-play:before,
.item-related>a i.fa-play:before,
.navigation .penci-megamenu .penci-mega-post a i.fa-play:before {
	margin-left: 2px
}
#navigation .penci-megamenu .penci-mega-post a:hover i,
.item-related>a:hover i,
.navigation .penci-megamenu .penci-mega-post a:hover i {
	opacity: 0;
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5)
}
.item-related h3 a {
	font-size: 14px;
	text-transform: uppercase;
	color: #313131;
	line-height: 1.4
}
.item-related h3 a:hover {
	color: var(--pcaccent-cl)
}
.item-related span.date {
	color: #888;
	display: inline-block;
	margin-top: 8px;
	font-size: 13px
}
ul.slick-dots {
	opacity: 0;
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s;
	list-style: none;
	text-align: center;
	display: block;
	clear: both;
	margin-top: 13px
}
.slick-slider.loaded ul.slick-dots {
	opacity: 1
}
ul.slick-dots li {
	display: inline-block;
	line-height: 1
}
ul.slick-dots li button {
	width: 12px;
	height: 12px;
	display: inline-block;
	border-radius: 6px;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	font-size: 0;
	background: #fff;
	margin: 0 5px;
	box-shadow: none;
	-webkit-box-shadow: none;
	-moz-box-shadow: none;
	outline: 0;
	vertical-align: top;
	cursor: pointer;
	transition: all .2s ease-in-out;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	border: 2px solid #dedede
}
ul.slick-dots li button:hover,
ul.slick-dots li.slick-active button {
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl)
}
.pcrlt-style-2 .item-related-inner {
	position: relative;
	text-align: left
}
.pcrlt-style-2 .item-related .item-related-inner>a {
	margin-bottom: 0
}
.pcrlt-style-2 .item-related .related-content {
	position: absolute;
	left: 0;
	right: 0;
	bottom: 0;
	padding: 15px;
	background: #000;
	background: linear-gradient(0deg, rgba(0, 0, 0, 1) 0, rgba(255, 255, 255, 0) 100%)
}
.pcrlt-style-2 .item-related .related-content h3 a,
.pcrlt-style-2 .item-related .related-content span {
	color: #fff
}
.pcrlt-style-2 a.penci-cat-name {
	position: absolute;
	top: 20px;
	left: 20px;
	z-index: 9;
	background-color: var(--pcaccent-cl);
	display: inline-block;
	width: auto;
	color: #fff;
	font-size: 12px;
	padding: 0 5px;
	line-height: 20px
}
.pcrlt-style-3 .related-content {
	background-color: #000;
	padding: 20px 10px;
	transition: all .1s ease-in-out;
	border: 1px solid transparent;
	border-bottom: none
}
.pcrlt-style-3 .item-related .item-related-inner>a {
	margin-bottom: 0
}
.pcrlt-style-3 .item-related .related-content h3 a,
.pcrlt-style-3 .item-related .related-content span {
	color: #fff
}
.pcrlt-style-3 .item-related-inner {
	display: flex;
	flex-wrap: wrap;
	flex-direction: column
}
.pcrlt-style-3 .item-related:nth-child(2n) .related-content {
	order: 1;
	background-color: var(--pcbg-cl);
	border: 1px solid var(--pcborder-cl);
	border-bottom: none
}
.pcrlt-style-3 .item-related:nth-child(2n) .related-content h3 a {
	color: var(--pcheading-cl)
}
.pcrlt-style-3 .item-related:nth-child(2n) .related-content span {
	color: var(--pcmeta-cl)
}
.pcrlt-style-3 .item-related:nth-child(2n) .related-thumb {
	order: 2
}
.pcrlt-style-4 .item-related-inner {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	text-align: left
}
.pcrlt-style-4 .item-related .item-related-inner>a {
	max-width: 160px;
	margin-bottom: 0
}
.pcrlt-style-4 .related-content {
	width: calc(100% - 160px);
	padding-left: 15px;
	display: flex;
	flex-wrap: wrap;
	align-content: center
}
.pcrlt-style-4 .item-related {
	width: 50%
}
.pcrlt-style-4 .penci-cat-name {
	font-size: 12px;
	display: inline-block;
	margin-bottom: 10px;
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font)
}
.pcrlt-style-5 .item-related .item-related-inner>a {
	margin-bottom: 0
}
.pcrlt-style-5 .related-content {
	position: relative;
	padding: 15px;
	width: 95%;
	margin: -10px 2.5% 0;
}
.pcrlt-style-5 .penci-owl-carousel .related-content {
	margin-bottom: 6px
}
.pcrlt-style-5 .penci-cat-name {
	position: absolute;
	top: -50px;
	left: 20px;
	z-index: 9;
	background-color: var(--pcaccent-cl);
	display: inline-block;
	width: auto;
	color: #fff;
	font-size: 12px;
	padding: 0 5px;
	line-height: 20px
}
.pcrlt-style-5 .penci-related-grid-display {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
}
.pcrlt-style-5 .penci-related-grid-display .item-related {
	display: flex;
	flex-shrink: 1;
	height: auto;
}
.pcrlt-style-5 .penci-related-grid-display .item-related .item-related-inner {
	position: relative;
}
.pcrlt-style-5 .penci-related-grid-display .related-content:before {
	content: '';
	position: absolute;
	top: -10px;
	height: 20px;
	left: 3px;
	right: 3px;
	background: var(--pcbg-cl);
	z-index: 1;
}
.pcrlt-style-5 .swiper .related-content {
	box-shadow: 0 3px 5px rgba(0, 0, 0, .2);
	background: var(--pcbg-cl);
}
.pcrlt-style-5 .penci-related-grid-display .item-related .item-related-inner:before {
	content: '';
	position: absolute;
	top: 0;
	left: 10px;
	right: 10px;
	bottom: 0;
	background: var(--pcbg-cl);
  	box-shadow: 0 3px 5px rgba(0, 0, 0, .2);
}
.pcrlt-style-5 .item-related .item-related-inner,
.pcrlt-style-6 .item-related .item-related-inner {
	width: 100%;
}
.pcrlt-style-6 .item-related .item-related-inner > a {
	margin-bottom: 0;
}
.pcrlt-style-6 .item-related-inner .related-content {
	padding: 20px;
}
.pcrlt-style-6 .penci-related-grid-display {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
}
.pcrlt-style-6 .penci-related-grid-display .item-related {
	display: flex;
	flex-shrink: 1;
	height: auto;
}
.pcrlt-style-6 .item-related .item-related-inner {
	height: 100%;
	border: 1px solid var(--pcborder-cl);
}
.pcrlt-style-6 .swiper .item-related {
	align-self: stretch;
}
@media only screen and (min-width:1170px) {
	.pcrlt-style-1 .penci-related-grid-display .item-related:nth-child(3n+1),
	.pcrlt-style-3 .penci-related-grid-display .item-related:nth-child(3n+1),
	.pcrlt-style-4 .penci-related-grid-display .item-related:nth-child(2n+1),
	.pcrlt-style-5 .penci-related-grid-display .item-related:nth-child(3n+1),
	.pcrlt-style-6 .penci-related-grid-display .item-related:nth-child(3n+1) {
		clear: both
	}
}
.penci-rlt-popup {
	position: fixed;
	bottom: 0;
	left: 0;
	z-index: 5000;
	background: #fff;
	box-shadow: 2px 10px 7px rgba(0, 0, 0, .2);
	width: 340px;
	max-height: 75%;
	overflow: hidden;
	padding: 0;
	-webkit-transform: translate(0, 100%);
	-moz-transform: translate(0, 100%);
	-ms-transform: translate(0, 100%);
	-o-transform: translate(0, 100%);
	transform: translate(0, 100%);
	-webkit-transition: all .6s cubic-bezier(.19, 1, .22, 1);
	-moz-transition: all .6s cubic-bezier(.19, 1, .22, 1);
	transition: all .6s cubic-bezier(.19, 1, .22, 1)
}
@media only screen and (min-width:961px) {
	.penci-vernav-enable.penci-vernav-poleft .penci-rltpopup-left {
		left: 330px
	}
	.penci-vernav-enable.penci-vernav-poright .penci-rltpopup-right {
		right: 330px
	}
}
.penci-rlt-popup.penci-rltpopup-right {
	left: auto;
	right: 0
}
.penci-rlt-popup.rltpopup-show-up {
	-webkit-transform: translate(0, 0);
	-moz-transform: translate(0, 0);
	-ms-transform: translate(0, 0);
	-o-transform: translate(0, 0);
	transform: translate(0, 0)
}
.penci-rlt-popup .penci-rtlpopup-content {
	padding: 20px
}
.penci-rlt-popup .penci-rtlpopup-content:after,
.penci-rlt-popup .penci-rtlpopup-content:before {
	content: "";
	display: table;
	clear: both
}
.penci-rlt-popup .rtlpopup-heading {
	font-size: 16px;
	text-transform: uppercase;
	margin-bottom: 16px;
	text-align: left;
	background: #111;
	color: #fff;
	padding: 8px 30px 8px 20px;
	line-height: 1.25;
	margin: 0;
	position: relative
}
.penci-rlt-popup .rltpopup-item {
	opacity: 0;
	visibility: hidden;
	-webkit-transform: translate(0, 10px);
	-moz-transform: translate(0, 10px);
	-ms-transform: translate(0, 10px);
	-o-transform: translate(0, 10px);
	transform: translate(0, 10px);
	-webkit-transition: all .3s ease-out;
	-moz-transition: all .3s ease-out;
	transition: all .3s ease-out;
	overflow: hidden;
	margin-bottom: 20px;
	padding-bottom: 20px;
	border-bottom: 1px solid #eaeaea
}
.penci-rlt-popup .penci-rtlpopup-content .rltpopup-item:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: none
}
.penci-rlt-popup.rltpopup-show-up .rltpopup-item {
	opacity: 1;
	visibility: visible;
	-webkit-transform: translate(0, 0);
	-moz-transform: translate(0, 0);
	-ms-transform: translate(0, 0);
	-o-transform: translate(0, 0);
	transform: translate(0, 0)
}
.penci-rlt-popup .rltpopup-thumbnail {
	display: block;
	float: left;
	width: 90px;
	margin: 0 20px 0 0;
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
.penci-rlt-popup .rltpopup-thumbnail:hover {
	opacity: .8
}
.penci-rlt-popup .rltpopup-meta {
	display: block;
	overflow: hidden
}
.penci-rlt-popup .rltpopup-meta .rltpopup-title {
	margin-bottom: 5px;
	color: #313131;
	display: block;
	font-size: 15px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	font-family: inherit;
	letter-spacing: 0;
	line-height: 1.35
}
.penci-rlt-popup .rltpopup-meta .rltpopup-title:hover {
	color: var(--pcaccent-cl)
}
.penci-rlt-popup .rltpopup-meta .date {
	letter-spacing: 0;
	color: #888;
	font-size: 13px
}
.penci-rlt-popup .penci-close-rltpopup {
	position: absolute;
	top: 50%;
	right: 6px;
	height: 24px;
	width: 24px;
	text-align: center;
	line-height: 22px;
	margin: -12px 0 0 0;
	padding: 0;
	border: 0;
	background: 0 0;
	color: #fff;
	outline: 0;
	box-shadow: none;
	font-size: 0 !important;
	opacity: .75;
	transition: opacity .3s;
	-webkit-transition: opacity .3s
}
.penci-rlt-popup .penci-close-rltpopup:hover {
	opacity: 1
}
.penci-rlt-popup .penci-close-rltpopup span {
	display: block;
	width: 20px;
	border-top: 1px solid;
	position: absolute;
	top: 50%;
	left: 0
}
.penci-rlt-popup .penci-close-rltpopup span:first-child {
	transform: rotate(-45deg);
	-webkit-transform: rotate(-45deg)
}
.penci-rlt-popup .penci-close-rltpopup span:last-child {
	transform: rotate(45deg);
	-webkit-transform: rotate(45deg)
}
.container.under-construction-page {
	text-align: center;
	margin-top: 232px;
	margin-bottom: 176px
}
.under-construction-page .under-title {
	font-size: 30px;
	color: #313131;
	text-transform: uppercase;
	margin: 0 0 8px
}
.under-construction-page .sub-title-content,
.under-construction-page .sub-title-content p {
	font-size: 16px;
	font-style: italic;
	margin: 0
}
.under-construction-page .sub-title-content a:hover {
	text-decoration: underline
}
.penci-countdown {
	text-align: center;
	margin: 71px 0 0 0
}
.penci-countdown .countdown-section {
	margin: 0 57px;
	display: inline-block
}
.penci-countdown .countdown-row .countdown-section:first-child {
	margin-left: 0
}
.penci-countdown .countdown-row .countdown-section:last-child {
	margin-right: 0
}
.penci-countdown .countdown-amount {
	font-size: 72px;
	color: var(--pcaccent-cl);
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	line-height: 1;
	display: block;
	text-align: center;
	letter-spacing: 3px
}
.penci-countdown .countdown-period {
	display: block;
	text-align: center;
	font-size: 20px;
	text-transform: uppercase;
	color: #313131;
	margin: 26px 0 0 0;
	line-height: 1;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.penci-column {
	margin-right: 4%;
	position: relative;
	float: left;
	min-height: 1px;
	display: block;
	padding: 0 !important;
	margin-bottom: 17px
}
.column-last {
	margin-right: 0 !important
}
.column-1-2 {
	width: 48%
}
.column-1-3 {
	width: 30.6666666667%
}
.column-2-3 {
	width: 65.3333333333%
}
.column-1-4 {
	width: 22%
}
.column-3-4 {
	width: 74%
}
#comments_pagination,
.penci-pagination {
	margin-bottom: 40px;
	overflow: hidden;
	clear: both;
	text-align: center
}
#comments_pagination {
	margin-bottom: 26px
}
.penci-pagination.align-left {
	text-align: left
}
.penci-pagination.align-center {
	text-align: center
}
.penci-pagination.align-right {
	text-align: right
}
.penci-pagenavi-shortcode {
	margin-top: 30px
}
.penci-pagination .disable-url,
.penci-pagination a {
	color: #999;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-transform: uppercase;
	font-size: 12px;
	display: inline-block;
	line-height: 1;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.penci-pagination .disable-url span {
	opacity: .5
}
.penci-pagination .disable-url i,
.penci-pagination a i {
	font-size: 14px;
	margin-left: 8px
}
.penci-fawesome-ver5 .penci-pagination .disable-url i,
.penci-fawesome-ver5 .penci-pagination a i {
	font-size: 12px
}
.penci-pagination .newer .disable-url i,
.penci-pagination .newer a i {
	margin: 0 8px 0 0
}
.penci-pagination a:hover {
	text-decoration: none;
	color: var(--pcaccent-cl)
}
.penci-pagination .newer,
.penci-pagination .older {
	display: inline-block
}
.penci-pagination .newer:after {
	content: "/";
	display: inline-block;
	margin: 0 16px 0 20px;
	font-family: var(--pchead-font);
	font-size: 12px;
	color: #999
}
.penci-pagination ul.page-numbers {
	list-style: none;
	display: inline-block;
	vertical-align: top;
	margin: 0;
	padding: 0
}
.penci-pagination ul.page-numbers li {
	display: inline-block;
	float: left;
	margin-right: 10px;
	margin-bottom: 0;
	list-style: none
}
.penci-pagination ul.page-numbers li:last-child {
	margin-right: 0
}
#comments_pagination a,
#comments_pagination span,
.penci-pagination ul.page-numbers li a,
.penci-pagination ul.page-numbers li span {
	padding: 0;
	min-width: 30px;
	height: 30px;
	text-align: center;
	line-height: 28px;
	font-size: 14px;
	display: inline-block;
	border: 1px solid #dedede;
	color: #888;
	text-decoration: none
}
#comments_pagination a,
#comments_pagination span,
.penci-pagination ul.page-numbers li a {
	padding: 0 5px
}
#comments_pagination a:hover,
.penci-pagination ul.page-numbers li a:hover {
	color: #313131;
	border-color: #999;
	text-decoration: none
}
#comments_pagination span,
.penci-pagination ul.page-numbers li span.current {
	color: #fff;
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	text-decoration: none
}
.penci-pagination ul.page-numbers li a i {
	font-size: 16px;
	line-height: 28px;
	margin-left: 2px;
	font-family: FontAwesome !important
}
.penci-fawesome-ver5 .penci-pagination ul.page-numbers li a i {
	font-family: "Font Awesome 5 Free" !important
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button {
	display: block;
	padding: 11px 10px;
	max-width: 400px;
	margin: 0 auto;
	border: 1px solid var(--pcborder-cl);
	line-height: 1.4;
	text-align: center;
	transition: all .25s;
	-webkit-transition: all .25s;
	background: #fff
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button .ajax-more-text {
	color: inherit;
	font-family: inherit;
	font-weight: inherit
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover {
	border-color: var(--pcaccent-cl)
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts {
	opacity: .8;
	color: #999 !important;
	border-color: #ececec !important;
	cursor: auto
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts span.ajaxdot:after {
	content: "...";
	font-size: inherit;
	color: inherit;
	font-family: inherit;
	font-weight: inherit
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button i {
	color: inherit
}
.penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts i {
	animation-name: pencirotate;
	-o-animation-name: pencirotate;
	-ms-animation-name: pencirotate;
	-webkit-animation-name: pencirotate;
	-moz-animation-name: pencirotate;
	animation-duration: .8s;
	-o-animation-duration: .8s;
	-ms-animation-duration: .8s;
	-webkit-animation-duration: .8s;
	-moz-animation-duration: .8s;
	animation-iteration-count: infinite;
	-o-animation-iteration-count: infinite;
	-ms-animation-iteration-count: infinite;
	-webkit-animation-iteration-count: infinite;
	-moz-animation-iteration-count: infinite;
	animation-timing-function: linear;
	-o-animation-timing-function: linear;
	-ms-animation-timing-function: linear;
	-webkit-animation-timing-function: linear;
	-moz-animation-timing-function: linear
}
@keyframes pencirotate {
	from {
		transform: rotate(360deg)
	}
	to {
		transform: rotate(0)
	}
}
@-o-keyframes pencirotate {
	from {
		-o-transform: rotate(360deg)
	}
	to {
		-o-transform: rotate(0)
	}
}
@-webkit-keyframes pencirotate {
	from {
		-webkit-transform: rotate(360deg)
	}
	to {
		-webkit-transform: rotate(0)
	}
}
@-moz-keyframes pencirotate {
	from {
		-moz-transform: rotate(360deg)
	}
	to {
		-moz-transform: rotate(0)
	}
}
p.no-comments {
	text-align: center;
	font-size: 16px
}
#footer-area {
	background: #171717;
	padding: 60px 0;
	text-align: center;
	position: relative;
	clear: both
}
#footer-section {
	padding: 0;
	background: #313131;
	text-align: center;
	color: #999;
	position: relative;
	background-repeat: no-repeat;
	background-size: cover;
	background-position: center center
}
.penci-footer-social-moved {
	background: #313131;
	border-top: 1px solid #ececec
}
.footer-socials-section {
	padding: 30px 0 15px;
	border-bottom: 1px solid #4a4a4a;
	text-align: center
}
.penci-footer-social-moved .footer-socials-section {
	border-bottom: none
}
ul.footer-socials {
	list-style: none;
	display: inline-block;
	vertical-align: top
}
ul.footer-socials li {
	float: none;
	display: inline-block;
	margin-right: 30px;
	margin-bottom: 15px
}
ul.footer-socials li:last-child {
	margin-right: 0
}
ul.footer-socials li a {
	line-height: 36px;
	display: inline-block;
	vertical-align: top
}
ul.footer-socials li a i {
	width: 36px;
	height: 36px;
	line-height: 34px;
	display: inline-block;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	background: 0 0;
	color: #999;
	border: 1px solid #999;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	-o-transition: all .2s ease-in-out;
	transition: all .2s ease-in-out;
	font-size: 14px;
	vertical-align: top
}
ul.footer-socials li a i svg {
	fill: #999
}
ul.footer-socials li a:hover i {
	background: var(--pcaccent-cl);
	color: #fff;
	border-color: var(--pcaccent-cl)
}
ul.footer-socials li a span {
	text-transform: uppercase;
	font-size: 14px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	color: #999;
	display: inline-block;
	margin-left: 10px;
	vertical-align: top;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s
}
ul.footer-socials li a:hover span {
	color: var(--pcaccent-cl)
}
.footer-social-remove-circle ul.footer-socials li a {
	line-height: 20px
}
.footer-social-remove-circle ul.footer-socials li a i,
.footer-social-remove-circle ul.footer-socials li a:hover i {
	border: none;
	background: 0 0;
	padding: 0;
	width: auto;
	height: auto;
	line-height: 20px
}
.footer-social-drop-line ul.footer-socials li a span {
	margin: 5px 0 0;
	display: block
}
.footer-social-remove-radius ul.footer-socials li a i {
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
.footer-social-remove-text ul.footer-socials li a span {
	display: none
}
.widget-social svg,
ul.footer-socials li svg {
	vertical-align: middle
}
.widget-social svg,
ul.footer-socials li svg {
	max-width: 16px;
	height: auto
}
.footer-logo-copyright {
	padding: 40px 0 73px;
	text-align: center
}
.footer-logo-copyright.footer-not-gotop {
	padding: 40px 0
}
.footer-logo-copyright.footer-not-logo {
	padding: 20px 0 62px
}
.footer-logo-copyright.footer-not-logo.footer-not-gotop {
	padding: 20px 0
}
#footer-logo {
	margin: 0 0 32px 0
}
#footer-logo a {
	display: inline-block;
	vertical-align: top
}
#footer-logo .penci-lazy[src*=penci-holder] {
	width: 0
}
#footer-copyright * {
	font-size: 14px;
	color: #999;
	line-height: 1.4;
	font-style: italic
}
#footer-copyright a {
	color: var(--pcaccent-cl)
}
#footer-copyright a:hover {
	text-decoration: underline
}
body.single-penci-block .penci-go-to-top-floating,
body.single-penci-block .penci-wrap-gprd-law {
	display: none !important
}
body.single-penci-block .clear-footer {
	margin-bottom: 0;
	height: 0
}
body.single-penci-block .pc-wrapbuilder-header {
	margin-bottom: 0
}
.footer-menu-wrap {
	display: block;
	text-align: center;
	margin-bottom: 10px
}
.footer-menu-wrap:before {
	content: "";
	display: table
}
.footer-menu-wrap:after {
	display: block;
	height: 0;
	clear: both;
	visibility: hidden;
	content: ""
}
div.footer-menu>ul,
ul.footer-menu {
	list-style: none;
	display: inline-block;
	vertical-align: top
}
.footer-menu li {
	display: inline-block;
	padding: 0 15px;
	position: relative;
	margin-bottom: 5px
}
#footer-section .footer-menu li a {
	color: #999
}
#footer-section .footer-menu li a:hover {
	color: var(--pcaccent-cl)
}
.footer-menu ul.sub-menu {
	display: none !important
}
#footer-section .go-to-top-parent {
	width: 100%;
	height: auto;
	display: block;
	position: absolute;
	left: 0;
	bottom: 17px;
	text-align: center;
	z-index: 10
}
#footer-section .go-to-top-parent span {
	color: #999;
	font-size: 12px;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	text-transform: uppercase;
	line-height: 1;
	display: inline-block;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
#footer-section .go-to-top-parent span:after,
#footer-section .go-to-top-parent span:before {
	content: " ";
	display: table
}
#footer-section .go-to-top-parent span:after {
	clear: both
}
#footer-section .go-to-top-parent i {
	font-size: 12px;
	z-index: 5;
	position: relative;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	color: #999;
	line-height: 1;
	margin-bottom: 3px
}
#footer-section .go-to-top:hover i,
#footer-section .go-to-top:hover span {
	color: #fff
}
.penci-go-to-top-floating {
	cursor: pointer;
	position: fixed;
	bottom: 20px;
	right: 20px;
	width: 40px;
	height: 40px;
	line-height: 40px;
	font-size: 16px;
	background-color: var(--pcaccent-cl);
	color: #fff;
	z-index: 99999;
	text-align: center;
	transform: translate3d(0, 80px, 0);
	-webkit-transform: translate3d(0, 80px, 0);
	-webkit-transition: transform .5s cubic-bezier(.55, 0, .05, 1.1) 0s, opacity .3s;
	transition: transform .5s cubic-bezier(.55, 0, .05, 1.1) 0s, opacity .3s
}
.penci-go-to-top-floating i[class^=penciicon-] {
	vertical-align: top;
	line-height: inherit
}
.penci-go-to-top-floating.show-up {
	transform: translate3d(0, 0, 0);
	-webkit-transform: translate3d(0, 0, 0);
	-moz-transform: translate3d(0, 0, 0);
	-ms-transform: translate3d(0, 0, 0);
	-o-transform: translate3d(0, 0, 0)
}
.penci-go-to-top-floating:hover {
	opacity: .85
}
.penci-go-to-top-floating i {
	font-size: inherit;
	line-height: inherit;
	color: inherit
}
.penci-go-to-top-floating.pgtt-style-2 {
	border-radius: 50%;
}
.penci-go-to-top-floating.pgtt-style-3 {
	border-radius: 50%;
	background: var(--pcbg-cl);
	color: var(--pcaccent-cl);
	box-shadow: 0px 5px 20px 0px rgba(0, 0, 0, 0.15);
}  
.textwidget {
	line-height: 1.8
}
#widget-area {
	overflow: hidden;
	margin: 0;
	padding: 60px 0;
	background: #fff;
	position: relative;
	border-top: 1px solid #ececec;
	background-repeat: no-repeat;
	background-size: cover;
	background-position: center center
}
#widget-area>.container {
	position: relative;
	z-index: 3
}
#widget-area>.container:after,
#widget-area>.container:before {
	content: "";
	display: table;
	clear: both
}
.footer-widget-wrapper {
	width: 31%;
	margin-right: 3.5%;
	float: left
}
.footer-widget-wrapper.footer-widget-style-2 {
	width: 32.1666%
}
.footer-widget-wrapper.footer-widget-style-2.last {
	width: 64.3334%
}
.footer-widget-wrapper.footer-widget-style-3 {
	width: 64.3334%
}
.footer-widget-wrapper.footer-widget-style-3.last {
	width: 32.1666%
}
.footer-widget-wrapper.footer-widget-style-4 {
	width: 22.75%;
	margin-right: 3%
}
.footer-widget-wrapper.footer-widget-style-5,
.footer-widget-wrapper.footer-widget-style-6,
.footer-widget-wrapper.footer-widget-style-7 {
	width: 23.25%
}
.footer-widget-wrapper.footer-widget-style-5:first-child,
.footer-widget-wrapper.footer-widget-style-6:nth-child(2),.footer-widget-wrapper.footer-widget-style-7:last-child {
	width: 46.5%
}
.footer-widget-wrapper.footer-widget-style-8,
.footer-widget-wrapper.footer-widget-style-9 {
	width: 23.5%
}
.footer-widget-wrapper.footer-widget-style-8:last-child,
.footer-widget-wrapper.footer-widget-style-9:first-child {
	width: 73%
}
.footer-widget-wrapper.footer-widget-style-10 {
	width: 48%;
	margin-right: 4%
}
#widget-area .footer-widget-wrapper.last {
	margin-right: 0
}
.footer-widget-wrapper>.widget:last-child {
	margin-bottom: 0 !important
}
.widget input {
	font-weight: 400
}
.penci-button,
.widget button[type=submit],
.widget input[type=submit] {
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.penci-sidebar-content.pcsb-boxed-whole {
	padding: 20px;
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 60px
}
.penci-sidebar-content .widget {
	width: 100%;
	margin-right: 0;
	float: none;
	margin-bottom: 60px;
	clear: both
}
.penci-sidebar-content.pcsb-boxed-widget .widget {
	padding: 20px;
	border: 1px solid var(--pcborder-cl)
}
.penci-sidebar-content.pcsb-boxed-whole .widget:last-child {
	margin-bottom: 0
}
.penci-sidebar-content img {
	max-width: 100%;
	height: auto;
	vertical-align: top
}
.penci-sidebar-content .widget-title {
	color: #313131;
	margin-bottom: 30px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	position: relative;
	text-align: center;
	line-height: 1.3;
	background: 0 0
}
body.ehf-header .featuredsl-customizer,
body.ehf-header .penci-header-wrap {
	display: none
}
body.ehf-footer #footer-section,
body.ehf-footer #widget-area,
body.ehf-footer .clear-footer,
body.ehf-footer .footer-instagram,
body.ehf-footer .footer-subscribe,
body.ehf-footer .penci-footer-social-media {
	display: none
}
.penci-sidebar-content.pcalign-left .widget-title {
	text-align: left
}
.penci-sidebar-content.pcalign-right .widget-title {
	text-align: right
}
.penci-homepage-title.style-10,
.penci-homepage-title.style-11,
.penci-homepage-title.style-12,
.penci-homepage-title.style-13,
.penci-homepage-title.style-2,
.penci-homepage-title.style-3,
.penci-homepage-title.style-4,
.penci-homepage-title.style-5,
.penci-homepage-title.style-6,
.penci-homepage-title.style-7,
.penci-homepage-title.style-8,
.penci-homepage-title.style-9,
.penci-sidebar-content.style-10 .widget-title,
.penci-sidebar-content.style-11 .widget-title,
.penci-sidebar-content.style-12 .widget-title,
.penci-sidebar-content.style-13 .widget-title,
.penci-sidebar-content.style-14 .widget-title,
.penci-sidebar-content.style-2 .widget-title,
.penci-sidebar-content.style-3 .widget-title,
.penci-sidebar-content.style-4 .widget-title,
.penci-sidebar-content.style-5 .widget-title,
.penci-sidebar-content.style-6 .widget-title,
.penci-sidebar-content.style-7 .widget-title,
.penci-sidebar-content.style-8 .widget-title,
.penci-sidebar-content.style-9 .widget-title {
	margin-left: 0;
	margin-right: 0;
	margin-top: 0
}
.penci-homepage-title.style-14 {
	margin-left: 6px;
	margin-right: 6px;
	margin-top: 0
}
.penci-homepage-title.style-2:before,
.penci-sidebar-content.style-2 .penci-border-arrow:before {
	bottom: -4px
}
.penci-border-arrow.penci-homepage-title.style-2:after,
.penci-sidebar-content.style-2 .penci-border-arrow:after {
	width: 0;
	height: 0;
	border-style: solid;
	border-color: transparent;
	bottom: -2px;
	left: 50%;
	top: auto;
	right: auto;
	border-width: 6px;
	border-bottom: 0;
	margin-left: -6px;
	z-index: 5;
	border-top-color: #fff;
	background: 0 0 !important
}
.penci-homepage-title.style-2 .inner-arrow,
.penci-sidebar-content.style-2 .penci-border-arrow .inner-arrow {
	border-width: 2px
}
.penci-homepage-title.style-1.pcalign-left:before,
.penci-homepage-title.style-2.pcalign-left:after,
.penci-homepage-title.style-2.pcalign-left:before,
.penci-sidebar-content.style-1.pcalign-left .penci-border-arrow:before,
.penci-sidebar-content.style-2.pcalign-left .penci-border-arrow:after,
.penci-sidebar-content.style-2.pcalign-left .penci-border-arrow:before {
	left: 19px;
	right: auto
}
.penci-homepage-title.style-1.pcalign-right:before,
.penci-homepage-title.style-2.pcalign-right:after,
.penci-homepage-title.style-2.pcalign-right:before,
.penci-sidebar-content.style-1.pcalign-right .penci-border-arrow:before,
.penci-sidebar-content.style-2.pcalign-right .penci-border-arrow:after,
.penci-sidebar-content.style-2.pcalign-right .penci-border-arrow:before {
	left: auto;
	right: 19px
}
.penci-homepage-title.style-1.pcalign-center:before,
.penci-homepage-title.style-2.pcalign-center:after,
.penci-homepage-title.style-2.pcalign-center:before {
	left: 50%;
	margin-left: -6px;
	right: auto
}
.penci-homepage-title.style-3:after,
.penci-homepage-title.style-3:before,
.penci-homepage-title.style-4:after,
.penci-homepage-title.style-4:before,
.penci-homepage-title.style-5:after,
.penci-homepage-title.style-5:before,
.penci-homepage-title.style-6:after,
.penci-homepage-title.style-6:before,
.penci-homepage-title.style-7:after,
.penci-homepage-title.style-7:before,
.penci-homepage-title.style-8:after,
.penci-homepage-title.style-8:before,
.penci-homepage-title.style-9:after,
.penci-homepage-title.style-9:before,
.penci-sidebar-content.style-3 .penci-border-arrow:after,
.penci-sidebar-content.style-3 .penci-border-arrow:before,
.penci-sidebar-content.style-4 .penci-border-arrow:after,
.penci-sidebar-content.style-4 .penci-border-arrow:before,
.penci-sidebar-content.style-5 .penci-border-arrow:after,
.penci-sidebar-content.style-5 .penci-border-arrow:before,
.penci-sidebar-content.style-6 .penci-border-arrow:after,
.penci-sidebar-content.style-6 .penci-border-arrow:before,
.penci-sidebar-content.style-7 .penci-border-arrow:after,
.penci-sidebar-content.style-7 .penci-border-arrow:before,
.penci-sidebar-content.style-8 .penci-border-arrow:after,
.penci-sidebar-content.style-8 .penci-border-arrow:before,
.penci-sidebar-content.style-9 .penci-border-arrow:after,
.penci-sidebar-content.style-9 .penci-border-arrow:before {
	content: none
}
.penci-homepage-title.style-3.pcalign-center .inner-arrow,
.penci-homepage-title.style-3.pcalign-left .inner-arrow,
.penci-sidebar-content.style-3.pcalign-center .penci-border-arrow .inner-arrow,
.penci-sidebar-content.style-3.pcalign-left .penci-border-arrow .inner-arrow {
	border-left-width: 6px
}
.penci-homepage-title.style-3.pcalign-right .inner-arrow,
.penci-sidebar-content.style-3.pcalign-right .penci-border-arrow .inner-arrow {
	border-right-width: 6px
}
.pc-flexmnld,
.penci-homepage-title.style-4,
.penci-sidebar-content.style-4 .penci-border-arrow {
	overflow: hidden
}
.pc-flexmnld .penci-homepage-title.style-4,
.pc-flexmnld .penci-sidebar-content.style-4 .penci-border-arrow {
	overflow: visible
}
.elementor-widget-penci-block-heading .pc-flexmnld {
	overflow: visible
}
.penci-homepage-title.style-4 .inner-arrow,
.penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow {
	padding: 0 12px;
	border: none;
	display: inline-block;
	background: 0 0 !important
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow>span {
	position: relative;
	padding: 0 12px
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4.pcalign-left .inner-arrow>span,
.penci-homepage-title.style-4.pcalign-left .inner-arrow,
.penci-sidebar-content.style-4.pcalign-left .penci-border-arrow .inner-arrow {
	padding-left: 0
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4.pcalign-right .inner-arrow>span,
.penci-homepage-title.style-4.pcalign-right .inner-arrow,
.penci-sidebar-content.style-4.pcalign-right .penci-border-arrow .inner-arrow {
	padding-right: 0
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow {
	overflow: hidden
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow>span:after,
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow>span:before,
.penci-homepage-title.style-4 .inner-arrow:after,
.penci-homepage-title.style-4 .inner-arrow:before,
.penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow:before {
	position: absolute;
	content: "";
	width: 1200px;
	height: 0;
	top: 50%;
	left: 100%;
	border: none;
	border-bottom: 1px solid;
	z-index: 1;
	opacity: .5
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow:after,
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow:before {
	display: none
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow>span:before,
.penci-homepage-title.style-4 .inner-arrow:before,
.penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow:before {
	left: auto;
	right: 100%
}
.elementor-widget-penci-block-heading .penci-homepage-title.style-4 .inner-arrow {
	display: block
}
.penci-homepage-title.style-5,
.penci-homepage-title.style-7,
.penci-homepage-title.style-9,
.penci-sidebar-content.style-5 .penci-border-arrow,
.penci-sidebar-content.style-7 .penci-border-arrow,
.penci-sidebar-content.style-9 .penci-border-arrow {
	border-bottom: 2px solid #313131
}
.penci-homepage-title.style-5 .inner-arrow,
.penci-sidebar-content.style-5 .penci-border-arrow .inner-arrow {
	display: inline-block;
	border-bottom-width: 2px;
	margin-bottom: -2px !important
}
.penci-homepage-title.style-5.pcalign-left .inner-arrow,
.penci-sidebar-content.style-5.pcalign-left .penci-border-arrow .inner-arrow {
	border-left-width: 2px
}
.penci-homepage-title.style-5.pcalign-right .inner-arrow,
.penci-sidebar-content.style-5.pcalign-right .penci-border-arrow .inner-arrow {
	border-right-width: 2px
}
.penci-homepage-title.style-6 .inner-arrow,
.penci-sidebar-content.style-6 .penci-border-arrow .inner-arrow {
	background: 0 0 !important;
	padding: 0 !important;
	border: none !important
}
.penci-homepage-title.style-7,
.penci-sidebar-content.style-7 .penci-border-arrow {
	border-bottom-width: 3px
}
.penci-homepage-title.style-9,
.penci-sidebar-content.style-9 .penci-border-arrow {
	border-bottom-width: 1px
}
.penci-homepage-title.style-7 .inner-arrow,
.penci-homepage-title.style-9 .inner-arrow,
.penci-sidebar-content.style-7 .penci-border-arrow .inner-arrow,
.penci-sidebar-content.style-9 .penci-border-arrow .inner-arrow {
	background: 0 0 !important;
	padding: 0 0 8px 0;
	border: none
}
.penci-homepage-title.style-7 .inner-arrow:before,
.penci-homepage-title.style-9 .inner-arrow:before,
.penci-sidebar-content.style-7 .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-9 .penci-border-arrow .inner-arrow:before {
	content: "";
	width: 40px;
	height: 3px;
	position: absolute;
	bottom: -3px;
	background: var(--pcaccent-cl)
}
.penci-homepage-title.style-9 .inner-arrow:before,
.penci-sidebar-content.style-9 .penci-border-arrow .inner-arrow:before {
	bottom: -2px
}
.penci-homepage-title.style-7.pcalign-center .inner-arrow:before,
.penci-homepage-title.style-9.pcalign-center .inner-arrow:before,
.penci-sidebar-content.style-7.pcalign-center .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-9.pcalign-center .penci-border-arrow .inner-arrow:before {
	left: 50%;
	margin-left: -20px
}
.penci-homepage-title.style-7.pcalign-left .inner-arrow:before,
.penci-homepage-title.style-9.pcalign-left .inner-arrow:before,
.penci-sidebar-content.style-7.pcalign-left .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-9.pcalign-left .penci-border-arrow .inner-arrow:before {
	left: 0;
	margin: 0
}
.penci-homepage-title.style-7.pcalign-right .inner-arrow:before,
.penci-homepage-title.style-9.pcalign-right .inner-arrow:before,
.penci-sidebar-content.style-7.pcalign-right .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-9.pcalign-right .penci-border-arrow .inner-arrow:before {
	right: 0;
	margin: 0
}
.penci-homepage-title.style-8 .inner-arrow,
.penci-sidebar-content.style-8 .penci-border-arrow .inner-arrow {
	background-repeat: no-repeat;
	background-position: center center;
	background-size: auto 100%;
	border: none !important;
	padding-top: 13px;
	padding-bottom: 12px
}
.penci-homepage-title.style-8.pcalign-left .inner-arrow,
.penci-sidebar-content.style-8.pcalign-left .penci-border-arrow .inner-arrow {
	background-position: left center
}
.penci-homepage-title.style-8.pcalign-right .inner-arrow,
.penci-sidebar-content.style-8.pcalign-right .penci-border-arrow .inner-arrow {
	background-position: right center
}
.penci-homepage-title.style-8.pcalign-center .inner-arrow,
.penci-sidebar-content.style-8.pcalign-center .penci-border-arrow .inner-arrow {
	background-position: center center
}
.penci-homepage-title.style-10,
.penci-sidebar-content.style-10 .penci-border-arrow {
	border-top: 3px solid #313131;
	border-bottom: 1px solid #dedede
}
.penci-homepage-title.style-10 .inner-arrow,
.penci-sidebar-content.style-10 .penci-border-arrow .inner-arrow {
	background: 0 0 !important;
	border: none !important;
	padding: 9px 0 !important
}
.penci-sidebar-content.style-10 .penci-border-arrow:after,
.penci-sidebar-content.style-10 .penci-border-arrow:before,
.penci-sidebar-content.style-11 .penci-border-arrow:after,
.penci-sidebar-content.style-11 .penci-border-arrow:before,
.penci-sidebar-content.style-12 .penci-border-arrow:after,
.penci-sidebar-content.style-12 .penci-border-arrow:before,
.penci-sidebar-content.style-13 .penci-border-arrow:after,
.penci-sidebar-content.style-13 .penci-border-arrow:before,
.penci-sidebar-content.style-14 .penci-border-arrow:after,
.penci-sidebar-content.style-14 .penci-border-arrow:before {
	content: none
}
.penci-homepage-title.style-10:after,
.penci-homepage-title.style-10:before,
.penci-homepage-title.style-11:after,
.penci-homepage-title.style-11:before,
.penci-homepage-title.style-12:after,
.penci-homepage-title.style-12:before,
.penci-homepage-title.style-13:after,
.penci-homepage-title.style-13:before,
.penci-homepage-title.style-14:after,
.penci-homepage-title.style-14:before {
	content: none
}
.penci-homepage-title.style-11 .inner-arrow,
.penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow {
	border: none !important;
	background-color: #444;
	color: #fff;
	border-radius: 0 0 12px;
	padding-left: 25px;
	padding-right: 25px;
	display: inline-block;
	padding-top: 0;
	padding-bottom: 0;
	line-height: 34px
}
.penci-homepage-title.style-11 .inner-arrow:after,
.penci-homepage-title.style-11 .inner-arrow:before,
.penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:before {
	content: "";
	display: inline-block;
	position: absolute;
	top: 0;
	left: 0;
	width: 0;
	height: 0;
	z-index: 1;
	border-top: 20px solid #fff;
	border-right: 15px solid transparent
}
.penci-homepage-title.style-11 .inner-arrow:after,
.penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:after {
	border-right: none;
	border-top: none;
	border-bottom: 20px solid rgba(0, 0, 0, .3);
	border-left: 15px solid transparent;
	box-shadow: 2px 2px 2px rgba(0, 0, 0, .05)
}
.penci-homepage-title.style-12,
.penci-sidebar-content.style-12 .penci-border-arrow {
	border-bottom: 2px solid #313131
}
.penci-homepage-title.style-12 .inner-arrow,
.penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow {
	display: inline-block;
	margin-bottom: -2px;
	background-color: #313131;
	color: #fff;
	border: 0;
	padding-top: 0;
	padding-bottom: 0;
	line-height: 34px
}
.penci-homepage-title.style-12 .inner-arrow:before,
.penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow:before {
	content: "";
	display: inline-block;
	position: absolute;
	top: 0;
	width: 0;
	height: 0;
	border-bottom: 34px solid #000;
	border-right: 20px solid transparent;
	z-index: 1;
	right: -20px;
	opacity: .7;
	background-color: transparent !important
}
.penci-homepage-title.style-12.pcalign-center .inner-arrow:after,
.penci-homepage-title.style-12.pcalign-right .inner-arrow:after,
.penci-sidebar-content.style-12.pcalign-center .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-12.pcalign-right .penci-border-arrow .inner-arrow:after {
	content: "";
	display: inline-block;
	position: absolute;
	top: 0;
	width: 0;
	height: 0;
	border-bottom: 34px solid #000;
	border-left: 20px solid transparent;
	z-index: 1;
	left: -20px;
	opacity: .7;
	background-color: transparent !important
}
.penci-homepage-title.style-12.pcalign-right .inner-arrow:before,
.penci-sidebar-content.style-12.pcalign-right .penci-border-arrow .inner-arrow:before {
	content: none
}
.penci-homepage-title.style-13 .inner-arrow,
.penci-sidebar-content.style-13 .penci-border-arrow .inner-arrow {
	display: inline-block;
	margin-bottom: 0;
	background-color: #313131;
	color: #fff;
	border: 0;
	padding-top: 0;
	padding-bottom: 0;
	line-height: 34px
}
.penci-homepage-title.style-13.pcalign-right .inner-arrow:before,
.penci-sidebar-content.style-13.pcalign-right .penci-border-arrow .inner-arrow:before {
	content: none
}
.penci-homepage-title.style-13.pcalign-left .inner-arrow,
.penci-sidebar-content.style-13.pcalign-left .penci-border-arrow .inner-arrow {
	padding-right: 30px
}
.penci-homepage-title.style-13.pcalign-center .inner-arrow:after,
.penci-homepage-title.style-13.pcalign-center .inner-arrow:before,
.penci-homepage-title.style-13.pcalign-left .inner-arrow:after,
.penci-homepage-title.style-13.pcalign-right .inner-arrow:before,
.penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-13.pcalign-left .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-13.pcalign-right .penci-border-arrow .inner-arrow:before {
	content: "";
	display: inline-block;
	position: absolute;
	top: 0;
	width: 0;
	height: 0;
	z-index: 1;
	border-top: 16px solid transparent;
	border-bottom: 17px solid transparent
}
.penci-homepage-title.style-13.pcalign-center .inner-arrow:after,
.penci-homepage-title.style-13.pcalign-left .inner-arrow:after,
.penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:after,
.penci-sidebar-content.style-13.pcalign-left .penci-border-arrow .inner-arrow:after {
	border-right: 16px solid #fff;
	right: 0
}
.penci-homepage-title.style-13.pcalign-center .inner-arrow,
.penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow {
	padding-right: 30px;
	padding-left: 30px
}
.penci-homepage-title.style-13.pcalign-right .inner-arrow,
.penci-sidebar-content.style-13.pcalign-right .penci-border-arrow .inner-arrow {
	padding-right: 15px;
	padding-left: 30px
}
.penci-homepage-title.style-13.pcalign-center .inner-arrow:before,
.penci-homepage-title.style-13.pcalign-right .inner-arrow:before,
.penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-13.pcalign-right .penci-border-arrow .inner-arrow:before {
	left: 0;
	border-left: 15px solid #fff
}
.penci-homepage-title.style-14 .inner-arrow,
.penci-sidebar-content.style-14 .penci-border-arrow .inner-arrow {
	display: inline-block;
	margin-bottom: 0;
	background-color: transparent !important;
	color: #fff;
	border: 0;
	position: relative;
	padding-left: 25px;
	padding-right: 25px
}
.penci-homepage-title.style-11 .inner-arrow a,
.penci-homepage-title.style-12 .inner-arrow a,
.penci-homepage-title.style-13 .inner-arrow a,
.penci-homepage-title.style-14 .inner-arrow a {
	color: inherit
}
.penci-homepage-title.style-14 .inner-arrow:before,
.penci-sidebar-content.style-14 .penci-border-arrow .inner-arrow:before {
	background: #313131;
	-webkit-transform: skew(-20deg);
	-moz-transform: skew(-20deg);
	-o-transform: skew(-20deg);
	content: "";
	position: absolute;
	bottom: 0;
	top: 0;
	left: 0;
	right: 0;
	z-index: -1
}
.penci-homepage-title.style-15,
.penci-homepage-title.style-16,
.penci-homepage-title.style-18,
.penci-sidebar-content.style-15 .widget-title,
.penci-sidebar-content.style-16 .widget-title,
.penci-sidebar-content.style-18 .widget-title {
	margin-left: 0;
	margin-right: 0;
	margin-top: 0
}
.penci-homepage-title.style-15 .inner-arrow,
.penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow {
	background: #f2f2f2;
	border: none;
	padding-right: 48px
}
.penci-homepage-title.style-15.penci-border-arrow:before,
.penci-sidebar-content.style-15 .penci-border-arrow:before {
	width: 36px;
	display: block;
	top: 0;
	left: auto;
	right: 0;
	bottom: 0;
	height: 100%;
	background: #e6e6e6;
	z-index: 5;
	border: none;
	margin: 0
}
.penci-homepage-title.style-15.penci-border-arrow:after,
.penci-sidebar-content.style-15 .penci-border-arrow:after {
	left: auto;
	right: 0;
	bottom: auto;
	width: 36px;
	border: none;
	background: 0 0;
	border: none;
	z-index: 10;
	display: inline-block;
	content: "\f11a";
	font-size: 12px;
	font-family: penciicon;
	font-weight: 600;
	text-align: center;
	height: 24px;
	line-height: 24px;
	top: 50%;
	transform: translateY(-50%);
	margin: 0
}
.penci-homepage-title.style-15.pciconp-left .inner-arrow,
.penci-sidebar-content.style-15.pciconp-left .penci-border-arrow .inner-arrow {
	padding-right: 12px;
	padding-left: 48px
}
.penci-homepage-title.style-15.pciconp-left.penci-border-arrow:after,
.penci-homepage-title.style-15.pciconp-left.penci-border-arrow:before,
.penci-sidebar-content.style-15.pciconp-left .penci-border-arrow:after,
.penci-sidebar-content.style-15.pciconp-left .penci-border-arrow:before {
	left: 0;
	right: auto
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-left:after,
.penci-sidebar-content.style-15.pcicon-left .penci-border-arrow:after {
	content: "\f11d"
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-down:after,
.penci-sidebar-content.style-15.pcicon-down .penci-border-arrow:after {
	content: "\f11c"
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-up:after,
.penci-sidebar-content.style-15.pcicon-up .penci-border-arrow:after {
	content: "\f11d"
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-star:after,
.penci-sidebar-content.style-15.pcicon-star .penci-border-arrow:after {
	content: "\f005";
	font-family: FontAwesome;
	font-size: 14px
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-bars:after,
.penci-sidebar-content.style-15.pcicon-bars .penci-border-arrow:after {
	content: "\f0c9";
	font-family: FontAwesome;
	font-size: 14px
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-file:after,
.penci-sidebar-content.style-15.pcicon-file .penci-border-arrow:after {
	content: "\f0f6";
	font-family: FontAwesome;
	font-size: 14px
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-fire:after,
.penci-sidebar-content.style-15.pcicon-fire .penci-border-arrow:after {
	content: "\f06d";
	font-family: FontAwesome;
	font-size: 14px
}
.penci-homepage-title.style-15.penci-border-arrow.pcicon-book:after,
.penci-sidebar-content.style-15.pcicon-book .penci-border-arrow:after {
	content: "\f02d";
	font-family: FontAwesome;
	font-size: 14px
}
.penci-homepage-title.style-16.penci-border-arrow:before,
.penci-sidebar-content.style-16 .penci-border-arrow:before {
	content: none;
	display: none
}
.penci-homepage-title.style-16 .inner-arrow,
.penci-sidebar-content.style-16 .widget-title .inner-arrow {
	padding: 0 3px;
	border: none;
	background: 0 0 !important
}
.penci-homepage-title.style-16.penci-border-arrow:after,
.penci-sidebar-content.style-16 .penci-border-arrow:after {
	left: 0;
	right: 0;
	bottom: 0;
	top: auto;
	height: 10px;
	border: none;
	background: #efefef
}
.penci-homepage-title.style-17 .inner-arrow,
.penci-sidebar-content.style-17 .widget-title .inner-arrow {
	display: inline-block
}
.penci-homepage-title.style-18 .inner-arrow,
.penci-sidebar-content.style-18 .widget-title .inner-arrow {
	border: none !important;
	background: 0 0 !important
}
.penci-homepage-title.style-18.penci-border-arrow:after,
.penci-sidebar-content.style-18 .penci-border-arrow:after {
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	width: 100%;
	margin: 0;
	color: #dedede;
	background-image: linear-gradient(-45deg, transparent, transparent 30%, currentColor 30%, currentColor 50%, transparent 50%, transparent 80%, currentColor 80%);
	background-size: 5px 5px;
	background-color: transparent !important;
	border: none !important
}
.penci-homepage-title.style-18.penci-border-arrow:before,
.penci-sidebar-content.style-18 .penci-border-arrow:before {
	content: none;
	display: none
}
.penci-homepage-title.style-19.penci-border-arrow:after,
.penci-sidebar-content.style-19 .penci-border-arrow:after {
	background-image: linear-gradient(-90deg, transparent, transparent 30%, currentColor 30%, currentColor 50%, transparent 50%, transparent 80%, currentColor 80%)
}
.penci-homepage-title.style-20.penci-border-arrow:after,
.penci-sidebar-content.style-20 .penci-border-arrow:after {
	background-image: linear-gradient(0deg, transparent, transparent 30%, currentColor 30%, currentColor 50%, transparent 50%, transparent 80%, currentColor 80%)
}
.penci-homepage-title.style-21.penci-border-arrow,
.penci-homepage-title.style-21 .inner-arrow,
.penci-sidebar-content.style-21 .inner-arrow,
.penci-sidebar-content.style-21 .widget-title {
	border: 0;
	background: 0 0 !important;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0
}
.penci-homepage-title.style-21:after,
.penci-homepage-title.style-21:before,
.penci-sidebar-content.style-21 .widget-title:after,
.penci-sidebar-content.style-21 .widget-title:before {
	display: none
}
.penci-sidebar-content.style-21 .widget-title,
.penci-homepage-title.style-22.penci-border-arrow {
	display: block;
}
.penci-sidebar-content.style-21 .inner-arrow,
.penci-homepage-title.style-22.penci-border-arrow .inner-arrow {
	padding-top: 7px;
	background: transparent !important;
}
.penci-homepage-title.style-21 .inner-arrow span,
.penci-sidebar-content.style-21 .widget-title span {
	color: var(--pcheading-cl)
}
.penci-homepage-title.style-21 .inner-arrow>a:after,
.penci-homepage-title.style-21 .inner-arrow>span:after,
.penci-sidebar-content.style-21 .widget-title span:after {
	position: absolute;
	left: 0;
	bottom: 0;
	width: 100px;
	height: 2px;
	content: "";
	background: linear-gradient(90deg, var(--pcaccent-cl) 0, transparent 100%)
}
.penci-homepage-title.style-21.pcalign-right .inner-arrow>span:after,
.penci-homepage-title.style-21.pcalign-right .inner-arrow>a:after,
.penci-sidebar-content.style-21.pcalign-right .widget-title span:after {
	right: 0;
	left: auto;
	background: linear-gradient(90deg, transparent 0, var(--pcaccent-cl) 100%)
}
.penci-homepage-title.style-21.pcalign-center .inner-arrow>a:after,
.penci-homepage-title.style-21.pcalign-center .inner-arrow>span:after,
.penci-sidebar-content.style-21.pcalign-center .widget-title span:after {
	left: 50%;
	right: 50%;
	transform: translateX(-50%);
	background: linear-gradient(90deg, transparent 0, var(--pcaccent-cl) 50%, transparent 100%)
}
.penci-homepage-title.style-22.penci-border-arrow,
.penci-homepage-title.style-22 .inner-arrow,
.penci-sidebar-content.style-22 .inner-arrow,
.penci-sidebar-content.style-22 .widget-title {
	border: 0;
	background: 0 0;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0;
	display: inline-block
}
.penci-homepage-title.style-22.penci-border-arrow,
.penci-sidebar-content.style-22 .widget-title {
	display: block;
}
.penci-homepage-title.style-22:after,
.penci-homepage-title.style-22:before {
	display: none
}
.penci-homepage-title.style-22 .inner-arrow>a,
.penci-homepage-title.style-22 .inner-arrow>span,
.penci-sidebar-content.style-22 .widget-title>span {
	color: var(--pcheading-cl);
	letter-spacing: .05rem;
	z-index: 3;
	position: relative;
	background: var(--pcbg-cl);
	margin: 0 30px;
	padding: 0 10px
}
.penci-homepage-title.style-22 .inner-arrow:after,
.penci-homepage-title.style-22 .inner-arrow:before,
.penci-sidebar-content.style-22 .widget-title:after,
.penci-sidebar-content.style-22 .widget-title:before {
	position: absolute;
	left: 0;
	top: 50%;
	bottom: 50%;
	width: 8px;
	height: 8px;
	content: "";
	transform: translateY(-50%);
	background: var(--pcaccent-cl);
	z-index: 2;
	border-radius: 50%;
	border: 0
}
.penci-homepage-title.style-22 .inner-arrow:after,
.penci-sidebar-content.style-22 .widget-title:after {
	background: var(--pcborder-cl);
	left: 0;
	right: 0;
	height: 1px;
	z-index: 1;
	width: 100%
}
.penci-sidebar-content.style-22 .widget-title:after,
.penci-sidebar-content.style-22 .widget-title:before {
	display: block;
}
.penci-homepage-title.style-23.penci-border-arrow,
.penci-homepage-title.style-23 .inner-arrow,
.penci-sidebar-content.style-23 .inner-arrow,
.penci-sidebar-content.style-23 .widget-title {
	border: 0;
	background: 0 0 !important;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0
}
.penci-homepage-title.style-23:after,
.penci-homepage-title.style-23:before,
.penci-sidebar-content.style-23 .widget-title:after,
.penci-sidebar-content.style-23 .widget-title:before {
	display: none
}
.penci-homepage-title.style-23 .inner-arrow>a,
.penci-homepage-title.style-23 .inner-arrow>span,
.penci-sidebar-content.style-23 .widget-title>span {
	color: var(--pcheading-cl);
	letter-spacing: -.005rem;
	z-index: 3;
	padding: 0 0 0 35px;
	position: relative;
	display: inline-block
}
.penci-homepage-title.style-23 .inner-arrow>span:after,
.penci-homepage-title.style-23 .inner-arrow>span:before,
.penci-homepage-title.style-23 .inner-arrow>a:after,
.penci-homepage-title.style-23 .inner-arrow>a:before,
.penci-sidebar-content.style-23 .widget-title>span:after,
.penci-sidebar-content.style-23 .widget-title>span:before {
	position: absolute;
	left: 5px;
	top: 50%;
	bottom: 50%;
	width: 9px;
	height: 85%;
	content: "";
	transform: translateY(-50%) skew(-20deg);
	background: var(--pcaccent-cl);
	z-index: 2
}
.penci-homepage-title.style-23 .inner-arrow>a:after,
.penci-homepage-title.style-23 .inner-arrow>span:after,
.penci-sidebar-content.style-23 .widget-title>span:after {
	left: 17px;
	background: var(--pcborder-cl)
}
.penci-homepage-title.style-24.penci-border-arrow,
.penci-homepage-title.style-24 .inner-arrow,
.penci-sidebar-content.style-24 .inner-arrow,
.penci-sidebar-content.style-24 .widget-title {
	border: 0;
	background: 0 0 !important;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0
}
.penci-homepage-title.style-24:after,
.penci-homepage-title.style-24:before,
.penci-sidebar-content.style-24 .widget-title:after,
.penci-sidebar-content.style-24 .widget-title:before {
	display: none
}
.penci-homepage-title.style-24 .inner-arrow>a,
.penci-homepage-title.style-24 .inner-arrow>span,
.penci-sidebar-content.style-24 .widget-title>span {
	color: var(--pcheading-cl);
	padding: 0 0 10px;
	z-index: 3;
	position: relative;
	display: inline-block
}
.penci-homepage-title.style-24 .inner-arrow>a:after,
.penci-homepage-title.style-24 .inner-arrow>a:before,
.penci-homepage-title.style-24 .inner-arrow>span:after,
.penci-homepage-title.style-24 .inner-arrow>span:before,
.penci-sidebar-content.style-24 .widget-title>span:after,
.penci-sidebar-content.style-24 .widget-title>span:before {
	position: absolute;
	left: 0;
	bottom: 0;
	width: 15px;
	height: 5px;
	content: "";
	background: var(--pcaccent-cl);
	z-index: 2
}
.penci-homepage-title.style-24 .inner-arrow>a:after,
.penci-homepage-title.style-24 .inner-arrow>span:after,
.penci-sidebar-content.style-24 .widget-title>span:after {
	left: 20px;
	background: var(--pcborder-cl);
	width: calc(100% - 20px)
}
.penci-homepage-title.style-25.penci-border-arrow,
.penci-homepage-title.style-25 .inner-arrow,
.penci-sidebar-content.style-25 .inner-arrow,
.penci-sidebar-content.style-25 .widget-title {
	border: 0;
	background: 0 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0
}
.penci-homepage-title.style-25 .inner-arrow,
.penci-sidebar-content.style-25 .inner-arrow,
.penci-sidebar-content.style-25 .widget-title {
	border: 0;
	background: var(--pcaccent-cl);
	overflow: hidden
}
.penci-homepage-title.style-25:after,
.penci-homepage-title.style-25:before,
.penci-sidebar-content.style-25 .widget-title:after,
.penci-sidebar-content.style-25 .widget-title:before {
	display: none
}
.penci-homepage-title.style-25 .inner-arrow>a,
.penci-homepage-title.style-25 .inner-arrow>span,
.penci-sidebar-content.style-25 .widget-title span {
	color: #fff;
	font-size: 18px;
	z-index: 3;
	font-weight: bolder;
	text-shadow: var(--pcheading-cl) 1px 1px, var(--pcheading-cl) 2px 2px, var(--pcheading-cl) 3px 3px, var(--pcheading-cl) 3px 3px, var(--pcheading-cl) 4px 4px, var(--pcheading-cl) 5px 5px, var(--pcheading-cl) 6px 6px, var(--pcheading-cl) 7px 7px, var(--pcheading-cl) 8px 8px, var(--pcheading-cl) 9px 9px, var(--pcheading-cl) 10px 10px, var(--pcheading-cl) 11px 11px, var(--pcheading-cl) 12px 12px, var(--pcheading-cl) 13px 13px, var(--pcheading-cl) 14px 14px, var(--pcheading-cl) 15px 15px, var(--pcheading-cl) 16px 16px, var(--pcheading-cl) 17px 17px, var(--pcheading-cl) 18px 18px, var(--pcheading-cl) 19px 19px, var(--pcheading-cl) 20px 20px, var(--pcheading-cl) 21px 21px, var(--pcheading-cl) 22px 22px, var(--pcheading-cl) 23px 23px, var(--pcheading-cl) 24px 24px, var(--pcheading-cl) 25px 25px, var(--pcheading-cl) 26px 26px, var(--pcheading-cl) 27px 27px, var(--pcheading-cl) 28px 28px, var(--pcheading-cl) 29px 29px, var(--pcheading-cl) 30px 30px, var(--pcheading-cl) 31px 31px, var(--pcheading-cl) 32px 32px, var(--pcheading-cl) 33px 33px, var(--pcheading-cl) 34px 34px, var(--pcheading-cl) 35px 35px, var(--pcheading-cl) 36px 36px, var(--pcheading-cl) 37px 37px, var(--pcheading-cl) 38px 38px, var(--pcheading-cl) 39px 39px, var(--pcheading-cl) 40px 40px, var(--pcheading-cl) 41px 41px, var(--pcheading-cl) 42px 42px, var(--pcheading-cl) 43px 43px, var(--pcheading-cl) 44px 44px, var(--pcheading-cl) 45px 45px, var(--pcheading-cl) 46px 46px, var(--pcheading-cl) 47px 47px, var(--pcheading-cl) 48px 48px, var(--pcheading-cl) 49px 49px, var(--pcheading-cl) 50px 50px, var(--pcheading-cl) 51px 51px, var(--pcheading-cl) 52px 52px, var(--pcheading-cl) 53px 53px, var(--pcheading-cl) 54px 54px, var(--pcheading-cl) 55px 55px, var(--pcheading-cl) 56px 56px, var(--pcheading-cl) 57px 57px, var(--pcheading-cl) 58px 58px, var(--pcheading-cl) 59px 59px, var(--pcheading-cl) 60px 60px, var(--pcheading-cl) 61px 61px, var(--pcheading-cl) 62px 62px, var(--pcheading-cl) 63px 63px, var(--pcheading-cl) 64px 64px, var(--pcheading-cl) 65px 65px, var(--pcheading-cl) 66px 66px, var(--pcheading-cl) 67px 67px, var(--pcheading-cl) 68px 68px, var(--pcheading-cl) 69px 69px, var(--pcheading-cl) 70px 70px, var(--pcheading-cl) 71px 71px, var(--pcheading-cl) 72px 72px, var(--pcheading-cl) 73px 73px, var(--pcheading-cl) 74px 74px, var(--pcheading-cl) 75px 75px, var(--pcheading-cl) 76px 76px, var(--pcheading-cl) 77px 77px, var(--pcheading-cl) 78px 78px, var(--pcheading-cl) 79px 79px, var(--pcheading-cl) 80px 80px, var(--pcheading-cl) 81px 81px, var(--pcheading-cl) 82px 82px, var(--pcheading-cl) 83px 83px, var(--pcheading-cl) 84px 84px, var(--pcheading-cl) 85px 85px, var(--pcheading-cl) 86px 86px, var(--pcheading-cl) 87px 87px, var(--pcheading-cl) 88px 88px, var(--pcheading-cl) 89px 89px, var(--pcheading-cl) 90px 90px, var(--pcheading-cl) 91px 91px, var(--pcheading-cl) 92px 92px, var(--pcheading-cl) 93px 93px, var(--pcheading-cl) 94px 94px, var(--pcheading-cl) 95px 95px, var(--pcheading-cl) 96px 96px, var(--pcheading-cl) 97px 97px, var(--pcheading-cl) 98px 98px, var(--pcheading-cl) 99px 99px, var(--pcheading-cl) 100px 100px
}
.penci-homepage-title.style-26 .inner-arrow, 
.penci-sidebar-content.style-26 .inner-arrow, 
.penci-sidebar-content.style-26 .widget-title {
  	border: 0;
}
.penci-homepage-title.style-26 .inner-arrow, 
.penci-sidebar-content.style-26 .widget-title{
	background: transparent !important;
}
.penci-sidebar-content.style-26 .widget-title:before,
.penci-sidebar-content.style-26 .widget-title:after,
.penci-homepage-title.style-26:before, 
.penci-homepage-title.style-26:after {
  	display: none;
}
.penci-sidebar-content.style-26 .widget-title,
.penci-homepage-title.style-26 {
  	margin-left: 0;
  	margin-right: 0;
	margin-top: 0;
}
.penci-sidebar-content.style-26 .inner-arrow,
.penci-homepage-title.style-26 .inner-arrow {
  	padding: 0;
}
.penci-sidebar-content.style-26 .inner-arrow {
  	display: inline-block;
}
.penci-sidebar-content.style-26 .widget-title {
	position: relative;
}
.penci-sidebar-content.style-26 .widget-title:after,
.penci-homepage-title.style-26 .inner-arrow:after {
	width: 100%;
	content: '';
	background: var(--pcborder-cl);
	display: block;
	height: 2px;
	position: absolute;
	top: 50%;
	bottom: 50%;
	border: 0;
	left: 0;
	right: 0;
	margin-top: -1px;
}
.penci-sidebar-content.style-26 .inner-arrow,
.penci-homepage-title.style-26 .inner-arrow span span {
	background-color: var(--pcbg-cl) !important;
	position: relative;
	z-index: 2;
	padding-right: 20px;
	border-right: 2px solid var(--pcborder-cl);
}
.penci-homepage-title.style-26 .pcnav-lgroup {
	background-color: var(--pcbg-cl) !important;
}
.penci-sidebar-content.style-26.pcalign-right .inner-arrow,
.penci-sidebar-content.style-26.pcalign-center .inner-arrow,
.penci-homepage-title.style-26.pcalign-right .inner-arrow span span,
.penci-homepage-title.style-26.pcalign-center .inner-arrow span span {
  	padding-left: 20px;
  	border-left: 2px solid var(--pcborder-cl);
}
.penci-sidebar-content.style-26.pcalign-right .inner-arrow,
.penci-homepage-title.style-26.pcalign-right .inner-arrow span span {
	border-right: 0;
	padding-right: 0;
}
.penci-homepage-title.style-27 .inner-arrow,
.penci-sidebar-content.style-27 .inner-arrow,
.penci-sidebar-content.style-27 .widget-title {
	border: 0;
}
.penci-homepage-title.style-27 .inner-arrow,
.penci-sidebar-content.style-27 .widget-title {
	background: transparent !important;
}
.penci-sidebar-content.style-27 .widget-title:before,
.penci-sidebar-content.style-27 .widget-title:after,
.penci-homepage-title.style-27:before,
.penci-homepage-title.style-27:after {
	display: none;
}
.penci-sidebar-content.style-27 .widget-title,
.penci-homepage-title.style-27 {
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
}
.penci-sidebar-content.style-27 .inner-arrow,
.penci-homepage-title.style-27 .inner-arrow {
	padding: 0;
}
.penci-sidebar-content.style-27 .inner-arrow {
	display: inline-block;
}
.penci-sidebar-content.style-27 .widget-title {
	position: relative;
}
.penci-sidebar-content.style-27 .widget-title:after,
.penci-homepage-title.style-27 .inner-arrow:after {
	width: 100%;
	content: "";
	background: var(--pcborder-cl);
	box-shadow: 0px 3px 0px var(--pcborder-cl);
	display: block;
	height: 1px;
	position: absolute;
	top: 50%;
	bottom: 50%;
	border: 0;
	left: 0;
	right: 0;
	margin-top: -1px;
}
.penci-sidebar-content.style-27 .inner-arrow,
.penci-homepage-title.style-27 .inner-arrow span span {
	background-color: var(--pcbg-cl) !important;
	position: relative;
	z-index: 2;
	padding-right: 20px;
}
.penci-homepage-title.style-27 .pcnav-lgroup {
	background-color: var(--pcbg-cl) !important;
}
.penci-sidebar-content.style-27.pcalign-right .inner-arrow,
.penci-sidebar-content.style-27.pcalign-center .inner-arrow,
.penci-homepage-title.style-27.pcalign-right .inner-arrow span span,
.penci-homepage-title.style-27.pcalign-center .inner-arrow span span {
	padding-left: 20px;
}
.penci-sidebar-content.style-27.pcalign-right .inner-arrow,
.penci-homepage-title.style-27.pcalign-right .inner-arrow span span {
	border-right: 0;
	padding-right: 0;
}
.penci-homepage-title.style-28 {
	padding: 0;
	margin-top: 0;
	margin-left: 0;
	margin-right: 0;
	--pcheading-cl: #fff;
}
.penci-homepage-title.style-28 .inner-arrow {
	border: 0;
	background: transparent;
	padding: 0;
  	padding-left: 10px;
}
.penci-homepage-title.style-28:before,
.penci-homepage-title.style-28:after {
	display: none;
}
.penci-homepage-title.style-28 span a,
.penci-homepage-title.style-28 span {
	position: relative;
}
.penci-homepage-title.style-28 .inner-arrow > span {
	display: inline-flex;
  	align-items: center;
}
.penci-homepage-title.style-28 span a,
.penci-homepage-title.style-28 span span {
	padding: 5px 12px;
	margin: 0 10px;
	z-index: 4;
	color: var(--pcheading-cl);
}
.penci-homepage-title.style-28 .inner-arrow > span:before,
.penci-homepage-title.style-28 .inner-arrow > span:after,
.penci-homepage-title.style-28 span a:before,
.penci-homepage-title.style-28 span a:after,
.penci-homepage-title.style-28 span span:before,
.penci-homepage-title.style-28 span span:after {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: var(--pcaccent-cl);
	content: "";
	display: block;
	z-index: -1;
	transform: skew(-10deg, 0deg);
	opacity: 1;
}
.penci-homepage-title.style-28 span a:before,
.penci-homepage-title.style-28 span span:before {
	width: 10px;
	right: auto;
	left: -15px;
	opacity: 0.7;
}
.penci-homepage-title.style-28 .inner-arrow > span:before,
.penci-homepage-title.style-28 .inner-arrow > span:after {
	width: 7px;
	left: auto;
	right: -2px;
	opacity: 0.7;
}
.penci-homepage-title.style-28 .inner-arrow > span:after {
	right: -18px;
	width: 12px;
	opacity: 0.5;
}
.penci-sidebar-content.style-28 .inner-arrow,
.penci-sidebar-content.style-28 .widget-title {
	border: 0;
}
.penci-sidebar-content.style-28 .widget-title {
	background: transparent !important;
}
.penci-sidebar-content.style-28 .widget-title:before,
.penci-sidebar-content.style-28 .widget-title:after {
	display: none;
}
.penci-sidebar-content.style-28 .widget-title {
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
}
.penci-sidebar-content.style-28 .inner-arrow {
	padding: 0;
}
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow {
	padding: 0;
	margin: 0;
	--pcheading-cl: #fff;
}
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow {
	border: 0;
	background: transparent;
}
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow {
	position: relative;
}
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow {
	padding: 5px 12px;
	margin: 0 10px;
	z-index: 4;
	color: var(--pcheading-cl);
}
.penci-sidebar-content.style-28 .penci-border-arrow:before,
.penci-sidebar-content.style-28 .penci-border-arrow:after,
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow:before,
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow:after {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: var(--pcaccent-cl);
	content: "";
	display: block;
	z-index: -1;
	transform: skew(-10deg, 0deg);
	opacity: 1;
	height: 100%;
}
.penci-sidebar-content.style-28 .penci-border-arrow:before,
.penci-sidebar-content.style-28 .penci-border-arrow:after,
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow:before {
	width: 10px;
	right: auto;
	left: -15px;
	opacity: 0.7;
}
.penci-sidebar-content.style-28 .penci-border-arrow:before,
.penci-sidebar-content.style-28 .penci-border-arrow:after {
	border: 0;
}
.penci-sidebar-content.style-28 .penci-border-arrow:before,
.penci-sidebar-content.style-28 .penci-border-arrow:after {
	width: 7px;
	left: auto;
	right: -2px;
	opacity: 0.7;
}
.penci-sidebar-content.style-28 .penci-border-arrow:before {
	right: 14px;
	left: auto;
	opacity: 1;
	margin: 0;
	position: absolute;
}
.penci-sidebar-content.style-28 .penci-border-arrow .inner-arrow:after {
	right: 0;
	left: 0;
	opacity: 1;
	width: calc(100% - 15px);
}
.penci-sidebar-content.style-28 .penci-border-arrow:after {
	right: 0;
	width: 10px;
	left: auto;
}
.penci-homepage-title.style-29.penci-border-arrow,
.penci-homepage-title.style-29 .inner-arrow,
.penci-sidebar-content.style-29 .inner-arrow,
.penci-sidebar-content.style-29 .widget-title {
	border: 0;
	background: 0 0 !important;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0;
}
.penci-homepage-title.style-29:after,
.penci-homepage-title.style-29:before,
.penci-sidebar-content.style-29 .widget-title:after,
.penci-sidebar-content.style-29 .widget-title:before {
	display: none;
}
.penci-sidebar-content.style-29 .widget-title,
.penci-homepage-title.style-29.penci-border-arrow {
	display: block;
}
.penci-sidebar-content.style-29 .inner-arrow,
.penci-homepage-title.style-29.penci-border-arrow .inner-arrow {
	padding-top: 7px;
	background: transparent !important;
}
.penci-homepage-title.style-29 .inner-arrow span,
.penci-sidebar-content.style-29 .widget-title span {
	color: var(--pcheading-cl);
}
.penci-homepage-title.style-29 .inner-arrow > span,
.penci-sidebar-content.style-29 .widget-title > span {
	padding: 0 0 0 20px;
	position: relative;
}
.penci-homepage-title.style-29.pcalign-right .inner-arrow > span,
.penci-sidebar-content.style-29.pcalign-right .widget-title > span {
	padding: 0 20px 0 0;
}
.penci-homepage-title.style-29 .inner-arrow > span:before,
.penci-sidebar-content.style-29 .widget-title > span:before {
	content: "";
	width: 10px;
	height: 3px;
	background: var(--pcaccent-cl);
	position: absolute;
	top: 0;
	left: 0;
}
.penci-homepage-title.style-29 .inner-arrow > span:after,
.penci-sidebar-content.style-29 .widget-title > span:after {
	content: "";
	width: 3px;
	height: 10px;
	background: var(--pcaccent-cl);
	position: absolute;
	top: 0;
	left: 0;
}
.penci-sidebar-content.style-29.pcalign-right .widget-title > span:before,
.penci-homepage-title.style-29.pcalign-right .inner-arrow > span:before {
	left: auto;
	right: 0;
}
.penci-sidebar-content.style-29.pcalign-right .widget-title > span:after,
.penci-homepage-title.style-29.pcalign-right .inner-arrow > span:after {
	left: auto;
	right: 0;
}
.penci-homepage-title.style-30.penci-border-arrow,
.penci-homepage-title.style-30 .inner-arrow,
.penci-sidebar-content.style-30 .inner-arrow,
.penci-sidebar-content.style-30 .widget-title {
	border: 0;
	background: 0 0;
	padding-left: 0;
	padding-right: 0;
	margin-left: 0;
	margin-right: 0;
	margin-top: 0;
	padding-top: 0;
}
.penci-homepage-title.style-30:after,
.penci-homepage-title.style-30:before,
.penci-sidebar-content.style-30 .widget-title:after,
.penci-sidebar-content.style-30 .widget-title:before {
	display: none;
}
.penci-sidebar-content.style-30 .widget-title,
.penci-homepage-title.style-30.penci-border-arrow {
	display: block;
}
.penci-sidebar-content.style-30 .inner-arrow,
.penci-homepage-title.style-30.penci-border-arrow .inner-arrow {
	padding-top: 0;
	background: transparent;
}
.penci-homepage-title.style-30 .inner-arrow > span,
.penci-sidebar-content.style-30 .widget-title > span {
	color: #fff;
	background: var(--pcaccent-cl);
	display: inline-block;
	padding: 5px 10px;
	transform: skewX(-15deg);
	z-index: 2;
	position: relative;
}
.penci-sidebar-content.style-30 .widget-title:before,
.penci-homepage-title.style-30:before {
	display: block;
	border: 0;
	width: calc(100% - 5px);
	height: 1px;
	background: var(--pcborder-cl);
	left: 5px;
	right: 0;
	top: 50%;
	transform: translateY(-50%);
	z-index: 1;
}
.penciel-bheading .inner-arrow span {
	display: inline-flex;
	align-items: center;
}
.widget ol,
.widget ul {
	list-style: none
}
.penci-block-popular-cat ul {
	padding-left: 0
}
.widget ol ol,
.widget ul ul {
	padding-top: 11px;
	margin-top: 12px;
	border-top: 1px solid var(--pcborder-cl);
	padding-left: 20px
}
.widget ol li,
.widget ul li {
	margin-bottom: 11px;
	padding-bottom: 12px;
	border-bottom: 1px solid var(--pcborder-cl);
	font-size: 14px;
	color: #888
}
.widget ol>li:last-child,
.widget ul>li:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: none
}
.widget ol li a,
.widget ul li a {
	font-size: 14px;
	font-style: normal;
	line-height: 1.4
}
.widget a {
	color: var(--pctext-cl)
}
.widget a:hover {
	color: var(--pcaccent-cl);
	text-decoration: underline
}
.widget.widget_archive label.screen-reader-text,
.widget.widget_categories label.screen-reader-text {
	display: none
}
.widget .screen-reader-text {
	display: block;
	margin: 0 0 10px 0;
	font-size: 14px
}
.widget select {
	padding: 2px;
	line-height: 32px;
	min-height: 32px;
	vertical-align: middle;
	border-spacing: 0;
	clear: both;
	margin: 0;
	font-size: 14px;
	width: 100%;
	max-width: 360px;
	outline: 0
}
.pc-widget-advanced-tax.tax-style-1 ul li,
.widget.widget_archive ul li,
.widget.widget_categories ul li {
	text-align: right;
	color: #888;
	display: table;
	width: 100%;
	font-style: italic;
	padding-right: 0
}
.pc-widget-advanced-tax.tax-style-1 ul li,
.widget.widget_categories ul li {
	text-align: left
}
.widget.widget_archive ul li a {
	float: left
}
.pc-widget-advanced-tax.tax-style-1 ul li a,
.widget.widget_categories ul li a {
	display: block !important;
	text-decoration: none
}
.pc-widget-advanced-tax.tax-style-1 ul li a:before,
.widget.widget_archive ul li a:before,
.widget.widget_categories ul li a:before {
	content: "\f105";
	font-family: FontAwesome;
	display: inline-block;
	margin-right: 10px;
	font-size: 90%
}
.penci-fawesome-ver5 .widget.widget_archive ul li a:before,
.penci-fawesome-ver5 .widget.widget_categories ul li a:before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900
}
.pc-widget-advanced-tax.tax-style-1 ul li span.category-item-count,
.widget.widget_categories ul li span.category-item-count {
	float: right;
	font-style: normal;
	color: #888;
	font-family: var(--pcbody-font);
	font-weight: 400
}
form.pc-searchform {
	position: relative
}
form.pc-searchform input.search-input {
	border: 1px solid #e9e9e9;
	background: 0 0;
	padding: 12px 40px 12px 20px;
	color: #313131;
	font-size: 13px;
	font-family: var(--pcbody-font);
	font-weight: 400;
	width: 100%
}
form.pc-searchform i {
	position: absolute;
	color: var(--pctext-cl);
	top: 50%;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	right: 20px;
	z-index: 1;
	font-size: 15px;
	opacity: .9
}
form.pc-searchform #s:focus {
	outline: 0
}
.penci-sidebar-content .widget form.pc-searchform input.search-input,
.widget form.pc-searchform input.search-input {
	width: 100%;
	max-width: 100%;
	background-color: transparent;
	margin-bottom: 0
}
.penci-about-me .about-widget,
.widget .about-widget {
	text-align: center
}
.penci-about-me .about-widget.pc_alignleft,
.widget .about-widget.pc_alignleft {
	text-align: left
}
.penci-about-me .about-widget.pc_alignright,
.widget .about-widget.pc_alignright {
	text-align: right
}
.about-widget img {
	max-width: 100% !important;
	height: auto;
	margin-bottom: 20px;
	width: 100%
}
.about-widget .about-me-heading {
	color: #313131;
	font-size: 18px;
	font-family: var(--pcbody-font);
	font-weight: 700;
	padding-bottom: 16px;
	line-height: 1.3;
	margin-bottom: 19px;
	position: relative
}
.about-widget .about-me-heading:before {
	content: "";
	display: inline-block;
	width: 60px;
	position: absolute;
	margin-left: -30px;
	left: 50%;
	bottom: 0;
	border-top: 1px solid var(--pcaccent-cl)
}
.about-widget.pc_alignleft .about-me-heading:before {
	margin: 0;
	left: 0
}
.about-widget.pc_alignright .about-me-heading:before {
	margin: 0;
	left: auto;
	right: 0
}
.pc-widget-advanced-tax.tax-style-2 a,
.widget .tagcloud a {
	text-transform: uppercase;
	background: #fff;
	color: #999;
	padding: 6px 12px 5px;
	margin-right: 5px;
	margin-bottom: 8px;
	display: inline-block;
	font-size: 11px;
	background: 0 0;
	border: 1px solid #dedede;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	outline: 0;
	font-weight: 400;
	line-height: 1.2
}
.widget .tagcloud a {
	font-size: 11px !important;
}
.pc-widget-advanced-tax.tax-style-2 a {
	display: inline-flex;
  	align-items: center;
}
.pc-widget-advanced-tax.tax-style-3 select {
	padding-left: 10px;
	padding-right: 10px;
}
.pc-widget-advanced-tax.tax-style-2 .tag-link-count {
	margin-left: 3px;
}
.pc-widget-advanced-tax.tax-style-2 a:hover,
.widget .tagcloud a:hover {
	color: #fff;
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	text-decoration: none
}
#wp-calendar {
	width: 100%
}
#wp-calendar caption {
	text-align: center;
	color: #777;
	font-size: 14px;
	margin-top: 10px;
	margin-bottom: 10px;
	font-weight: 700
}
.post-entry #wp-calendar caption {
	font-size: 16px;
	margin-bottom: 10px;
	color: inherit
}
#wp-calendar thead {
	font-size: 12px
}
#wp-calendar thead th {
	padding-bottom: 10px
}
#wp-calendar tbody {
	color: #aaa
}
#wp-calendar tbody td {
	background: #f5f5f5;
	border: 1px solid #fff;
	text-align: center;
	padding: 8px
}
#wp-calendar tbody td a {
	font-weight: 700;
	color: #222
}
#wp-calendar tbody td:hover {
	background: #fff
}
#wp-calendar tbody .pad {
	background: 0 0
}
#wp-calendar tfoot #next {
	font-size: 11px;
	text-transform: uppercase;
	text-align: right
}
#wp-calendar tfoot #prev {
	font-size: 12px;
	text-transform: uppercase;
	padding-top: 15px
}
#wp-calendar thead th {
	padding-bottom: 10px;
	text-align: center
}
.wp-calendar-nav {
	margin-top: 10px
}
.post-entry .wp-calendar-nav {
	margin-bottom: 20px;
	margin-top: 0
}
.wp-block-calendar a {
	text-decoration: none
}
.wp-block-search__inside-wrapper {
	display: flex;
	flex: auto;
	flex-wrap: nowrap;
	max-width: 100%
}
.widgettitle {
	margin-bottom: 10px
}
.penci_recent-posts-sc ul.side-newsfeed {
	padding: 0;
	margin: 0
}
.penci_recent-posts-sc ul.side-newsfeed:after,
.penci_recent-posts-sc ul.side-newsfeed:before,
.widget ul.side-newsfeed:after,
.widget ul.side-newsfeed:before {
	display: table;
	content: "";
	clear: both;
	line-height: 0
}
.penci_recent-posts-sc ul.side-newsfeed li {
	border-bottom: 1px solid #dedede;
	font-size: 14px;
	color: #888
}
.penci_recent-posts-sc ul.side-newsfeed li,
.widget ul.side-newsfeed li {
	list-style-type: none;
	margin-bottom: 20px;
	padding-bottom: 20px;
	margin-left: 0;
	position: relative
}
.side-newsfeed.penci-vscroll .js-marquee-wrapper .js-marquee {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 20px;
	margin-bottom: 20px;
}
ul.side-newsfeed.penci-rcpw-hborders li {
	padding-bottom: 0 !important;
	border-bottom: none !important
}
.penci_recent-posts-sc ul.penci-feed-2columns li,
.widget ul.penci-feed-2columns li {
	width: 47%;
	float: left;
	padding-bottom: 0;
	margin-bottom: 20px;
	border-bottom: none
}
.penci_recent-posts-sc ul.penci-feed-2columns.display-order-numbers li,
.widget ul.penci-feed-2columns.display-order-numbers li {
	margin-bottom: 30px
}
.penci_recent-posts-sc ul.penci-2columns-feed>li:nth-child(2n+1),
.widget ul.penci-2columns-feed>li:nth-child(2n+1) {
	clear: both;
	margin-right: 6%
}
.penci_recent-posts-sc ul.penci-2columns-featured>li:nth-child(2n),
.widget ul.penci-2columns-featured>li:nth-child(2n) {
	clear: both;
	margin-right: 6%
}
.penci_recent-posts-sc ul.side-newsfeed li:last-child,
.penci_recent-posts-sc ul.side-newsfeed.penci-feed-2columns li:nth-last-child(2),
.widget ul.side-newsfeed li:last-child,
.widget ul.side-newsfeed.penci-feed-2columns li:nth-last-child(2) {
	margin-bottom: 0 !important;
	padding-bottom: 0 !important
}
.penci_recent-posts-sc ul.side-newsfeed li:last-child {
	border-bottom: 0 !important
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item,
.widget ul.side-newsfeed li .side-item {
	overflow: hidden;
	position: relative
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image,
.widget ul.side-newsfeed li .side-item .side-image {
	float: left;
	margin-right: 20px;
	position: relative
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image.thumbnail-right,
.widget ul.side-newsfeed li .side-item .side-image.thumbnail-right {
	float: right;
	margin-right: 0;
	margin-left: 20px
}
.penci_recent-posts-sc ul.penci-feed-2columns li .side-item .side-image,
.penci_recent-posts-sc ul.penci-feed-2columns li .side-item .side-image.thumbnail-right,
.widget ul.penci-feed-2columns li .side-item .side-image,
.widget ul.penci-feed-2columns li .side-item .side-image.thumbnail-right {
	width: 100%;
	margin: 0 0 16px 0;
	float: none !important
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a,
.widget ul.side-newsfeed li .side-item .side-image a {
	transition: opacity .3s;
	-webkit-transition: opacity .3s;
	-moz-transition: opacity .3s
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a:hover,
.widget ul.side-newsfeed li .side-item .side-image a:hover {
	opacity: .8
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a span.count-post,
.widget ul.side-newsfeed li .side-item .side-image a span.count-post {
	position: absolute;
	z-index: 2;
	bottom: 10px;
	left: 10px;
	display: inline-block;
	background: #fff;
	color: #010101;
	width: 30px;
	height: 30px;
	line-height: 30px;
	font-size: 16px;
	text-align: center;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image img,
.widget ul.side-newsfeed li .side-item .side-image img {
	width: 120px;
	height: auto
}
.penci_recent-posts-sc ul.penci-feed-2columns li .side-item .side-image .small-fix-size,
.widget ul.penci-feed-2columns li .side-item .side-image .small-fix-size {
	width: 100%
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text,
.widget ul.side-newsfeed li .side-item .side-item-text {
	overflow: hidden
}
.penci_recent-posts-sc ul.penci-feed-2columns li .side-item .side-item-text,
.widget ul.penci-feed-2columns li .side-item .side-item-text {
	display: block
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4,
.widget ul.side-newsfeed li .side-item .side-item-text h4 {
	margin-bottom: 0
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a,
.widget ul.side-newsfeed li .side-item .side-item-text h4 a {
	margin-bottom: 0;
	color: var(--pcheading-cl);
	display: block;
	font-size: 16px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	letter-spacing: 0;
	line-height: 1.4
}
.penci_recent-posts-sc ul.penci-feed-2columns li .side-item .side-item-text h4 a,
.widget ul.penci-feed-2columns li .side-item .side-item-text h4 a {
	font-size: 14px;
	margin-bottom: 2px
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a:hover,
.widget ul.side-newsfeed li .side-item .side-item-text h4 a:hover {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text .side-item-meta,
.widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta {
	letter-spacing: 0;
	color: #888;
	font-family: inherit;
	font-size: 13px
}
.widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a {
	color: var(--pctext-cl);
	font-size: inherit
}
.widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a:hover {
	color: var(--pcaccent-cl)
}
ul.side-newsfeed li .grid-post-box-meta.penci-side-item-meta {
	margin-top: 5px;
	line-height: 1.2
}
ul.side-newsfeed li .grid-post-box-meta.penci-side-item-meta.pcsnmt-above {
	margin: 0 0 5px 0
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news,
.widget ul.side-newsfeed li.featured-news {
	width: 100% !important;
	margin-right: 0
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news.all-featured-news,
.widget ul.side-newsfeed li.featured-news.all-featured-news {
	border-bottom: none;
	margin-bottom: 0;
	padding-bottom: 26px
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-image,
.widget ul.side-newsfeed li.featured-news .side-image {
	float: none !important;
	margin: 0 0 12px 0 !important
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-image img,
.widget ul.side-newsfeed li.featured-news .side-image img {
	width: 100% !important
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .side-item .side-item-text h4 a,
.widget ul.side-newsfeed li.featured-news .side-item .side-item-text h4 a {
	font-size: 18px;
	margin-bottom: 6px
}
.penci_recent-posts-sc .penci-feed-excerpt,
.widget .penci-feed-excerpt {
	margin-top: 16px
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news2 .side-item .side-item-text,
.widget ul.side-newsfeed li.featured-news2 .side-item .side-item-text {
	position: absolute;
	z-index: 1;
	bottom: 12px;
	padding: 15px 10px 0 20px;
	left: 20px;
	right: 20px;
	background: #fff
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news2.all-featured-news .side-item .side-item-text,
.widget ul.side-newsfeed li.featured-news2.all-featured-news .side-item .side-item-text {
	padding-left: 10px
}
.penci_recent-posts-sc ul.side-newsfeed li .order-border-number,
.widget ul.side-newsfeed li .order-border-number {
	position: absolute;
	left: 5px;
	top: -15px;
	background-color: rgba(255, 255, 255, .3);
	box-shadow: 0 1px 2px 0 rgba(0, 0, 0, .25);
	display: inline-block;
	vertical-align: middle;
	width: 30px;
	height: 30px;
	line-height: 28px;
	border-radius: 50%;
	z-index: 6;
	text-align: center
}
.penci_recent-posts-sc ul.side-newsfeed li .order-border-number.right-side,
.widget ul.side-newsfeed li .order-border-number.right-side {
	left: auto;
	right: 5px
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .order-border-number.right-side,
.widget ul.side-newsfeed li.featured-news .order-border-number.right-side {
	left: 15px;
	right: auto
}
.penci_recent-posts-sc ul.side-newsfeed li .number-post,
.widget ul.side-newsfeed li .number-post {
	background-color: #383838;
	border-radius: 50%;
	width: 26px;
	height: 26px;
	line-height: 28px;
	text-align: center;
	display: inline-block;
	vertical-align: middle;
	color: #fff;
	font-size: 12px;
	font-family: var(--pchead-font);
	font-weight: 600;
	z-index: 3
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .order-border-number,
.widget ul.side-newsfeed li.featured-news .order-border-number {
	width: 40px;
	height: 40px;
	line-height: 38px
}
.penci_recent-posts-sc ul.side-newsfeed li.featured-news .number-post,
.widget ul.side-newsfeed li.featured-news .number-post {
	width: 36px;
	height: 36px;
	line-height: 38px;
	font-size: 16px
}
.side-newsfeed.pctlst {
	padding-left: 20px !important;
	border-left: 1px solid;
	border-color: var(--pcborder-cl);
	margin-left: 5px !important
}
.side-newsfeed.pctlst .penci-feed:after,
.side-newsfeed.pctlst .penci-feed:before {
	width: 9px;
	height: 9px;
	left: -25px;
	display: inline-block;
	top: 0;
	transition: all .3s;
	background: var(--pcaccent-cl);
	position: absolute;
	border-radius: 50%;
	z-index: 2
}
.side-newsfeed.pctlst .penci-feed:before {
	content: "";
	z-index: 1
}
.side-newsfeed.pctlst.penci-2columns-featured>.penci-feed:not(.featured-news):nth-child(2n+1):after,
.side-newsfeed.pctlst.penci-2columns-featured>.penci-feed:not(.featured-news):nth-child(2n+1):before,
.side-newsfeed.pctlst.penci-2columns-feed>.penci-feed:nth-child(2n):after,
.side-newsfeed.pctlst.penci-2columns-feed>.penci-feed:nth-child(2n):before {
	content: none
}
@keyframes pencisonar {
	0% {
		opacity: 0;
		transform: scale(.2)
	}
	50% {
		opacity: .9
	}
	100% {
		opacity: 0;
		transform: scale(1)
	}
}
.side-newsfeed.pctlst.pctl-s2 .penci-feed:before,
.side-newsfeed.pctlst.pctl-s3 .penci-feed:before {
	background: var(--pcborder-cl)
}
.side-newsfeed.pctlst.pctl-s2 .penci-feed:hover:before {
	background: var(--pcaccent-cl)
}
.side-newsfeed.pctlst.pctl-s3 .penci-feed:after {
	content: "";
	background: var(--pcaccent-cl);
	animation: pencisonar 1.5s ease infinite
}
.penci-widget-slider {
	width: 100%
}
.widget .penci-widget-slider .penci-slide-widget {
	margin: 0;
	padding: 0;
	border-bottom: none
}
.widget .penci-widget-slider .penci-slide-widget:after,
.widget .penci-widget-slider .penci-slide-widget:before {
	content: none;
	display: none
}
.penci-widget-slider .penci-slide-content {
	position: relative;
	text-align: center
}
.penci-widget-slider-overlay {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	opacity: .3;
	transition: opacity .25s ease;
	-webkit-transition: opacity .25s ease;
	-moz-transition: opacity .25s ease;
	z-index: 2
}
.penci-widget-slider .penci-widget-slide-detail {
	position: absolute;
	top: 50%;
	left: 25px;
	right: 25px;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	-moz-transform: translateY(-50%);
	z-index: 5
}
.penci_post-slider-sc .penci-post-slider-style-1 .penci-widget-slide-detail h4 a,
.penci_post-slider-sc .penci-post-slider-style-2 .penci-widget-slide-detail h4 a,
.widget .penci-widget-slider .penci-widget-slide-detail h4 a {
	color: #fff;
	font-size: 18px;
	text-decoration: none;
	letter-spacing: 0
}
.penci_post-slider-sc .penci-post-slider-style-3 .penci-widget-slide-detail h4 a {
	color: #313131
}
.penci-widget-slide-detail .slide-item-date {
	color: #fff;
	display: block;
	margin-top: 5px;
	font-size: 13px
}
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-next,
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-prev,
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-next,
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-prev {
	width: 16px;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	background: 0 0;
	color: #fff;
	font-size: 16px
}
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-prev,
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-prev {
	left: 10px
}
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-next,
.penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-next {
	right: 10px
}
.penci-widget-slider.penci-post-slider-style-2 .penci-slide-content,
.penci-widget-slider.penci-post-slider-style-3 .penci-slide-content {
	text-align: left
}
.penci-widget-slider.penci-post-slider-style-2 .penci-widget-slide-detail {
	transform: none;
	-webkit-transform: none;
	-moz-transform: none;
	top: auto;
	bottom: 20px
}
.penci-post-slider-style-2 .penci-widget-slider-overlay {
	background: -moz-linear-gradient(top, transparent 0, #000 100%);
	background: -webkit-linear-gradient(top, transparent 0, #000 100%);
	background: -o-linear-gradient(top, transparent 0, #000 100%);
	background: -ms-linear-gradient(top, transparent 0, #000 100%);
	background: linear-gradient(to bottom, transparent 0, #000 100%);
	-webkit-transition: opacity .4s ease 0s;
	-moz-transition: opacity .4s ease 0s;
	-o-transition: opacity .4s ease 0s;
	transition: opacity .4s ease 0s;
	opacity: .7
}
.penci-post-slider-style-2 .penci-slide-widget:hover .penci-widget-slider-overlay {
	opacity: .9
}
.penci-widget-slider.penci-post-slider-style-3 .penci-widget-slide-detail {
	transform: none;
	-webkit-transform: none;
	-moz-transform: none;
	position: static;
	margin-top: 16px
}
.widget .penci-widget-slider.penci-post-slider-style-3 .penci-widget-slide-detail h4 a {
	color: inherit;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s
}
.widget .penci-widget-slider.penci-post-slider-style-3 .penci-widget-slide-detail h4 a:hover {
	opacity: .8
}
.penci-post-slider-style-3 .penci-widget-slide-detail .slide-item-date {
	color: #888
}
.widget-social {
	text-align: center;
	display: table;
	width: 100%;
	font-size: 0;
}
.widget-social.pc_alignleft {
	text-align: left
}
.widget-social.pc_alignright {
	text-align: right
}
.widget-social.pc_alignleft>a:first-child i {
	margin-left: 0
}
.widget-social.pc_alignright>a:last-child i {
	margin-right: 0
}
@media only screen and (max-width:767px) {
	.pcfb-wrapper .widget-social.pc_alignleft,
	.pcfb-wrapper .widget-social.pc_alignright {
		text-align: center
	}
}
.widget-social.show-text {
	margin-left: -5px
}
.widget-social a i {
	width: 36px;
	height: 36px;
	line-height: 34px;
	background: 0 0;
	color: #313131;
	border: 1px solid #e0e0e0;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	margin: 0 5px 5px 0px;
	display: inline-block;
	font-size: 14px;
	-webkit-transition: all .2s ease-in-out;
	-moz-transition: all .2s ease-in-out;
	-o-transition: all .2s ease-in-out;
	transition: all .2s ease-in-out;
	text-align: center
}
.widget-social.show-text a i {
	margin-bottom: 0
}
.widget-social a:hover {
	text-decoration: none !important
}
.widget-social a:hover i {
	text-decoration: none;
	color: #fff;
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl)
}
.widget-social a span {
	display: none
}
.widget-social a:first-child {
	margin-left: 0
}
.widget-social a:last-child {
	margin-right: 0
}
.widget-social.show-text {
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
	flex-direction: row;
	margin-left: 0;
}
.widget-social.show-text>a {
	width: 49%;
	text-align: left;
	margin-bottom: 10px;
	text-decoration: none;
	display: flex;
	justify-items: center;
	flex-wrap: wrap;
	flex-direction: row;
	align-items: center;
}
.widget-social.show-text>a:nth-child(2n+1) {
	clear: both
}
.widget-social.show-text a span {
	display: inline-block;
	color: #313131;
	text-transform: uppercase;
	font-size: 13px;
	margin-left: 5px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	letter-spacing: 0;
	transition: color .3s;
	-webkit-transition: color .3s;
	-moz-transition: color .3s;
	line-height: 20px
}
.widget-social.show-text.remove-uppercase-text a span {
	text-transform: none
}
.widget-social.show-text a:hover span {
	color: var(--pcaccent-cl)
}
.widget-social.remove-circle a i {
	width: auto;
	height: auto;
	line-height: 20px;
	background: 0 0 !important;
	border: none !important
}
.widget-social.remove-circle a:hover i {
	color: var(--pcaccent-cl)
}
.widget-social.remove-circle a span {
	line-height: 20px;
	margin-left: 5px
}
.widget-social.remove-circle:not(.show-text) a i {
	margin: 0 7px 5px
}
.widget-social.penci-social-colored a i {
	border: none !important;
	line-height: 36px;
	color: #fff !important
}
.widget-social.penci-social-colored a:hover i {
	opacity: .85
}
.widget-social.remove-border-radius a i {
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
.quote-widget {
	position: relative;
	display: block
}
.quote-widget>i {
	color: #999;
	position: absolute;
	top: 0;
	left: 0;
	font-size: 22px
}
.quote-widget>p {
	padding-left: 40px
}
.footer-widget-wrapper .quote-widget>i {
	font-size: 24px
}
.footer-widget-wrapper .quote-widget>p {
	padding-left: 42px
}
.penci-pinterest-widget-container {
	margin: -5px -5px 0 -5px
}
.penci-images-pin-widget:after,
.penci-images-pin-widget:before {
	display: table;
	clear: both;
	content: ""
}
.penci-pinterest-widget-container .penci-images-pin-widget a {
	width: 33.3333%;
	display: inline-block;
	padding: 5px;
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s;
	position: relative;
	float: left;
	vertical-align: top
}
.penci-pinterest-widget-container .penci-images-pin-widget a .penci-image-holder {
	border-radius: 0;
	-webkit-border-radius: 0
}
.penci-pinterest-widget-container .penci-images-pin-widget a:hover {
	opacity: .8
}
.penci-pinterest-widget-container .penci-images-pin-widget a:after,
.penci-pinterest-widget-container .penci-images-pin-widget a:before {
	position: absolute;
	top: 10px;
	right: 10px;
	bottom: 10px;
	left: 10px;
	content: "";
	opacity: 0;
	-webkit-transition: opacity .35s, -webkit-transform .35s;
	transition: opacity .35s, transform .35s;
	z-index: 1
}
.penci-pinterest-widget-container .penci-images-pin-widget a:before {
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transform: scale(0, 1);
	transform: scale(0, 1)
}
.penci-pinterest-widget-container .penci-images-pin-widget a:after {
	border-right: 1px solid #fff;
	border-left: 1px solid #fff;
	-webkit-transform: scale(1, 0);
	transform: scale(1, 0)
}
.penci-pinterest-widget-container .penci-images-pin-widget a:hover:after,
.penci-pinterest-widget-container .penci-images-pin-widget a:hover:before {
	opacity: 1;
	-webkit-transform: scale(1);
	transform: scale(1)
}
.penci-pinterest-widget-container .pin_link {
	text-align: center;
	margin-top: 20px
}
.penci-pinterest-widget-container.penci-loading .pin_link {
	clear: both;
	display: block
}
.penci-pinterest-widget-container .pin_link a {
	font-style: italic;
	color: #999;
	font-size: 16px
}
.penci-list-banner {
	display: block
}
.penci-promo-item {
	position: relative;
	width: 100%;
	margin: 0 0 25px 0;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover;
	-moz-background-size: cover;
	-o-background-size: cover;
	background-color: #ccc
}
.penci-list-banner .penci-promo-item:last-child {
	margin-bottom: 0
}
.penci-promo-item.penci-banner-crop {
	padding-bottom: 56%
}
.penci-promo-item.penci-banner-has-text:after {
	position: absolute;
	left: 10px;
	right: 10px;
	top: 10px;
	bottom: 10px;
	content: "";
	-webkit-transition: all .4s;
	transition: all .4s;
	z-index: 5;
	border: 1px solid #fff;
	opacity: .4
}
.penci-promo-item.penci-banner-has-text:hover:after {
	opacity: 1
}
.penci-promo-url {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 100;
	background: 0 0 !important
}
.penci-promo-text {
	position: absolute;
	display: block;
	top: 50%;
	width: 100%;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%);
	padding: 0 10px;
	left: 0;
	z-index: 1;
	text-align: center
}
.penci-promo-text h4 {
	text-transform: uppercase;
	font-size: 12px;
	line-height: 1.3;
	background: #fff;
	display: inline-block;
	padding: 12px 12px;
	min-width: 120px;
	text-align: center;
	color: #010101
}
.penci-promo-item img {
	width: 100%
}
.penci-list.penci-wpb {
	list-style: none;
	margin: 0;
	padding: 0
}
.penci-list.penci-wpb li {
	list-style: none
}
.penci-list.penci-wpb li a:hover {
	text-decoration: none
}
.footer-widget-wrapper .widget {
	margin-bottom: 30px
}
.footer-widget-wrapper .widget .widget-title {
	color: #313131;
	margin: 0 0 30px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	position: relative;
	text-align: left;
	font-size: 16px;
	text-transform: uppercase;
	background: 0 0
}
.footer-widget-wrapper .widget .widget-title .inner-arrow {
	border-top: none;
	border-left: none;
	border-right: none;
	padding: 0 0 10px;
	background: 0 0;
	border-bottom: 3px solid #e0e0e0
}
.footer-widget-wrapper .widget .widget-title:after,
.footer-widget-wrapper .widget .widget-title:before {
	content: none
}
.mc4wp-form {
	max-width: 450px;
	width: 100%;
	margin: 0;
	text-align: center;
	margin-left: auto;
	margin-right: auto
}
.post-entry .mc4wp-form {
	margin-left: auto;
	margin-right: auto;
	margin-bottom: 17px
}
.mc4wp-form .mc4wp-form-fields>p,
.mc4wp-form>form>p {
	margin-bottom: 20px
}
.penci-mailchimp-s3 .footer-subscribe .mc4wp-form .memail {
	margin-bottom: 0
}
.mc4wp-form .mc4wp-form-fields>p:last-of-type,
.widget .mc4wp-form>form>p:last-of-type {
	margin-bottom: 0
}
.mc4wp-form input {
	border: 1px solid #dedede;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	outline: 0;
	background: 0 0;
	display: block;
	font-size: 12px;
	line-height: 1;
	padding: 17px 20px;
	margin-bottom: 20px;
	letter-spacing: 0;
	font-family: var(--pcbody-font)
}
.mc4wp-form input:focus {
	background: #fff
}
.mc4wp-form input[type=date],
.mc4wp-form input[type=email],
.mc4wp-form input[type=number],
.mc4wp-form input[type=text] {
	width: 100%
}
.mc4wp-form input[type=checkbox] {
	display: inline-block;
	vertical-align: middle
}
.mc4wp-form input[type=submit] {
	display: block;
	width: 100%;
	font-size: 14px;
	padding: 18px 20px;
	text-transform: uppercase;
	color: #313131;
	margin: 0;
	cursor: pointer;
	border: none;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	background: #f5f5f5
}
.mc4wp-form input[type=submit]:hover {
	background: var(--pcaccent-cl);
	color: #fff
}
div.wpforms-container .wpforms-form.wpforms-form .wpforms-field:not(:last-child) {
	padding: 0 0 28px 0
}
div.wpforms-container .wpforms-form.wpforms-form .wpforms-field-label {
	color: #939393;
	font-size: 12px;
	display: block;
	font-family: var(--pchead-font);
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
	margin-bottom: 8px
}
div.wpforms-container .wpforms-form.wpforms-form input[type=date],
div.wpforms-container .wpforms-form.wpforms-form input[type=datetime-local],
div.wpforms-container .wpforms-form.wpforms-form input[type=datetime],
div.wpforms-container .wpforms-form.wpforms-form input[type=email],
div.wpforms-container .wpforms-form.wpforms-form input[type=month],
div.wpforms-container .wpforms-form.wpforms-form input[type=number],
div.wpforms-container .wpforms-form.wpforms-form input[type=password],
div.wpforms-container .wpforms-form.wpforms-form input[type=range],
div.wpforms-container .wpforms-form.wpforms-form input[type=search],
div.wpforms-container .wpforms-form.wpforms-form input[type=tel],
div.wpforms-container .wpforms-form.wpforms-form input[type=text],
div.wpforms-container .wpforms-form.wpforms-form input[type=time],
div.wpforms-container .wpforms-form.wpforms-form input[type=url],
div.wpforms-container .wpforms-form.wpforms-form input[type=week],
div.wpforms-container .wpforms-form.wpforms-form select,
div.wpforms-container .wpforms-form.wpforms-form textarea {
	padding: 12px 20px;
	border: 1px solid #dedede;
	font-size: 12px;
	width: 100%;
	font-weight: 400;
	font-family: var(--pcbody-font);
	max-height: 50px;
	height: auto;
	background: 0 0
}
div.wpforms-container .wpforms-form .wpforms-field-label-inline {
	font-size: inherit;
	font-weight: inherit;
	line-height: 1.3
}
div.wpforms-container-full .wpforms-form label.wpforms-error {
	margin-top: 5px
}
div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button,
div.wpforms-container .wpforms-form.wpforms-form button[type=submit],
div.wpforms-container .wpforms-form.wpforms-form input[type=submit] {
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	background: #f5f5f5;
	border-radius: 0;
	font-size: 14px;
	color: #313131;
	padding: 12px 20px;
	display: inline-block;
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	cursor: pointer;
	width: auto;
	min-width: 120px;
	text-align: center;
	margin: 0;
	border: none
}
.mc4wp-form input[type=submit]:hover,
div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button:hover,
div.wpforms-container .wpforms-form.wpforms-form button[type=submit]:hover,
div.wpforms-container .wpforms-form.wpforms-form input[type=submit]:hover {
	color: #fff;
	border: none;
	background: var(--pcaccent-cl)
}
.footer-widget-wrapper .widget .jr-insta-thumb,
.penci-sidebar-content .widget .jr-insta-thumb {
	margin: -5px -5px 0 -5px
}
.footer-widget-wrapper .widget .jr-insta-thumb ul.thumbnails li,
.penci-sidebar-content .widget .jr-insta-thumb ul.thumbnails li {
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s;
	margin: 0
}
.footer-widget-wrapper .widget .jr-insta-thumb ul.thumbnails li:hover,
.penci-sidebar-content .widget .jr-insta-thumb ul.thumbnails li:hover {
	opacity: .8
}
.footer-widget-wrapper .widget .jr-insta-thumb ul.thumbnails li img,
.penci-sidebar-content .widget .jr-insta-thumb ul.thumbnails li img {
	padding: 5px;
	width: 100%
}
.jr-insta-thumb ul.thumbnails li img {
	width: 100%
}
.widget .jr-insta-thumb ul.thumbnails {
	margin: 0
}
.widget .jr-insta-thumb ul.thumbnails.jr_col_2 li {
	width: 50% !important
}
.widget .jr-insta-thumb ul.thumbnails.jr_col_3 li {
	width: 33.3333% !important
}
.widget .jr-insta-thumb ul.thumbnails.jr_col_4 li {
	width: 25% !important
}
.widget .jr-insta-thumb ul.thumbnails.jr_col_5 li {
	width: 20% !important
}
.pllexislider .pllex-direction-nav {
	background: 0 0 !important;
	border-radius: 0 !important;
	-webkit-border-radius: 0 !important;
	-moz-border-radius: 0 !important
}
.pllexislider .pllex-direction-nav .pllex-next {
	margin-left: 1px
}
.pllexislider .pllex-direction-nav li a {
	width: 40px;
	height: 40px;
	line-height: 40px !important;
	background: rgba(0, 0, 0, .5);
	text-align: center
}
.pllexislider .pllex-direction-nav li {
	border: none !important
}
.pllexislider .pllex-direction-nav .pllex-next:before,
.pllexislider .pllex-direction-nav .pllex-prev:before {
	font-family: FontAwesome, sans-serif !important;
	padding: 0 !important;
	text-shadow: none !important;
	font-size: 22px !important
}
.penci-fawesome-ver5 .pllexislider .pllex-direction-nav .pllex-next:before,
.penci-fawesome-ver5 .pllexislider .pllex-direction-nav .pllex-prev:before {
	font-family: "Font Awesome 5 Free" !important;
	font-weight: 900
}
.pllexislider .pllex-direction-nav .pllex-next:before {
	content: "\f105" !important
}
.pllexislider .pllex-direction-nav .pllex-prev:before {
	content: "\f104" !important
}
.pllexislider-overlay ul li .jr-insta-wrap .jr-insta-datacontainer .jr-insta-caption {
	font-size: 12px !important;
	line-height: 1.5em !important;
	margin-top: 8px !important;
	margin-bottom: 0 !important
}
.pllexislider-overlay ul li .jr-insta-wrap .jr-insta-datacontainer {
	text-shadow: none !important;
	padding-top: 10px !important;
	padding-bottom: 10px !important
}
.penci-instaslider-normal .penci-insta-datacontainer {
	margin-top: 5px;
	margin-bottom: 5px;
	display: block
}
.penci-instaslider-normal .penci-insta-datacontainer .penci-insta-username {
	text-decoration: none;
	display: inline-block
}
.penci-instaslider-normal .penci-insta-datacontainer .penci-insta-time {
	float: right;
	display: inline-block;
	text-align: right;
	display: none
}
.penci-instaslider-normal .penci-insta-datacontainer .penci-insta-caption {
	line-height: normal;
	margin-top: 5px;
	margin-bottom: 5px;
	display: block;
	clear: both
}
.penci-instaslider-overlay a {
	color: #fff;
	text-decoration: none
}
.penci-instaslider-overlay .penci-insta-wrap {
	position: relative;
	color: #fff;
	line-height: normal
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer {
	opacity: 0;
	visibility: hidden;
	transition: all .3s;
	position: absolute;
	left: 0;
	bottom: 0;
	width: 100%;
	text-shadow: 0 0 5px rgba(0, 0, 0, .7);
	background: rgba(0, 0, 0, .4);
	padding: 5px 15px;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box
}
.penci-instaslider-overlay .penci-insta-info:hover .penci-insta-wrap .penci-insta-datacontainer {
	opacity: 1;
	visibility: visible
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer .penci-insta-username a {
	color: #fff !important;
	text-decoration: none;
	font-weight: 700
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer .penci-insta-time {
	float: right;
	text-align: right
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer .penci-insta-caption {
	line-height: normal;
	color: #fff;
	margin-top: 5px;
	margin-bottom: 5px;
	display: block
}
.penci-insta-thumb .penci-image-holder {
	border-radius: 0;
	-webkit-border-radius: 0
}
.penci-insta-thumb ul.thumbnails {
	list-style: none;
	font-size: 0;
	margin-left: -2.5%;
	padding: 0;
	margin-bottom: 0
}
.penci-insta-thumb ul.thumbnails.no-border {
	margin-left: 0
}
.penci-insta-thumb ul.thumbnails li {
	display: inline-block;
	padding: 0;
	margin: 0 0 2.5% 2.5%;
	background: 0 0;
	border: 0;
	vertical-align: top;
	box-shadow: none;
	box-sizing: border-box;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box
}
.penci-insta-thumb ul.thumbnails.no-border li {
	margin: 0
}
.penci-insta-thumb ul.thumbnails li img {
	max-width: 100% !important;
	height: auto !important;
	margin: 0 !important;
	border: 0 !important;
	vertical-align: top
}
.penci-insta-thumb ul.thumbnails li a {
	margin: 0;
	padding: 0;
	border: 0;
	font-size: 100%;
	font: inherit;
	vertical-align: baseline
}
.penci-insta-thumb ul.thumbnails.penci-inscol1 li {
	width: 97.5% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol2 li {
	width: 47.5% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol3 li {
	width: 30.83% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol4 li {
	width: 22.5% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol5 li {
	width: 17.5% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol6 li {
	width: 16.66% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol7 li {
	width: 14.28% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol8 li {
	width: 12.5% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol9 li {
	width: 11.11% !important
}
.penci-insta-thumb ul.thumbnails.penci-inscol10 li {
	width: 10% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol1 li {
	width: 100% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol2 li {
	width: 50% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol3 li {
	width: 33.33% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol4 li {
	width: 25% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol5 li {
	width: 20% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol6 li {
	width: 16.66% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol7 li {
	width: 14.28% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol8 li {
	width: 12.5% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol9 li {
	width: 11.11% !important
}
.penci-insta-thumb ul.thumbnails.no-border.penci-inscol10 li {
	width: 10% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol1 li {
	width: 100% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol6 li {
	width: 16.66% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol7 li {
	width: 14.28% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol8 li {
	width: 12.5% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol9 li {
	width: 11.11% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol10 li {
	width: 10% !important
}
.penci-insta-thumb .penci-image-holder:before {
	padding-top: 100%
}
@media all and (max-width:640px) {
	.penci-insta-thumb ul.thumbnails.penci-inscol3 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol4 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol5 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol6 li {
		width: 47.5% !important
	}
	.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol6 li {
		width: 33.3333% !important
	}
	.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol10 li,
	.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol7 li,
	.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol8 li,
	.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol9 li {
		width: 25% !important
	}
	.penci-insta-thumb ul.thumbnails.penci-inscol10 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol7 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol8 li,
	.penci-insta-thumb ul.thumbnails.penci-inscol9 li {
		width: 22.5% !important
	}
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol3 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol4 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol5 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol6 li {
		width: 50% !important
	}
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol10 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol7 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol8 li,
	.penci-insta-thumb ul.thumbnails.no-border.penci-inscol9 li {
		width: 25% !important
	}
}
@media all and (max-width:480px) {
	.penci-insta-thumb ul.thumbnails li {
		width: 100% !important
	}
}
.footer-widget-wrapper .widget .penci-insta-thumb,
.penci-sidebar-content .widget .penci-insta-thumb,
.penci_instagram_widget-sc .penci-insta-thumb {
	margin: -5px -5px 0 -5px
}
.penci_instagram_widget-sc.penci_insta-thumbs-no-border .penci-insta-thumb {
	margin: 0
}
.footer-widget-wrapper .widget .penci-insta-thumb ul.thumbnails li,
.penci-sidebar-content .widget .penci-insta-thumb ul.thumbnails li,
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails li {
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s;
	margin: 0
}
.footer-widget-wrapper .widget .penci-insta-thumb ul.thumbnails li:hover,
.penci-sidebar-content .widget .penci-insta-thumb ul.thumbnails li:hover,
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails li:hover {
	opacity: .8
}
.footer-widget-wrapper .widget .penci-insta-thumb ul.thumbnails li a,
.penci-sidebar-content .widget .penci-insta-thumb ul.thumbnails li a,
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails li a {
	padding: 5px;
	width: 100%
}
.penci_instagram_widget-sc.penci_insta-thumbs-no-border .penci-insta-thumb ul.thumbnails li a {
	padding: 0
}
.penci-insta-thumb ul.thumbnails li img {
	width: 100%
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails,
.widget .penci-insta-thumb ul.thumbnails {
	margin: 0
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol2 li,
.widget .penci-insta-thumb ul.thumbnails.penci-inscol2 li {
	width: 50% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol3 li,
.widget .penci-insta-thumb ul.thumbnails.penci-inscol3 li {
	width: 33.3333% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol4 li,
.widget .penci-insta-thumb ul.thumbnails.penci-inscol4 li {
	width: 25% !important
}
.penci_instagram_widget-sc .penci-insta-thumb ul.thumbnails.penci-inscol5 li,
.widget .penci-insta-thumb ul.thumbnails.penci-inscol5 li {
	width: 20% !important
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer .penci-insta-caption {
	font-size: 12px !important;
	line-height: 1.5em !important;
	margin-top: 8px !important;
	margin-bottom: 0 !important
}
.penci-instaslider-overlay .penci-insta-wrap .penci-insta-datacontainer {
	text-shadow: none !important;
	padding-top: 10px !important;
	padding-bottom: 10px !important
}
.footer-subscribe {
	text-align: center;
	padding: 50px 0 40px;
	background-color: #f7f7f7
}
.footer-subscribe h4.footer-subscribe-title {
	font-size: 32px;
	letter-spacing: 0;
	text-transform: none;
	margin-bottom: 10px;
	line-height: 1.3
}
.footer-subscribe .mc4wp-form {
	max-width: 540px;
	margin: 0 auto
}
.footer-subscribe .mc4wp-form-fields:after,
.footer-subscribe .mc4wp-form-fields:before,
.footer-subscribe .mc4wp-form:after,
.footer-subscribe .mc4wp-form:before {
	content: "";
	display: table;
	clear: both
}
.footer-subscribe .mc4wp-form .mdes {
	color: #5c5c5e;
	font-size: 18px;
	font-style: italic;
	line-height: 1.5;
	width: 740px;
	display: block;
	clear: both;
	margin-bottom: 23px;
	margin-left: -100px
}
.footer-subscribe .mc4wp-form .mname {
	display: none
}
.footer-subscribe .mc4wp-form .memail {
	display: inline-block;
	float: left;
	width: 390px
}
.footer-subscribe .mc4wp-form .msubmit {
	display: inline-block;
	float: left;
	width: 140px;
	margin-left: 10px
}
.mc4wp-response {
	clear: both;
	color: #5c5c5e
}
.mc4wp-response p {
	line-height: 1.4;
	color: #5c5c5e
}
.footer-subscribe .widget .mc4wp-form input[type=email],
.footer-subscribe .widget .mc4wp-form input[type=text] {
	background: 0 0;
	border-radius: 0;
	border-color: #d7d7da;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	padding-top: 0;
	padding-bottom: 0;
	height: 48px;
	line-height: 48px;
	font-size: 14px;
	margin: 0;
	color: #313131
}
.footer-subscribe input[type=email]::-webkit-input-placeholder {
	color: #313131
}
.footer-subscribe input[type=email]:-moz-placeholder {
	color: #313131;
	opacity: 1
}
.footer-subscribe input[type=email]::-moz-placeholder {
	color: #313131;
	opacity: 1
}
.footer-subscribe input[type=email]:-ms-input-placeholder {
	color: #313131
}
.footer-subscribe input[type=email]::-ms-input-placeholder {
	color: #313131
}
.footer-subscribe input[type=text]::-webkit-input-placeholder {
	color: #313131
}
.footer-subscribe input[type=text]:-moz-placeholder {
	color: #313131;
	opacity: 1
}
.footer-subscribe input[type=text]::-moz-placeholder {
	color: #313131;
	opacity: 1
}
.footer-subscribe input[type=text]:-ms-input-placeholder {
	color: #313131
}
.footer-subscribe input[type=text]::-ms-input-placeholder {
	color: #313131
}
.footer-subscribe .widget .mc4wp-form input[type=email]:focus,
.footer-subscribe .widget .mc4wp-form input[type=email]:hover,
.footer-subscribe .widget .mc4wp-form input[type=text]:focus,
.footer-subscribe .widget .mc4wp-form input[type=text]:hover {
	border-color: #888
}
.footer-subscribe .widget .mc4wp-form input[type=submit] {
	background: #313131;
	border-radius: 0;
	color: #fff;
	padding-top: 0;
	padding-bottom: 0;
	height: 48px;
	line-height: 48px;
	padding: 0;
	text-align: center
}
.footer-subscribe .widget .mc4wp-form input[type=submit]:hover {
	background: var(--pcaccent-cl)
}
.footer-instagram {
	width: 100%;
	clear: both;
	display: block;
	position: relative
}
.footer-instagram .widget {
	margin: 0
}
.footer-instagram h4.footer-instagram-title {
	position: relative;
	white-space: nowrap;
	margin: 0;
	width: 100%;
	color: #313131;
	text-align: center;
	padding: 12px 0;
	border-top: 1px solid #ececec
}
.footer-instagram.penci-top-instagram h4.footer-instagram-title {
	border-top: none
}
.footer-instagram h4.footer-instagram-title span {
	display: inline-block;
	position: relative;
	padding: 0;
	background: inherit;
	color: inherit;
	text-transform: uppercase;
	font-size: 16px;
	z-index: 20;
	vertical-align: top
}
.footer-instagram h4.footer-instagram-title span.title {
	padding: 0;
	background: 0 0;
	position: relative;
	z-index: 10
}
.footer-instagram h4.footer-instagram-title>span:before {
	content: "\f16d";
	font-family: FontAwesome;
	font-size: 16px;
	color: inherit;
	margin-right: 8px;
	display: inline-block;
	vertical-align: middle;
	letter-spacing: 0;
	margin-bottom: 3px
}
.penci-fawesome-ver5 .footer-instagram h4.footer-instagram-title>span:before {
	font-family: "Font Awesome 5 Brands" !important;
	font-weight: 900
}
.footer-instagram .jr-insta-thumb {
	position: relative;
	z-index: 1
}
.footer-instagram .jr-insta-thumb ul.thumbnails li {
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s
}
.footer-instagram .jr-insta-thumb ul.thumbnails li:hover {
	opacity: .9
}
.jr-insta-thumb ul.thumbnails li a {
	position: relative;
	display: inline-block;
	vertical-align: top !important;
	width: 100%
}
.jr-insta-thumb ul.thumbnails li a:after,
.jr-insta-thumb ul.thumbnails li a:before {
	position: absolute;
	left: 10px;
	right: 10px;
	top: 10px;
	bottom: 10px;
	content: "";
	opacity: 0;
	-webkit-transition: opacity .35s, -webkit-transform .35s;
	transition: opacity .35s, transform .35s
}
.footer-instagram .jr-insta-thumb ul.thumbnails li a:after,
.footer-instagram .jr-insta-thumb ul.thumbnails li a:before {
	top: 5px;
	right: 5px;
	bottom: 5px;
	left: 5px
}
.penci-insta-thumb ul.thumbnails li a {
	position: relative;
	display: inline-block;
	vertical-align: top !important;
	width: 100%
}
.penci-insta-thumb ul.thumbnails li a:after,
.penci-insta-thumb ul.thumbnails li a:before {
	position: absolute;
	left: 10px;
	right: 10px;
	top: 10px;
	bottom: 10px;
	content: "";
	opacity: 0;
	z-index: 10;
	-webkit-transition: opacity .35s, -webkit-transform .35s;
	transition: opacity .35s, transform .35s
}
.footer-instagram .penci-insta-thumb ul.thumbnails li a:after,
.footer-instagram .penci-insta-thumb ul.thumbnails li a:before {
	top: 5px;
	right: 5px;
	bottom: 5px;
	left: 5px
}
.penci-insta-thumb ul.thumbnails li a:before {
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transform: scale(0, 1);
	transform: scale(0, 1)
}
.penci-insta-thumb ul.thumbnails li a:after {
	border-right: 1px solid #fff;
	border-left: 1px solid #fff;
	-webkit-transform: scale(1, 0);
	transform: scale(1, 0)
}
.penci-insta-thumb ul.thumbnails li a:hover:after,
.penci-insta-thumb ul.thumbnails li a:hover:before {
	opacity: 1;
	-webkit-transform: scale(1);
	transform: scale(1)
}
.jr-insta-thumb ul.thumbnails li a:before {
	border-top: 1px solid #fff;
	border-bottom: 1px solid #fff;
	-webkit-transform: scale(0, 1);
	transform: scale(0, 1)
}
.jr-insta-thumb ul.thumbnails li a:after {
	border-right: 1px solid #fff;
	border-left: 1px solid #fff;
	-webkit-transform: scale(1, 0);
	transform: scale(1, 0)
}
.jr-insta-thumb ul.thumbnails li a:hover:after,
.jr-insta-thumb ul.thumbnails li a:hover:before {
	opacity: 1;
	-webkit-transform: scale(1);
	transform: scale(1)
}
.footer-instagram.penci-insta-title-overlay h4.footer-instagram-title {
	position: absolute;
	top: 50%;
	margin-top: -25px;
	padding: 0;
	border: none
}
.footer-instagram.penci-insta-title-overlay h4.footer-instagram-title>span {
	display: inline-block;
	line-height: 50px;
	padding: 0 20px;
	background: #fff
}
.footer-instagram.penci-insta-title-overlay h4.footer-instagram-title>span,
.footer-instagram.penci-insta-title-overlay h4.footer-instagram-title>span>span {
	font-size: 13px
}
.footer-instagram.penci-insta-title-overlay h4.footer-instagram-title>span:before {
	font-size: 15px;
	margin-bottom: 0
}
form#commentform>div.penci-gdpr-message {
	line-height: 1.5;
	margin: -4px 0 15px;
	font-size: 14px;
	color: #777
}
.post-comments .post-title-box {
	border-top: 1px solid #dedede;
	padding-top: 36px
}
body.single-portfolio .post-comments .post-title-box {
	border-top: none
}
h3.comment-reply-title {
	padding-top: 36px !important;
	border-top: 1px solid #dedede
}
.comments .comment {
	border-top: 1px solid #dedede
}
.comments .comment>.comment:first-child,
.comments>.comment:first-child {
	border-top: none
}
.thecomment {
	padding-top: 28px;
	padding-bottom: 21px;
	display: table;
	width: 100%
}
.comments>.comment:first-child>.thecomment {
	padding-top: 0
}
.thecomment .author-img {
	float: left;
	margin-right: 20px;
	width: 60px
}
.thecomment .author-img img {
	margin: 0;
	width: 100%
}
.thecomment .comment-text {
	margin-left: 80px;
	position: relative
}
.thecomment .comment-text span.author,
.thecomment .comment-text span.author a {
	display: block;
	font-size: 13px;
	text-transform: uppercase;
	color: #313131;
	margin-bottom: 11px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.thecomment .comment-text span.author a {
	display: inline-block;
	margin: 0
}
.thecomment .comment-text span.author a:hover {
	color: #9e9e9e
}
.thecomment .comment-text span.date {
	font-size: 12px;
	color: #888;
	display: block
}
.thecomment .comment-text span.date i {
	margin-right: 5px
}
.thecomment .comment-text>em {
	font-size: 12px;
	display: block;
	color: orange;
	margin: 5px 0 0
}
.thecomment .comment-text>em i {
	font-size: 14px;
	color: #f3bd00
}
.thecomment .comment-content {
	margin-top: 15px;
	margin-bottom: 0
}
.thecomment .comment-text span.reply {
	position: absolute;
	top: 0;
	right: 0
}
.post-comments span.reply a {
	font-size: 11px;
	color: #888;
	margin-left: 18px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	text-transform: uppercase;
	line-height: 1;
	display: inline-block;
	text-align: center
}
.post-comments span.reply a:hover {
	color: #313131
}
.comments .children,
.comments>.comment>.comment,
.comments>.comment>.comment>.comment,
.comments>.comment>.comment>.comment>.comment,
.comments>.comment>.comment>.comment>.comment>.comment {
	margin: 0 0 0 60px
}
@media only screen and (max-width:767px) {
	.comment-respond .comment-reply-title small {
		display: block;
		margin-top: 15px
	}
}
#respond {
	overflow: hidden;
	margin-bottom: 40px;
	position: relative
}
.no-comment-yet #respond {
	padding-top: 0;
	border-top: 0
}
#respond h3 {
	font-size: 14px;
	color: #939393;
	font-weight: 500;
	margin-bottom: 30px;
	font-family: var(--pchead-font);
	text-transform: uppercase
}
#respond h3 a {
	color: #000;
	display: inline-block
}
#respond h3 small a {
	text-transform: uppercase;
	font-size: 12px;
	color: #888;
	padding: 0;
	margin-left: 7px;
	letter-spacing: 0;
	-o-transition: .3s;
	-ms-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	font-weight: 500;
	position: absolute;
	right: 0
}
#respond h3 small a:hover {
	color: #313131
}
form.wpcf7-form {
	margin-left: -14px;
	margin-right: -14px
}
#respond form#commentform {
	margin: 0
}
#respond form#commentform>iframe.jetpack_remote_comment {
	max-width: calc(100% - 1px)
}
.mc4wp-form label {
	text-align: left;
	margin-bottom: 10px;
	display: block
}
#respond p.comment-form-author,
#respond p.comment-form-email,
#respond p.comment-form-url,
.wpcf7 p.email,
.wpcf7 p.name,
.wpcf7 p.subject {
	width: 33.333333%;
	padding: 0 14px;
	float: left;
	display: inline-block;
	margin: 0
}
#respond p.comment-form-author,
#respond p.comment-form-email,
#respond p.comment-form-url {
	width: 32%;
	margin-left: 2%;
	padding: 0
}
.wpcf7 .ajax-loader {
	display: none
}
.wpcf7 form.submitting .ajax-loader {
	display: inline-block
}
#respond p.comment-form-author {
	margin-left: 0
}
#respond #add_comment_rating_wrap,
#respond .review-title-form,
#respond p.comment-form-comment {
	clear: both;
	margin: 0
}
#respond #add_comment_rating_wrap {
	position: relative;
	font-size: 12px;
	display: block;
	margin-bottom: 20px
}
#add_comment_rating_wrap i {
	color: #ffb900
}
#add_post_rating {
	position: absolute;
	bottom: 0;
	right: 0;
	visibility: hidden
}
.wpcf7 p.message {
	clear: both;
	margin: 0 14px
}
form#commentform>div,
form#commentform>input,
form#commentform>label,
form#commentform>p,
form#commentform>span,
form#commentform>textarea,
form.comment-form>div,
form.comment-form>input,
form.comment-form>label,
form.comment-form>p,
form.comment-form>span,
form.comment-form>textarea,
form.wpcf7-form>div,
form.wpcf7-form>input,
form.wpcf7-form>label,
form.wpcf7-form>p,
form.wpcf7-form>span,
form.wpcf7-form>textarea {
	margin: 0 14px
}
form#commentform>input[type=checkbox] {
	margin-left: 14px !important;
	margin-right: 14px !important
}
form.wpcf7-form>div.wpcf7-response-output {
	margin-left: 14px;
	margin-right: 14px
}
form#commentform>p.comment-form-mailpoet,
form#commentform>p.mc4wp-checkbox {
	margin-left: 0
}
.captchaSizeDivLarge {
	clear: both
}
label#captcha_code_label {
	display: inline-block
}
form#commentform>p.comment-subscription-form {
	margin-top: 15px;
	margin-left: 0;
	line-height: 1.3
}
form#commentform>p.comment-subscription-form:last-child {
	margin-top: 5px
}
form#commentform>p.comment-subscription-form input[type=checkbox] {
	margin: 0;
	vertical-align: top
}
#respond p.comment-subscription-form label {
	vertical-align: top
}
form#commentform p.comment-subscription-form label,
form#commentform p.mc4wp-checkbox label {
	font-family: inherit;
	font-size: inherit;
	text-transform: inherit;
	letter-spacing: inherit;
	font-weight: inherit;
	color: #777
}
#respond label,
.wpcf7 label {
	color: #939393;
	font-size: 12px;
	display: block;
	font-family: var(--pchead-font);
	text-transform: none;
	font-weight: var(--pchead-wei);
	margin-bottom: 8px
}
#respond .comment-form label {
	font-family: inherit;
	font-weight: inherit;
	font-size: inherit;
	color: inherit;
	letter-spacing: 0
}
#respond .comment-form #add_comment_rating_wrap label {
	font-family: var(--pcbody-font);
	font-weight: inherit;
	font-size: inherit;
	color: var(--pctext-cl);
	letter-spacing: 0;
	font-size: 14px
}
#respond .comment-form-cookies-consent label {
	display: inline
}
#respond p.form-submit,
.wpcf7 p.submit {
	margin: 0 14px;
	text-align: center;
	clear: both
}
#respond p.form-submit {
	margin: 0
}
.pclg-2col:after,
.pclg-2col:before,
.penci-login-register:after,
.penci-login-register:before {
	content: "";
	display: table;
	width: 100%
}
#respond input,
.penci-login-register input[type=email],
.penci-login-register input[type=number],
.penci-login-register input[type=password],
.penci-login-register input[type=text],
.widget_wysija input,
.wpcf7 input {
	padding: 12px 20px;
	max-width: 100%;
	border: 1px solid #dedede;
	margin-bottom: 28px;
	font-size: 14px;
	width: 100%;
	font-weight: 400;
	font-family: var(--pcbody-font);
	max-height: 50px;
	background: 0 0
}
#respond input:focus,
.penci-login-register input:focus,
.wpcf7 input:focus {
	outline: 0
}
.jetpack_subscription_widget #subscribe-email input {
	width: 100% !important;
	padding: 12px 20px !important;
	margin-top: 10px
}
#respond textarea,
.penci-login-register textarea,
.wpcf7 textarea {
	padding: 15px 20px;
	border: 1px solid #dedede;
	width: 100%;
	height: 120px;
	font-size: 14px;
	color: #313131;
	margin-bottom: 28px;
	line-height: 20px;
	font-weight: 400;
	outline: 0;
	vertical-align: top;
	font-family: var(--pcbody-font)
}
#respond textarea:focus,
.penci-login-register textarea:focus,
.wpcf7 textarea:focus {
	outline: 0
}
#respond #submit,
.penci-login-register input[type=submit],
.widget_wysija input[type=submit],
.wpcf7 input[type=submit] {
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	background: #f5f5f5;
	border-radius: 0;
	font-size: 14px;
	color: #313131;
	padding: 12px 20px;
	display: inline-block;
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	cursor: pointer;
	width: auto;
	min-width: 120px;
	text-align: center;
	margin: 0;
	border: none
}
#respond #submit:hover,
.penci-login-register input[type=submit]:hover,
.widget_wysija input[type=submit]:hover,
.wpcf7 input[type=submit]:hover {
	color: #fff;
	background: var(--pcaccent-cl)
}
.contact-form input[type=email],
.contact-form input[type=text] {
	max-width: 300px;
	width: 100%;
	padding: 10px 15px
}
.contact-form input[type=submit] {
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	background: #f5f5f5;
	border-radius: 0;
	font-size: 14px;
	color: #313131;
	padding: 16px 20px;
	display: inline-block;
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	cursor: pointer;
	width: auto;
	min-width: 120px;
	text-align: center;
	margin: 0;
	border: none
}
.widget input[type=date],
.widget input[type=email],
.widget input[type=number],
.widget input[type=password],
.widget input[type=search],
.widget input[type=text] {
	border: 1px solid #dedede;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	outline: 0;
	background: 0 0;
	display: block;
	font-size: 13px;
	padding: 11px 20px;
	margin-bottom: 20px;
	letter-spacing: 0;
	font-family: var(--pcbody-font);
	width: 100%;
	max-width: 100%;
	display: block;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	cursor: auto;
	height: auto;
	vertical-align: baseline;
	line-height: normal
}
.penci-button,
.widget button[type=submit],
.widget input[type=submit] {
	display: block;
	width: 100%;
	font-size: 14px;
	padding: 12px 20px;
	text-transform: uppercase;
	color: #313131;
	margin: 0;
	cursor: pointer;
	border: none;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	background: #f5f5f5;
	max-width: 100%;
	outline: 0
}
.penci-button,
.widget button[type=submit]:hover,
.widget input[type=submit]:hover {
	background: var(--pcaccent-cl);
	color: #fff
}
#respond input[type=checkbox],
#respond input[type=radio],
.widget input[type=checkbox],
.widget input[type=radio],
.widget_wysija input[type=checkbox],
.widget_wysija input[type=radio],
.wpcf7 input[type=checkbox],
.wpcf7 input[type=radio] {
	width: auto;
	margin: 0;
	padding: 0
}
form#commentform>.comment-form-cookies-consent {
	margin: 0 0 15px 0;
	clear: both;
	line-height: 1.4;
	color: #777
}
#respond .comment-form-cookies-consent input[type=checkbox] {
	margin-right: 5px;
	transform: translateY(2px);
	-webkit-transform: translateY(2px)
}
@media only screen and (min-width:768px) {
	.post-comments.penci-comments-hide-1 #respond input,
	.post-comments.penci-comments-hide-2 #respond input {
		max-width: 100%
	}
	.post-comments.penci-comments-hide-1 #respond p.comment-form-author,
	.post-comments.penci-comments-hide-1 #respond p.comment-form-email,
	.post-comments.penci-comments-hide-1 #respond p.comment-form-url {
		width: 49%
	}
	.post-comments.penci-comments-hide-1 #respond .comment-form>p:nth-child(2) {
		margin-left: 0
	}
	.post-comments.penci-comments-hide-2 #respond p.comment-form-author,
	.post-comments.penci-comments-hide-2 #respond p.comment-form-email,
	.post-comments.penci-comments-hide-2 #respond p.comment-form-url {
		width: 100%;
		margin-left: 0;
		margin-right: 0
	}
}
.penci-sidebar-content .wp-block-search {
	margin-bottom: 0
}
.wp-block-search .wp-block-search__label {
	display: block
}
.widget_block.widget_search input[type=search] {
	margin: 0
}
.widget_block.widget_search button[type=submit] {
	margin-left: .625em;
	width: auto;
	white-space: nowrap
}
.widget_block.widget_search .wp-block-search__no-button .wp-block-search__inside-wrapper {
	position: relative
}
.widget_block.widget_search .wp-block-search__no-button .wp-block-search__inside-wrapper:before {
	content: "\f108";
	font-family: penciicon;
	font-style: normal;
	font-weight: 400;
	display: inline-block;
	position: absolute;
	color: var(--pctext-cl);
	top: 50%;
	transform: translateY(-50%);
	-webkit-transform: translateY(-50%);
	right: 20px;
	z-index: 1;
	font-size: 15px;
	opacity: .9
}
.widget_block.widget_search .wp-block-search__no-button input[type=search] {
	padding-right: 40px
}
.widget_block.widget_search .wp-block-search__no-button input[type=search]::-webkit-search-cancel-button {
	display: none
}
.widget.widget_block .wp-block-latest-posts {
	padding: 0 !important;
	border: none
}
.widget .wp-block-group>div>h1 {
	margin-bottom: 20px;
	font-size: 24px
}
.widget .wp-block-group>div>h2 {
	margin-bottom: 20px;
	font-size: 20px
}
.widget .wp-block-group>div>h3:not(.penci-border-arrow) {
	margin-bottom: 20px;
	font-size: 18px
}
.widget .wp-block-group>div>h4 {
	margin-bottom: 20px;
	font-size: 17px
}
.widget .wp-block-group>div>h5 {
	margin-bottom: 20px;
	font-size: 16px
}
.widget .wp-block-group>div>h6 {
	margin-bottom: 20px;
	font-size: 14px
}
.wp-block-search.wp-block-search__button-inside .wp-block-search__inside-wrapper .wp-block-search__button,
.wp-block-search.wp-block-search__button-outside .wp-block-search__inside-wrapper .wp-block-search__button {
	padding: 8px 15px
}
.wp-block-search.wp-block-search__button-inside .wp-block-search__inside-wrapper {
	border-color: var(--pcborder-cl)
}
.penci-sidebar-content .widget.penci_block_heading_widget {
	margin-bottom: 0
}
.archive-box {
	background: 0 0;
	margin: 0 0 30px 0;
	position: relative;
	text-align: center
}
.archive-box.container {
	margin-left: auto;
	margin-right: auto;
}
.archive-box:after,
.archive-box:before {
	content: none
}
.archive-box:before {
	width: 60px;
	bottom: -5px;
	margin-left: -30px
}
.archive-box .title-bar {
	position: relative;
	display: block
}
.archive-box .title-bar.pcatitle-right {
	text-align: right;
}
.archive-box .title-bar.pcatitle-left {
	text-align: left;
}
.archive-box .title-bar.pcatitle-center {
	text-align: center;
}
.archive-box h1,
.archive-box span {
	color: #313131;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-transform: uppercase;
	font-size: 24px;
	line-height: 1.2em;
	position: relative;
	z-index: 10
}
.archive-box h1 {
	display: inline-block;
	color: var(--pcaccent-cl)
}
.archive-box .pccat-count {
	--size: 35px;
	min-width: var(--size);
	height: var(--size);
	display: inline-flex;
	background: var(--pcheading-cl);
	line-height: var(--size);
	margin-left: 10px;
	color: var(--pcbg-cl);
	padding-left: 5px;
	padding-right: 5px;
	justify-content: center;
	align-content: center;
}
.pc-title-bar-sorter form {
	display: flex;
	column-gap: 10px;
	flex-wrap: wrap;
	flex-direction: row;
}
.pc-title-bar-sorter form select {
	flex: 1 calc(50% - 10px);
}
.nothing {
	margin-bottom: 60px;
	text-align: center
}
.nothing span {
	position: relative;
	z-index: 10;
	color: inherit;
	font-size: 14px
}
.penci-category-description {
	margin-bottom: 35px;
	line-height: 1.8
}
.penci-category-description.pcdesc-left {
	text-align: left
}
.penci-category-description.pcdesc-center {
	text-align: center
}
.penci-category-description.pcdesc-right {
	text-align: right
}
.container.penci-breadcrumb,
.penci-container-inside.penci-breadcrumb {
	line-height: 1.4;
	margin-bottom: 20px
}
.container.penci-breadcrumb {
	margin-top: calc(25px - var(--pchd-mg));
	clear: both
}
.container.penci-breadcrumb.penci-crumb-inside {
	width: 100%;
	margin-top: 0
}
.post-image .container.penci-breadcrumb {
	width: 100%;
	margin-bottom: 20px
}
.single.penci-body-single-style-5 .container.penci-breadcrumb,
.single.penci-body-single-style-6 .container.penci-breadcrumb {
	margin-bottom: 20px
}
.penci-header-text-white .container.penci-breadcrumb {
	margin-top: 0
}
.wrapper-boxed.penci-page-hide-header .container.penci-breadcrumb {
	margin-top: 10px
}
.penci-container-inside.penci-breadcrumb {
	margin-top: -5px
}
.wrapper-boxed.penci-page-hide-header .featured-area+.container.penci-breadcrumb {
	margin-top: calc(25px - var(--pchd-mg))
}
.page #sidebar-nav+.container.penci-breadcrumb {
	margin-top: 0
}
.container.penci-breadcrumb a,
.container.penci-breadcrumb span,
.container.penci-breadcrumb span a,
.penci-container-inside.penci-breadcrumb a,
.penci-container-inside.penci-breadcrumb span,
.penci-container-inside.penci-breadcrumb span a {
	font-size: 13px;
	color: #888
}
.container.penci-breadcrumb a:hover,
.container.penci-breadcrumb span a:hover,
.penci-container-inside.penci-breadcrumb a:hover,
.penci-container-inside.penci-breadcrumb span a:hover {
	color: var(--pcaccent-cl)
}
.container.penci-breadcrumb i,
.container.penci-breadcrumb span.separator,
.penci-container-inside.penci-breadcrumb i,
.penci-container-inside.penci-breadcrumb span.separator {
	color: #888;
	font-size: 13px;
	margin: 0 15px 0 19px
}
.container.penci-breadcrumb span.separator,
.penci-container-inside.penci-breadcrumb span.separator {
	margin: 0 15px 0 15px
}
.container.penci-woo-breadcrumb,
.penci-container-inside.penci-woo-breadcrumb {
	width: 100% !important;
	margin-top: 0
}
.penci-page-header {
	margin: 0 0 30px 0;
	text-align: center;
	position: relative
}
.penci-page-header:after,
.penci-page-header:before {
	content: none
}
.penci-page-header h1 {
	font-size: 24px;
	color: #313131;
	text-transform: uppercase
}
.alignnone {
	margin: 5px 0 20px 0
}
.post-entry p>.alignnone {
	margin: 5px 0 0 0
}
.aligncenter,
.video-align-center,
div.aligncenter {
	display: block;
	margin: 5px auto 20px auto
}
.alignright,
.video-align-right {
	float: right;
	margin: 5px 0 20px 20px
}
.alignleft,
.video-align-left {
	float: left;
	margin: 5px 20px 20px 0
}
.video-align-left,
.video-align-right {
	display: block;
	width: 100%
}
.aligncenter {
	display: block;
	margin: 5px auto 20px auto
}
a img.alignright {
	float: right;
	margin: 5px 0 17px 30px
}
a img.alignnone {
	margin: 5px 20px 20px 0
}
a img.alignleft {
	float: left;
	margin: 5px 30px 17px 0
}
a img.aligncenter {
	display: block;
	margin-left: auto;
	margin-right: auto
}
.wp-caption {
	background: 0 0;
	border: none;
	padding: 0;
	max-width: 100%;
	text-align: center;
	position: relative;
	overflow: hidden
}
.wp-caption.alignnone {
	margin: 5px 0 17px 0
}
.wp-caption.alignleft {
	margin: 5px 30px 17px 0
}
.wp-caption.alignright {
	margin: 5px 0 17px 30px
}
.wp-caption img {
	border: 0 none;
	height: auto;
	margin: 0;
	max-width: 100%;
	padding: 0;
	width: 100%
}
.penci-featured-caption,
.wp-caption p.wp-caption-text {
	font-size: 14px;
	line-height: 1.4;
	margin: 0;
	padding: 11px 10px;
	color: #fff;
	font-style: italic;
	position: absolute;
	bottom: 0;
	left: 0;
	width: 100%;
	background: rgba(0, 0, 0, .5);
	transition: all .4s;
	-webkit-transition: all .4s;
	-moz-transition: all .4s
}
.wp-caption p.wp-caption-text {
	text-align: center
}
.post-image:hover .penci-featured-caption,
.wp-caption:hover p.wp-caption-text {
	transform: translateY(100%);
	-webkit-transform: translateY(100%);
	opacity: .7
}
.penci-single-style-3 .penci-featured-caption,
.penci-single-style-3 .post-image .penci-owl-carousel figure p,
.penci-single-style-16 .penci-featured-caption,
.penci-single-style-16 .post-image .penci-owl-carousel figure p,
.penci-single-style-7 .penci-featured-caption,
.penci-single-style-7 .post-image .penci-owl-carousel figure p {
	bottom: 40px;
	text-align: left;
	display: inline-block;
	width: auto;
	transform: none !important;
	opacity: 1 !important;
	padding: 10px 20px;
	left: 0;
	right: auto
}
.penci-single-style-7 .penci-featured-caption,
.penci-single-style-7 .post-image .penci-owl-carousel figure p,
.penci-single-style-16 .penci-featured-caption,
.penci-single-style-16 .post-image .penci-owl-carousel figure p {
	width: 100%;
	text-align: center
}
.penci-featured-caption.penci-fixed-caption {
	transform: none !important;
	opacity: 1 !important;
	z-index: 3;
}
.penci-single-style-14 .penci-featured-caption.penci-fixed-caption {
	bottom: 55px;
	margin-left: 40px;
}
.penci-single-style-16 .penci-featured-caption.penci-fixed-caption,
.penci-single-style-22 .penci-featured-caption.penci-fixed-caption {
	bottom: auto;
	top: 0;
}
.penci-featured-caption.penci-fixed-caption.penci-caption-relative {
	position: static;
	background: 0 0;
	padding: 0;
	display: block;
	margin-top: 10px
}
.penci-featured-caption.penci-fixed-caption.penci-caption-relative:before {
	content: none;
	display: none
}
.penci-featured-caption.penci-fixed-caption.penci-caption-relative a {
	color: inherit
}
@media only screen and (min-width: 961px) {
	.penci-single-style-13.penci-two-sidebar .penci-single-s13-content,
	.penci-two-sidebar .penci-single-style-16 {
		--pcctain: var(--pcctain2);
	}
}
@media only screen and (max-width:960px) {
	.penci-single-style-3 .penci-featured-caption,
	.penci-single-style-3 .post-image .penci-owl-carousel figure p,
	.penci-single-style-16 .penci-featured-caption,
	.penci-single-style-16 .post-image .penci-owl-carousel figure p,
	.penci-single-style-7 .penci-featured-caption,
	.penci-single-style-7 .post-image .penci-owl-carousel figure p {
		bottom: 0;
		width: 100%;
		text-align: center
	}
	.penci-single-style-14 .penci-featured-caption.penci-fixed-caption {
		bottom: 0;
  		margin-left: 0;
	}
}
.penci-body-single-style-12.penci-body-title-bellow .penci-single-style-12 {
	margin-bottom: 0;
}
.penci-single-style-12 .post-image {
	overflow: visible;
}
@media only screen and (min-width: 768px){
	.penci-single-style-12 .post-image .standard-post-special_wrapper.two-sidebar,
	.penci-single-style-12 .post-image .standard-post-special_wrapper {
		padding: 40px 40px 0;
		background: var(--pcbg-cl);
		bottom: -95px;
		width: calc(var(--pcctain) - 8%);
	}
	.penci-single-style-12 {
		margin-bottom: 105px;
	}
}
@media only screen and (min-width: 1401px){
	.penci-single-style-12 .post-image .standard-post-special_wrapper.two-sidebar {
		max-width: calc(var(--pcctain2) - 8%);
	}
}
@media only screen and (min-width: 961px) and (max-width: 1400px) {
	.penci-single-style-12 .post-image .standard-post-special_wrapper.two-sidebar {
		max-width: 92%;
	}
}
.penci-single-style-12 .container.penci-breadcrumb {
	margin-top: 0;
}
.post-entry pre {
	display: block;
	font-size: 14px;
	word-break: break-all;
	word-wrap: break-word;
	white-space: pre-wrap;
	background-color: #f4f4f4;
	border: 1px solid rgba(0, 0, 0, .1);
	margin: 0 0 20px;
	line-height: 1.4;
	padding: 15px;
	letter-spacing: 0;
	color: inherit
}
.post-entry code {
	padding: 2px;
	border-radius: 2px;
	color: #23282d;
	background: #f4f4f4;
	font-family: Menlo, Consolas, monaco, monospace;
	font-size: inherit;
	border: none
}
.penci-single-block {
	display: block;
	clear: both
}
.penci-ldsingle {
	display: block;
	clear: both;
	text-align: center;
	width: 100%;
	margin: 30px 0
}
.penci-ldspinner {
	display: inline-block;
	vertical-align: top
}
.penci-ldspinner>div {
	width: 18px;
	height: 18px;
	margin: 0 5px;
	background-color: var(--pcaccent-cl);
	border-radius: 100%;
	display: inline-block;
	-webkit-animation: sk-bouncedelay 1.2s infinite ease-in-out both;
	animation: sk-bouncedelay 1.2s infinite ease-in-out both
}
.penci-ldspinner .bounce1 {
	-webkit-animation-delay: -.32s;
	animation-delay: -.32s
}
.penci-ldspinner .bounce2 {
	-webkit-animation-delay: -.16s;
	animation-delay: -.16s
}
@-webkit-keyframes sk-bouncedelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1)
	}
}
@keyframes sk-bouncedelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1);
		transform: scale(1)
	}
}
.penci-single-infiads {
	margin: 10px 0 40px;
	clear: both;
	display: block;
	overflow: hidden;
	width: 100%;
	text-align: center
}
.penci-single-infiscroll .penci-single-block:not(:first-child) .container.penci-breadcrumb {
	margin-top: 0
}
.widget .zframe-flickr-wrap-ltr,
.widget ul.instagram-pics {
	list-style: none;
	margin: 0;
	padding: 0;
	overflow: hidden;
	margin-left: -3px;
	margin-right: -3px
}
.widget .zframe-flickr-wrap-ltr .flickr_badge_image,
.widget ul.instagram-pics li {
	display: block;
	float: left;
	width: 33.33%;
	padding: 3px;
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	margin: 0 !important;
	border: none !important
}
.widget .zframe-flickr-wrap-ltr .flickr_badge_image img {
	margin: 0;
	width: 100%;
	float: none;
	height: auto
}
.instag ul.thumbnails>li,
.jr-insta-thumb ul>li {
	width: 32% !important
}
.instag ul li,
.jr-insta-thumb ul li {
	margin: 0;
	padding-bottom: 0;
	border-bottom: none
}
.pllexislider ul li {
	margin: 0;
	padding-bottom: 0;
	border-bottom: none
}
.pllexislider-normal ul li .jr-insta-datacontainer .jr-insta-caption,
.pllexislider-normal ul li .jr-insta-datacontainer .jr-insta-time,
.pllexislider-normal ul li .jr-insta-datacontainer .jr-insta-username {
	line-height: 1.5
}
.gallery .gallery-caption {
	font-size: 13px;
	color: #939393;
	font-family: var(--pchead-font);
	font-style: italic
}
.gallery .gallery-icon img {
	border-radius: 2px;
	border: 1px solid #eee !important;
	padding: 7px
}
.gallery .gallery-icon img:hover {
	border: 1px solid #ccc !important
}
.penci-post-gallery-container {
	margin-bottom: 20px
}
.penci-post-gallery-container a {
	opacity: 0
}
.penci-post-gallery-container.single-slider a,
.penci-post-gallery-container.thumbnail-slider a {
	opacity: 1
}
.penci-post-gallery-container.single-slider figure,
.penci-post-gallery-container.thumbnail-slider figure,
.post-image .penci-owl-carousel figure {
	position: relative
}
.penci-post-gallery-container.single-slider figure p,
.penci-post-gallery-container.thumbnail-slider figure p,
.post-image .penci-owl-carousel figure p {
	margin: 0;
	position: absolute;
	bottom: 0;
	right: 0;
	display: inline-block;
	vertical-align: top;
	background: rgba(0, 0, 0, .6);
	color: #fff;
	padding: 7px 15px;
	font-style: italic;
	font-size: 13px;
	line-height: 1.4;
	z-index: 2
}
.penci-post-gallery-container.thumbnail-slider figure p {
	right: 15px;
	max-width: calc(100% - 30px);
	text-align: right
}
.justified-gallery>a>.caption,
.justified-gallery>div>.caption {
	font-family: inherit;
	font-weight: inherit;
	padding: 9px 15px;
	line-height: 1.5;
	background: rgba(0, 0, 0, .6);
	opacity: 1
}
.penci-post-gallery-container.masonry .item-gallery-masonry {
	width: 33.33333%;
	float: left;
	margin-bottom: 6px;
	padding: 0 3px;
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	display: inline-block;
	position: relative
}
.penci-post-gallery-container.masonry.column-2 .item-gallery-masonry {
	width: 50%
}
.penci-post-gallery-container.masonry.column-4 .item-gallery-masonry {
	width: 25%
}
.penci-post-gallery-container.masonry .item-gallery-masonry a {
	position: relative;
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s;
	-webkit-animation-delay: .1s;
	-moz-animation-delay: .1s;
	-o-animation-delay: .1s;
	animation-delay: .1s;
	display: inline-block;
	width: 100%
}
.penci-post-gallery-container.masonry .item-gallery-masonry a.animated {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp;
	opacity: 1
}
.masonry.column-2 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(2n+2) a,
.masonry.column-3 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(3n+2) a,
.masonry.column-4 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(4n+2) a {
	-webkit-animation-delay: .3s;
	-moz-animation-delay: .3s;
	-o-animation-delay: .3s;
	animation-delay: .3s
}
.masonry.column-3 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(3n+3) a,
.masonry.column-4 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(4n+3) a {
	-webkit-animation-delay: .6s;
	-moz-animation-delay: .6s;
	-o-animation-delay: .6s;
	animation-delay: .6s
}
.masonry.column-4 .inner-gallery-masonry-container .item-gallery-masonry:nth-child(4n+4) a {
	-webkit-animation-delay: .9s;
	-moz-animation-delay: .9s;
	-o-animation-delay: .9s;
	animation-delay: .9s
}
.penci-post-gallery-container.masonry {
	margin-left: -3px;
	margin-right: -3px
}
.penci-post-gallery-container.masonry img {
	width: 100%
}
.penci-post-gallery-container.masonry .inner-gallery-masonry-container {
	display: inline-block;
	width: 100%;
	vertical-align: top
}
.inner-item-masonry-gallery {
	position: relative
}
.penci-post-gallery-container.masonry .item-gallery-masonry .caption {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	margin: 0;
	color: #fff;
	font-size: 13px;
	font-family: inherit;
	font-weight: inherit;
	padding: 9px 15px;
	line-height: 1.5;
	background: rgba(0, 0, 0, .6);
	opacity: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	z-index: 2
}
.penci-post-gallery-container.masonry .item-gallery-masonry:hover .caption {
	opacity: 1
}
.penci-tweets-widget-content ul li {
	margin: 0 !important;
	padding: 0 !important;
	border: none !important
}
.penci-slider.penci-tweets-slider ul.slides li:after,
.penci-slider.penci-tweets-slider ul.slides li:before {
	content: none !important;
	display: none !important
}
.penci-tweets-widget-content .icon-tweets {
	display: block;
	text-align: center;
	margin-bottom: 12px;
	font-size: 32px;
	color: var(--pcaccent-cl);
	margin-top: -10px
}
.penci-tweets-widget-content .tweet-text {
	color: #313131;
	margin-bottom: 10px;
	text-align: center
}
.penci-tweets-widget-content .tweet-intents {
	text-align: center;
	overflow: hidden;
	line-height: 1
}
.penci-tweets-widget-content .tweet-intents a {
	color: var(--pcaccent-cl);
	font-size: 13px;
	font-style: italic
}
.penci-tweets-widget-content .tweet-intents span:after {
	content: "/";
	margin: 0 5px;
	font-size: 11px;
	color: var(--pcaccent-cl);
	font-family: var(--pcbody-font)
}
.penci-tweets-widget-content .tweet-intents span:last-child:after {
	content: none;
	display: none
}
.penci-tweets-widget-content .tweet-intents-inner {
	display: inline-block;
	vertical-align: top;
	position: relative
}
.penci-tweets-widget-content .tweet-intents-inner:after,
.penci-tweets-widget-content .tweet-intents-inner:before {
	content: "";
	position: absolute;
	top: 50%;
	width: 250px;
	height: 1px;
	background: var(--pcaccent-cl);
	right: 100%;
	margin-right: 15px;
	opacity: .5
}
.penci-tweets-widget-content .tweet-intents-inner:after {
	right: auto;
	left: 100%;
	margin-right: 0;
	margin-left: 15px
}
.penci-tweets-widget-content .tweet-date {
	line-height: 1.8;
	white-space: nowrap;
	text-align: center;
	margin-bottom: 9px;
	opacity: .7;
	font-size: 14px
}
.penci-owl-carousel.penci-tweets-slider .penci-owl-dots {
	position: static;
	margin-top: 23px !important
}
.penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot {
	margin: 0 4px
}
.penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot span {
	width: 10px;
	height: 10px;
	box-shadow: none;
	-webkit-box-shadow: none;
	border: 1px solid #d4d4d4
}
.penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot.active span,
.penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot:hover span {
	border-color: var(--pcaccent-cl);
	background: var(--pcaccent-cl)
}
.penci-tweets-widget-content.pc_alignleft .icon-tweets,
.penci-tweets-widget-content.pc_alignleft .penci-owl-carousel-slider .penci-owl-dots,
.penci-tweets-widget-content.pc_alignleft .tweet-date,
.penci-tweets-widget-content.pc_alignleft .tweet-intents,
.penci-tweets-widget-content.pc_alignleft .tweet-text {
	text-align: left
}
.penci-tweets-widget-content.pc_alignright .icon-tweets,
.penci-tweets-widget-content.pc_alignright .penci-owl-carousel-slider .penci-owl-dots,
.penci-tweets-widget-content.pc_alignright .tweet-date,
.penci-tweets-widget-content.pc_alignright .tweet-intents,
.penci-tweets-widget-content.pc_alignright .tweet-text {
	text-align: right
}
div.wpcf7 {
	overflow: hidden;
	margin-top: 40px
}
span.wpcf7-not-valid-tip {
	margin-top: -15px;
	margin-bottom: 15px
}
div.wpcf7-response-output {
	margin: 20px 14px 1em;
	padding: .6em 1em;
	margin-top: 20px !important
}
.error-404 {
	text-align: center;
	margin: 150px 0 112px
}
.error-image {
	position: relative;
	padding-bottom: 41px;
	margin-bottom: 30px
}
.error-image img {
	display: block;
	margin-left: auto;
	margin-right: auto
}
.error-image:after {
	content: "";
	position: absolute;
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	bottom: 0;
	left: 50%;
	margin-left: -30px
}
.error-404 .sub-heading-text-404 {
	font-size: 16px;
	font-weight: 400;
	margin: 0;
	color: #313131;
	text-align: center
}
.error-404 form.pc-searchform {
	margin: 31px 0 0;
	padding: 0 10px
}
.error-404 form.pc-searchform .pc-searchform-inner {
	width: 100%;
	max-width: 350px;
	margin: 0 auto;
	position: relative
}
.error-404 .go-back-home {
	margin-top: 50px;
	text-align: center
}
.error-404 .go-back-home a {
	font-size: 12px;
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-decoration: none;
	line-height: 1.5;
	position: relative;
	display: inline-block;
	padding-bottom: 1px
}
.error-404 .go-back-home a:after {
	position: absolute;
	width: 100%;
	height: 1px;
	bottom: 0;
	left: 0;
	background: var(--pcaccent-cl);
	content: ""
}
.penci-mailchimp-block {
	--pcmc-height: 40px;
	--pcmc-bdw: 1px
}
.penci-mailchimp-block input[type=date],
.penci-mailchimp-block input[type=email],
.penci-mailchimp-block input[type=number],
.penci-mailchimp-block input[type=search],
.penci-mailchimp-block input[type=text] {
	border-width: var(--pcmc-bdw)
}
.penci-header-signup-form {
	display: block;
	padding: 20px 0;
	background: var(--pcaccent-cl);
	margin: -50px 0 60px;
	clear: both
}
.penci-header-signup-form.penci-header-signup-form-below {
	padding-left: 20px;
	padding-right: 20px;
	margin-left: auto;
	margin-right: auto
}
.elementor-template-full-width .wrapper-boxed>.penci-header-signup-form {
	display: none
}
.penci-header-signup-form .mc4wp-form {
	margin: 0;
	width: 100%;
	max-width: 100%;
	color: #fff
}
.penci-header-signup-form .mc4wp-form>form {
	display: table;
	width: 100%
}
.penci-header-signup-form h4.header-signup-form {
	text-align: center;
	margin-bottom: 18px;
	font-size: 24px;
	color: #fff;
	text-transform: uppercase
}
.penci-header-signup-form .mc4wp-form-fields {
	display: table;
	width: 100%
}
.penci-header-signup-form .mc4wp-form-fields>p,
.penci-header-signup-form form>p {
	display: table-cell;
	text-align: left;
	color: #fff;
	padding-right: 20px;
	line-height: 1.5;
	vertical-align: middle
}
.penci-header-signup-form .mc4wp-form-fields>p:last-of-type,
.penci-header-signup-form form>p:last-of-type {
	padding-right: 0
}
.penci-header-signup-form .mc4wp-form-fields>p:first-of-type,
.penci-header-signup-form form>p:first-of-type {
	max-width: 500px
}
.penci-header-signup-form .mc4wp-form input[type=email],
.penci-header-signup-form .mc4wp-form input[type=text] {
	margin: 0;
	margin-right: 20px;
	border-color: #fff;
	color: #fff
}
.penci-header-signup-form .mc4wp-form input[type=email]::-webkit-input-placeholder,
.penci-header-signup-form .mc4wp-form input[type=text]::-webkit-input-placeholder {
	color: #fff
}
.penci-header-signup-form .mc4wp-form input[type=email]:-moz-placeholder,
.penci-header-signup-form .mc4wp-form input[type=text]:-moz-placeholder {
	color: #fff;
	opacity: 1
}
.penci-header-signup-form .mc4wp-form input[type=email]::-moz-placeholder,
.penci-header-signup-form .mc4wp-form input[type=text]::-moz-placeholder {
	color: #fff;
	opacity: 1
}
.penci-header-signup-form .mc4wp-form input[type=email]:-ms-input-placeholder,
.penci-header-signup-form .mc4wp-form input[type=text]:-ms-input-placeholder {
	color: #fff
}
.penci-header-signup-form .widget input[type=submit] {
	color: #313131;
	background: #fff
}
.penci-header-signup-form .mc4wp-alert,
.penci-header-signup-form .mc4wp-error {
	margin-top: 15px
}
.penci-mailchimp-s3 {
	--pcmc-height: 48px
}
.penci-mailchimp-block .mc4wp-form-fields .memail input,
.penci-mailchimp-block .mc4wp-form-fields .mname input {
	padding: 0 20px;
	line-height: calc(var(--pcmc-height) - 2 * var(--pcmc-bdw))
}
.penci-mailchimp-block .mc4wp-form-fields .msubmit input {
	padding: 0 20px;
	line-height: var(--pcmc-height)
}
@media only screen and (min-width:1170px) {
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields>p {
		margin-bottom: 0 !important
	}
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields {
		display: flex;
		align-items: center
	}
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields .mdes {
		flex: 1 1 400px
	}
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields .memail,
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields .mname {
		flex: 1 1 200px
	}
	.penci-mailchimp-s2 .penci-header-signup-form .mc4wp-form-fields .msubmit {
		flex: 0 0 auto
	}
}
.penci-mailchimp-s4 .mc4wp-form-fields {
	display: flex;
	align-items: center;
	margin-left: -5px;
	margin-right: -5px
}
@media only screen and (max-width:479px) {
	.penci-mailchimp-s4 .mc4wp-form-fields {
		flex-wrap: wrap
	}
}
.penci-mailchimp-s4 .mc4wp-form-fields .memail,
.penci-mailchimp-s4 .mc4wp-form-fields .mname {
	flex: 1 1 200px;
	padding: 0 5px
}
.penci-mailchimp-s4 .mc4wp-form-fields .msubmit {
	flex: 0 0 auto;
	padding: 0 5px
}
.penci-mailchimp-s4 .mc4wp-form-fields .memail,
.penci-mailchimp-s4 .mc4wp-form-fields .mname,
.penci-mailchimp-s4 .mc4wp-form-fields .msubmit {
	margin-bottom: 10px !important
}
.penci-mailchimp-s4 .mc4wp-form-fields .memail input,
.penci-mailchimp-s4 .mc4wp-form-fields .mname input,
.penci-mailchimp-s4 .mc4wp-form-fields .msubmit input {
	margin-bottom: 0 !important
}
.penci-mailchimp-s4 .mc4wp-form-fields .mdes,
.penci-mailchimp-s4 .mc4wp-form-fields .mname {
	display: none
}
.penci-portfolio-thumbnail .penci-image-placeholder {
	position: relative;
	display: block;
	background-color: #eee;
	background-repeat: no-repeat;
	background-position: center center;
	background-size: cover;
	-webkit-background-size: cover
}
.penci-portfolio-thumbnail .penci-image-placeholder>img {
	position: absolute;
	display: block;
	max-width: 100%;
	width: 100%;
	height: 100%;
	top: 0;
	left: 0
}
.wrapper-penci-portfolio {
	width: 100%;
	overflow: hidden
}
.penci-portfolio-filter {
	display: block;
	text-align: center;
	margin: 0 0 15px 0
}
.penci-portfolio-filter ul,
.post-entry .penci-portfolio-filter ul {
	list-style: none;
	display: inline-block;
	vertical-align: top;
	padding: 0 !important;
	margin: 0
}
.penci-portfolio-filter ul li,
.post-entry .penci-portfolio-filter ul li {
	display: inline-block;
	float: left;
	margin: 0 15px 5px;
	padding: 0
}
.penci-portfolio-filter ul li a,
.post-entry .penci-portfolio-filter ul li a {
	color: #313131;
	font-family: var(--pchead-font)
}
.penci-portfolio-filter ul li a:hover,
.penci-portfolio-filter ul li.active a,
.post-entry .penci-portfolio-filter ul li a:hover,
.post-entry .penci-portfolio-filter ul li.active a {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.penci-portfolio-wrap {
	margin-left: -10px;
	margin-right: -10px
}
.penci-portfolio-wrap .inner-portfolio-posts {
	display: inline-block;
	width: 100%;
	vertical-align: top
}
.inner-portfolio-posts .portfolio-item {
	width: 33.33333%;
	padding: 0 10px;
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	float: left;
	margin-bottom: 20px
}
.container .penci-portfolio.column-2 .inner-portfolio-posts .portfolio-item,
.penci-portfolio.column-2 .inner-portfolio-posts .portfolio-item {
	width: 50%
}
.inner-item-portfolio {
	position: relative;
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .7s;
	-moz-animation-duration: .7s;
	-ms-animation-duration: .7s;
	-o-animation-duration: .7s;
	animation-duration: .7s;
	-webkit-animation-delay: .1s;
	-moz-animation-delay: .1s;
	-o-animation-delay: .1s;
	animation-delay: .1s
}
.penci-portfolio-wrap.column-2 .portfolio-item:nth-child(2n+1) .inner-item-portfolio,
.penci-portfolio-wrap.column-3 .portfolio-item:nth-child(3n+2) .inner-item-portfolio {
	-webkit-animation-delay: .4s;
	-moz-animation-delay: .4s;
	-o-animation-delay: .4s;
	animation-delay: .4s
}
.penci-portfolio-wrap.column-3 .portfolio-item:nth-child(3n+3) .inner-item-portfolio {
	-webkit-animation-delay: .7s;
	-moz-animation-delay: .7s;
	-o-animation-delay: .7s;
	animation-delay: .7s
}
.pcpt-ajax-ftl .inner-portfolio-posts.loaded .inner-item-portfolio.animated,
.penci-portfolio.loaded .inner-item-portfolio.animated {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp;
	opacity: 1
}
.penci-portfolio-thumbnail a:after {
	opacity: 0;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	background: #fff;
	content: "";
	-webkit-transition: .5s;
	transition: .5s;
	z-index: 10
}
.inner-item-portfolio:hover .penci-portfolio-thumbnail a:after {
	opacity: .87
}
.inner-item-portfolio .portfolio-desc {
	position: absolute;
	text-align: center;
	top: 50%;
	width: 100%;
	padding: 0 10px;
	margin: 0;
	z-index: 12;
	-webkit-transform: translateY(-50%);
	-ms-transform: translateY(-50%);
	transform: translateY(-50%)
}
.inner-item-portfolio a {
	text-decoration: none !important
}
.inner-item-portfolio .portfolio-desc h3 {
	opacity: 0;
	text-transform: uppercase;
	font-size: 14px;
	margin-bottom: 10px;
	position: relative;
	-webkit-transform: translateY(15px);
	-ms-transform: translateY(15px);
	transform: translateY(15px);
	-webkit-transition: .3s cubic-bezier(.215, .61, .355, 1) 0s;
	transition: .3s cubic-bezier(.215, .61, .355, 1) 0s;
	transition-delay: .2s;
	-webkit-transition-delay: .2s;
	-moz-transition-delay: .2s;
	color: #313131
}
.inner-item-portfolio .portfolio-desc span {
	opacity: 0;
	font-size: 12px;
	display: block;
	vertical-align: top;
	line-height: 1.3;
	text-decoration: none;
	color: #888;
	-webkit-transform: translateY(-15px);
	-ms-transform: translateY(-15px);
	transform: translateY(-15px);
	-webkit-transition: .3s cubic-bezier(.215, .61, .355, 1) 0s;
	transition: .3s cubic-bezier(.215, .61, .355, 1) 0s;
	transition-delay: .2s;
	-webkit-transition-delay: .2s;
	-moz-transition-delay: .2s
}
.inner-item-portfolio .portfolio-desc span del {
	margin-right: 5px;
	transform: translateY(2px);
	-webkit-transform: translateY(2px);
	display: inline-block
}
.inner-item-portfolio .portfolio-desc span span {
	display: inline-block
}
.inner-item-portfolio .portfolio-desc span del span {
	text-decoration: inherit
}
.inner-item-portfolio .portfolio-desc span ins span {
	font-size: 13px
}
.inner-item-portfolio:hover .portfolio-desc h3,
.inner-item-portfolio:hover .portfolio-desc span {
	opacity: 1;
	-webkit-transform: translateY(0);
	-ms-transform: translateY(0);
	transform: translateY(0)
}
.penci-portfolio-below_img .inner-item-portfolio .portfolio-desc {
	margin-top: 20px;
	position: relative;
	top: 0;
	transform: none
}
.penci-portfolio-below_img .inner-item-portfolio .portfolio-desc h3,
.penci-portfolio-below_img .inner-item-portfolio .portfolio-desc span {
	opacity: 1;
	-webkit-transform: translateY(0);
	-ms-transform: translateY(0);
	transform: translateY(0)
}
.penci-portfolio-below_img .penci-portfolio-thumbnail a:after {
	content: none
}
.single-portfolio-thumbnail {
	margin-bottom: 26px;
	text-align: center;
	vertical-align: top
}
.portfolio-page-content .portfolio-detail {
	margin: 0 auto;
	max-width: 1000px
}
.project-pagination a {
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	text-transform: uppercase;
	font-size: 13px
}
.project-pagination .next-post a:after {
	display: inline-block;
	color: inherit;
	content: "\f178";
	font-family: FontAwesome;
	font-size: 14px;
	margin-left: 5px
}
.project-pagination .prev-post a:before {
	display: inline-block;
	color: inherit;
	content: "\f177";
	font-family: FontAwesome;
	font-size: 14px;
	margin-right: 5px
}
.penci-fawesome-ver5 .project-pagination .next-post a:after,
.penci-fawesome-ver5 .project-pagination .prev-post a:before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900
}
.tags-share-box.hide-tags.page-share.no-border-bottom-portfolio {
	border-bottom: none
}
.penci-plf-loadmore {
	position: relative
}
.penci-pfl-ajaxdot {
	display: inline-block;
	width: 30px;
	height: 30px;
	background-color: #111;
	border-radius: 100%;
	-webkit-animation: scaleoutPortfolio 1s infinite ease-in-out;
	animation: scaleoutPortfolio 1s infinite ease-in-out;
	z-index: 50;
	opacity: 0;
	position: absolute;
	top: 5px;
	left: 50%;
	margin-left: -15px;
	visibility: hidden
}
.penci-ajax-more-button.loading-portfolios .penci-pfl-ajaxdot {
	opacity: 1;
	z-index: 100;
	visibility: visible
}
.penci-ajax-more-button.loading-portfolios .ajax-more-text {
	opacity: 0;
	visibility: hidden
}
.penci-ajax-more-button.loading-portfolios {
	background: 0 0 !important;
	color: transparent !important;
	border-color: transparent !important
}
@-webkit-keyframes scaleoutPortfolio {
	0% {
		-webkit-transform: scale(0)
	}
	100% {
		-webkit-transform: scale(1);
		opacity: 0
	}
}
@keyframes scaleoutPortfolio {
	0% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	100% {
		-webkit-transform: scale(1);
		transform: scale(1);
		opacity: 0
	}
}
.portfolio-page-content .portfolio-detail {
	margin-left: 0;
	margin-right: 0
}
.penci-portfolio-meta-wrapper {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	margin: 30px -15px;
	--pc-pf-ct-w: 60%;
	--pc-pf-mt-w: 40%
}
.penci-portfolio-meta-wrapper .penci-page-header {
	text-align: left;
	padding-left: 15px;
	padding-right: 15px
}
.penci-portfolio-meta-wrapper .penci-portfolio-col {
	width: var(--pc-pf-ct-w);
	padding-left: 15px;
	padding-right: 15px
}
.penci-portfolio-meta-wrapper .penci-meta-lists {
	width: var(--pc-pf-mt-w)
}
@media only screen and (max-width:767px) {
	.penci-portfolio-meta-wrapper .penci-meta-lists {
		width: 100%
	}
}
.penci-portfolio-meta-wrapper .penci-shortdesc {
	width: var(--pc-pf-ct-w)
}
@media only screen and (max-width:767px) {
	.penci-portfolio-meta-wrapper .penci-shortdesc {
		width: 100%
	}
}
ul.portfolio-meta-lists {
	list-style: none;
	margin: 0;
	padding: 0;
	display: table;
	width: 100%
}
ul.portfolio-meta-lists li {
	display: table-row
}
ul.portfolio-meta-lists li:not(:last-child) span {
	padding-bottom: 10px
}
ul.portfolio-meta-lists span {
	display: table-cell
}
ul.portfolio-meta-lists span.title {
	font-weight: 700;
	min-width: 70px;
	padding-right: 10px
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row
}
@media only screen and (max-width:767px) {
	.container:not(.penci_sidebar) .post-entry.portfolio-style-3 {
		flex-direction: column-reverse
	}
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .penci-portfolio-meta-wrapper {
	flex-direction: column;
	margin-top: 0;
	margin-bottom: 0
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .penci-portfolio-meta-wrapper .penci-portfolio-col {
	width: 100%
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .penci-portfolio-meta-wrapper,
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .portfolio-page-content {
	flex: 0 0 auto
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .penci-portfolio-meta-wrapper {
	width: 29.06%
}
@media only screen and (max-width:767px) {
	.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .penci-portfolio-meta-wrapper {
		width: 100%
	}
}
.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .portfolio-page-content {
	width: 70.94%;
	padding-left: 60px
}
@media only screen and (max-width:767px) {
	.container:not(.penci_sidebar) .post-entry.portfolio-style-3 .portfolio-page-content {
		width: 100%;
		padding-left: 0
	}
}
.container.no_content .post-entry.portfolio-style-3 .portfolio-page-content {
	width: 100%;
	padding-left: 0
}
.penci-sidebar-content .penci-portfolio-meta-wrapper {
	flex-direction: column;
	margin-top: 0;
	margin-bottom: 60px
}
.penci-sidebar-content .penci-portfolio-meta-wrapper .penci-portfolio-col {
	width: 100%
}
.portfolio-bottom-share {
	text-align: center
}
.portfolio-bottom-share.has-border {
	border-bottom: 1px solid #dedede
}
.portfolio-share-box>span {
	border-top: 1px solid var(--pcborder-cl);
	padding-top: 10px;
	margin-top: 10px
}
.portfolio-bottom-share .portfolio-share-box>span {
	border-top: 0;
	padding-top: 0;
	margin-top: 0
}
.portfolio-share-box.tags-share-box {
	padding-right: 0
}
.portfolio-share-box .share-title {
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	font-size: 12px;
	text-transform: uppercase;
	margin-right: 10px
}
.portfolio-share-box .list-posts-share a {
	color: var(--pcheading-cl);
	text-decoration: none
}
.portfolio-share-box .list-posts-share a:hover {
	color: var(--pcaccent-cl)
}
.portfolio-share-box .list-posts-share a span {
	display: none
}
.portfolio-share-box .list-posts-share a:not(:last-child) {
	margin-right: 10px
}
.portfolio-share-box.style-2 .list-posts-share a,
.portfolio-share-box.style-3 .list-posts-share a,
.portfolio-share-box.style-4 .list-posts-share a {
	display: inline-flex;
	align-items: center;
	justify-content: center;
	width: 36px;
	height: 36px;
	margin-right: 5px;
	transition: all .3s ease-in-out;
	color: #000;
	border: 1px solid var(--pcborder-cl);
	border-radius: 50%
}
.portfolio-share-box.style-2 .list-posts-share a:hover,
.portfolio-share-box.style-3 .list-posts-share a,
.portfolio-share-box.style-3 .list-posts-share a:hover,
.portfolio-share-box.style-4 .list-posts-share a:hover {
	color: #fff
}
.portfolio-share-box.style-2 a.post-share-facebook:hover,
.portfolio-share-box.style-3 a.post-share-facebook,
.portfolio-share-box.style-3 a.post-share-facebook:hover,
.portfolio-share-box.style-4 a.post-share-facebook:hover {
	background-color: #0d47a1;
	border-color: #0d47a1
}
.portfolio-share-box.style-2 a.post-share-twitter:hover,
.portfolio-share-box.style-3 a.post-share-twitter,
.portfolio-share-box.style-3 a.post-share-twitter:hover,
.portfolio-share-box.style-4 a.post-share-twitter:hover {
	background-color: #40c4ff;
	border-color: #40c4ff
}
.portfolio-share-box.style-2 a.post-share-pinterest:hover,
.portfolio-share-box.style-3 a.post-share-pinterest,
.portfolio-share-box.style-3 a.post-share-pinterest:hover,
.portfolio-share-box.style-4 a.post-share-pinterest:hover {
	background-color: #bd081c;
	border-color: #bd081c
}
.portfolio-share-box.style-2 a.post-share-email:hover,
.portfolio-share-box.style-3 a.post-share-email,
.portfolio-share-box.style-3 a.post-share-email:hover,
.portfolio-share-box.style-4 a.post-share-email:hover {
	background-color: #0084ff;
	border-color: #0084ff
}
.portfolio-share-box.style-2 a.post-share-linkedin:hover,
.portfolio-share-box.style-3 a.post-share-linkedin,
.portfolio-share-box.style-3 a.post-share-linkedin:hover,
.portfolio-share-box.style-4 a.post-share-linkedin:hover {
	background-color: #0077b5;
	border-color: #0077b5
}
.portfolio-share-box.style-2 a.post-share-tumblr:hover,
.portfolio-share-box.style-3 a.post-share-tumblr,
.portfolio-share-box.style-3 a.post-share-tumblr:hover,
.portfolio-share-box.style-4 a.post-share-tumblr:hover {
	background-color: #34465d;
	border-color: #34465d
}
.portfolio-share-box.style-2 a.post-share-vk:hover,
.portfolio-share-box.style-3 a.post-share-vk,
.portfolio-share-box.style-3 a.post-share-vk:hover,
.portfolio-share-box.style-4 a.post-share-vk:hover {
	background-color: #5181b8;
	border-color: #5181b8
}
.portfolio-share-box.style-2 a.post-share-pocket:hover,
.portfolio-share-box.style-3 a.post-share-pocket,
.portfolio-share-box.style-3 a.post-share-pocket:hover,
.portfolio-share-box.style-4 a.post-share-pocket:hover {
	background-color: #ef4056;
	border-color: #ef4056
}
.portfolio-share-box.style-2 a.post-share-skype:hover,
.portfolio-share-box.style-3 a.post-share-skype,
.portfolio-share-box.style-3 a.post-share-skype:hover,
.portfolio-share-box.style-4 a.post-share-skype:hover {
	background-color: #00aff0;
	border-color: #00aff0
}
.portfolio-share-box.style-2 a.post-share-whatsapp:hover,
.portfolio-share-box.style-3 a.post-share-whatsapp,
.portfolio-share-box.style-3 a.post-share-whatsapp:hover,
.portfolio-share-box.style-4 a.post-share-whatsapp:hover {
	background-color: #00e676;
	border-color: #00e676
}
.portfolio-share-box.style-2 a.post-share-telegram:hover,
.portfolio-share-box.style-3 a.post-share-telegram,
.portfolio-share-box.style-3 a.post-share-telegram:hover,
.portfolio-share-box.style-4 a.post-share-telegram:hover {
	background-color: #289fd9;
	border-color: #289fd9
}
.portfolio-share-box.style-2 a.post-share-reddit:hover,
.portfolio-share-box.style-3 a.post-share-reddit,
.portfolio-share-box.style-3 a.post-share-reddit:hover,
.portfolio-share-box.style-4 a.post-share-reddit:hover {
	background-color: #f74300;
	border-color: #f74300
}
.portfolio-share-box.style-2 a.post-share-ok:hover,
.portfolio-share-box.style-3 a.post-share-ok,
.portfolio-share-box.style-3 a.post-share-ok:hover,
.portfolio-share-box.style-4 a.post-share-ok:hover {
	background-color: #f18f00;
	border-color: #f18f00
}
.portfolio-share-box.style-2 a.post-share-stumbleupon:hover,
.portfolio-share-box.style-3 a.post-share-stumbleupon,
.portfolio-share-box.style-3 a.post-share-stumbleupon:hover,
.portfolio-share-box.style-4 a.post-share-stumbleupon:hover {
	background-color: #eb4823;
	border-color: #eb4823
}
.portfolio-share-box.style-2 a.post-share-viber:hover,
.portfolio-share-box.style-3 a.post-share-viber,
.portfolio-share-box.style-3 a.post-share-viber:hover,
.portfolio-share-box.style-4 a.post-share-viber:hover {
	background-color: #7d51a0;
	border-color: #7d51a0
}
.portfolio-share-box.style-2 a.post-share-line:hover,
.portfolio-share-box.style-3 a.post-share-line,
.portfolio-share-box.style-3 a.post-share-line:hover,
.portfolio-share-box.style-4 a.post-share-line:hover {
	background-color: #01b901;
	border-color: #01b901
}
.portfolio-share-box.style-3 .list-posts-share a:hover {
	opacity: .85
}
.portfolio-share-box.style-4 .list-posts-share a {
	background-color: #eee;
	border-color: #eee
}
.portfolio-share-box.style-4 .list-posts-share a:hover {
	color: #fff
}
@media only screen and (min-width:768px) {
	.container.portfolio-single-width-no-sidebar-small-container {
		max-width: 770px;
		margin-left: auto;
		margin-right: auto
	}
}
.container.portfolio-single-width-fullwidth {
	width: 100%;
	padding-left: 15px;
	padding-right: 15px
}
.portfolio-releated-area .item-related h3 a {
	letter-spacing: 0;
	text-transform: none;
	font-size: 16px
}
.portfolio-releated-area .item-related .portfolio-cat {
	display: block;
	margin-top: 6px
}
.portfolio-releated-area .item-related .portfolio-cat a {
	color: var(--pcmeta-cl)
}
.portfolio-releated-area .item-related .portfolio-cat a:hover {
	color: var(--pcaccent-cl)
}
.portfolio-releated-area .item-related .portfolio-cat a:not(:last-child):after {
	content: ",";
	display: inline-block
}
.portfolio-page-content .portfolio-detail {
	max-width: unset
}
div.bbp-breadcrumb {
	float: none;
	display: block;
	margin-bottom: 30px
}
.bbp-breadcrumb a,
.bbp-breadcrumb span {
	font-size: 13px;
	color: #888;
	font-family: var(--pchead-font);
	font-weight: 500
}
.bbp-breadcrumb .bbp-breadcrumb-sep {
	color: #888;
	font-size: 13px;
	margin: 0 15px
}
.widget_display_stats dl {
	overflow: hidden
}
.widget_display_stats dd,
.widget_display_stats dt {
	display: inline-block;
	vertical-align: top;
	margin-bottom: 11px;
	padding-bottom: 12px;
	border-bottom: 1px solid #dedede;
	font-size: 14px
}
.widget_display_stats dd:last-of-type,
.widget_display_stats dt:last-of-type {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: none
}
.widget_display_stats dt {
	float: left;
	width: 75%
}
.widget_display_stats dt:before {
	content: "\f105";
	font-family: FontAwesome;
	display: inline-block;
	margin-right: 10px;
	font-size: 90%
}
.penci-fawesome-ver5 .widget_display_stats dt:before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900
}
.widget_display_stats dd {
	float: right;
	font-style: italic;
	color: #888;
	font-family: var(--pcbody-font);
	font-weight: 400;
	text-align: right;
	width: 25%;
	position: relative
}
.widget_display_stats dd strong {
	font-weight: 400
}
div.ppt {
	font-weight: 400
}
.pp_gallery ul,
.pp_gallery ul a {
	height: 62px
}
.pp_gallery {
	margin-top: -65px
}
.pp_nav p {
	line-height: 1
}
.penci-google-adsense,
.penci-google-adsense-1,
.penci-google-adsense-2 {
	margin: 0 0 30px;
	text-align: center;
	overflow: hidden;
	display: block
}
@media only screen and (max-width:767px) {
	.penci-google-adsense,
	.penci-google-adsense-1,
	.penci-google-adsense-2 {
		overflow: visible
	}
}
.penci-google-adsense.penci-google-adsense-footer {
	margin-left: auto;
	margin-right: auto;
	margin-bottom: 50px
}
.penci-adsense-below-slider {
	margin-left: auto;
	margin-right: auto;
	margin-bottom: 60px;
	margin-top: calc(30px - var(--pchd-mg));
	text-align: center
}
.widget_text .textwidget blockquote {
	margin-bottom: 10px;
	padding-left: 40px;
	position: relative
}
.widget_text .textwidget blockquote:before {
	color: #999;
	position: absolute;
	top: 0;
	left: 0;
	font-size: 22px;
	content: "\f10d";
	font-family: FontAwesome;
	line-height: 1
}
.penci-fawesome-ver5 .widget_text .textwidget blockquote:before {
	font-family: "Font Awesome 5 Free";
	font-weight: 900
}
.penci-vernav-enable .penci-menu-hbg {
	box-shadow: 0 0 2px 0 rgba(0, 0, 0, .15);
	-moz-box-shadow: 0 0 2px 0 rgba(0, 0, 0, .15);
	-webkit-box-shadow: 0 0 2px 0 rgba(0, 0, 0, .15)
}
.penci-vernav-toggle {
	position: fixed;
	width: 50px;
	height: 50px;
	display: none;
	line-height: 40px;
	background: 0 0;
	top: 0;
	left: 0;
	z-index: 99997;
	transition: all .5s;
	-webkit-transition: all .5s;
	overflow: hidden
}
.penci-vernav-toggle svg {
	position: absolute;
	top: 5px;
	left: 5px;
	fill: #fff
}
.penci-vernav-poright .penci-vernav-toggle svg {
	left: auto;
	right: 5px
}
.penci-vernav-poright .penci-vernav-toggle {
	right: 0;
	left: auto
}
.penci-vernav-poleft.penci-menuhbg-open .penci-vernav-toggle {
	left: 330px
}
.penci-vernav-poright.penci-menuhbg-open .penci-vernav-toggle {
	right: 330px
}
body.admin-bar .penci-vernav-toggle {
	top: 32px
}
@media screen and (max-width:782px) {
	body.admin-bar .penci-vernav-toggle {
		top: 46px
	}
}
.penci-vernav-toggle:before {
	width: 0;
	height: 0;
	border-top: 50px solid var(--pcaccent-cl);
	border-right: 50px solid transparent;
	content: "";
	display: block
}
.penci-vernav-poright .penci-vernav-toggle:before {
	border-left: 50px solid transparent
}
.penci-vernav-toggle i {
	position: absolute;
	z-index: 10;
	font-size: 14px;
	top: 7px;
	left: 9px;
	font-weight: 400;
	line-height: 1;
	color: #fff
}
body.penci-fawesome-ver5 .penci-vernav-toggle i {
	font-weight: 900
}
.penci-vernav-poright .penci-vernav-toggle i {
	left: auto;
	right: 9px
}
@media only screen and (min-width:961px) {
	.penci-vernav-enable.penci-vernav-poleft .pencipdc_podcast.pencipdc_dock_player,
	.penci-vernav-enable.penci-vernav-poleft .wrapper-boxed {
		padding-left: 330px
	}
	.penci-vernav-enable.penci-vernav-poright .pencipdc_podcast.pencipdc_dock_player,
	.penci-vernav-enable.penci-vernav-poright .wrapper-boxed {
		padding-right: 330px
	}
	.penci-vernav-enable .is-sticky #navigation {
		width: calc(100% - 330px)
	}
	.penci-vernav-enable .penci-menu-hbg {
		transform: none !important;
		-webkit-transform: none !important;
		-moz-transform: none !important
	}
}
@media only screen and (max-width:960px) {
	.penci-vernav-toggle {
		display: inline-block
	}
}
@media only screen and (max-width:479px) {
	.penci-menu-hbg {
		width: 330px !important
	}
	.penci-menuhbg-open .penci-menu-hbg.penci-menu-hbg-left,
	.penci-vernav-poleft.penci-menuhbg-open .penci-vernav-toggle {
		left: 330px !important
	}
	.penci-menuhbg-open .penci-menu-hbg.penci-menu-hbg-right,
	.penci-vernav-poright.penci-menuhbg-open .penci-vernav-toggle {
		right: 330px !important
	}
	.penci-menu-hbg.penci-menu-hbg-right {
		transform: translateX(330px) !important;
		-webkit-transform: translateX(330px) !important;
		-moz-transform: translateX(330px) !important
	}
	.penci-menu-hbg.penci-menu-hbg-left {
		transform: translateX(-330px) !important;
		-webkit-transform: translateX(-330px) !important;
		-moz-transform: translateX(-330px) !important
	}
}
.penci-hbg-search-box {
	margin-bottom: 30px
}
form.pc-searchform.penci-hbg-search-form .inner-hbg-search-form {
	position: relative
}
form.pc-searchform.penci-hbg-search-form input.search-input {
	width: 100%;
	background: 0 0;
	font-size: 13px;
	letter-spacing: 0;
	transition: all .3s;
	-webkit-transition: all .3s
}
form.pc-searchform.penci-hbg-search-form input.search-input:focus,
form.pc-searchform.penci-hbg-search-form input.search-input:hover {
	border-color: var(--pcaccent-cl)
}
form.pc-searchform.penci-hbg-search-form i {
	font-size: 14px;
	color: #c7c7c7
}
#sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:focus,
#sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:hover {
	border-color: #e9e9e9
}
@media only screen and (max-width:1350px) and (min-width:961px) {
	.penci-vernav-enable .container.penci_sidebar #main,
	.penci-vernav-enable .penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-10 #sidebar.penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-10 .penci-single-s10-content,
	.penci-vernav-enable .penci-single-style-13 #sidebar.penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-13 .penci-single-s13-content {
		width: 100%;
		padding-left: 0 !important;
		padding-right: 0 !important
	}
	.penci-vernav-enable .penci-single-style-10 .penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-10 .penci-single-s10-content,
	.penci-vernav-enable .penci-single-style-13 .penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-13 .penci-single-s13-content {
		width: 100%;
		position: static;
		margin-left: 0;
		top: auto;
		float: none;
		display: block
	}
	.penci-vernav-enable .penci-single-style-10 .penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-13 .penci-sidebar-content {
		margin-bottom: 30px
	}
	.penci-vernav-enable .penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-10 #sidebar.penci-sidebar-content,
	.penci-vernav-enable .penci-single-style-13 #sidebar.penci-sidebar-content {
		margin-bottom: 40px
	}
}
@media only screen and (max-width:1300px) and (min-width:961px) {
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-1,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-2,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-3,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-5,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-6,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-7,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-8,
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-9 {
		width: 100%;
		margin-right: 0;
		margin-bottom: 30px
	}
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-4 {
		width: 48.5%;
		margin-bottom: 30px
	}
	.penci-vernav-enable .footer-widget-wrapper.last {
		margin-bottom: 0
	}
	.penci-vernav-enable .footer-widget-wrapper.footer-widget-style-4:nth-child(2n+2) {
		margin-right: 0
	}
}
.penci-wpblock .penci-gutenberg-missing {
	display: none !important
}
.penci-wpblock ul.penci-grid {
	margin-left: 0;
	padding-left: 0
}
.post-entry ol li.wp-block-latest-comments__comment {
	margin-bottom: 15px
}
.post-entry .wp-block-quote::before,
.wp-block-quote::before {
	content: "â€"
}
.penci_is_nosidebar .alignfull,
.penci_is_nosidebar .wp-block-cover-image.alignfull,
.penci_is_nosidebar .wp-block-cover.alignfull,
.penci_is_nosidebar .wp-block-gallery.alignfull,
.penci_is_nosidebar .wp-block-image.alignfull {
	margin-left: calc(50% - 50vw);
	width: 100vw;
	max-width: 100vw
}
.penci_is_nosidebar .alignfull,
.penci_is_nosidebar .wp-block-cover-image.alignfull,
.penci_is_nosidebar .wp-block-cover.alignfull,
.penci_is_nosidebar .wp-block-gallery.alignfull,
.penci_is_nosidebar .wp-block-image.alignfull {
	margin-left: calc(50% - 50vw);
	width: 100vw;
	max-width: 100vw
}
.post-entry ul.blocks-gallery-grid {
	padding-left: 0
}
.is-type-wp-embed .wp-block-embed__wrapper iframe {
	position: static !important
}
.is-type-wp-embed .wp-block-embed__wrapper blockquote {
	display: none
}
@media only screen and (min-width:961px) {
	.penci-vernav-enable .penci_is_nosidebar .alignfull,
	.penci-vernav-enable .penci_is_nosidebar .wp-block-cover-image.alignfull,
	.penci-vernav-enable .penci_is_nosidebar .wp-block-cover.alignfull,
	.penci-vernav-enable .penci_is_nosidebar .wp-block-gallery.alignfull,
	.penci-vernav-enable .penci_is_nosidebar .wp-block-image.alignfull {
		margin-left: calc(50% - 50vw + 165px);
		width: calc(100vw - 330px)
	}
}
.penci_is_nosidebar .alignwide,
.penci_is_nosidebar .wp-block-cover-image.alignwide,
.penci_is_nosidebar .wp-block-cover.alignwide,
.penci_is_nosidebar .wp-block-gallery.alignwide,
.penci_is_nosidebar .wp-block-image.alignwide {
	margin-left: calc(25% - 25vw);
	width: calc(50vw + 50%);
	max-width: calc(50vw + 50%)
}
@media only screen and (max-width:767px) {
	.penci_is_nosidebar .alignwide,
	.penci_is_nosidebar .wp-block-cover-image.alignwide,
	.penci_is_nosidebar .wp-block-cover.alignwide,
	.penci_is_nosidebar .wp-block-gallery.alignwide,
	.penci_is_nosidebar .wp-block-image.alignwide {
		margin-left: calc(50% - 50vw);
		width: 100vw;
		max-width: 100vw
	}
}
.wp-block-cover .wp-block-cover-image-text,
.wp-block-cover .wp-block-cover-text,
.wp-block-cover h2,
.wp-block-cover-image .wp-block-cover-image-text,
.wp-block-cover-image .wp-block-cover-text,
.wp-block-cover-image h2 {
	font-size: 36px
}
@media only screen and (max-width:767px) {
	.wp-block-cover .wp-block-cover-image-text,
	.wp-block-cover .wp-block-cover-text,
	.wp-block-cover h2,
	.wp-block-cover-image .wp-block-cover-image-text,
	.wp-block-cover-image .wp-block-cover-text,
	.wp-block-cover-image h2 {
		font-size: 28px
	}
}
.post-entry .wp-block-cover .wp-block-cover-text a {
	color: #fff;
	text-decoration: none
}
blockquote.wp-block-quote:before {
	content: none;
	display: none
}
.post-entry blockquote.wp-block-quote p,
.wpb_text_column blockquote.wp-block-quote p {
	font-size: 16px;
	font-style: normal;
	color: #191e23
}
.post-entry blockquote.wp-block-quote cite,
.wpb_text_column blockquote.wp-block-quote cite {
	color: #6c7781;
	font-size: 13px;
	font-style: normal;
	font-weight: 400;
	text-transform: none;
	font-family: inherit
}
.wp-block-quote.is-large,
.wp-block-quote.is-style-large {
	background: #f5f5f5;
	padding: 10px 20px 11px
}
.post-entry blockquote.wp-block-quote.is-large p,
.post-entry blockquote.wp-block-quote.is-style-large p,
.wpb_text_column blockquote.wp-block-quote.is-large p,
.wpb_text_column blockquote.wp-block-quote.is-style-large p {
	font-size: 24px;
	font-style: italic
}
.wpb_text_column ol,
.wpb_text_column ul {
	padding-left: 36px;
	margin-bottom: 20px
}
.wpb_text_column ol ol,
.wpb_text_column ol ul,
.wpb_text_column ul ol,
.wpb_text_column ul ul {
	margin: 2px 0;
	padding-left: 22px
}
.wpb_text_column ul li {
	margin-bottom: 6px;
	position: relative;
	list-style-type: square;
	line-height: 1.7
}
.wpb_text_column ol li {
	margin-bottom: 2px;
	list-style: decimal
}
.post-entry .wp-block-file {
	font-size: 16px
}
.container-single .post-entry .wp-block-file a,
.post-entry .wp-block-file a {
	color: inherit
}
.post-entry .wp-block-file a.wp-block-file__button {
	color: #fff;
	font-size: 14px
}
.penci_is_nosidebar .wp-block-video.alignfull video,
.penci_is_nosidebar .wp-block-video.alignwide video {
	width: 100%
}
.post-entry .wp-block-table.is-style-stripes {
	border-top: none;
	border-left: none;
	border-right: none
}
.post-entry .wp-block-verse pre,
.post-entry pre.wp-block-verse {
	border: none;
	background: #f5f5f5;
	padding: 10px 20px;
	font-size: 16px;
	font-family: inherit;
	white-space: nowrap;
	overflow: auto;
	line-height: 1.8
}
.post-entry .wp-block-pullquote {
	padding: 30px 0;
	margin-bottom: 20px
}
.post-entry .wp-block-pullquote blockquote,
.post-entry .wp-block-pullquote blockquote cite,
.post-entry .wp-block-pullquote blockquote p {
	text-align: inherit
}
.post-entry .wp-block-pullquote blockquote {
	padding-left: 0;
	margin-bottom: 0
}
.post-entry .wp-block-pullquote blockquote:before {
	content: none;
	display: none
}
.post-entry .wp-block-pullquote blockquote p {
	font-size: 28px;
	font-style: normal;
	color: #313131
}
.post-entry .wp-block-pullquote blockquote cite {
	font-weight: inherit;
	color: inherit;
	font-family: inherit;
	margin-top: 10px;
	font-size: 13px
}
.wp-block-pullquote.is-style-solid-color {
	background: #f5f5f5
}
@media (min-width:600px) {
	.wp-block-columns .wp-block-column:last-child {
		margin-right: 0
	}
	.penci_is_nosidebar .wp-block-column .alignfull,
	.penci_is_nosidebar .wp-block-column .alignwide,
	.penci_is_nosidebar .wp-block-column .wp-block-cover-image.alignfull,
	.penci_is_nosidebar .wp-block-column .wp-block-cover-image.alignwide,
	.penci_is_nosidebar .wp-block-column .wp-block-gallery.alignfull,
	.penci_is_nosidebar .wp-block-column .wp-block-gallery.alignwide,
	.penci_is_nosidebar .wp-block-column .wp-block-image.alignfull,
	.penci_is_nosidebar .wp-block-column .wp-block-image.alignwide {
		margin-left: 0;
		width: 100%;
		max-width: 100%
	}
}
.post-entry a.wp-block-button__link {
	text-decoration: none
}
.has-huge-font-size,
.has-larger-font-size {
	line-height: 1.4
}
.container-single .post-entry a.has-white-color,
.container-single .post-entry a.wp-block-button__link,
.post-entry a.has-white-color,
.post-entry a.wp-block-button__link {
	color: #fff
}
.container-single .post-entry a.has-black-color,
.post-entry a.has-black-color {
	color: #000
}
.container-single .post-entry a.has-vivid-purple-color,
.post-entry a.has-vivid-purple-color {
	color: #9b51e0
}
.post-entry .wp-block-social-links:not(.is-style-logos-only) .wp-social-link a {
	color: #fff
}
.wp-block-media-text .wp-block-media-text__content p:last-child {
	margin-bottom: 0
}
.post-entry hr.wp-block-separator,
.wp-block-separator {
	border-bottom: 2px solid #8f98a1
}
.post-entry hr.wp-block-separator.is-style-wide,
.wp-block-separator.is-style-wide {
	border-width: 1px
}
.wp-block-separator.is-style-dots {
	border: none !important
}
.wp-block-separator.is-style-dots:before {
	color: inherit;
	line-height: 1
}
.wp-block-latest-posts {
	padding: 16px 20px 16px 36px !important;
	border: 1px solid #dedede
}
.wp-block-latest-posts.is-grid {
	padding-bottom: 0 !important
}
.wp-block-categories .category-item-count {
	color: #313131
}
@media (min-width:600px) {
	.wp-block-latest-posts.is-grid li {
		padding-right: 8px
	}
}
@media only screen and (max-width:767px) {
	.wp-block-media-text {
		display: block
	}
	.wp-block-media-text .wp-block-media-text__content {
		display: block;
		padding: 0;
		text-align: center;
		margin-top: 20px
	}
	.wp-block-media-text .has-huge-font-size,
	.wp-block-media-text .has-large-font-size {
		font-size: 22px;
		line-height: 1.5
	}
}
.has-pale-pink-color.has-pale-pink-color {
	color: #f78da7 !important
}
.has-vivid-red-color.has-vivid-red-color {
	color: #cf2e2e !important
}
.has-luminous-vivid-orange-color.has-luminous-vivid-orange-color {
	color: #ff6900 !important
}
.has-luminous-vivid-amber-color.has-luminous-vivid-amber-color {
	color: #fcb900 !important
}
.has-light-green-cyan-color.has-light-green-cyan-color {
	color: #7bdcb5 !important
}
.has-vivid-green-cyan-color.has-vivid-green-cyan-color {
	color: #00d084 !important
}
.has-pale-cyan-blue-color.has-pale-cyan-blue-color {
	color: #8ed1fc !important
}
.has-vivid-cyan-blue-color.has-vivid-cyan-blue-color {
	color: #0693e3 !important
}
.has-very-light-gray-color.has-very-light-gray-color {
	color: #eee !important
}
.has-cyan-bluish-gray-color.has-cyan-bluish-gray-color {
	color: #abb8c3 !important
}
.has-very-dark-gray-color.has-very-dark-gray-color {
	color: #313131 !important
}
.wp-block-embed .wp-block-embed__wrapper iframe,
.wp-block-embed .wp-block-embed__wrapper twitter-widget {
	display: inline-block !important
}
.wp-block-embed.aligncenter,
.wp-block-embed.alignfull,
.wp-block-embed.alignwide {
	text-align: center
}
.wp-block-embed.alignleft {
	text-align: left
}
.wp-block-embed.alignright {
	text-align: right
}
.wp-block-embed-instagram figcaption {
	margin-top: -8px
}
.wp-block-embed-dailymotion .wp-block-embed__wrapper {
	position: relative;
	padding-bottom: 56.2393%
}
.wp-block-embed-youtube .wp-block-embed__wrapper {
	position: relative;
	padding-bottom: 56.25%
}
.wp-block-embed-youtube .wp-block-embed__wrapper .yt-video-place.embed-responsive {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	padding-bottom: 0;
	width: 100%;
	padding-bottom: 0 !important
}
.yt-video-place {
	position: relative;
	text-align: center
}
.yt-video-place .play-yt-video {
	margin: auto
}
.yt-video-place.embed-responsive {
	padding-bottom: 10px !important;
	height: auto
}
.yt-video-place.embed-responsive:before {
	padding: 0 !important
}
.start-video {
	position: absolute;
	padding: 0;
	opacity: 1;
	cursor: pointer;
	border-radius: 50%;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%)
}
#hpp_mPlayNxt {
	width: 100%;
	height: 100%;
	position: fixed;
	left: 0;
	top: 0;
	z-index: 999000000;
	text-align: center
}
#hpp_mPlayNxt .yt-video-place {
	top: 10%;
	display: inline-block;
	height: auto
}
#hpp_mPlayNxt .cover {
	position: absolute;
	background: #dadada;
	opacity: .5;
	width: 100%;
	height: 100%
}
.widget_media_video iframe {
	width: 100%;
	min-height: 400px
}
mediaelementwrapper>iframe {
	width: 100%;
	height: 100%
}
.mejs-overlay-play {
	width: 100% !important
}
.mejs-mediaelement {
	position: relative !important
}
.mejs-container.wp-video-shortcode {
	height: auto !important
}
.mejs-container video {
	height: auto
}
.yt-video-place.embed-responsive .play-yt-video {
	width: 100%;
	aspect-ratio: 16/9;
	object-fit: cover
}
.yt-video-place.embed-responsive .start-video {
	display: block;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	position: absolute;
	transform: none
}
.yt-video-place.embed-responsive .start-video svg {
	margin: 0;
	padding: 0;
	top: 50%;
	display: inline-block;
	position: absolute;
	left: 50%;
	transform: translate(-50%, -50%);
	width: 68px;
	height: auto
}
.yt-video-place.embed-responsive .start-video:hover svg path {
	transition: .3s all ease-in-out
}
.yt-video-place.embed-responsive .start-video svg .red {
	fill: #212121;
	fill-opacity: .8
}
.yt-video-place.embed-responsive .start-video svg .white {
	fill: #fff
}
.yt-video-place.embed-responsive .start-video:hover svg .red {
	fill: red;
	fill-opacity: 1
}
.fluid-width-video-wrapper iframe {
	z-index: 10
}
.fluid-width-video-wrapper .yt-video-place.embed-responsive {
	position: absolute;
	left: 0;
	right: 0;
	top: 0;
	width: 100%;
	height: 100%
}
.fluid-width-video-wrapper .yt-video-place.embed-responsive>img {
	position: absolute;
	left: 0;
	top: 0;
	width: 100%;
	height: 100%;
	object-fit: cover
}
.wp-block-embed-youtube .wp-block-embed__wrapper .fluid-width-video-wrapper {
	padding-top: 0 !important;
	position: static !important
}
.wp-block-embed-dailymotion .wp-block-embed__wrapper iframe,
.wp-block-embed-youtube .wp-block-embed__wrapper iframe {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.wp-block-yoast-how-to-block .schema-how-to-description,
.wp-block-yoast-how-to-block .schema-how-to-total-time {
	font-size: 16px;
	margin-bottom: 7px
}
.wp-block-yoast-how-to-block ol.schema-how-to-steps {
	padding: 15px 20px 20px 32px;
	border: 1px solid #dedede
}
.wp-block-yoast-how-to-block ol.schema-how-to-steps li {
	padding: 0;
	border-bottom: 1px solid #dedede;
	margin-bottom: 17px
}
.wp-block-yoast-how-to-block ol.schema-how-to-steps li:last-child {
	margin-bottom: 0;
	border-bottom: none
}
.wp-block-yoast-how-to-block ol.schema-how-to-steps li:last-child p.schema-how-to-step-text {
	margin-bottom: 0
}
.wp-block-yoast-faq-block .schema-faq-section {
	border: 1px solid #dedede;
	padding: 15px 20px;
	margin-bottom: 15px
}
.wp-block-yoast-faq-block .schema-faq-answer {
	margin-bottom: 0
}
p.has-drop-cap:not(:focus):first-letter {
	float: left;
	font-size: 60px;
	line-height: .9;
	margin: 0 8px 0 0;
	text-transform: uppercase;
	font-style: normal
}
.has-small-font-size,
.post-entry p.has-small-font-size>* {
	font-size: 12px
}
.has-medium-font-size,
.post-entry p.has-medium-font-size>* {
	font-size: 20px
}
.has-large-font-size,
.post-entry p.has-large-font-size>* {
	font-size: 32px
}
.has-huge-font-size,
.post-entry p.has-huge-font-size>* {
	font-size: 42px
}
.wp-block-embed-soundcloud .wp-block-embed__wrapper {
	width: 100%;
	position: relative;
	padding: 0;
	padding-top: 23.0555%
}
.wp-block-embed-soundcloud .wp-block-embed__wrapper iframe {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.wp-block-search {
	margin-bottom: 20px
}
.wp-block-search .wp-block-search__label {
	margin-bottom: 5px
}
.wp-block-search .wp-block-search__input {
	border: 1px solid #dedede;
	padding: 10px 20px
}
.wp-block-search .wp-block-search__button {
	border: none;
	outline: 0;
	padding: 0 12px;
	cursor: pointer;
	background: #e2e2e2
}
.post-entry .grid-header-box,
.post-entry .grid-header-box .grid-title,
.post-entry .grid-post-box-meta,
.post-entry .header-list-style,
.post-entry .header-list-style .grid-title,
.post-entry .header-standard,
.post-entry .inner-boxed-2,
.post-entry .inner-boxed-2 .grid-title,
.post-entry .item-related,
.post-entry .main-typography,
.post-entry .main-typography .grid-title,
.post-entry .penci-overlay-over .overlay-header-box {
	line-height: 1
}
.post-entry .grid-header-box .grid-title,
.post-entry .header-list-style .grid-title,
.post-entry .header-standard .post-title,
.post-entry .header-standard h2,
.post-entry .pc_titlebig_standard,
.post-entry .home-featured-cat .magcat-titlte,
.post-entry .home-pupular-posts-title,
.post-entry .inner-boxed-2 .grid-title,
.post-entry .item-related h3,
.post-entry .main-typography .grid-title,
.post-entry .overlay-title,
.post-entry .penci-border-arrow .inner-arrow,
.post-entry ul.penci-grid {
	margin-bottom: 0
}
.post-entry .cat>a.penci-cat-name,
.post-entry .grid-mixed .mixed-detail a,
.post-entry .grid-post-box-meta a,
.post-entry .header-standard .author-post span a,
.post-entry .header-standard h2 a,
.post-entry .pc_titlebig_standard a,
.post-entry .item-related a,
.post-entry .overlay-author a,
.post-entry .overlay-header-box .overlay-title a,
.post-entry .penci-featured-cat-seemore a,
.post-entry .penci-grid li .item h2 a,
.post-entry .penci-magazine-title a,
.post-entry .penci-masonry .item-masonry h2 a,
.post-entry .penci-post-box-meta .penci-box-meta a,
.post-entry .penci-readmore-btn a {
	text-decoration: none
}
.post-entry .penci-grid>li {
	margin-bottom: 40px
}
.post-entry .item-content p,
.post-entry .mag-excerpt p {
	margin-bottom: 0
}
.elementor-column-gap-wider>.elementor-column>.theiaStickySidebar>.elementor-element-populated {
	padding: 30px
}
.elementor-column-gap-wide>.elementor-column>.theiaStickySidebar>.elementor-element-populated {
	padding: 20px
}
.elementor-column-gap-extended>.elementor-column>.theiaStickySidebar>.elementor-element-populated {
	padding: 15px
}
.elementor-column-gap-default>.elementor-column>.theiaStickySidebar>.elementor-element-populated {
	padding: 10px
}
.elementor-column-gap-narrow>.elementor-column>.theiaStickySidebar>.elementor-element-populated {
	padding: 5px
}
.post-pagination.pcpagp-style-2 .prev-post-title,
.post-pagination.pcpagp-style-3 .prev-post-title,
.post-pagination.pcpagp-style-4 .prev-post-title,
.post-pagination.pcpagp-style-5 .prev-post-title {
	text-transform: uppercase;
	font-size: 12px;
	font-family: var(--pchead-font);
	letter-spacing: .05em;
	position: relative
}
.post-pagination.pcpagp-style-2 .penci-post-nav-thumb {
	flex: 0 0 170px;
	height: 170px
}
.post-pagination.pcpagp-style-2 .next-post,
.post-pagination.pcpagp-style-2 .prev-post {
	display: flex;
	flex-direction: row;
	align-items: center
}
.post-pagination.pcpagp-style-2 .next-post {
	flex-direction: row-reverse
}
.post-pagination.pcpagp-style-3 {
	display: flex;
	justify-content: space-between
}
.post-pagination.pcpagp-style-3 .penci-post-nav-thumb.nav-thumb-next {
	margin: 0
}
.post-pagination.pcpagp-style-3 .next-post,
.post-pagination.pcpagp-style-3 .prev-post {
	position: relative
}
.post-pagination.pcpagp-style-3 .penci-post-nav-thumb {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	width: 100%;
	height: 100%
}
.post-pagination.pcpagp-style-3 .next-post-inner,
.post-pagination.pcpagp-style-3 .prev-post-inner {
	position: relative;
	padding: 40px 20px;
	height: 100%;
	display: flex;
	align-items: center
}
.post-pagination.pcpagp-style-3 .next-post-inner:before,
.post-pagination.pcpagp-style-3 .prev-post-inner:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: rgba(0, 0, 0, .5)
}
.post-pagination.pcpagp-style-3 h5,
.post-pagination.pcpagp-style-3 span {
	color: #fff;
	padding: 0
}
.post-pagination.pcpagp-style-4 .penci-post-nav-thumb,
.post-pagination.pcpagp-style-5 .penci-post-nav-thumb {
	width: 100%;
	height: 170px;
	float: none;
	margin-bottom: 15px
}
.post-pagination.pcpagp-style-5 .penci-post-nav-thumb.nav-thumb-next {
	margin-left: 0;
	margin-right: 0
}
.post-pagination.pcpagp-style-4 {
	display: flex;
	flex-wrap: wrap;
	gap: 15px;
	justify-content: space-between;
}
.post-pagination.pcpagp-style-4 .penci-post-nav-thumb.nav-thumb-next {
	margin-left: 0;
}
.post-pagination.pcpagp-style-4 .prev-post,
.post-pagination.pcpagp-style-4 .next-post {
	width: auto;
	flex: 0 0 calc(50% - 15px);
}
.post-pagination.pcpagp-style-3 .next-post,
.post-pagination.pcpagp-style-3 .prev-post,
.post-pagination.pcpagp-style-5 .next-post,
.post-pagination.pcpagp-style-5 .prev-post {
	width: calc(50% - 10px)
}
.post-pagination.pcpagp-style-5 .next-post-inner,
.post-pagination.pcpagp-style-5 .prev-post-inner {
	padding: 20px 20px 20px 0;
	background: #fff;
	margin: -60px 60px 0 0;
	position: relative
}
.post-pagination.pcpagp-style-5 .next-post-inner {
	margin: -60px 0 0 60px;
	padding: 20px 0 20px 20px
}
.post-entry.blockquote-style-3 blockquote:not(.wp-block-quote) {
	padding: 15px 50px 15px 0;
	border-top: 5px solid var(--pcaccent-cl);
	border-bottom: 1px solid var(--pcaccent-cl)
}
.post-entry.blockquote-style-3 blockquote:not(.wp-block-quote) p {
	font-size: 24px;
	color: var(--pcaccent-cl);
	font-style: normal;
	line-height: 1.6;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font)
}
.post-entry.blockquote-style-3 blockquote:not(.wp-block-quote):before {
	transform: rotate(180deg);
	font-size: 50px;
	bottom: 10px;
	right: 0;
	top: auto;
	left: auto;
	opacity: .1
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote),
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote),
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) {
	padding: 15px 10%;
	margin: 1.2em auto
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote) p {
	font-size: 22px;
	color: var(--pcmeta-cl);
	font-style: italic;
	line-height: 1.6;
	text-align: center
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote):after,
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote):before,
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote):after {
	content: "";
	width: 100px;
	height: 2px;
	background: var(--pcmeta-cl);
	left: 50%;
	right: 50%;
	transform: translateX(-50%);
	position: absolute;
	opacity: .5;
	top: 0
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote):after {
	bottom: 0;
	top: auto
}
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote),
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote),
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote),
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) {
	padding-top: 40px
}
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote) p,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) p,
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote) p,
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) p {
	font-size: 22px;
	color: var(--pcheading-cl);
	font-style: italic;
	line-height: 1.6;
	text-align: center
}
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote):before,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote):before,
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote):before,
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote):before {
	left: 50%;
	right: 50%;
	transform: translateX(-50%) rotate(180deg);
	top: 0;
	color: var(--pcmeta-cl);
	display: inline-block;
	width: 40px;
	text-align: center;
	font-size: 32px;
	opacity: .7
}
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote):after,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote):after {
	bottom: 0;
	top: auto
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) .author {
	text-align: center
}
.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote) .author span:after,
.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote) .author span:after,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) .author span:after,
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote) .author span:after,
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) .author span:after {
	display: none
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) {
	background: var(--pcaccent-cl);
	border-radius: 5px;
	overflow: visible !important;
	margin-top: 30px;
	padding: 30px 30px 30px 90px
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) .author,
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote) p {
	text-align: left;
	color: #fff
}
.post-entry.blockquote-style-6 blockquote:not(.wp-block-quote):before {
	opacity: 1;
	top: 30px;
	left: 40px;
	color: #fff;
	transform: scaleY(-1)
}
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote) {
	background: #22c1c3;
	background: linear-gradient(0deg, rgba(34, 193, 195, 1) 0, rgba(146, 190, 119, 1) 50%, var(--pcaccent-cl) 100%);
	border-radius: 5px;
	overflow: visible !important;
	padding: 40px;
	margin-top: 43px
}
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote) p {
	color: #fff
}
.post-entry.blockquote-style-7 blockquote:not(.wp-block-quote):before {
	background: #22c1c3;
	background: linear-gradient(0deg, rgba(34, 193, 195, 1) 0, rgba(146, 190, 119, 1) 50%, var(--pcaccent-cl) 100%);
	border: 5px solid #fff;
	top: -25px;
	border-radius: 50%;
	line-height: 50px;
	width: 50px;
	color: #fff;
	opacity: 1
}
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) {
	border: 3px solid var(--pcaccent-cl);
	border-radius: 5px;
	overflow: visible !important;
	margin-top: 43px;
	padding: 40px
}
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote) p {
	color: var(--pcaccent-cl)
}
.post-entry.blockquote-style-8 blockquote:not(.wp-block-quote):before {
	background: #22c1c3;
	background: linear-gradient(0deg, rgba(34, 193, 195, 1) 0, var(--pcaccent-cl) 100%);
	top: -30px;
	border-radius: 50%;
	line-height: 50px;
	border: 5px solid #fff;
	width: 50px;
	color: #fff;
	opacity: 1
}
.penci-preview-thumb {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 5
}
.penci-preview-thumb.active {
	background: #000;
}
.penci-preview-thumb .penci-preview-iframe {
	position: relative;
	overflow: hidden;
	width: 100%;
	height: 100%
}
.penci-preview-thumb iframe,
.penci-preview-thumb video {
	width: 100%;
	height: 100%;
	object-fit: cover;
	pointer-events: none
}
.penci-preview-thumb iframe:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 3
}
.post-related .penci-preview-thumb {
	margin-left: 10px;
	margin-right: 10px;
	max-height: 160px
}
.penci-preview-iframe,
.penci-preview-iframe iframe {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	pointer-events: none
}
.penci-preview-iframe iframe {
	max-width: unset !important;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%)
}
.e-con>.e-con-inner>.theiaStickySidebar>.elementor-widget>.elementor-widget-container,
.e-con>.theiaStickySidebar>.elementor-widget>.elementor-widget-container {
	height: 100%
}
.e-con.e-con>.theiaStickySidebar>.e-con-inner>.elementor-widget,
.elementor.elementor .e-con>.theiaStickySidebar>.elementor-widget {
	max-width: 100%
}
.elementor-element:where(.e-con-full) .theiaStickySidebar {
	display: var(--display);
	flex-direction: var(--flex-direction);
	flex-wrap: var(--flex-wrap);
	justify-content: var(--justify-content);
	align-items: var(--align-items);
	align-content: var(--align-content);
	gap: var(--gap)
}
.elementor-widget-penci-sidebar .theiaStickySidebar {
	display: block !important
}
.pc-comment-s1-button a {
	padding: 0 25px;
	line-height: 46px;
	background: var(--pcaccent-cl);
	color: #fff;
	display: inline-block;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	margin-bottom: 30px;
	font-size: 16px
}
.pc-comment-s1-button i {
	display: inline-block;
	vertical-align: middle;
	margin: 0 10px 0 0;
	line-height: inherit
}
.pc-comment-s1 {
	display: none
}
.comments .pc-comment-s1 {
	display: block
}
.pc-comment-s1.active {
	display: block
}
.comments.pc-cms-style-2 .thecomment .comment-text {
	padding: 30px;
	background: #f1f1f1
}
.comments.pc-cms-style-2 .thecomment .comment-text span.reply {
	top: 30px;
	right: 30px
}
.comments.pc-cms-style-2 .thecomment {
	padding-bottom: 0
}
.comments.pc-cms-style-2 .comment {
	border-top: 0;
	padding-bottom: 0
}
.comments.pc-cms-style-2 .thecomment .comment-text:before {
	content: "";
	position: absolute;
	left: -10px;
	border-left: 7px solid transparent;
	border-right: 7px solid transparent;
	border-bottom: 7px solid #f1f1f1;
	transform: translatey(-50%) rotate(-90deg)
}
a.penci_cmrm {
	display: inline-block;
	margin-top: 15px;
	font-size: 14px;
	font-weight: var(--pchead-wei)
}
.thecomment .comment-text.showfull .comment-content {
	-webkit-line-clamp: initial
}
.comments.pc-cms-style-2 h3.comment-reply-title {
	border-top: 0
}
.comments.pc-cms-style-2 #respond {
	margin-left: 80px
}
.pc-cms-style-3 .thecomment .author-img {
	width: 30px;
	margin-right: 20px;
	border-radius: 5px
}
.pc-cms-style-3 .thecomment .comment-text {
	margin-left: 50px;
	border: 1px solid var(--pcborder-cl);
	padding: 15px;
	border-radius: 5px
}
.pc-cms-style-3 .thecomment .comment-text:after,
.pc-cms-style-3 .thecomment .comment-text:before {
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 10px 10px 10px 0;
	border-color: transparent var(--pcborder-cl) transparent transparent;
	transform: rotate(0);
	content: '';
	position: absolute;
	top: 10px;
	left: -10px
}
.pc-cms-style-3 .thecomment {
	padding-bottom: 0
}
.pc-cms-style-3 .thecomment .comment-text:after {
	border-width: 8px 8px 8px 0;
	border-color: transparent var(--pcbg-cl) transparent transparent;
	left: -8px;
	top: 12px
}
.pc-cms-style-3.comments .comment {
	border-top: 0
}
.pc-cms-style-3 .thecomment .comment-text span.reply {
	top: 15px;
	right: 15px
}
@media only screen and (min-width:961px) and (max-width:1400px) {
	.container.two-sidebar.two-sidebar {
		width: 100%;
		max-width: 100%;
		padding-left: 10px;
		padding-right: 10px
	}
}
@media only screen and (min-width:1170px) {
	.footer-widget-wrapper .fb_iframe_widget,
	.footer-widget-wrapper .fb_iframe_widget span,
	.footer-widget-wrapper .fb_iframe_widget span iframe[style] {
		width: 340px !important
	}
	.footer-widget-wrapper .widget.penci_facebook_widget {
		text-align: center
	}
}
@media only screen and (max-width:1200px) {
	.featured-style-38 .penci-owl-carousel .swiper-slide {
		width: 400px
	}
}
@media only screen and (max-width:1169px) {
	.penci-video-overlay-background {
		display: block
	}
	.inner-portfolio-posts .portfolio-item,
	.penci-post-gallery-container.masonry .item-gallery-masonry {
		width: 50%
	}
	.penci-header-signup-form .mc4wp-form-fields>p,
	.penci-header-signup-form form>p {
		display: block;
		max-width: 100% !important;
		text-align: center;
		padding: 0
	}
	.penci-header-signup-form .mc4wp-form input[type=email],
	.penci-header-signup-form .mc4wp-form input[type=submit],
	.penci-header-signup-form .mc4wp-form input[type=text] {
		margin: 20px auto 0;
		max-width: 400px
	}
	.post-entry ul.homepage-featured-boxes,
	ul.homepage-featured-boxes {
		margin-left: -8px;
		margin-right: -8px
	}
	.post-entry ul.homepage-featured-boxes li,
	ul.homepage-featured-boxes li {
		padding: 0 8px
	}
	.penci-post-gallery-container.masonry.column-4 .item-gallery-masonry {
		width: 50%
	}
	.pencislider-container {
		padding: 0 25px
	}
	.featured-style-3 .penci-owl-carousel .penci-image-holder:before {
		height: 0;
		padding-top: 50%
	}
	.featured-style-20 .penci-mag-featured-content .feat-meta,
	.featured-style-21 .penci-mag-featured-content .feat-meta,
	.featured-style-22 .penci-mag-featured-content .feat-meta,
	.featured-style-23 .penci-mag-featured-content .feat-meta,
	.featured-style-24 .penci-mag-featured-content .feat-meta,
	.featured-style-25 .penci-mag-featured-content .feat-meta,
	.featured-style-26 .penci-mag-featured-content .feat-meta {
		display: none
	}
	.penci-item-mag {
		overflow: hidden
	}
	.featured-style-24 .penci-image-holder:before {
		height: 160px
	}
	.featured-style-24 .penci-item-2 .penci-image-holder:before {
		height: 200px
	}
	.featured-style-24 .penci-item-1 .penci-image-holder:before {
		height: 364px
	}
	.featured-style-24 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 20px
	}
	.featured-style-24 .penci-item-2 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-24 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-3 .penci-mag-featured-content h3 a {
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-25 .penci-image-holder:before {
		height: 150px
	}
	.featured-style-26 .penci-image-holder:before {
		height: 160px
	}
	.featured-style-25 .penci-item-1 .penci-image-holder:before {
		height: 458px
	}
	.featured-style-26 .penci-item-1 .penci-image-holder:before {
		height: 324px
	}
	.featured-style-29.style-30 .penci-image-holder:before {
		height: 450px
	}
	.footer-widget-wrapper.footer-widget-style-4 {
		width: 48%;
		margin-right: 4%
	}
	.footer-widget-wrapper.footer-widget-style-4:nth-child(2) {
		margin-right: 0
	}
	.footer-widget-wrapper.footer-widget-style-4:nth-child(3) {
		clear: both
	}
	.footer-widget-wrapper.footer-widget-style-4:nth-child(1),
	.footer-widget-wrapper.footer-widget-style-4:nth-child(2) {
		margin-bottom: 30px
	}
	.footer-widget-wrapper.footer-widget-style-5,
	.footer-widget-wrapper.footer-widget-style-6,
	.footer-widget-wrapper.footer-widget-style-7 {
		width: 25.25%
	}
	.footer-widget-wrapper.footer-widget-style-5:first-child,
	.footer-widget-wrapper.footer-widget-style-6:nth-child(2),.footer-widget-wrapper.footer-widget-style-7:last-child {
		width: 42.5%
	}
	.footer-widget-wrapper.footer-widget-style-8,
	.footer-widget-wrapper.footer-widget-style-9 {
		width: 26%
	}
	.footer-widget-wrapper.footer-widget-style-8:last-child,
	.footer-widget-wrapper.footer-widget-style-9:first-child {
		width: 70.5%
	}
	.penci-related-grid-display .item-related {
		width: 50%
	}
	.penci-related-grid-display .item-related:nth-child(3n+1) {
		clear: none
	}
	.penci-related-grid-display .item-related:nth-child(2n+1) {
		clear: both
	}
	.featured-style-35 .penci-featured-content-right,
	.featured-style-35.style-36 .penci-featured-content-right {
		width: 350px
	}
	.featured-style-35 .penci-image-holder:before,
	.featured-style-35.style-36 .penci-image-holder:before {
		height: 450px
	}
	.featured-style-35 .featured-content-excerpt p {
		display: none
	}
	.featured-style-35 .feat-text-right .penci-featured-slider-button {
		animation-delay: 1.2s;
		-webkit-animation-delay: 1.2s
	}
	.featured-style-35 .feat-text-right h3 a {
		font-size: 24px
	}
	.penci-headline {
		text-align: center;
		padding: 15px 0 8px
	}
	.penci-headline .pctopbar-item {
		float: none;
		margin-left: 0;
		margin-right: 0;
		display: block;
		margin-bottom: 10px;
		line-height: normal
	}
	.penci-headline .pctopbar-item.penci-topbar-social,
	.penci-headline .pctopbar-item.penci-topbar-social-mobile {
		margin-bottom: 6px
	}
	.penci-topbar-social a,
	.penci-topbar-social-mobile a {
		line-height: normal;
		float: none;
		margin-bottom: 5px
	}
	div.penci-topbar-menu-mobile>ul>li>a,
	div.penci-topbar-menu>ul>li>a,
	ul.penci-topbar-menu-mobile>li>a,
	ul.penci-topbar-menu>li>a {
		line-height: 1.6
	}
	.penci-headline .pctopbar-item.penci-topbar-trending {
		margin-left: auto;
		margin-right: auto
	}
	.pctopbar-login-btn li.pclogin-item img {
		top: auto;
		display: inline-block
	}
}
@media only screen and (min-width:961px) and (max-width:1169px) {
	body {
		--pcctain: 940px;
	}
	#navigation ul.menu>li.megamenu>ul.sub-menu,
	.container,
	.featured-area.magazine-slider,
	.featured-area.style-1,
	.featured-area.style-4 {
		width: var(--pcctain);
		max-width: calc(100% - 60px);
	}
	.wrapper-boxed.enable-boxed,
	.wrapper-boxed.enable-boxed .is-sticky #navigation {
		max-width: 1000px
	}
	.container.has-banner #logo {
		width: 320px;
		padding-right: 30px
	}
	.container.has-banner .header-banner {
		width: 620px
	}
	#navigation.header-4 .pcheader-icon,
	#navigation.header-5 .pcheader-icon,
	#navigation.header-6 .pcheader-icon {
		margin-left: 26px
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post {
		width: 25%
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post {
		width: 33.3333%
	}
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-1 .penci-mega-post:nth-child(4),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-2 .penci-mega-post:nth-child(7),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-2 .penci-mega-post:nth-child(8),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-3 .penci-mega-post:nth-child(10),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-3 .penci-mega-post:nth-child(11),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-3 .penci-mega-post:nth-child(12),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-1 .penci-mega-post:nth-child(5),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-2 .penci-mega-post:nth-child(10),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-2 .penci-mega-post:nth-child(9),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-3 .penci-mega-post:nth-child(13),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-3 .penci-mega-post:nth-child(14),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5.mega-row-3 .penci-mega-post:nth-child(15) {
		display: none
	}
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-4 .penci-mega-post:nth-child(4n+1),
	#navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(5n+1) {
		clear: none
	}
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-2 .penci-mega-post:nth-child(3n+1),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-4.mega-row-3 .penci-mega-post:nth-child(3n+1),
	#navigation .penci-megamenu .penci-content-megamenu:not(.pcmis-5) .penci-mega-latest-posts.col-mn-5 .penci-mega-post:nth-child(4n+1) {
		clear: both
	}
	#navigation .menu>ul>li,
	#navigation ul.menu>li {
		margin-right: 16px
	}
	#navigation .menu ul li.megamenu ul ul>li>a,
	#navigation ul.menu li.megamenu ul ul>li>a {
		margin: 0 10px
	}
	.featured-carousel .featured-content,
	.featured-carousel.style-2 .featured-content {
		top: 38.7%
	}
	.featured-carousel.style-7 .featured-content .feat-text h3,
	.featured-carousel.style-7 .featured-content .feat-text h3 a,
	.wrapper-boxed.enable-boxed .featured-carousel.style-7 .featured-content .feat-text h3 {
		padding: 0
	}
	.featured-carousel.style-7 .featured-content .feat-text h3 a:after,
	.featured-carousel.style-7 .featured-content .feat-text h3 a:before {
		content: none;
		display: none
	}
	.penci-image-holder.slider-style-1-fix {
		height: 480px
	}
	.penci-image-holder.slider-style-3-fix {
		height: 460px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content {
		height: 300px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content {
		height: 600px
	}
	.penci-magazine-slider ul.mag-wrap li {
		width: 303px;
		height: 212px
	}
	.penci-magazine-slider ul.mag-wrap li.mag-item-1 {
		width: 636px;
		height: 424px
	}
	ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 .fea-box-img:before {
		left: 10px;
		top: 10px;
		right: 10px;
		bottom: 10px
	}
	.featured-style-6 .wrapper-item .penci-item-mag {
		width: 32.83%
	}
	.featured-style-6 .wrapper-item .penci-item-1 {
		width: 67.17%;
		border-right: 5px solid transparent
	}
	.featured-style-6 .wrapper-item .penci-item-2 {
		border-bottom: 2px solid transparent
	}
	.featured-style-6 .wrapper-item .penci-item-0 {
		border-top: 3px solid transparent
	}
	.featured-style-13 .penci-image-holder:before,
	.featured-style-15 .penci-image-holder:before {
		height: 350px
	}
	.featured-style-14 .penci-image-holder:before,
	.featured-style-16 .penci-image-holder:before {
		height: 300px
	}
	.featured-style-16 .penci-mag-featured-content h3 a {
		font-size: 15px
	}
	.featured-style-17 .penci-image-holder:before,
	.featured-style-18 .penci-image-holder:before {
		height: 160px
	}
	.featured-style-17 .penci-slide17-item-2 .penci-image-holder:before,
	.featured-style-18 .penci-slide17-item-2 .penci-image-holder:before {
		height: 324px
	}
	.featured-style-17 .penci-mag-featured-content .feat-meta,
	.featured-style-18 .penci-mag-featured-content .feat-meta {
		display: none
	}
	.penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-17 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-18 .penci-item-3 .penci-mag-featured-content h3 a {
		font-size: 20px
	}
	.featured-style-17 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-18 .penci-slide-overlay .penci-mag-featured-content {
		left: 0;
		width: 100%;
		padding: 0 5px;
		text-align: center
	}
	.penci-grid li.list-boxed-post-2 {
		width: 50%
	}
	.penci_sidebar .penci-grid li.list-boxed-post-2 {
		width: 100%
	}
	.penci-grid li.list-boxed-post-2:nth-of-type(2n+1) {
		clear: both
	}
	.penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
		height: 312px
	}
	.penci-grid li.list-boxed-post-2:nth-of-type(2n+1) .content-boxed-2.show-top {
		display: none
	}
	.penci-grid li.list-boxed-post-2:nth-of-type(2n+1) .content-boxed-2.show-bottom {
		display: block
	}
	.penci-grid li.list-boxed-post-2:nth-of-type(2n+2) .content-boxed-2.show-top {
		display: block
	}
	.penci-grid li.list-boxed-post-2:nth-of-type(2n+2) .content-boxed-2.show-bottom {
		display: none
	}
	.penci_sidebar .penci-grid li.list-boxed-post-2 .content-boxed-2.show-top {
		display: none !important
	}
	.penci_sidebar .penci-grid li.list-boxed-post-2 .content-boxed-2.show-bottom {
		display: block !important
	}
	.penci_sidebar .penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
		min-height: 312px;
		height: auto
	}
	.penci-grid li.list-boxed-post-2 .item>.thumbnail:before {
		display: none;
		content: none
	}
	.penci-photo-2-effect figcaption h2 {
		padding: 0 20px 20px;
		font-size: 18px
	}
	.penci-photo-2-effect figcaption p {
		margin-top: 20px;
		padding: 0 20px;
		font-size: 93%
	}
	.penci_sidebar .penci-photo-2-effect figcaption p {
		display: none
	}
	.penci_sidebar .penci-photo-2-effect figcaption:after,
	.penci_sidebar .penci-photo-2-effect figcaption:before {
		display: none;
		content: none
	}
	.penci_sidebar .penci-photo-2-effect figcaption h2 {
		padding: 0 20px;
		transform: translateY(-50%);
		-webkit-transform: translateY(-50%);
		font-size: 14px
	}
	.container.penci_sidebar .penci-grid li.typography-style {
		width: 48.05%;
		margin-right: 3.9%
	}
	.container.penci_sidebar .penci-grid li.typography-style:nth-of-type(3n+3) {
		margin-right: 3.9%;
		clear: none
	}
	.container.penci_sidebar .penci-grid li.typography-style:nth-of-type(2n+1) {
		margin-right: 0
	}
	.container.penci_sidebar .penci-grid li.typography-style:nth-of-type(2n+1) {
		clear: both
	}
	.container.penci_sidebar .penci-grid li.typography-style {
		width: 100%;
		margin-right: 0
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image img,
	.widget ul.side-newsfeed li .side-item .side-image img {
		width: 100px
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a,
	.widget ul.side-newsfeed li .side-item .side-item-text h4 a {
		font-size: 14px
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text .side-item-meta,
	.widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta {
		font-size: 11px
	}
	.penci_sidebar .penci-portfolio.column-2 .portfolio-overlay-content .portfolio-short,
	.portfolio-overlay-content .portfolio-short {
		margin-top: 17%
	}
	.penci-grid .list-post.list-boxed-post .item .content-list-right {
		min-height: 313px;
		height: 313px
	}
	.container.penci_sidebar .penci-masonry .item-masonry.standard-masonry {
		width: 100%
	}
	.home-featured-cat-content .mag-photo .magcat-detail {
		width: 100%
	}
	.home-featured-cat-content .magcat-detail h3 a {
		font-size: 14px
	}
	.home-featured-cat-content .magcat-detail .mag-meta {
		margin-top: 5px
	}
	.home-featured-cat-content .mag-photo .grid-post-box-meta span,
	.home-featured-cat-content .mag-photo .grid-post-box-meta span a {
		font-size: 12px
	}
	.widget-social.show-text a span {
		margin-left: 1px;
		font-size: 12px
	}
	ul.footer-socials li {
		margin-right: 12px
	}
	ul.footer-socials li a span {
		margin-left: 8px
	}
	.overlay-header-box .overlay-title a {
		font-size: 20px
	}
	.widget .penci-widget-slider .penci-widget-slide-detail h4 a {
		font-size: 14px
	}
	.penci-widget-slide-detail .slide-item-date {
		font-size: 13px
	}
	.home-featured-cat-content .mag-photo .magcat-detail {
		padding: 15px
	}
	.home-featured-cat-content .penci-magcat-carousel .magcat-detail h3 a {
		font-size: 16px
	}
	.penci-single-mag-slider .magcat-detail .magcat-titlte {
		font-size: 20px
	}
}
@media only screen and (max-width:1169px) {
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 {
		margin: 0 0 5px;
		width: 100% !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 {
		margin: 0
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content {
		width: 50%;
		float: left;
		display: block;
		margin: 0 !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content:first-child {
		border-right: 3px solid transparent
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content:last-child {
		border-left: 3px solid transparent
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content {
		width: 100%;
		border: none !important
	}
	.penci-magazine-slider img {
		width: 100%
	}
}
@media only screen and (min-width:961px) {
	#navigation .menu {
		display: inline-block !important
	}
}
@media only screen and (max-width:960px) {
	.container.has-banner #logo {
		text-align: center;
		display: block;
		width: auto
	}
	.container.has-banner .header-banner {
		display: block;
		margin-top: 30px;
		width: 100%;
		text-align: center
	}
	.featured-area.style-7.loaded .featured-carousel:before {
		content: none;
		display: none
	}
	.featured-style-2 .penci-owl-carousel .swiper-slide {
		width: 760px
	}
	.penci-top-bar {
		text-align: center
	}
	.penci-top-bar.no-social.topbar-menu {
		display: block
	}
	.penci-topbar-social {
		float: none
	}
	.overlay-video-click {
		display: none !important
	}
	#navigation.header-10>.container,
	#navigation.header-11>.container {
		display: table
	}
	#navigation.header-10 .penci-menu-wrap,
	#navigation.header-11 .penci-menu-wrap {
		display: none
	}
	#navigation.header-10,
	#navigation.header-10 .penci-menuhbg-toggle,
	#navigation.header-11,
	#navigation.header-11 .penci-menuhbg-toggle,
	#navigation.header-6,
	#navigation.header-6 .penci-menuhbg-toggle {
		height: 60px
	}
	#navigation.header-6 .container {
		text-align: center
	}
	#navigation.header-6 #logo {
		float: none;
		display: inline-block
	}
	#navigation.header-6 #logo img {
		max-height: 58px;
		padding: 10px 0
	}
	#navigation.header-10 .show-search,
	#navigation.header-11 .show-search,
	#navigation.header-6 .show-search,
	#navigation.header-9 .show-search {
		height: 58px
	}
	#navigation.header-10 .main-nav-social,
	#navigation.header-10 .pcheader-icon>a,
	#navigation.header-10 .show-search a.close-search,
	#navigation.header-11 .main-nav-social,
	#navigation.header-11 .pcheader-icon>a,
	#navigation.header-11 .show-search a.close-search,
	#navigation.header-9 .main-nav-social,
	#navigation.header-9 .pcheader-icon>a,
	#navigation.header-9 .show-search a.close-search {
		height: 58px;
		line-height: 58px
	}
	#navigation.header-6 .main-nav-social,
	#navigation.header-6 .pcheader-icon>a,
	#navigation.header-6 .show-search a.close-search {
		height: 58px;
		line-height: 58px
	}
	#navigation.header-6 .show-search form.pc-searchform input.search-input {
		height: 58px;
		padding: 15px 35px 15px 0
	}
	#navigation.header-6 .pcheader-icon.shoping-cart-icon>a>span {
		top: 12px
	}
	#navigation.header-7,
	#navigation.header-8,
	#navigation.header-9 {
		padding: 0 10px
	}
	.penci-magazine-slider ul.mag-wrap li {
		width: 50%;
		height: 240px;
		border: none
	}
	.wrapper-boxed.enable-boxed .featured-area.style-2.loaded-wait button.slick-prev {
		left: 0 !important
	}
	.wrapper-boxed.enable-boxed .featured-area.style-2.loaded-wait button.slick-next {
		right: 0 !important
	}
	.penci-magazine-slider ul.mag-wrap li.mag-item-1 {
		width: 100%;
		padding-bottom: 66.11%;
		height: 0;
		border: none;
		border-bottom: 4px solid transparent
	}
	.penci-magazine-slider ul.mag-wrap li.mag-item-2 {
		border-right: 2px solid transparent;
		border-bottom: none
	}
	.penci-magazine-slider ul.mag-wrap li.mag-item-3 {
		border-left: 2px solid transparent;
		border-bottom: none
	}
	.featured-style-4 .penci-owl-carousel .penci-image-holder:before,
	.featured-style-5 .penci-owl-carousel .penci-image-holder:before {
		height: 0;
		padding-top: 50%
	}
	.featured-style-4 .penci-featured-content .featured-slider-overlay,
	.featured-style-5 .penci-featured-content .featured-slider-overlay {
		background: #000
	}
	.featured-style-4 .penci-featured-content .feat-text h3 a,
	.featured-style-5 .penci-featured-content .feat-text h3 a {
		font-size: 22px
	}
	.featured-style-4 .penci-featured-content,
	.featured-style-4 .penci-owl-carousel .penci-image-holder,
	.featured-style-5 .penci-featured-content,
	.featured-style-5 .penci-owl-carousel .penci-image-holder {
		width: 100%
	}
	.penci-slider4-overlay,
	.penci-slider5-overlay {
		background: 0 0 !important
	}
	.featured-style-6 .wrapper-item .penci-item-mag {
		width: 50%;
		border: none
	}
	.featured-style-14 .wrapper-item .penci-item-1,
	.featured-style-16 .wrapper-item .penci-item-2,
	.featured-style-16 .wrapper-item .penci-item-mag,
	.featured-style-6 .wrapper-item .penci-item-1 {
		width: 100%;
		border: none;
		border-bottom: 4px solid transparent
	}
	.featured-style-6 .wrapper-item .penci-item-2 {
		border-right: 2px solid transparent
	}
	.featured-style-6 .wrapper-item .penci-item-0 {
		border-left: 2px solid transparent
	}
	.featured-style-13 .wrapper-item .penci-item-mag,
	.featured-style-14 .wrapper-item .penci-item-mag {
		width: 50%
	}
	.featured-style-13 .wrapper-item .penci-item-1,
	.featured-style-14 .wrapper-item .penci-item-1,
	.featured-style-15 .wrapper-item .penci-item-2,
	.featured-style-15 .wrapper-item .penci-item-mag {
		width: 100%
	}
	.featured-style-13 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-14 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-15 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-16 .penci-slide-overlay .penci-mag-featured-content {
		text-align: center
	}
	.featured-style-13 .penci-image-holder:before {
		height: 400px
	}
	.featured-style-14 .penci-image-holder:before,
	.featured-style-15 .penci-image-holder:before,
	.featured-style-16 .penci-image-holder:before {
		height: 350px
	}
	.featured-style-17 .wrapper-item .penci-slide17-item-2,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item,
	.featured-style-18 .wrapper-item .penci-slide17-item-2,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item {
		float: none;
		width: 100%;
		vertical-align: top
	}
	.featured-style-17 .wrapper-item .penci-slide17-item-2,
	.featured-style-18 .wrapper-item .penci-slide17-item-2 {
		border: none;
		border-top: 4px solid transparent;
		border-bottom: 4px solid transparent
	}
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-0,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-1,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-2,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-4,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-0,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-1,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-2,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-4 {
		width: 50%;
		float: left
	}
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-1,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-4,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-1,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-4 {
		border-right: 2px solid transparent;
		margin: 0
	}
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-0,
	.featured-style-17 .wrapper-item .penci-slider17-mag-item .penci-item-2,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-0,
	.featured-style-18 .wrapper-item .penci-slider17-mag-item .penci-item-2 {
		border-left: 2px solid transparent
	}
	.featured-style-17 .penci-image-holder:before,
	.featured-style-18 .penci-image-holder:before {
		height: 200px
	}
	.featured-style-17 .penci-slide17-item-2 .penci-image-holder:before,
	.featured-style-18 .penci-slide17-item-2 .penci-image-holder:before {
		height: 300px
	}
	.featured-style-19 .penci-mag-featured-content .feat-meta {
		display: none
	}
	.featured-style-19 .penci-image-holder:before {
		height: 215px
	}
	.featured-style-19 .penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-19 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-19 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 18px
	}
	.featured-style-20 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-20 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-4 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-20 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-20 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-20 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-3 .penci-mag-featured-content h3 a {
		font-size: 14px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-22 .wrapper-item .penci-item-mag,
	.featured-style-23 .wrapper-item .penci-item-mag,
	.featured-style-27 .wrapper-item .penci-item-mag {
		border-bottom: 4px solid transparent;
		width: 50%
	}
	.featured-style-22 .wrapper-item .penci-item-1,
	.featured-style-27 .wrapper-item .penci-item-1 {
		width: 100%
	}
	.featured-style-22 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-5 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-6 .penci-mag-featured-content h3 a {
		font-size: 16px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-23 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-5 .penci-mag-featured-content h3 a {
		font-size: 18px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-24 .wrapper-item .penci-item-mag,
	.featured-style-25 .wrapper-item .penci-item-1,
	.featured-style-25 .wrapper-item .penci-item-mag,
	.featured-style-26 .wrapper-item .penci-item-mag {
		width: 50%
	}
	.featured-style-24 .wrapper-item .penci-item-0,
	.featured-style-24 .wrapper-item .penci-item-1,
	.featured-style-24 .wrapper-item .penci-item-2,
	.featured-style-24 .wrapper-item .penci-item-3 {
		border-bottom: 4px solid transparent
	}
	.featured-style-24 .penci-item-0 .penci-image-holder:before,
	.featured-style-24 .penci-item-1 .penci-image-holder:before,
	.featured-style-24 .penci-item-2 .penci-image-holder:before,
	.featured-style-24 .penci-item-3 .penci-image-holder:before,
	.featured-style-25 .penci-item-0 .penci-image-holder:before,
	.featured-style-25 .penci-item-1 .penci-image-holder:before,
	.featured-style-25 .penci-item-2 .penci-image-holder:before,
	.featured-style-25 .penci-item-3 .penci-image-holder:before,
	.featured-style-27 .penci-image-holder:before {
		height: 200px
	}
	.featured-style-24 .penci-mag-featured-content .cat,
	.featured-style-25 .penci-mag-featured-content .cat {
		display: none
	}
	.featured-style-24 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-3 .penci-mag-featured-content h3 a {
		font-size: 16px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-26 .wrapper-item .penci-item-1 {
		width: 100%;
		border-bottom: 4px solid transparent
	}
	.featured-style-27 .penci-mag-featured-content .feat-meta {
		display: none
	}
	.featured-style-27 .penci-item-1 .penci-image-holder:before {
		height: 250px
	}
	.featured-style-35 .penci-featured-content-right,
	.featured-style-35.style-36 .penci-featured-content-right {
		width: 100%;
		text-align: center
	}
	.featured-style-35 .penci-image-holder:before,
	.featured-style-35.style-36 .penci-image-holder:before {
		height: 0;
		padding-top: 55%
	}
	.featured-style-35 .feat-text-right .penci-featured-slider-button {
		display: none
	}
	.penci-featured-content-right:before {
		content: none
	}
	.penci-featured-content-right .feat-text-right:before {
		background: #000;
		opacity: .7;
		content: "";
		position: absolute;
		top: 0;
		left: 0;
		bottom: 0;
		right: 0;
		width: 100%;
		height: 100%;
		display: block;
		z-index: 1
	}
	.featured-style-35 .feat-text-right h3,
	.featured-style-35 .featured-cat {
		z-index: 5;
		position: relative
	}
	.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .feat-text-right h3,
	.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .featured-cat,
	.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .featured-content-excerpt,
	.featured-style-35 .penci-owl-carousel.penci-owl-loaded .active .penci-featured-slider-button {
		animation-name: none;
		-webkit-animation-name: none;
		-moz-animation-name: none;
		-o-animation-name: none
	}
	.featured-style-35 .featured-content-excerpt {
		display: none
	}
	.feat-text-right {
		padding-top: 15px;
		padding-bottom: 15px;
		width: 450px;
		left: 50%;
		margin-left: -225px
	}
	.featured-style-37 .penci-featured-items-left,
	.featured-style-37 .penci-featured-items-right {
		width: 100%;
		border: none;
		float: none
	}
	.featured-style-37 .penci-featured-items-left {
		margin-bottom: 4px
	}
	.featured-style-37 .penci-featured-items-right .item {
		width: 50%;
		border: none;
		margin: 0 !important;
		float: left
	}
	.featured-style-37 .penci-featured-items-right .item:first-child {
		border-right: 2px solid transparent
	}
	.featured-style-37 .penci-featured-items-right .item:last-child {
		border-left: 2px solid transparent
	}
	h2.penci-heading-video {
		font-size: 24px
	}
	p.penci-sub-heading-video {
		font-size: 14px
	}
	.penci-grid li.list-boxed-post-2 {
		width: 100% !important
	}
	.penci-grid li.list-boxed-post-2 .content-boxed-2.show-top {
		display: none !important
	}
	.penci-grid li.list-boxed-post-2 .content-boxed-2.show-bottom {
		display: block !important
	}
	.penci-grid li.list-boxed-post-2 .inner-parent-boxed-2,
	.penci_sidebar .penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
		min-height: 312px;
		height: auto
	}
	.penci-grid li.list-boxed-post-2 .item>.thumbnail:before {
		display: none;
		content: none
	}
	.container .penci-grid li.typography-style {
		width: 100% !important;
		margin-right: 0 !important
	}
	.penci-photo-2-effect figcaption p,
	.penci_sidebar .penci-photo-2-effect figcaption p {
		display: none
	}
	.penci-photo-2-effect figcaption:after,
	.penci-photo-2-effect figcaption:before,
	.penci_sidebar .penci-photo-2-effect figcaption:after,
	.penci_sidebar .penci-photo-2-effect figcaption:before {
		display: none;
		content: none
	}
	.penci-photo-2-effect figcaption h2,
	.penci_sidebar .penci-photo-2-effect figcaption h2 {
		padding: 0 20px;
		transform: translateY(-50%);
		-webkit-transform: translateY(-50%)
	}
	.grid-mixed .thumbnail img {
		width: 100%;
		height: auto
	}
	.grid-mixed .mixed-detail,
	.grid-mixed .thumbnail.thumb-left {
		display: block !important;
		width: 100%
	}
	.grid-mixed .mixed-detail {
		padding: 30px
	}
	.grid-mixed .penci-post-box-meta {
		position: relative;
		margin: 31px 0 4px;
		left: auto;
		right: auto;
		bottom: auto
	}
	.grid-mixed .thumbnail.thumb-right {
		display: none !important
	}
	#navigation.header-4 .container,
	#navigation.header-5 .container {
		text-align: right
	}
	#navigation.header-4 .container .pcheader-icon,
	#navigation.header-5 .container .pcheader-icon,
	#navigation.header-6 .container .pcheader-icon {
		margin-left: 15px
	}
	#navigation .button-menu-mobile {
		display: inline-block
	}
	#navigation .menu {
		display: none !important
	}
	.portfolio-page-content .portfolio-left,
	.portfolio-page-content .portfolio-right {
		width: 100%;
		padding: 0
	}
	.portfolio-page-content .portfolio-left {
		margin-bottom: 30px
	}
	.container.penci_sidebar #main {
		width: 100%;
		margin: 0 0 60px 0;
		padding: 0 !important;
		float: none !important
	}
	.penci-single-style-10 .penci-single-s10-content,
	.penci-single-style-13 .penci-single-s13-content {
		width: 100%;
		margin: 20px 0 0 0;
		padding: 0 !important;
		float: none !important
	}
	.penci-sidebar-content {
		position: static !important;
		margin-left: 0 !important;
		top: auto !important;
		float: none !important;
		width: 100% !important
	}
	.penci-single-infiscroll .penci-single-block:not(.penci-single-infiblock-end) .penci-sidebar-content {
		display: none !important
	}
	.penci-single-infiscroll .penci-single-block:not(.penci-single-infiblock-end) .container.penci_sidebar #main {
		margin: 0
	}
	.penci-single-infiscroll .penci-single-block:not(.penci-single-infiblock-end) article.post {
		margin-bottom: 40px
	}
	.featured-carousel .featured-content .feat-text h3 a {
		font-size: 18px
	}
	.featured-carousel .carousel-meta {
		margin-top: 5px
	}
	.featured-carousel .carousel-meta span {
		font-size: 13px
	}
	.featured-carousel .featured-cat a {
		font-size: 11px
	}
	.about-widget {
		text-align: center
	}
	.footer-widget-wrapper {
		width: 100% !important;
		margin: 0 0 30px 0 !important;
		float: none
	}
	.footer-widget-wrapper.last {
		margin-bottom: 0 !important
	}
	.widget .jr-insta-thumb ul.thumbnails.no-border.jr_col_6 li {
		width: 33.33% !important
	}
	.widget .jr-insta-thumb ul.thumbnails.no-border.jr_col_8 li {
		width: 25% !important
	}
	.widget .jr-insta-thumb ul.thumbnails.no-border.jr_col_10 li {
		width: 20% !important
	}
	.container .penci-portfolio.column-3 .inner-portfolio-posts .portfolio-item {
		width: 50%
	}
	.column-1-2,
	.column-1-3,
	.column-1-4,
	.column-2-3,
	.column-3-4 {
		width: 100%;
		margin: 0 0 30px 0
	}
	.penci-masonry .item-masonry {
		width: 50%
	}
	.standard-masonry .standard-content .standard-share-box {
		display: none
	}
	.standard-masonry .standard-main-content.has-padding {
		min-height: 0;
		padding-left: 0
	}
	.pencisc-grid-tablet-6 .penci-masonry .item-masonry {
		width: 16.6666667%
	}
	.pencisc-grid-tablet-5 .penci-masonry .item-masonry {
		width: 20%
	}
	.pencisc-grid-tablet-4 .penci-masonry .item-masonry {
		width: 25%
	}
	.pencisc-grid-tablet-3 .penci-masonry .item-masonry {
		width: 33.3333%
	}
	.pencisc-grid-tablet-2 .penci-masonry .item-masonry {
		width: 50%
	}
	.pencisc-grid-tablet-1 .penci-masonry .item-masonry {
		width: 100%
	}
	.footer-social-drop-line ul.footer-socials li a span,
	ul.footer-socials li a span {
		display: none
	}
	.inner-item-portfolio {
		opacity: 1
	}
	.pcpt-ajax-ftl .inner-portfolio-posts.loaded .inner-item-portfolio.animated,
	.penci-portfolio.loaded .inner-item-portfolio.animated {
		-webkit-animation-name: none;
		-moz-animation-name: none;
		-o-animation-name: none;
		animation-name: none
	}
	div.penci-topbar-menu>ul {
		display: none !important
	}
	div.penci-topbar-menu>ul,
	ul.penci-topbar-menu {
		width: 100%;
		text-align: center
	}
	div.penci-topbar-menu>ul>li,
	ul.penci-topbar-menu>li {
		float: none;
		margin-right: 15px
	}
	div.penci-topbar-menu>ul ul.sub-menu,
	ul.penci-topbar-menu ul.sub-menu {
		top: auto
	}
}
@media only screen and (min-width:768px) and (max-width:960px) {
	body {
		--pcctain: 726px;
	}
	.container,
	.container.two-sidebar.two-sidebar,
	.featured-area.magazine-slider,
	.featured-area.style-1,
	.featured-area.style-4,
	.featured-carousel.style-2 .item img {
		width: var(--pcctain);
		max-width: calc(100% - 60px);
	}
	.wrapper-boxed.enable-boxed,
	.wrapper-boxed.enable-boxed .is-sticky #navigation {
		max-width: 766px
	}
	.featured-area .featured-carousel,
	.featured-area .featured-carousel.style-2,
	.penci-slick-slider {
		max-height: 420px
	}
	.featured-area.style-4,
	.featured-area.style-5,
	.penci-magazine-slider.penci-loading {
		min-height: 420px
	}
	#logo img {
		max-width: 600px;
		height: auto
	}
	.penci-image-holder.slider-style-1-fix {
		height: 372px
	}
	.penci-image-holder.slider-style-2-fix {
		width: 726px
	}
	.penci-image-holder.slider-style-3-fix {
		height: 400px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 {
		padding-bottom: 0 !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content {
		height: 230px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content {
		height: 450px
	}
	.featured-carousel .featured-content,
	.featured-carousel.style-2 .featured-content {
		top: 35.3%
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-title {
		font-size: 26px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-caption {
		font-size: 16px
	}
	ul.homepage-featured-boxes {
		margin-left: -10px;
		margin-right: -10px
	}
	.post-entry ul.homepage-featured-boxes li,
	ul.homepage-featured-boxes li {
		padding: 0 10px
	}
	ul.homepage-featured-boxes.boxes-4-columns li {
		width: 50%
	}
	ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 .fea-box-img:before {
		left: 8px;
		top: 8px;
		right: 8px;
		bottom: 8px
	}
	.penci-grid .list-post.list-boxed-post .item .content-list-right {
		display: inline-block;
		padding: 20px 20px 20px 30px;
		min-height: 0;
		height: auto
	}
	.penci-photo-2-effect figcaption h2,
	.penci_sidebar .penci-photo-2-effect figcaption h2 {
		font-size: 14px
	}
	.list-boxed-post .inner-content-list-right {
		vertical-align: top;
		display: block
	}
	.penci-pinterest-widget-container .penci-images-pin-widget a {
		width: 16.6666%
	}
	.penci-countdown .countdown-section {
		margin: 0 20px
	}
	.penci-countdown .countdown-amount {
		font-size: 60px
	}
	.penci-latest-posts-mixed-larger .penci-grid>li,
	.penci-layout-mixed .penci-grid>li {
		width: 100% !important
	}
	.container.penci_sidebar .penci-grid>li,
	.penci-grid>li,
	.penci-grid>li.grid-2-style {
		width: calc((100% - var(--pcrgap))/ 2)
	}
}
.penci-featured-cat-sc .home-featured-cat-content .mag-photo:last-child,
.penci-featured-cat-sc .home-featured-cat-content.style-6 .cat-right .mag-post-box:last-child {
	margin-bottom: 0 !important
}
@media only screen and (min-width:768px) {
	.penci-featured-cat-sc .home-featured-cat-content .mag-photo:nth-last-child(2) .penci-featured-cat-sc .home-featured-cat-content.style-6 .cat-right .mag-post-box:nth-last-child(2),
	.penci-featured-cat-sc .home-featured-cat-content.style-10 .mag-post-box:nth-last-child(2),
	.penci-featured-cat-sc .home-featured-cat-content.style-9 .mag-post-box:nth-last-child(2) {
		margin-bottom: 0 !important
	}
	.penci-featured-cat-sc .home-featured-cat-content.style-10 .mag-post-box:nth-last-child(2),
	.penci-featured-cat-sc .home-featured-cat-content.style-9 .mag-post-box:nth-last-child(2) {
		padding-bottom: 0 !important
	}
	.penci-featured-cat-sc .home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-detail,
	.penci-featured-cat-sc .penci-grid li.list-post .item .content-list-right,
	.penci-grid li.pclist-layout .item .content-list-right,
	.penci-latest-posts-sc .penci-grid li.penci-item-listp .item .content-list-right {
		padding-left: 30px;
		width: 53.75%;
		float: left
	}
	.penci-featured-cat-sc .penci-grid li.list-post .item>.thumbnail,
	.penci-grid li.pclist-layout .item>.thumbnail,
	.penci-latest-posts-sc .penci-grid li.list-post .item>.thumbnail {
		max-width: 100%
	}
	.penci-featured-cat-sc .home-featured-cat-content.style-6 .mag-post-box.first-post.full-mag-cat .magcat-detail {
		padding: 0 !important
	}
	.penci-featured-cat-sc .penci-grid li.list-post .item .content-list-right.fullwidth,
	.penci-latest-posts-sc .penci-grid li.list-post .item .content-list-right.fullwidth {
		padding: 0;
		width: 100%
	}
}
@media only screen and (max-width:767px) {
	.container,
	.container.two-sidebar.two-sidebar,
	.featured-area.magazine-slider,
	.featured-area.style-1,
	.featured-area.style-4,
	.featured-carousel.style-2 .item img {
		width: 100%
	}
	.wrapper-boxed.enable-boxed,
	.wrapper-boxed.enable-boxed .is-sticky #navigation {
		max-width: 100%
	}
	.header-slogan .header-slogan-text {
		padding: 0 10px
	}
	.featured-area .featured-carousel,
	.featured-area .featured-carousel.style-2,
	.penci-slick-slider {
		max-height: 180px
	}
	.featured-area.style-4,
	.featured-area.style-5,
	.penci-magazine-slider.penci-loading {
		min-height: 180px
	}
	.penci-image-holder.slider-style-1-fix {
		height: 250px
	}
	.penci-image-holder.slider-style-2-fix {
		width: 480px
	}
	.penci-image-holder.slider-style-3-fix {
		height: 260px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content {
		width: 100% !important;
		border: none !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li {
		padding-bottom: 0 !important;
		height: auto !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 .mag-content,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content {
		height: 200px
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1 .mag-content:first-child,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-3 .mag-content:first-child {
		margin-bottom: 10px !important
	}
	.featured-carousel .feat-text .feat-time {
		display: none
	}
	.featured-carousel .featured-cat a {
		margin-bottom: 0
	}
	.penci-magazine-slider ul.mag-wrap li {
		width: 100% !important;
		border: none !important;
		height: 0 !important;
		padding-bottom: 55% !important;
		border-bottom: 4px solid transparent !important
	}
	#penci-end-sidebar-sticky,
	.penci-magazine-slider .mag-cat {
		display: none
	}
	.penci-magazine-slider .mag-item-1 .mag-meta h3 a,
	.penci-magazine-slider .mag-meta h3 a {
		font-size: 18px
	}
	.penci-magazine-slider .mag-item-1 .mag-meta-child {
		margin-top: 5px
	}
	.home-featured-cat-content.style-10 .mag-post-box:nth-last-child(2),
	.home-featured-cat-content.style-9 .mag-post-box:nth-last-child(2) {
		padding-bottom: 15px;
		margin-bottom: 15px
	}
	.featured-carousel.style-7 .featured-content .feat-text h3,
	.featured-carousel.style-7 .featured-content .feat-text h3 a,
	.wrapper-boxed.enable-boxed .featured-carousel.style-7 .featured-content .feat-text h3 {
		padding: 0
	}
	.featured-carousel.style-7 .featured-content .feat-text h3 a:after,
	.featured-carousel.style-7 .featured-content .feat-text h3 a:before {
		content: none;
		display: none
	}
	.penci-featured-content .feat-text {
		padding: 15px 5px 16px;
		max-width: 350px
	}
	.penci-flat-overlay .penci-slide-overlay .penci-mag-featured-content {
		padding: 12px 5px
	}
	.penci-slide-overlay .penci-mag-featured-content .feat-text {
		text-align: center
	}
	.featured-style-35 .featured-cat,
	.penci-featured-content .feat-text .feat-meta,
	.penci-featured-content .feat-text .featured-cat,
	.penci-mag-featured-content .cat,
	.penci-mag-featured-content .feat-meta {
		display: none
	}
	.penci-slide-overlay .penci-mag-featured-content {
		left: 0;
		width: 100%;
		padding: 0 5px;
		bottom: 10px
	}
	.featured-style-13 .penci-mag-featured-content h3 a,
	.penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-13 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-17 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-26 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-37 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-6 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 20px
	}
	.featured-style-35 .feat-text-right h3 a,
	.featured-style-4 .penci-featured-content .feat-text h3 a,
	.featured-style-5 .penci-featured-content .feat-text h3 a,
	.penci-featured-content .feat-text h3 a {
		font-size: 18px
	}
	.feat-text-right {
		padding-left: 15px;
		padding-right: 15px;
		width: 350px;
		margin-left: -175px
	}
	.featured-style-2 .penci-owl-carousel .swiper-slide {
		width: 480px
	}
	.featured-style-10 .penci-mag-featured-content h3 a,
	.featured-style-11 .penci-mag-featured-content h3 a,
	.featured-style-12 .penci-mag-featured-content h3 a,
	.featured-style-15 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-15 .penci-mag-featured-content h3 a,
	.featured-style-16 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-16 .penci-mag-featured-content h3 a,
	.featured-style-7 .penci-mag-featured-content h3 a,
	.featured-style-8 .penci-mag-featured-content h3 a,
	.featured-style-9 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-13 .penci-image-holder:before,
	.featured-style-14 .penci-image-holder:before {
		height: 300px
	}
	.featured-style-15 .penci-image-holder:before,
	.featured-style-16 .penci-image-holder:before {
		height: 200px
	}
	.featured-style-17 .penci-image-holder:before,
	.featured-style-18 .penci-image-holder:before {
		height: 160px
	}
	.featured-style-17 .penci-slide17-item-2 .penci-image-holder:before,
	.featured-style-18 .penci-slide17-item-2 .penci-image-holder:before {
		height: 240px
	}
	.featured-style-19 .penci-image-holder:before {
		height: 150px
	}
	.featured-style-19 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-19 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-19 .penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-19 .wrapper-item .penci-item-2,
	.featured-style-19 .wrapper-item .penci-item-3,
	.featured-style-19 .wrapper-item .penci-item-mag {
		width: 50%
	}
	.featured-style-19 .wrapper-item .penci-item-1,
	.featured-style-19 .wrapper-item .penci-item-3 {
		border-right: 2px solid transparent
	}
	.featured-style-19 .wrapper-item .penci-item-0,
	.featured-style-19 .wrapper-item .penci-item-2 {
		border-left: 2px solid transparent
	}
	.featured-style-20 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-20 .penci-item-2 .penci-mag-featured-content h3 a {
		font-size: 14px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-20 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-20 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-20 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-21 .penci-item-4 .penci-mag-featured-content h3 a {
		font-size: 14px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-20 .wrapper-item .penci-item-mag,
	.featured-style-21 .wrapper-item .penci-item-mag {
		width: 50%
	}
	.featured-style-20 .wrapper-item .penci-item-1,
	.featured-style-21 .wrapper-item .penci-item-1 {
		width: 100%;
		border-bottom: 4px solid transparent
	}
	.featured-style-20 .wrapper-item .penci-item-3 {
		border-bottom: 4px solid transparent
	}
	.featured-style-23 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-23 .penci-item-5 .penci-mag-featured-content h3 a,
	.featured-style-27 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-27 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-27 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-27 .penci-item-4 .penci-mag-featured-content h3 a {
		font-size: 14px;
		text-transform: none;
		letter-spacing: 0
	}
	.featured-style-24 .penci-item-0 .penci-image-holder:before,
	.featured-style-24 .penci-item-1 .penci-image-holder:before,
	.featured-style-24 .penci-item-2 .penci-image-holder:before,
	.featured-style-24 .penci-item-3 .penci-image-holder:before,
	.featured-style-25 .penci-item-0 .penci-image-holder:before,
	.featured-style-25 .penci-item-1 .penci-image-holder:before,
	.featured-style-25 .penci-item-2 .penci-image-holder:before,
	.featured-style-25 .penci-item-3 .penci-image-holder:before,
	.featured-style-27 .penci-item-0 .penci-image-holder:before,
	.featured-style-27 .penci-item-2 .penci-image-holder:before,
	.featured-style-27 .penci-item-3 .penci-image-holder:before,
	.featured-style-27 .penci-item-4 .penci-image-holder:before {
		height: 150px
	}
	.featured-style-24 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-24 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-25 .penci-item-3 .penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-27 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 18px
	}
	.featured-style-28 .wrapper-item .penci-item-1 {
		width: 480px
	}
	.featured-style-28 .penci-item-1 .penci-image-holder:before {
		height: 404px;
		padding: 0
	}
	.featured-style-28 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-29 .penci-featured-content .feat-text h3 a {
		font-size: 24px
	}
	.featured-style-29.style-30 .penci-featured-content .feat-text h3 a {
		font-size: 20px
	}
	.featured-style-29.style-30 .penci-featured-content {
		padding: 0 15px
	}
	.featured-style-29 .penci-image-holder:before,
	.featured-style-29.style-30 .penci-image-holder:before {
		height: 400px
	}
	.pencislider-container .pencislider-content .pencislider-title {
		font-size: 24px
	}
	.pencislider-container .pencislider-content .pencislider-caption span,
	.pencislider-container .pencislider-content .pencislider-title span {
		padding: 2px 10px
	}
	.pencislider-container .pencislider-content .pencislider-button {
		padding: 9px 15px 9px;
		font-size: 12px
	}
	.penci-home-popular-posts {
		padding: 30px 0 0 0;
		border: none
	}
	.penci-video-overlay {
		left: 10px;
		right: 10px
	}
	.penci-video-custom-img {
		-webkit-animation-delay: .1s;
		-moz-animation-delay: .1s;
		-o-animation-delay: .1s;
		animation-delay: .1s
	}
	h2.penci-heading-video {
		font-size: 18px;
		-webkit-animation-delay: .3s;
		-moz-animation-delay: .3s;
		-o-animation-delay: .3s;
		animation-delay: .3s
	}
	p.penci-sub-heading-video {
		font-size: 12px;
		-webkit-animation-delay: .5s;
		-moz-animation-delay: .5s;
		-o-animation-delay: .5s;
		animation-delay: .5s
	}
	.home-featured-boxes-sc ul.homepage-featured-boxes.boxes-2-columns li,
	.post-entry ul.homepage-featured-boxes li,
	ul.homepage-featured-boxes li {
		width: 100% !important;
		margin-bottom: 20px
	}
	.grid-mixed,
	.grid-mixed>article {
		display: block
	}
	#logo img {
		max-width: 100%;
		height: auto
	}
	.archive-box h1,
	.archive-box span,
	.post-header h1,
	.post-header h1 a,
	.post-header h2 a {
		font-size: 18px
	}
	.standard-content .standard-share-box {
		display: none
	}
	.standard-main-content.has-padding {
		padding-left: 0
	}
	.standard-main-content.classic-main-content.has-padding,
	.standard-main-content.has-padding {
		min-height: 0
	}
	.post-image.audio iframe,
	.standard-post-image.audio iframe {
		height: 120px;
		width: 100%
	}
	.thecomment .author-img {
		display: none
	}
	.thecomment .comment-text {
		margin-left: 0
	}
	#respond p.comment-form-author,
	#respond p.comment-form-email,
	#respond p.comment-form-url,
	.wpcf7 p.email,
	.wpcf7 p.name,
	.wpcf7 p.subject {
		width: 100%;
		margin: 0
	}
	.featured-carousel .featured-content,
	.featured-carousel.style-2 .featured-content {
		top: 34%
	}
	.featured-carousel>button.slick-next,
	.featured-carousel>button.slick-prev {
		right: 10px
	}
	.featured-carousel>button.slick-prev,
	.penci-slider .penci-direction-nav .penci-prev {
		left: 10px
	}
	.featured-carousel .featured-content {
		width: 340px
	}
	.featured-carousel .featured-content .feat-text {
		padding: 20px 10px !important
	}
	.error-404 .heading-text-404,
	.header-classic>h2,
	.standard-main-content>h2 {
		font-size: 24px;
		padding: 0
	}
	.penci-slider.penci-loading {
		min-height: 250px
	}
	.penci-slider ul.slides li .pencislider-container {
		padding: 0 65px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-title {
		font-size: 18px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-caption {
		font-size: 13px
	}
	.penci-slider .pencislider-container .pencislider-content .penci-button {
		margin: 20px 0 0
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-button {
		padding: 8px 20px;
		font-size: 12px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-button:before {
		content: none;
		display: none
	}
	.header-classic>h2 a:after,
	.header-classic>h2 a:before,
	.post-header h1 span:after,
	.post-header h1 span:before,
	.post-header h2 span:after,
	.post-header h2 span:before,
	.standard-main-content>h2:before {
		content: none !important
	}
	.container.penci_sidebar .penci-grid>li {
		width: 100% !important;
		margin: 0 0 40px !important
	}
	.container.penci_sidebar .penci-grid[data-mcols="2"]>li,
	.penci-grid[data-mcols="2"]>li {
		width: calc((100% - var(--pcrgap))/ 2) !important;
		margin-bottom: 20px
	}
	.post-header h1 span,
	.post-header h2 span {
		padding: 0
	}
	.penci-portfolio-filter ul {
		display: block
	}
	.inner-portfolio-posts .portfolio-item,
	.penci-post-gallery-container.masonry .item-gallery-masonry {
		width: 100% !important
	}
	.post-entry .penci-portfolio-filter ul li {
		float: none
	}
	.penci-portfolio-filter ul li,
	.post-entry .penci-portfolio-filter ul li {
		margin: 0 10px 5px
	}
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-detail,
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-thumb,
	.penci-grid .list-post.list-boxed-post .item .content-list-right,
	.penci-grid .list-post.list-boxed-post .item>.thumbnail,
	.penci-grid li.list-post .item>.thumbnail {
		width: 100% !important;
		display: block;
		height: auto;
		min-height: 0;
		float: none;
		max-width: 100%
	}
	.penci-grid .list-post.list-boxed-post .item>.thumbnail:before {
		content: none;
		display: none
	}
	.penci-grid li {
		width: 100% !important;
		margin-right: 0 !important;
		float: none
	}
	.container.penci_sidebar .penci-masonry .item-masonry {
		width: 100%;
		float: none;
		position: static !important;
		margin-bottom: 30px
	}
	.penci-grid li.pclist-layout.pc-has-thumb.pc-list-imgright .item .content-list-right,
	.penci-grid li.list-post .item .content-list-right {
		padding: 0;
		width: 100% !important;
		float: none
	}
	.penci-grid .list-post.list-boxed-post .item .content-list-right {
		padding: 30px
	}
	.penci-grid li.list-post .item>.thumbnail {
		margin-bottom: 30px
	}
	.penci-grid .list-post.list-boxed-post .item>.thumbnail {
		margin-bottom: 0
	}
	.penci-grid li .item>.thumbnail,
	.penci-masonry .item-masonry>.thumbnail {
		width: 100%
	}
	.penci-masonry .item-masonry {
		width: 100% !important
	}
	.penci-grid li.list-post.penci-slistp .item>.thumbnail {
		width: 120px !important
	}
	.pencisc-grid-mobile-6 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-6 .penci-masonry .item-masonry {
		width: 16.6666667% !important
	}
	.pencisc-grid-mobile-5 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-5 .penci-masonry .item-masonry {
		width: 20% !important
	}
	.pencisc-grid-mobile-4 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-4 .penci-masonry .item-masonry {
		width: 25% !important
	}
	.pencisc-grid-mobile-3 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-3 .penci-masonry .item-masonry {
		width: 33.3333% !important
	}
	.pencisc-grid-mobile-2 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-2 .penci-masonry .item-masonry {
		width: 50% !important
	}
	.pencisc-grid-mobile-1 .home-featured-cat-content .mag-photo,
	.pencisc-grid-mobile-1 .penci-masonry .item-masonry {
		width: 100% !important
	}
	.container.penci_sidebar .penci-masonry[data-mcols="2"] .item-masonry,
	.penci-masonry[data-mcols="2"] .item-masonry {
		width: 50% !important;
		float: left !important
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-2 .home-featured-cat-content .mag-photo,
	.penci-featured-cat-ctcol.pencisc-grid-mobile-3 .home-featured-cat-content .mag-photo,
	.penci-featured-cat-ctcol.pencisc-grid-mobile-4 .home-featured-cat-content .mag-photo,
	.penci-featured-cat-ctcol.pencisc-grid-mobile-5 .home-featured-cat-content .mag-photo,
	.penci-featured-cat-ctcol.pencisc-grid-mobile-6 .home-featured-cat-content .mag-photo {
		width: 100% !important
	}
	.list-boxed-post .inner-content-list-right {
		display: block
	}
	.penci-photo-2-effect figcaption h2,
	.penci_sidebar .penci-photo-2-effect figcaption h2 {
		font-size: 22px
	}
	.home-featured-cat-content .mag-photo {
		width: 100%;
		margin-bottom: 15px
	}
	.home-featured-cat-content.style-1 {
		margin-left: 0;
		margin-right: 0;
		width: 100%
	}
	.home-featured-cat-content .cat-left,
	.home-featured-cat-content .cat-right {
		width: 100%;
		float: none
	}
	.home-featured-cat-content.style-1 .cat-left,
	.home-featured-cat-content.style-1 .cat-right {
		padding: 0
	}
	.home-featured-cat-content .cat-left {
		margin-bottom: 30px
	}
	.home-featured-cat.mag-cat-style-2 {
		width: 100%;
		margin: 0 0 20px 0;
		float: none
	}
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-detail {
		padding: 0
	}
	.home-featured-cat-content.style-6 .mag-post-box.first-post .magcat-thumb {
		margin-bottom: 24px
	}
	.home-featured-cat-content.style-6 .cat-right .mag-post-box {
		margin-right: 0;
		width: 100%;
		float: none;
		display: table;
		padding-bottom: 15px;
		border-bottom: 1px solid #dedede;
		margin-bottom: 15px
	}
	.home-featured-cat-content.style-6 .cat-right .mag-post-box:last-child {
		border: none
	}
	.home-featured-cat-content.style-10 .mag-post-box,
	.home-featured-cat-content.style-9 .mag-post-box {
		width: 100%;
		float: none;
		margin-right: 0
	}
	.content-special-list {
		padding: 15px
	}
	.format-post-box .post-format-icon {
		top: 10px;
		margin-left: -35px;
		display: none
	}
	.format-post-box .post-format-icon i {
		font-size: 24px
	}
	.format-post-box .dt-special,
	.format-post-box .dt-special a,
	.format-post-box.penci-format-quote .dt-special {
		font-size: 16px;
		line-height: 1.7
	}
	.author-quote span {
		font-size: 13px
	}
	.under-construction-page .under-title {
		font-size: 23px
	}
	.penci-countdown .countdown-section {
		margin: 0 5px
	}
	.penci-countdown .countdown-amount {
		font-size: 30px
	}
	.penci-countdown .countdown-period {
		font-size: 13px;
		margin: 15px 0 0
	}
	.post-entry h1 {
		font-size: 24px
	}
	.post-entry h2 {
		font-size: 22px
	}
	.post-entry h3 {
		font-size: 20px
	}
	.post-entry h4 {
		font-size: 18px
	}
	.post-entry h5 {
		font-size: 16px
	}
	.post-entry h6 {
		font-size: 15px
	}
	.elementor-widget-text-editor h1 {
		font-size: 24px
	}
	.elementor-widget-text-editor h2 {
		font-size: 22px
	}
	.elementor-widget-text-editor h3 {
		font-size: 20px
	}
	.elementor-widget-text-editor h4 {
		font-size: 18px
	}
	.elementor-widget-text-editor h5 {
		font-size: 16px
	}
	.elementor-widget-text-editor h6 {
		font-size: 15px
	}
	.penci-post-gallery-container.masonry .item-gallery-masonry a {
		opacity: 1;
		-webkit-animation-delay: 0s !important;
		-moz-animation-delay: 0s !important;
		-o-animation-delay: 0s !important;
		animation-delay: 0s !important;
		-webkit-animation-name: none !important;
		-moz-animation-name: none !important;
		-o-animation-name: none !important;
		animation-name: none !important
	}
	ul.footer-socials li {
		margin-right: 20px
	}
	.header-standard .post-title,
	.header-standard h2,
	.header-standard h2 a,
	.pc_titlebig_standard,
	.pc_titlebig_standard a,
	.penci-header-signup-form h4.header-signup-form,
	.penci-page-header h1 {
		font-size: 20px
	}
	.tags-share-box {
		padding: 20px 0
	}
	.post-share {
		position: static;
		margin-top: 15px;
		clear: both;
		display: block
	}
	.post-share.tags-share-box-top {
		margin-top: 0;
	}
	.penci-overlay-over .overlay-header-box {
		padding: 0;
		left: 10px;
		right: 10px
	}
	.overlay-header-box .cat,
	.overlay-header-box .overlay-author {
		display: none
	}
	.overlay-header-box .overlay-title a {
		font-size: 18px
	}
	.penci-overlay-over .overlay-header-box:after {
		content: none;
		display: none
	}
	.overlay-post-box-meta {
		position: static;
		padding: 20px 0 0
	}
	.penci-single-mag-slider .magcat-detail .magcat-titlte {
		font-size: 20px
	}
	.home-featured-cat-content .penci-single-mag-slider .grid-post-box-meta {
		margin-top: 7px
	}
	.post-pagination .next-post,
	.post-pagination .prev-post {
		float: none;
		width: 100%;
		display: table
	}
	.post-pagination .prev-post {
		margin-bottom: 15px
	}
	.footer-subscribe h4.footer-subscribe-title {
		font-size: 28px
	}
	.footer-subscribe .mc4wp-form {
		width: 480px
	}
	.footer-subscribe .mc4wp-form .mdes {
		margin-left: 0;
		width: 100%;
		font-size: 16px
	}
	.footer-subscribe .mc4wp-form .memail {
		width: 328px
	}
	.footer-social-remove-circle ul.footer-socials li a i {
		font-size: 16px
	}
	.post-pagination.pcpagp-style-3 {
		display: block
	}
	.post-pagination.pcpagp-style-3 .next-post {
		padding-left: 0
	}
	.penci-post-nav-thumb.nav-thumb-next {
		margin: 0
	}
	.post-pagination.pcpagp-style-5 .next-post-inner,
	.post-pagination.pcpagp-style-5 .prev-post-inner {
		margin: -60px 10px 0 10px;
		padding: 15px 10px 10px 10px
	}
	.post-entry.blockquote-style-4 blockquote:not(.wp-block-quote),
	.post-entry.blockquote-style-5 blockquote:not(.wp-block-quote) {
		padding-left: 0;
		padding-right: 0
	}
	.post-pagination.pcpagp-style-3 .next-post,
	.post-pagination.pcpagp-style-3 .prev-post,
	.post-pagination.pcpagp-style-5 .next-post,
	.post-pagination.pcpagp-style-5 .prev-post {
		width: 100%
	}
	.e-parent.e-con.e-flex {
		--flex-wrap: nowrap
	}
	.comments.pc-cms-style-2 .thecomment .author-img,
	.comments.pc-cms-style-3 .thecomment .author-img {
		display: block;
		margin-right: 10px;
		width: 30px
	}
	.comments.pc-cms-style-2 .comment-text {
		margin-left: 40px
	}
	.comments.pc-cms-style-2 .thecomment .comment-text:before {
		top: 15px
	}
	.pcrstb-wrap {
		width: 100%;
		overflow: auto;
	}
}
@media only screen and (min-width:480px) and (max-width:767px) {
	body {
		--pcctain: 480px;
	}
	.container,
	.container.two-sidebar.two-sidebar,
	.featured-area.magazine-slider,
	.featured-area.style-1,
	.featured-area.style-4,
	.featured-carousel.style-2 .item img {
		width: var(--pcctain)
	}
	.wrapper-boxed.enable-boxed,
	.wrapper-boxed.enable-boxed .is-sticky #navigation {
		max-width: 520px
	}
	.featured-area .featured-carousel,
	.featured-area .featured-carousel.style-2,
	.penci-slick-slider {
		max-height: 280px
	}
	.featured-area.style-4,
	.featured-area.style-5,
	.penci-magazine-slider.penci-loading {
		min-height: 280px
	}
	#logo img {
		max-width: 100%;
		height: auto
	}
	.standard-content-special,
	.standard-post-image .audio-iframe {
		left: 15px;
		right: 15px;
		bottom: 15px
	}
	.post-image.audio iframe {
		width: 100%;
		height: auto
	}
	.penci-countdown .countdown-section {
		margin: 0 15px
	}
	.penci-countdown .countdown-amount {
		font-size: 40px
	}
	.penci-countdown .countdown-period {
		font-size: 16px;
		margin: 20px 0 0
	}
}
@media only screen and (max-width:479px) {
	#footer-section>.container,
	#widget-area>.container,
	.penci-page-header-wrap .penci-page-header-inner.container,
	.penci-post-image-wrapper>.container,
	.penci-single-smore .container,
	.penci-two-sidebar .container.penci-breadcrumb,
	.wrapper-boxed>.container,
	.wrapper-boxed>.penci-single-wrapper>.penci-single-block>.container,
	â€‹.penci-page-header-wrap {
		padding-left: 20px;
		padding-right: 20px
	}
	.penci-single-smore .container .container,
	.wrapper-boxed>.container>.container {
		padding-left: 0;
		padding-right: 0
	}
	#header .inner-header {
		height: auto
	}
	.penci-single-smore .container .container {
		padding-left: 0;
		padding-right: 0
	}
	.penci-header-signup-form {
		padding-left: 10px;
		padding-right: 10px
	}
	.penci-single-style-10 .header-standard,
	.penci-single-style-10 .post-box-meta-single,
	.penci-single-style-13 .header-standard,
	.penci-single-style-13 .post-box-meta-single {
		text-align: center
	}
	.feat-text-right {
		width: 330px;
		margin-left: -165px
	}
	.penci-google-adsense-single-s10 {
		width: 100%
	}
	#navigation,
	.inner-header {
		padding-left: 10px;
		padding-right: 10px
	}
	.header-slogan .header-slogan-text {
		font-size: 12px;
		padding: 0 10px
	}
	#navigation.header-6 .pcheader-icon {
		margin-left: 5px
	}
	#navigation.header-6 #logo img {
		max-width: 300px
	}
	.featured-carousel .featured-content {
		width: 250px
	}
	.featured-carousel .featured-content .feat-text h3 a,
	.featured-style-35 .feat-text-right h3 a {
		font-size: 16px
	}
	.featured-carousel .carousel-meta {
		display: none
	}
	.penci-image-holder.slider-style-1-fix {
		height: 180px
	}
	.penci-image-holder.slider-style-2-fix {
		width: 300px
	}
	.penci-image-holder.slider-style-3-fix {
		height: 180px
	}
	.penci-magazine-slider .mag-item-1 .mag-meta h3 a,
	.penci-magazine-slider .mag-meta h3 a {
		font-size: 14px
	}
	.penci-magazine-slider .mag-item-1 .mag-meta {
		padding: 15px
	}
	.featured-style-2 .penci-owl-carousel .swiper-slide,
	.featured-style-38 .penci-owl-carousel .swiper-slide {
		width: 360px
	}
	.featured-style-38 .penci-featured-content .feat-text h3 a {
		font-size: 18px
	}
	.penci-magazine-slider .penci-direction-nav a.penci-prev,
	.penci-owl-carousel .penci-owl-nav .owl-prev {
		left: 10px
	}
	.penci-magazine-slider .penci-direction-nav a.penci-next,
	.penci-owl-carousel .penci-owl-nav .owl-next {
		right: 10px
	}
	.penci-magazine-slider ul.mag-wrap li .mag-content {
		width: 100% !important;
		border: none !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li .mag-content {
		margin-bottom: 5px !important
	}
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-1,
	.penci-magazine-slider.penci-mag3-slider ul.mag-wrap li.mag-item-2 {
		margin: 0 !important;
		border: none !important
	}
	.featured-carousel.style-7 .featured-content {
		bottom: 5px
	}
	.featured-carousel.style-7 .featured-content .feat-text h3 a {
		padding: 0
	}
	.featured-style-37 .penci-owl-carousel .penci-owl-dots {
		display: none
	}
	.featured-style-37 .penci-item-1 .penci-slide-overlay .penci-mag-featured-content {
		bottom: 16px
	}
	.standard-content-special,
	.standard-post-image .audio-iframe {
		left: 10px;
		right: 10px;
		bottom: 10px
	}
	ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 .fea-box-img:before {
		top: 10px;
		left: 10px;
		bottom: 10px;
		right: 10px
	}
	.grid-overlay-meta .grid-header-box {
		margin-left: 10px;
		margin-right: 10px
	}
	.footer-widget-wrapper .quote-widget>p {
		padding-left: 35px
	}
	#penci-login-popup {
		padding: 30px
	}
	.penci-lgpop-title {
		font-size: 22px
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image img,
	.widget ul.side-newsfeed li .side-item .side-image img {
		width: 100px
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a,
	.widget ul.side-newsfeed li .side-item .side-item-text h4 a {
		font-size: 15px
	}
	.penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text .side-item-meta,
	.widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta {
		font-size: 13px
	}
	.post-box-meta span.author-post {
		display: none
	}
	.standard-post-special.penci-special-format-quote .standard-content-special {
		position: relative;
		left: auto;
		right: auto;
		bottom: auto;
		box-shadow: none;
		-webkit-box-shadow: none;
		-moz-box-shadow: none;
		border: 1px solid #dedede;
		border-top: none
	}
	.format-post-box {
		padding-left: 20px;
		padding-right: 20px;
		padding-top: 20px
	}
	.format-post-box.penci-format-link {
		padding: 15px
	}
	.format-post-box .dt-special a {
		font-size: 14px
	}
	.post-entry blockquote {
		padding: 0 0 0 40px
	}
	.post-entry blockquote:before {
		font-size: 30px
	}
	.post-entry blockquote,
	.post-entry blockquote p {
		font-size: 15px
	}
	.post-author .author-content {
		margin: 0
	}
	.author-img {
		margin-right: 20px
	}
	.author-img img {
		width: 80px;
		height: auto;
		margin: 0
	}
	.author-content h5,
	.author-content h5 a,
	.item-related h3 a,
	.post-box-title,
	.thecomment .comment-text span.author,
	.thecomment .comment-text span.author a {
		font-size: 18px
	}
	.penci-magazine-slider .penci-direction-nav a,
	.penci-slick-slider>button.slick-next,
	.penci-slick-slider>button.slick-prev {
		width: 32px;
		height: 32px;
		line-height: 32px;
		margin-top: -16px;
		font-size: 15px
	}
	.penci-slick-slider>button.slick-next {
		right: 10px
	}
	.penci-slick-slider>button.slick-prev {
		left: 10px
	}
	.penci-slick-slider>button.slick-next i,
	.penci-slick-slider>button.slick-prev i {
		line-height: 32px;
		font-size: 15px
	}
	.featured-carousel>button.slick-next,
	.featured-carousel>button.slick-prev {
		display: none !important
	}
	.featured-carousel .featured-content {
		width: 240px;
		top: 37%
	}
	.featured-carousel .featured-cat a {
		padding: 2px 10px 1px
	}
	.featured-carousel.style-2 .featured-content {
		top: 37%
	}
	.featured-carousel .featured-content .feat-text {
		padding: 15px 10px !important
	}
	.error-404 .heading-text-404,
	.header-classic>h2,
	.standard-main-content>h2 {
		font-size: 20px
	}
	.penci-portfolio.column-2 .portfolio-overlay-content .portfolio-short,
	.penci_sidebar .penci-portfolio.column-2 .portfolio-overlay-content .portfolio-short,
	.portfolio-overlay-content .portfolio-short {
		margin-top: 17.5%
	}
	.featured-carousel .featured-cat {
		margin-bottom: 5px
	}
	.featured-carousel .featured-content .feat-text h3 a,
	.wrapper-boxed.enable-boxed .featured-carousel .featured-content .feat-text h3 a {
		font-size: 14px
	}
	.penci-slider.penci-loading {
		min-height: 160px
	}
	.penci-slider ul.slides li .pencislider-container {
		padding: 0 20px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-title {
		font-size: 14px
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-caption {
		font-size: 12px;
		margin: 3px 0 0
	}
	.penci-slider .pencislider-container .pencislider-content .penci-button {
		margin: 14px 0 0
	}
	.penci-slider .pencislider-container .pencislider-content .pencislider-button {
		padding: 5px 10px;
		font-size: 10px
	}
	.penci-slider .penci-direction-nav .penci-next,
	.penci-slider .penci-direction-nav .penci-prev {
		display: none !important
	}
	.penci-grid .list-post.list-boxed-post .item .content-list-right {
		padding: 30px 15px !important;
		clear: both
	}
	.penci-featured-content .feat-text {
		width: 100%
	}
	.featured-style-4 .penci-featured-content .feat-text h3 a,
	.featured-style-5 .penci-featured-content .feat-text h3 a {
		font-size: 16px
	}
	.penci-featured-infor .penci-entry-title {
		font-size: 18px
	}
	.featured-style-13 .penci-mag-featured-content h3 a,
	.featured-style-18 .penci-mag-featured-content h3 a,
	.penci-mag-featured-content h3 a {
		font-size: 12px
	}
	.featured-style-13 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-14 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-15 .penci-mag-featured-content h3 a,
	.featured-style-17 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-18 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-37 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-6 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-1 .penci-owl-carousel .penci-image-holder:before {
		padding-top: 50%
	}
	.penci-photo-2-effect figcaption h2,
	.penci_sidebar .penci-photo-2-effect figcaption h2 {
		font-size: 14px
	}
	.featured-style-13 .penci-image-holder:before,
	.featured-style-14 .penci-image-holder:before {
		height: 200px
	}
	.featured-style-17 .penci-image-holder:before,
	.featured-style-18 .penci-image-holder:before {
		height: 140px
	}
	.featured-style-17 .penci-slide17-item-2 .penci-image-holder:before,
	.featured-style-18 .penci-slide17-item-2 .penci-image-holder:before {
		height: 220px
	}
	.featured-style-19 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-19 .penci-item-1 .penci-mag-featured-content h3 a,
	.featured-style-19 .penci-mag-featured-content h3 a {
		font-size: 13px
	}
	.featured-style-22 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-4 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-5 .penci-mag-featured-content h3 a,
	.featured-style-22 .penci-item-6 .penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-22 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-22 .penci-item-2 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22 .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22 .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22 .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22 .penci-item-6 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-1 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-2 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23 .penci-item-6 .penci-slide-overlay .penci-mag-featured-content {
		padding: 0 5px;
		bottom: 10px
	}
	.featured-style-22.penci-flat-overlay .penci-item-2 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22.penci-flat-overlay .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22.penci-flat-overlay .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22.penci-flat-overlay .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-22.penci-flat-overlay .penci-item-6 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-1 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-2 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-3 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-4 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-5 .penci-slide-overlay .penci-mag-featured-content,
	.featured-style-23.penci-flat-overlay .penci-item-6 .penci-slide-overlay .penci-mag-featured-content {
		padding: 12px 5px;
		bottom: 0
	}
	.featured-style-26 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-26 .penci-item-0 .penci-mag-featured-content h3 a,
	.featured-style-26 .penci-item-2 .penci-mag-featured-content h3 a,
	.featured-style-26 .penci-item-3 .penci-mag-featured-content h3 a,
	.featured-style-26 .penci-item-4 .penci-mag-featured-content h3 a {
		font-size: 14px
	}
	.featured-style-26 .penci-item-1 .penci-image-holder:before {
		height: 220px
	}
	.featured-style-27 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 16px
	}
	.featured-style-28 .wrapper-item .penci-item-1 {
		width: 300px
	}
	.featured-style-28 .penci-item-1 .penci-image-holder:before {
		height: 404px;
		padding: 0
	}
	.featured-style-28 .penci-item-1 .penci-mag-featured-content h3 a {
		font-size: 18px
	}
	.featured-style-29 .penci-featured-content,
	.featured-style-30 .penci-featured-content {
		padding: 0 15px
	}
	.featured-style-29 .penci-featured-content .feat-text h3 a,
	.featured-style-30 .penci-featured-content .feat-text h3 a {
		font-size: 18px
	}
	.featured-style-29 .penci-image-holder:before,
	.featured-style-30 .penci-image-holder:before {
		height: 300px
	}
	.featured-style-29 .penci-featured-slider-button a,
	.featured-style-30 .penci-featured-slider-button a {
		height: 30px;
		line-height: 26px;
		padding: 0 10px;
		font-size: 11px
	}
	.featured-style-31 .penci-image-holder,
	.featured-style-32 .penci-image-holder {
		height: 400px !important
	}
	.pencislider-container .pencislider-content .pencislider-title {
		font-size: 20px
	}
	.pencislider-container .pencislider-content .pencislider-caption {
		font-size: 14px
	}
	.pencislider-container .pencislider-content .pencislider-button {
		padding: 8px 15px 8px;
		font-size: 12px
	}
	.container .penci-grid li.typography-style .grid-post-box-meta {
		display: none
	}
	.grid-mixed .mixed-detail {
		padding: 30px 15px
	}
	.grid-mixed .mixed-detail h2 a {
		font-size: 16px
	}
	.typography-style .content-typography {
		left: 10px;
		right: 10px;
		top: 10px;
		bottom: 10px
	}
	.penci-grid li.list-boxed-post-2 .inner-parent-boxed-2,
	.penci_sidebar .penci-grid li.list-boxed-post-2 .inner-parent-boxed-2 {
		min-height: 200px;
		height: auto;
		padding: 30px 15px
	}
	.error-404 .sub-heading-text-404 {
		font-size: 13px
	}
	.penci-post-box-meta,
	.penci-post-box-meta.post-box-boxed-1 {
		text-align: center
	}
	.penci-post-box-meta .penci-post-share-box {
		display: block;
		float: none;
		margin-top: 15px
	}
	.penci-post-box-meta .penci-box-meta i {
		display: none
	}
	.penci-more-link a.more-link {
		font-size: 12px;
		padding: 5px 0
	}
	.widget .tagcloud a {
		font-size: 10px !important;
		padding: 4px 10px 3px;
		margin-right: 4px;
		margin-bottom: 8px
	}
	.header-standard .post-title,
	.header-standard h2,
	.header-standard h2 a,
	.pc_titlebig_standard,
	.pc_titlebig_standard a,
	.penci-header-signup-form h4.header-signup-form,
	.penci-page-header h1 {
		font-size: 18px
	}
	.cat>a.penci-cat-name,
	.penci-grid li .item .cat a,
	.penci-masonry .item-masonry .cat a {
		font-size: 11px
	}
	.home-featured-cat-content .mag-photo .magcat-detail {
		padding: 15px;
		width: 100%
	}
	.home-featured-cat-content .mag-photo .magcat-detail h3 a {
		font-size: 16px;
		letter-spacing: 0
	}
	.home-featured-cat-content .magcat-detail .mag-meta {
		margin-top: 5px
	}
	.home-featured-cat-content .mag-photo .grid-post-box-meta span,
	.home-featured-cat-content .mag-photo .grid-post-box-meta span a {
		font-size: 12px
	}
	.home-featured-cat-content .magcat-detail h3 a {
		font-size: 15px;
		line-height: 1.3
	}
	.home-featured-cat-content .magcat-detail .mag-meta span {
		font-size: 13px
	}
	.post-box-meta-single span {
		margin-top: 3px
	}
	.penci-pagination .disable-url,
	.penci-pagination a {
		font-size: 11px
	}
	.penci-pagination a i {
		font-size: 12px
	}
	ul.slick-dots li button {
		margin: 0 3px
	}
	.home-pupular-posts-title {
		font-size: 16px
	}
	#footer-copyright * {
		font-size: 12px
	}
	.penci_facebook_widget .fb_iframe_widget {
		display: block;
		margin-left: auto;
		margin-right: auto
	}
	.penci-rlt-popup {
		width: 240px
	}
	.penci-rlt-popup .rtlpopup-heading {
		padding-left: 12px;
		font-size: 14px
	}
	.penci-rlt-popup .rltpopup-item {
		padding-bottom: 12px;
		margin-bottom: 12px
	}
	.penci-rlt-popup .penci-rtlpopup-content {
		padding: 12px
	}
	.penci-rlt-popup .rltpopup-thumbnail {
		margin-right: 12px;
		width: 80px
	}
	.penci-rlt-popup .penci-close-rltpopup {
		right: 2px
	}
	.penci-rlt-popup .rltpopup-meta .rltpopup-title {
		font-size: 13px
	}
	.penci-rlt-popup .rltpopup-meta .date {
		font-size: 12px
	}
	a img.alignleft,
	a img.alignnone,
	a img.alignright {
		margin: 0 auto 30px auto;
		float: none;
		display: block
	}
	.video-align-left,
	.video-align-right {
		margin-left: 0;
		margin-right: 0;
		float: none
	}
	.elementor-widget-text-editor ol,
	.elementor-widget-text-editor ul,
	.post-entry ol,
	.post-entry ul,
	.woocommerce .page-description ol,
	.woocommerce .page-description ul {
		padding-left: 25px
	}
	.archive-box h1,
	.archive-box span,
	.author-content h5,
	.author-content h5 a,
	.item-related h3 a,
	.post-box-title,
	.thecomment .comment-text span.author,
	.thecomment .comment-text span.author a {
		font-size: 16px
	}
	.post-header h1 {
		font-size: 16px
	}
	.page .post-header h1 {
		font-size: 20px
	}
	.post-tags {
		display: block
	}
	.post-share {
		display: block;
		float: none;
		margin-top: 8px
	}
	.post-share .share-title {
		display: inline-block
	}
	.post-pagination .next-post,
	.post-pagination .prev-post {
		width: 100%;
		float: none;
		text-align: center
	}
	.post-pagination h5,
	.post-pagination h5.next-title {
		padding: 0 !important
	}
	.post-pagination .prev-post {
		margin-bottom: 15px
	}
	.post-pagination.pcpagp-style-1 .penci-post-nav-thumb,
	.post-pagination.pcpagp-style-2 .penci-post-nav-thumb {
		display: none !important
	}
	.penci-related-grid-display .item-related {
		width: 100%;
		float: none
	}
	.comments ul.children {
		margin: 0 0 0 35px
	}
	#sidebar-nav {
		width: var(--pcsnav-w);
		transform: translateX(calc( var(--pcsnav-w) * -1 ));
		-webkit-transform: translateX(calc( var(--pcsnav-w) * -1 ));
		-moz-transform: translateX(calc( var(--pcsnav-w) * -1 ))
	}
	.open-sidebar-nav #close-sidebar-nav {
		left: var(--pcsnav-w)
	}
	.open-sidebar-nav #sidebar-nav {
		left: var(--pcsnav-w)
	}
	.penci-pagination ul.page-numbers li {
		margin-right: 5px
	}
	.penci-pagination ul.page-numbers li a,
	.penci-pagination ul.page-numbers li span {
		width: 25px
	}
	ul.footer-socials li {
		margin-right: 10px
	}
	ul.footer-socials li a {
		line-height: 32px
	}
	ul.footer-socials li a i {
		width: 32px;
		height: 32px;
		line-height: 32px;
		font-size: 14px
	}
	#footer-logo a {
		max-width: 280px
	}
	#footer-logo img {
		max-width: 100%
	}
	.footer-instagram h4.footer-instagram-title span {
		padding: 0 20px;
		font-size: 14px
	}
	.comments .children,
	.comments>.comment>.comment {
		margin: 0 0 0 20px
	}
	.overlay-post-box-meta>div {
		margin-top: 15px
	}
	.overlay-post-box-meta>div:first-child {
		margin-top: 0;
		display: block
	}
	.overlay-post-box-meta>div:after {
		content: none;
		display: none
	}
	.penci-single-mag-slider .magcat-detail {
		padding: 10px 15px
	}
	.penci-single-mag-slider .magcat-detail .magcat-titlte {
		font-size: 15px
	}
	.footer-menu li {
		padding: 0 5px
	}
	.penci-post-gallery-container.masonry .item-gallery-masonry {
		width: 100% !important;
		opacity: 1
	}
	.penci-post-gallery-container.masonry .item-gallery-masonry.animated {
		animation-name: none;
		-webkit-animation-name: none;
		-moz-animation-name: none;
		-o-animation-name: none
	}
	.footer-subscribe {
		padding: 40px 0
	}
	.footer-subscribe h4.footer-subscribe-title {
		font-size: 24px
	}
	.footer-subscribe .mc4wp-form {
		width: 100%;
		padding: 0 20px
	}
	.footer-subscribe .mc4wp-form .memail,
	.footer-subscribe .mc4wp-form .msubmit {
		width: 100%;
		float: none;
		margin-left: 0
	}
	.footer-subscribe .widget .mc4wp-form input[type=submit] {
		max-width: 100%
	}
	.penci-menu-hbg.mstyle-fullwidth {
		width: 100% !important;
	}
	.open-mobile-builder-sidebar-nav .penci-builder-mobile-sidebar-nav.mstyle-fullwidth {
		left: 100%;
	}
	.penci-builder-mobile-sidebar-nav.mstyle-fullwidth {
		transform: translateX(-100%);
		-webkit-transform: translateX(-100%);
		-moz-transform: translateX(-100%);
		transition: unset;
	}
	.open-mobile-builder-sidebar-nav .close-mobile-menu-builder.mstyle-fullwidth {
		height: auto;
		top: 10px;
		left: 10px;
		right: auto;
		z-index: 99999999;
		padding: 0;
		background: transparent;
	}
	.close-mobile-menu-builder.mstyle-fullwidth i {
		background-color: transparent;
		font-size: 18px;
	}
	.close-mobile-menu-builder.mstyle-fullwidth {
		background-color: transparent;
		transition: none;
	}
	.open-mobile-builder-sidebar-nav #wpadminbar {
		z-index: 9;
	}
	#sidebar-nav.mstyle-fullwidth {
		width: 100% !important;
	}
	.open-sidebar-nav #sidebar-nav.mstyle-fullwidth {
		left: 100%;
	}
	#sidebar-nav.mstyle-fullwidth {
		transform: translateX(-100%);
		-webkit-transform: translateX(-100%);
		-moz-transform: translateX(-100%);
		transition: unset;
	}
	.open-sidebar-nav #close-sidebar-nav.mstyle-fullwidth {
		height: auto;
		top: 10px;
		left: 10px;
		right: auto;
		z-index: 99999999;
		padding: 0;
		background: transparent;
	}
	#close-sidebar-nav.mstyle-fullwidth i {
		background-color: transparent;
		font-size: 18px;
	}
	#close-sidebar-nav.mstyle-fullwidth {
		background-color: transparent;
		transition: none;
	}
	.open-sidebar-nav #wpadminbar {
		z-index: 9;
	}
	.penci-single-style-12 {
		margin-bottom: 0;
	}
}
@media screen and (max-width:782px) and (min-width:601px) {
	.admin-bar .is-sticky #navigation {
		top: 46px !important
	}
}
@media screen and (max-width:600px) {
	.is-sticky #navigation {
		top: 0 !important;
		z-index: 999999
	}
	#close-sidebar-nav,
	#sidebar-nav,
	.penci-menu-hbg,
	.penci-menu-hbg-overlay {
		z-index: 9999999
	}
	#close-sidebar-nav i {
		display: inline-block
	}
}
.penci-wrap-gprd-law {
	display: block;
	color: #212121;
	font-size: 14px
}
.penci-gprd-law {
	padding: 7px 15px;
	color: inherit;
	font-size: inherit;
	display: block;
	text-align: center;
	transition: all .3s;
	-webkit-transition: all .3s;
	background: #f5f5f5
}
.penci-gprd-law p {
	font-size: inherit;
	color: inherit;
	margin: 0;
	display: inline-block
}
.penci-gprd-law .penci-gprd-accept,
.penci-gprd-law .penci-gprd-more {
	display: inline-block;
	padding: 0;
	line-height: 1;
	font-size: inherit;
	color: inherit;
	margin-left: 10px;
	transition: opacity .3s;
	-webkit-transition: opacity .3s
}
.penci-gprd-law .penci-gprd-accept {
	background: #212121;
	color: #fff;
	padding: 6px 15px
}
.penci-gprd-law .penci-gprd-accept:hover,
.penci-gprd-law .penci-gprd-more:hover {
	opacity: .8
}
.penci-gprd-law,
.penci-wrap-gprd-law .penci-gdrd-show {
	position: fixed;
	z-index: 19999;
	left: 0;
	bottom: 0;
	right: 0;
	width: 100%
}
.penci-wrap-gprd-law .penci-gdrd-show {
	display: inline-block;
	width: auto;
	right: 100px;
	left: auto;
	padding: 6px 15px;
	font-size: inherit;
	color: inherit;
	background: #f5f5f5;
	line-height: 1;
	transition: all .3s;
	-webkit-transition: all .3s;
	transition-delay: .2s;
	-webkit-transition-delay: .2s
}
.penci-wrap-gprd-law-close {
	z-index: 0
}
.penci-close-all .penci-gdrd-show,
.penci-close-all .penci-gprd-law {
	visibility: hidden
}
.penci-wrap-gprd-law .penci-gdrd-show,
.penci-wrap-gprd-law-close .penci-gprd-law {
	transform: translateY(100%);
	-webkit-transform: translateY(100%)
}
.penci-wrap-gprd-law-close .penci-gdrd-show {
	transform: translateY(0);
	-webkit-transform: translateY(0)
}
@media screen and (max-width:767px) {
	.penci-wrap-gprd-law .penci-gdrd-show {
		display: none !important
	}
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc {
	padding: 20px
}
#flexi_searchbox #b_searchboxInc .b_submitButton_wrapper .b_submitButton {
	display: inline-block
}
.bos_searchbox_widget_class #flexi_searchbox h1,
.bos_searchbox_widget_class #flexi_searchbox h2,
.bos_searchbox_widget_class #flexi_searchbox h3,
.bos_searchbox_widget_class #flexi_searchbox h4 {
	font-family: var(--pchead-font);
	font-style: normal;
	font-weight: var(--pchead-wei)
}
.bos_searchbox_widget_class #flexi_searchbox h3,
.bos_searchbox_widget_class #flexi_searchbox h4 {
	margin-bottom: 10px
}
.bos_searchbox_widget_class #flexi_searchbox h3 {
	font-size: 24px
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc input[type=text],
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc select {
	border-radius: 0;
	border: none
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc input[type=text] {
	height: 34px;
	line-height: 34px;
	padding: 0 10px !important;
	width: 100% !important
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc select {
	padding: 5px 10px !important;
	height: 28px;
	line-height: 28px;
	margin-right: 10px
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc .b_submitButton_wrapper .b_submitButton,
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc .b_submitButton_wrapper .b_submitButton:hover {
	border-radius: 0;
	border: none;
	box-shadow: none;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 14px;
	padding: 0 20px;
	line-height: 40px
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc .b_submitButton_wrapper .b_submitButton:hover {
	border: 0;
	border-radius: 0;
	opacity: .8
}
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc #b_searchCheckInDate,
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc #b_searchCheckOutDate,
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc #b_searchDest,
.bos_searchbox_widget_class #flexi_searchbox #b_searchboxInc .b_submitButton_wrapper {
	margin-bottom: 20px
}
.penci-vc-row {
	margin-left: -10px;
	margin-right: -10px;
	display: flex;
	flex-wrap: wrap
}
.penci-vc-column {
	float: left;
	padding-left: 10px;
	padding-right: 10px
}
.penci-vc-row:after {
	content: " ";
	display: table;
	width: 100%
}
.penci-col-1,
.penci-col-10,
.penci-col-11,
.penci-col-12,
.penci-col-2,
.penci-col-3,
.penci-col-4,
.penci-col-5,
.penci-col-6,
.penci-col-7,
.penci-col-8,
.penci-col-9 {
	position: relative;
	min-height: 1px;
	padding-left: 10px;
	padding-right: 10px
}
@media (min-width:480px) {
	.penci-col-1,
	.penci-col-10,
	.penci-col-11,
	.penci-col-12,
	.penci-col-2,
	.penci-col-3,
	.penci-col-4,
	.penci-col-5,
	.penci-col-6,
	.penci-col-7,
	.penci-col-8,
	.penci-col-9 {
		width: 100%
	}
}
@media (min-width:768px) {
	.penci-col-10,
	.penci-col-11,
	.penci-col-12,
	.penci-col-7,
	.penci-col-8,
	.penci-col-9 {
		width: 100%
	}
}
@media (min-width:992px) {
	.penci-col-1,
	.penci-col-10,
	.penci-col-11,
	.penci-col-12,
	.penci-col-2,
	.penci-col-3,
	.penci-col-4,
	.penci-col-5,
	.penci-col-6,
	.penci-col-7,
	.penci-col-8,
	.penci-col-9 {
		float: left;
		margin-bottom: 0
	}
	.penci-col-12 {
		width: 100%
	}
	.penci-col-11 {
		width: 91.66666667%
	}
	.penci-col-10 {
		width: 83.33333333%
	}
	.penci-col-9 {
		width: 75%
	}
	.penci-col-8 {
		width: 66.66666667%
	}
	.penci-col-7 {
		width: 58.33333333%
	}
	.penci-col-6 {
		width: 50%
	}
	.penci-col-5 {
		width: 41.66666667%
	}
	.penci-col-4 {
		width: 33.33333333%
	}
	.penci-col-3 {
		width: 25%
	}
	.penci-col-2 {
		width: 16.66666667%
	}
	.penci-col-1 {
		width: 8.33333333%
	}
}
.pencisc-grid .pencisc-grid-item {
	word-break: break-word;
	min-width: 0
}
.penci-lposts-ctcol.pencisc-grid-1 .penci-grid,
.penci-lposts-ctcol.pencisc-grid-2 .penci-grid,
.penci-lposts-ctcol.pencisc-grid-3 .penci-grid,
.penci-lposts-ctcol.pencisc-grid-4 .penci-grid,
.penci-lposts-ctcol.pencisc-grid-5 .penci-grid,
.penci-lposts-ctcol.pencisc-grid-6 .penci-grid {
	display: flex;
	overflow: hidden;
	flex-wrap: wrap;
	grid-column-gap: 30px;
	grid-row-gap: 30px
}
.penci-featured-cat-ctcol.pencisc-grid-1 .home-featured-cat-content,
.penci-featured-cat-ctcol.pencisc-grid-2 .home-featured-cat-content,
.penci-featured-cat-ctcol.pencisc-grid-3 .home-featured-cat-content,
.penci-featured-cat-ctcol.pencisc-grid-4 .home-featured-cat-content,
.penci-featured-cat-ctcol.pencisc-grid-5 .home-featured-cat-content,
.penci-featured-cat-ctcol.pencisc-grid-6 .home-featured-cat-content {
	display: flex;
	overflow: hidden;
	flex-wrap: wrap;
	grid-column-gap: 10px;
	grid-row-gap: 10px
}
.pencisc-grid-1 .pencisc-grid,
.pencisc-grid-2 .pencisc-grid,
.pencisc-grid-3 .pencisc-grid,
.pencisc-grid-4 .pencisc-grid,
.pencisc-grid-5 .pencisc-grid,
.pencisc-grid-6 .pencisc-grid {
	display: flex;
	overflow: hidden;
	flex-wrap: wrap;
	grid-column-gap: 30px;
	grid-row-gap: 30px
}
.penci-gallery-bsc .pencisc-grid {
	grid-column-gap: 0;
	grid-row-gap: 0
}
.penci-featured-cat-ctcol.pencisc-grid-1 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-1 .penci-grid,
.pencisc-grid-1 .pencisc-grid {
	grid-template-columns: repeat(1, 1fr);
	display: grid
}
.penci-featured-cat-ctcol.pencisc-grid-2 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-2 .penci-grid,
.pencisc-grid-2 .pencisc-grid {
	grid-template-columns: repeat(2, 1fr);
	display: grid
}
.penci-featured-cat-ctcol.pencisc-grid-3 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-3 .penci-grid,
.pencisc-grid-3 .pencisc-grid {
	grid-template-columns: repeat(3, 1fr);
	display: grid
}
.penci-featured-cat-ctcol.pencisc-grid-4 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-4 .penci-grid,
.pencisc-grid-4 .pencisc-grid {
	grid-template-columns: repeat(4, 1fr);
	display: grid
}
.penci-featured-cat-ctcol.pencisc-grid-5 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-5 .penci-grid,
.pencisc-grid-5 .pencisc-grid {
	grid-template-columns: repeat(5, 1fr);
	display: grid
}
.penci-featured-cat-ctcol.pencisc-grid-6 .home-featured-cat-content,
.penci-lposts-ctcol.pencisc-grid-6 .penci-grid,
.pencisc-grid-6 .pencisc-grid {
	grid-template-columns: repeat(6, 1fr);
	display: grid
}
@media (max-width:1024px) {
	.pencisc-grid-tablet-0 .pencisc-grid {
		display: -webkit-box;
		display: -webkit-flex;
		display: -ms-flexbox;
		display: flex;
		overflow: hidden;
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-1 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-1 .penci-grid,
	.pencisc-grid-tablet-1 .pencisc-grid {
		grid-template-columns: repeat(1, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-2 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-2 .penci-grid,
	.pencisc-grid-tablet-2 .pencisc-grid {
		grid-template-columns: repeat(2, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-3 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-3 .penci-grid,
	.pencisc-grid-tablet-3 .pencisc-grid {
		grid-template-columns: repeat(3, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-4 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-4 .penci-grid,
	.pencisc-grid-tablet-4 .pencisc-grid {
		grid-template-columns: repeat(4, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-5 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-5 .penci-grid,
	.pencisc-grid-tablet-5 .pencisc-grid {
		grid-template-columns: repeat(5, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-tablet-6 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-tablet-6 .penci-grid,
	.pencisc-grid-tablet-6 .pencisc-grid {
		grid-template-columns: repeat(6, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-7 .pencisc-grid {
		grid-template-columns: repeat(7, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-8 .pencisc-grid {
		grid-template-columns: repeat(8, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-9 .pencisc-grid {
		grid-template-columns: repeat(9, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-10 .pencisc-grid {
		grid-template-columns: repeat(10, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-11 .pencisc-grid {
		grid-template-columns: repeat(11, 1fr);
		display: grid
	}
	.pencisc-grid-tablet-12 .pencisc-grid {
		grid-template-columns: repeat(12, 1fr);
		display: grid
	}
}
@media (max-width:767px) {
	.pencisc-grid-mobile-0 .pencisc-grid {
		display: -webkit-box;
		display: -webkit-flex;
		display: -ms-flexbox;
		display: flex;
		overflow: hidden;
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-1 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-1 .penci-grid,
	.pencisc-grid-mobile-1 .pencisc-grid {
		grid-template-columns: repeat(1, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-2 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-2 .penci-grid,
	.pencisc-grid-mobile-2 .pencisc-grid {
		grid-template-columns: repeat(2, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-3 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-3 .penci-grid,
	.pencisc-grid-mobile-3 .pencisc-grid {
		grid-template-columns: repeat(3, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-4 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-4 .penci-grid,
	.pencisc-grid-mobile-4 .pencisc-grid {
		grid-template-columns: repeat(4, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-5 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-5 .penci-grid,
	.pencisc-grid-mobile-5 .pencisc-grid {
		grid-template-columns: repeat(5, 1fr);
		display: grid
	}
	.penci-featured-cat-ctcol.pencisc-grid-mobile-6 .home-featured-cat-content,
	.penci-lposts-ctcol.pencisc-grid-mobile-6 .penci-grid,
	.pencisc-grid-mobile-6 .pencisc-grid {
		grid-template-columns: repeat(6, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-7 .pencisc-grid {
		grid-template-columns: repeat(7, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-8 .pencisc-grid {
		grid-template-columns: repeat(8, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-9 .pencisc-grid {
		grid-template-columns: repeat(9, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-10 .pencisc-grid {
		grid-template-columns: repeat(10, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-11 .pencisc-grid {
		grid-template-columns: repeat(11, 1fr);
		display: grid
	}
	.pencisc-grid-mobile-12 .pencisc-grid {
		grid-template-columns: repeat(12, 1fr);
		display: grid
	}
}
.container.two-sidebar {
	width: var(--pcctain2);
	display: flex;
	flex-wrap: wrap
}
.container.penci-breadcrumb.two-sidebar {
	display: block
}
.penci-two-sidebar .container.penci-breadcrumb {
	width: var(--pcctain2);
	display: block
}
.penci-vc-row.penci-vc-dis-padding {
	margin-left: 0;
	margin-right: 0
}
.container.two-sidebar #main,
.layout-14_12_14 .penci-main-content {
	width: 57%;
	order: 2;
	padding-left: 50px;
	padding-right: 50px
}
.container.two-sidebar .penci-sidebar-content,
.layout-14_12_14 .penci-vc-sidebar {
	width: 21.5%
}
.container.two-sidebar .penci-sidebar-left,
.layout-14_12_14 .penci-sidebar-left {
	order: 1
}
.container.two-sidebar .penci-sidebar-right,
.layout-14_12_14 .penci-sidebar-right {
	order: 3
}
.layout-12_14_14 .penci-main-content {
	order: 1;
	width: 53.5%;
	padding-right: 50px
}
.layout-12_14_14 .penci-sidebar-left {
	order: 2;
	width: 25%;
	padding-right: 50px
}
.layout-12_14_14 .penci-sidebar-right {
	order: 3;
	width: 21.5%
}
.layout-14_14_12 .penci-main-content {
	order: 3;
	width: 53.5%;
	padding-left: 50px
}
.layout-14_14_12 .penci-sidebar-left {
	order: 1;
	width: 21.5%
}
.layout-14_14_12 .penci-sidebar-right {
	order: 2;
	width: 25%;
	padding-left: 50px
}
.layout-13_23 .penci-main-content,
.layout-23_13 .penci-main-content {
	width: 70.94%;
	float: left
}
.layout-23_13 .penci-main-content {
	padding-right: 50px
}
.layout-13_23 .penci-main-content {
	padding-left: 50px
}
.layout-13_23 .penci-vc-sidebar,
.layout-23_13 .penci-vc-sidebar {
	width: 29.06%;
	float: right
}
.penci-vc-container {
	margin-left: auto;
	margin-right: auto
}
.vc-penci-w1080,
.vc-penci-w1170,
.vc-penci-w1400 {
	width: 100%
}
.vc-penci-w1080 {
	max-width: 1080px
}
.vc-penci-w1170 {
	max-width: var(--pcctain)
}
.vc-penci-w1400 {
	max-width: var(--pcctain2)
}
.penci-missing-settings {
	font-size: 13px;
	font-weight: 400;
	text-align: left;
	padding: 10px 10px 5px;
	outline: 2px dashed #d4d4d4;
	color: #131313;
	font-family: Verdana, Geneva, sans-serif;
	cursor: pointer;
	margin-top: 10px;
	margin-bottom: 10px
}
.penci-missing-settings span {
	font-size: 11px;
	position: relative;
	margin-right: 10px;
	margin-bottom: 5px;
	background-color: red;
	color: #fff;
	font-weight: 700;
	padding: 5px 10px;
	display: inline-block;
	vertical-align: top
}
.block-title-icon-left .inner-arrow i,
.block-title-icon-left .inner-arrow svg {
	margin-right: 8px;
	transition: 0.3s all ease-in-out;
}
.block-title-icon-right .inner-arrow i,
.block-title-icon-right .inner-arrow svg {
	margin-left: 8px;
	transition: 0.3s all ease-in-out;
}
.inner-arrow svg path {
	transition: 0.3s all ease-in-out;
}
.block-title-icon-left .inner-arrow svg,
.block-title-icon-right .inner-arrow svg {
	width: 16px;
	height: auto;
}
.penci-fancy-heading.penci-block-vc {
	background-color: transparent
}
.penci-fancy-heading.penci-heading-text-center {
	text-align: center
}
.penci-fancy-heading.penci-heading-text-center .penci-heading-content,
.penci-fancy-heading.penci-heading-text-center .penci-heading-subtitle {
	margin-left: auto;
	margin-right: auto
}
.penci-fancy-heading .penci-heading-content p {
	line-height: inherit;
	font-size: inherit;
	color: inherit;
	margin-bottom: 17px
}
.penci-fancy-heading .penci-heading-content p:last-child {
	margin-bottom: 0
}
.penci-fancy-heading.penci-heading-text-right {
	text-align: right;
	overflow: hidden
}
.penci-fancy-heading.penci-heading-text-right .penci-heading-content,
.penci-fancy-heading.penci-heading-text-right .penci-heading-subtitle,
.penci-fancy-heading.penci-heading-text-right .penci-heading-title {
	text-align: right;
	clear: both
}
.penci-fancy-heading.penci-heading-text-right .penci-heading-content {
	margin-right: 0;
	margin-left: auto
}
.penci-fancy-heading.penci-heading-text-right li {
	text-align: right;
	list-style-position: inside
}
.penci-fancy-heading.penci-heading-text-left {
	text-align: left
}
.penci-fancy-heading.penci-heading-text-left .penci-heading-content,
.penci-fancy-heading.penci-heading-text-left .penci-heading-subtitle,
.penci-fancy-heading.penci-heading-text-left .penci-heading-title {
	text-align: left;
	clear: both
}
.penci-fancy-heading.penci-heading-text-left .penci-heading-content {
	margin-right: auto;
	margin-left: 0
}
.penci-fancy-heading .penci-heading-title {
	font-size: 36px;
	color: #111;
	margin-top: 0;
	margin-bottom: 5px;
	line-height: 1.3;
	overflow: hidden
}
.penci-fancy-heading .inner-tit {
	font-size: inherit;
	font-weight: inherit;
	color: inherit;
	display: inline-block;
	vertical-align: top;
	font-family: inherit
}
.penci-fancy-heading.pc-fctline .inner-tit {
	position: relative;
	padding: 0 20px
}
.penci-fancy-heading.pc-fctline .inner-tit:after,
.penci-fancy-heading.pc-fctline .inner-tit:before {
	content: "";
	height: 1px;
	top: 50%;
	right: 100%;
	width: 1000px;
	display: block;
	background: var(--pcborder-cl);
	position: absolute;
	margin-top: 1px
}
.penci-fancy-heading.pc-fctline .inner-tit:after {
	right: auto;
	left: 100%
}
.penci-fancy-heading .penci-heading-subtitle {
	margin-bottom: 10px
}
.penci-fancy-heading .penci-heading-title+.penci-heading-subtitle {
	margin-top: 10px
}
.penci-fancy-heading .penci-heading-content,
.penci-fancy-heading .penci-heading-subtitle {
	font-size: 16px
}
.penci-fancy-heading .penci-heading-content {
	margin-top: 10px;
	clear: both
}
.penci-fancy-heading .penci-separator {
	margin-bottom: 15px
}
.penci-separator {
	display: flex;
	flex-direction: row;
	flex-wrap: nowrap;
	align-items: center;
	max-width: 60px;
	width: 100%;
	clear: both
}
.penci-separator-left .penci-heading-icon {
	margin-left: 0 !important
}
.penci-heading-text-left .inner-tit {
	padding-left: 0 !important
}
.penci-separator-center {
	margin-left: auto;
	margin-right: auto
}
.penci-separator-right {
	float: right
}
.penci-separator-right .penci-heading-icon {
	margin-right: 0 !important
}
.penci-heading-text-right .inner-tit {
	padding-right: 0 !important
}
.penci-separator-left .penci-sep_holder_l,
.penci-separator-right .penci-sep_holder_r {
	display: none
}
.penci-separator .penci-sep_holder {
	height: 1px;
	position: relative;
	-webkit-box-flex: 1;
	-webkit-flex: 1 1 auto;
	-ms-flex: 1 1 auto;
	flex: 1 1 auto;
	min-width: 10%
}
.penci-separator .penci-sep_line {
	height: 1px;
	border-top: 1px solid #dedede;
	border-color: #dedede;
	display: block;
	position: relative;
	top: 1px;
	width: 100%;
	border-bottom: none;
	border-left: none;
	border-right: none
}
.penci-separator-dotted .penci-sep_line {
	border-style: dotted
}
.penci-separator-dashed .penci-sep_line {
	border-style: dashed
}
.penci-separator-double .penci-sep_line {
	border-top-style: double;
	border-top-width: 4px;
	top: -2px
}
.penci-separator .penci-heading-icon {
	margin: 10px 15px;
	font-size: 20px;
	color: var(--pcaccent-cl)
}
.penci-animation-shrink {
	transition-duration: .3s;
	transition-property: transform
}
.penci-animation-shrink:active .penci-ibox-icon,
.penci-animation-shrink:hover .penci-ibox-icon {
	transform: scale(.9)
}
.penci-animation-grow {
	transition-duration: .3s;
	transition-property: transform
}
.penci-animation-grow:active .penci-ibox-icon,
.penci-animation-grow:hover .penci-ibox-icon {
	transform: scale(1.1)
}
@keyframes penci-animation-pulse {
	25% {
		transform: scale(1.1)
	}
	75% {
		transform: scale(.9)
	}
}
.penci-animation-pulse:active .penci-ibox-icon,
.penci-animation-pulse:hover .penci-ibox-icon {
	animation-name: penci-animation-pulse;
	animation-duration: 1s;
	animation-timing-function: linear;
	animation-iteration-count: infinite
}
@keyframes penci-animation-pulse-grow {
	to {
		transform: scale(1.1)
	}
}
.penci-animation-pulse-grow:active .penci-ibox-icon,
.penci-animation-pulse-grow:hover .penci-ibox-icon {
	animation-name: penci-animation-pulse-grow;
	animation-duration: .3s;
	animation-timing-function: linear;
	animation-iteration-count: infinite;
	animation-direction: alternate
}
@keyframes penci-animation-pulse-shrink {
	to {
		transform: scale(.9)
	}
}
.penci-animation-pulse-shrink:active .penci-ibox-icon,
.penci-animation-pulse-shrink:hover .penci-ibox-icon {
	animation-name: penci-animation-pulse-shrink;
	animation-duration: .3s;
	animation-timing-function: linear;
	animation-iteration-count: infinite;
	animation-direction: alternate
}
@keyframes penci-animation-push {
	50% {
		transform: scale(.8)
	}
	100% {
		transform: scale(1)
	}
}
.penci-animation-push:active .penci-ibox-icon,
.penci-animation-push:hover .penci-ibox-icon {
	animation-name: penci-animation-push;
	animation-duration: .3s;
	animation-timing-function: linear;
	animation-iteration-count: 1
}
@keyframes penci-animation-pop {
	50% {
		transform: scale(1.2)
	}
}
.penci-animation-pop:active .penci-ibox-icon,
.penci-animation-pop:hover .penci-ibox-icon {
	animation-name: penci-animation-pop;
	animation-duration: .3s;
	animation-timing-function: linear;
	animation-iteration-count: 1
}
.penci-icon {
	display: inline-block;
	line-height: 1;
	-webkit-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s;
	color: #818a91;
	font-size: 50px;
	text-align: center
}
.penci-icon i {
	width: 1em;
	height: 1em;
	position: relative;
	z-index: 20;
	display: block
}
.penci-info-box .penci-icon i:before,
.penci-info-box .penci-icon svg:before {
	position: absolute;
	left: 50%;
	top: 0;
	-webkit-transform: translateX(-50%);
	-ms-transform: translateX(-50%);
	transform: translateX(-50%)
}
.penci-icon:hover {
	color: #818a91
}
.penci-view-stacked .penci-icon {
	padding: .5em;
	background-color: #818a91;
	color: #fff;
	fill: #fff
}
.penci-view-stacked .penci-icon a {
	color: inherit
}
.penci-view-framed .penci-icon {
	padding: .5em;
	color: #818a91;
	border: 3px solid #818a91;
	background-color: transparent !important
}
.penci-shape-circle .penci-icon {
	-webkit-border-radius: 50%;
	border-radius: 50%
}
.penci-info-box {
	position: relative;
	margin-top: 0;
	padding-left: 0;
	padding-right: 0;
	transition: background-color .3s, background-image .3s, box-shadow .3s
}
.penci-info-box:after,
.penci-info-box:before {
	content: "";
	display: table;
	clear: both
}
.penci-info-box .penci-ibox-img_active {
	transition: all .7s
}
.penci-info-box .penci-ibox-img_hover {
	opacity: 0;
	visibility: hidden;
	position: absolute;
	top: auto;
	left: 0;
	transition: all .7s
}
.penci-info-box .penci-ibox-icon--image {
	width: 90px;
	height: auto !important;
	overflow: hidden;
	position: relative
}
.penci-info-box .penci-ibox-icon--image img {
	width: 100%;
	height: auto
}
.penci-info-box.penci-shape-circle .penci-ibox-icon--image {
	border-radius: 50%;
	-webkit-border-radius: 50%
}
.penci-info-box .penci-ibox-line {
	margin-top: 10px;
	margin-bottom: 0;
	width: 40px;
	height: 2px;
	background: var(--pcaccent-cl);
	display: inline-block;
	vertical-align: top
}
.penci-info-box .penci-ibox-icon svg {
	vertical-align: top;
	transition: fill .15s
}
.penci-info-box .penci-ibox-icon-fa {
	z-index: 2;
	position: relative
}
.penci-info-box a.penci-ibox-icon-fa-fix {
	z-index: 25;
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	display: flex;
	align-items: center;
	justify-content: center
}
.penci-iboxwrap-overlay {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: 30;
	display: block
}
.penci-info-box .penci-ibox-inner:hover .penci-ibox-icon--image.has-hover .penci-ibox-img_active {
	opacity: 0;
	visibility: hidden
}
.penci-info-box .penci-ibox-inner:hover .penci-ibox-icon--image.has-hover .penci-ibox-img_hover {
	opacity: 1;
	visibility: visible
}
.penci-info-box .penci-ibox-inner .penci-ibox-icon--image .penci-ibox-icon-fa {
	display: block;
	width: 100%;
	height: auto;
}

.penci-info-box .penci-ibox-title {
	font-size: 20px;
	font-weight: 700;
	margin-bottom: 0;
	color: #111
}
.penci-info-box .penci-ibox-content {
	margin: 8px 0 0 0;
	color: #999;
	line-height: 1.7
}
.penci-info-box .penci-ibox-content a,
.penci-info-box .penci-ibox-content p {
	font-size: inherit;
	font-family: inherit;
	line-height: 1.7
}
.penci-info-box .pc-ibox-ctext {
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.penci-info-box .penci-ibox-content>p:last-child {
	margin-bottom: 0
}
.penci-info-box .penci-ibox-stit {
	line-height: 1.4;
	margin-bottom: 5px;
	font-size: 13px;
	color: #666
}
.pc-ibox-wpline {
	line-height: 1
}
.penci-ibox-readmore,
.penci-media-rmbtn {
	margin-top: 15px;
	line-height: 1
}
.penci-info-box .penci-ibox-readmore a,
.penci-media-carousels .penci-media-rmbtn a {
	text-decoration: none;
	text-transform: uppercase;
	font-size: 14px;
	font-family: var(--pchead-font);
	font-weight: 500;
	background: #f2f2f2;
	color: #111;
	display: inline-block;
	vertical-align: top;
	transition: all .3s;
	padding: 12px 20px;
	line-height: 1;
	vertical-align: top
}
.penci-info-box .penci-ibox-readmore.pc-ibox-borders a,
.penci-media-carousels .penci-media-rmbtn.pc-rmbtn-borders a {
	border: 2px solid
}
.penci-info-box .penci-ibox-readmore a:hover,
.penci-media-carousels .penci-media-rmbtn a:hover {
	background: #ddd
}
.penci-ibox-top-center .penci-ibox-icon,
.penci-ibox-top-left .penci-ibox-icon,
.penci-ibox-top-right .penci-ibox-icon {
	margin-bottom: 20px;
	display: inline-flex;
	align-items: center;
	justify-content: center
}
.penci-ibox-top-center .penci-ibox-icon {
	margin-left: auto;
	margin-right: auto
}
.penci-ibox-top-center .penci-ibox-icon--image,
.penci-ibox-top-left .penci-ibox-icon--image,
.penci-ibox-top-right .penci-ibox-icon--image {
	height: auto
}
.penci-ibox-top-center .penci-ibox-inner {
	text-align: center
}
.penci-ibox-top-center .penci-ibox-icon--image {
	margin-left: auto;
	margin-right: auto
}
.penci-ibox-top-left .penci-ibox-inner {
	text-align: left
}
.penci-ibox-top-left .penci-ibox-inner .penci-ibox-icon {
	float: left
}
.penci-ibox-top-right .penci-ibox-inner {
	text-align: right
}
.penci-ibox-top-right .penci-ibox-inner .penci-ibox-icon {
	float: right
}
.penci-ibox-top-left .penci-ibox-content-wrap,
.penci-ibox-top-right .penci-ibox-content-wrap {
	clear: both
}
.penci-ibox-float-left .penci-ibox-inner {
	display: flex;
	text-align: left;
	flex-direction: row;
	align-items: flex-start
}
.penci-ibox-float-left .penci-ibox-icon {
	margin-right: 20px;
	margin-bottom: 0 !important
}
.penci-ibox-float-right .penci-ibox-icon {
	margin-left: 20px;
	margin-bottom: 0 !important
}
.penci-ibox-top-right .penci-ibox-icon--image {
	float: right
}
.penci-ibox-top-right .penci-ibox-content {
	clear: both
}
.penci-ibox-float-left .penci-ibox-icon,
.penci-ibox-float-right .penci-ibox-icon {
	display: inline-flex;
	flex: 0 0 auto;
	align-items: center;
	justify-content: center
}
.penci-ibox-float-right .penci-ibox-inner {
	display: flex;
	text-align: right;
	flex-direction: row-reverse;
	align-items: flex-start
}
.penci-info-box .penci-icon {
	position: relative
}
.penci-shape-circle .penci-animation-custom-1 .penci-ibox-icon:after,
.penci-shape-circle .penci-animation-custom-2 .penci-ibox-icon:after,
.penci-shape-circle .penci-animation-custom-3 .penci-ibox-icon:after,
.penci-shape-circle .penci-animation-custom-4 .penci-ibox-icon:after,
.penci-shape-circle .penci-animation-custom-5 .penci-ibox-icon:after {
	-webkit-border-radius: 50%;
	border-radius: 50%;
	z-index: 1
}
.penci-view-stacked .penci-animation-custom-1 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-2 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-3 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-4 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-5 .penci-ibox-icon:after {
	content: "";
	pointer-events: none;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	padding: 0;
	box-shadow: 0 0 0 3px #818a91;
	transition: transform .3s, opacity .3s;
	opacity: 0
}
.penci-view-stacked .penci-animation-custom-2 .penci-ibox-icon:after {
	transform: scale(1.3)
}
.penci-view-stacked .penci-animation-custom-1 .penci-ibox-icon:after {
	transform: scale(.8)
}
.penci-view-stacked .penci-animation-custom-1:hover .penci-ibox-icon,
.penci-view-stacked .penci-animation-custom-2:hover .penci-ibox-icon {
	background-color: #818a91;
	color: #fff;
	fill: #fff
}
.penci-view-stacked .penci-animation-custom-1:hover .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-2:hover .penci-ibox-icon:after {
	-webkit-transform: scale(1.11);
	-moz-transform: scale(1.11);
	-ms-transform: scale(1.11);
	transform: scale(1.11);
	opacity: 1
}
.penci-view-stacked .penci-animation-custom-3 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-4 .penci-ibox-icon:after,
.penci-view-stacked .penci-animation-custom-5 .penci-ibox-icon:after {
	transform: scale(1);
	box-shadow: none;
	background: #818a91;
	opacity: 1;
	z-index: 0
}
.penci-view-stacked .penci-animation-custom-3 .penci-ibox-icon,
.penci-view-stacked .penci-animation-custom-4 .penci-ibox-icon,
.penci-view-stacked .penci-animation-custom-5 .penci-ibox-icon {
	background-color: transparent !important;
	box-shadow: inset 0 0 0 3px #818a91
}
.penci-view-stacked .penci-animation-custom-3:hover .penci-ibox-icon:after {
	-webkit-transform: scale(.85);
	-moz-transform: scale(.85);
	-ms-transform: scale(.85);
	transform: scale(.85)
}
.penci-view-stacked .penci-animation-custom-4:hover .penci-ibox-icon:after {
	-webkit-transform: scale(0);
	-moz-transform: scale(0);
	-ms-transform: scale(0);
	transform: scale(0);
	opacity: 1
}
.penci-view-stacked .penci-animation-custom-4 .penci-ibox-icon:hover,
.penci-view-stacked .penci-animation-custom-5 .penci-ibox-icon:hover {
	color: #818a91;
	fill: #818a91
}
.penci-view-stacked .penci-animation-custom-5 {
	transition: color .3s
}
.penci-view-stacked .penci-animation-custom-5:hover .penci-ibox-icon:after {
	-webkit-transform: scale(1.3);
	-moz-transform: scale(1.3);
	-ms-transform: scale(1.3);
	transform: scale(1.3);
	opacity: 0
}
.penci-view-framed .penci-animation-custom-1 .penci-ibox-icon:after,
.penci-view-framed .penci-animation-custom-2 .penci-ibox-icon:after,
.penci-view-framed .penci-animation-custom-5 .penci-ibox-icon:after {
	content: "";
	pointer-events: none;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	padding: 0;
	transition: transform .2s, opacity .2s;
	opacity: 0
}
.penci-view-framed .penci-animation-custom-1 .penci-ibox-icon:after {
	background: #818a91;
	z-index: -1;
	transform: scale(1.3)
}
.penci-view-framed .penci-animation-custom-1 .penci-ibox-icon:hover {
	color: #fff
}
.penci-view-framed .penci-animation-custom-1:hover .penci-ibox-icon:after {
	transform: scale(1);
	opacity: 1
}
.penci-view-framed .penci-animation-custom-2 .penci-ibox-icon:after {
	z-index: 10;
	border: 3px dashed #818a91;
	top: -3px;
	left: -3px;
	right: -3px;
	bottom: -3px;
	width: auto;
	height: auto;
	opacity: 1
}
.penci-view-framed .penci-animation-custom-2 .penci-ibox-icon:hover {
	border-color: transparent !important
}
.penci-view-framed .penci-animation-custom-3 .penci-ibox-icon {
	box-shadow: 0 0 0 4px rgba(255, 255, 255, 1);
	overflow: hidden;
	transition: background .3s, color .3s, box-shadow .3s
}
.penci-view-framed .penci-animation-custom-3:hover .penci-ibox-icon--i {
	-webkit-animation: penciIconToRightFromLeft .3s forwards;
	-moz-animation: penciIconToRightFromLeft .3s forwards;
	animation: penciIconToRightFromLeft .3s forwards
}
@-webkit-keyframes penciIconToRightFromLeft {
	49% {
		-webkit-transform: translate(100%)
	}
	50% {
		opacity: 0;
		-webkit-transform: translate(-100%)
	}
	51% {
		opacity: 1
	}
}
@keyframes penciIconToRightFromLeft {
	49% {
		transform: translate(100%)
	}
	50% {
		opacity: 0;
		transform: translate(-100%)
	}
	51% {
		opacity: 1
	}
}
@-webkit-keyframes penciIconspinAround {
	from {
		-webkit-transform: rotate(0)
	}
	to {
		-webkit-transform: rotate(360deg)
	}
}
@keyframes penciIconspinAround {
	from {
		transform: rotate(0)
	}
	to {
		transform: rotate(360deg)
	}
}
.penci-view-framed .penci-animation-custom-4:hover .penci-ibox-icon--i {
	-webkit-animation: penciIconspinAround 2s linear infinite;
	-moz-animation: penciIconspinAround 2s linear infinite;
	animation: penciIconspinAround 2s linear infinite
}
.penci-view-framed .penci-animation-custom-5 .penci-ibox-icon:after {
	z-index: 10;
	border: 3px solid #818a91;
	top: -3px;
	left: -3px;
	right: -3px;
	bottom: -3px;
	width: auto;
	height: auto;
	opacity: 1
}
.penci-view-framed .penci-animation-custom-5:hover {
	border-color: transparent !important;
	box-shadow: 0 0 0 6px #818a91
}
.penci-view-framed .penci-animation-custom-5:hover .penci-ibox-icon:after {
	-webkit-transform: scale(.85);
	-moz-transform: scale(.85);
	-ms-transform: scale(.85);
	transform: scale(.85);
	opacity: .5
}
.penci-countdown-bsc {
	overflow: hidden
}
.penci-countdown-bsc:after,
.penci-countdown-bsc:before {
	content: "";
	display: table;
	clear: both
}
.penci-countdown-bsc.penci-style-center {
	text-align: center
}
.penci-countdown-bsc.penci-style-right {
	text-align: right
}
.penci-countdown-bsc.penci-border-solid .penci-countdown-amount {
	border-style: solid
}
.penci-countdown-bsc.penci-border-dashed .penci-countdown-amount {
	border-style: dashed
}
.penci-countdown-bsc.penci-border-dotted .penci-countdown-amount {
	border-style: dotted
}
.penci-countdown-bsc.penci-border-double .penci-countdown-amount {
	border-style: double
}
.penci-countdown-rtl {
	direction: rtl
}
.penci-countdown-holding span {
	color: #888
}
.penci-countdown-row {
	clear: both;
	width: 100%;
	padding: 0;
	display: block;
	margin: -30px auto 0
}
.penci-countdown-show1 .penci-countdown-section {
	width: 100%
}
.penci-countdown-show2 .penci-countdown-section {
	width: 50%
}
.penci-countdown-show3 .penci-countdown-section {
	width: 33.3333%
}
.penci-countdown-show4 .penci-countdown-section {
	width: 25%
}
.penci-countdown-show5 .penci-countdown-section {
	width: 20%
}
.penci-countdown-show6 .penci-countdown-section {
	width: 16.6666667%
}
.penci-countdown-show7 .penci-countdown-section {
	width: 14.2857143%
}
.penci-countdown-section {
	display: block;
	float: left;
	font-size: 75%;
	padding: 30px 15px 0
}
.penci-countdown-s1.penci-style-left .penci-countdown-section {
	padding-left: 0
}
.penci-countdown-s1.penci-style-right .penci-countdown-section {
	padding-right: 0
}
.penci-countdown-amount {
	font-size: 90px;
	color: #111;
	font-family: var(--pchead-font);
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
	min-width: 1em;
	max-width: 100%;
	min-height: 1em;
	line-height: 1em;
	display: inline-block
}
.penci-countdown-s1 .penci-countdown-period {
	display: block;
	vertical-align: top
}
.penci-countdown-period {
	display: inline-block;
	padding: 0 4px;
	font-size: 20px;
	color: #111;
	line-height: 1;
	margin-top: 5px
}
.penci-period-upper .penci-countdown-period {
	text-transform: uppercase
}
.penci-countdown-descr {
	display: block;
	width: 100%
}
.penci-countdown-s2 .penci-countdown-row,
.penci-countdown-s3 .penci-countdown-row,
.penci-countdown-s4 .penci-countdown-row {
	margin-left: -15px;
	margin-right: -15px;
	width: calc(100% + 30px)
}
.penci-countdown-s2 .penci-countdown-section,
.penci-countdown-s3 .penci-countdown-section,
.penci-countdown-s4 .penci-countdown-section {
	position: relative
}
.penci-countdown-s2 .penci-countdown-section:before,
.penci-countdown-s3 .penci-countdown-section:before,
.penci-countdown-s4 .penci-countdown-section:before {
	content: "";
	padding-top: 100%;
	display: block
}
.penci-countdown-s2 .penci-span-inner,
.penci-countdown-s3 .penci-span-inner,
.penci-countdown-s4 .penci-span-inner {
	border-width: 1px;
	border-style: solid;
	border-radius: 5px;
	overflow: hidden;
	position: absolute;
	top: 30px;
	left: 15px;
	right: 15px;
	bottom: 0;
	display: flex;
	align-items: center;
	justify-content: center;
	flex-direction: column
}
.penci-countdown-s2 .penci-countdown-amount,
.penci-countdown-s3 .penci-countdown-amount,
.penci-countdown-s4 .penci-countdown-amount {
	font-size: 70px
}
.penci-countdown-s2 .penci-countdown-period,
.penci-countdown-s3 .penci-countdown-period,
.penci-countdown-s4 .penci-countdown-period {
	margin-bottom: 15px
}
.penci-countdown-s2 .penci-span-inner span,
.penci-countdown-s3 .penci-span-inner span,
.penci-countdown-s4 .penci-span-inner span {
	display: block
}
.penci-countdown-s2 .penci-span-inner {
	border-color: var(--pcaccent-cl)
}
.penci-countdown-s3 .penci-span-inner {
	border-color: #f5f5f5;
	background-color: #f5f5f5;
	border-radius: 50%
}
.penci-countdown-s4 .penci-span-inner {
	border: 0;
	background: #fff;
	border-radius: 50%;
	box-shadow: 0 0 30px 0 rgba(0, 0, 0, .1)
}
.penci-cup_icon {
	font-size: 80px;
	display: inline-block;
	font-weight: 700;
	text-align: center;
	line-height: 1;
	margin-bottom: 12px
}
.penci-cup-number-wrapper {
	font-size: 50px;
	line-height: 50px;
	margin-bottom: 5px;
	color: #111;
	display: inline-block
}
.penci-cup-number-wrapper .penci-span-inner {
	display: flex;
	align-items: center
}
.penci-counter-up .penci-cup-label {
	font-size: 70%;
	line-height: 100%
}
.penci-counter-up .penci-counterup-number {
	margin-left: 5px;
	margin-right: 5px
}
.penci-counter-up .penci-cup-title {
	font-family: var(--pchead-font);
	font-style: normal;
	font-weight: var(--pchead-wei);
	font-size: 24px;
	margin-top: 5px
}
.penci-counterup-center {
	text-align: center
}
.penci-counterup-right {
	text-align: right;
	float: right
}
.penci-counterup-left {
	text-align: left
}
.penci-counter-up.penci-style-s2 .penci-counter-up_inner {
	display: flex;
	align-items: center
}
.penci-style-s2 .penci-cup_icon {
	margin-right: 15px
}
.penci-image-not-caption .caption {
	display: none !important
}
.penci-image-gallery-s2 .penci-block_content,
.penci-image-gallery-s3 .penci-block_content {
	display: flex;
	flex-wrap: wrap
}
.penci-image-gallery .pencisc-grid {
	grid-column-gap: 0;
	grid-row-gap: 0
}
.penci-image-gallery .caption {
	position: absolute;
	bottom: 0;
	background-color: #000;
	left: 0;
	right: 0;
	margin: 0;
	color: #fff;
	font-size: 12px;
	font-family: sans-serif;
	font-weight: inherit;
	padding: 9px 15px;
	line-height: 1.5;
	background: rgba(0, 0, 0, .6);
	opacity: 0;
	transition: all .3s;
	z-index: 20
}
.penci-gallery-item:hover .caption {
	opacity: 1
}
.penci-gallery-item i {
	font-size: 25px;
	width: 1em;
	height: 1em;
	margin-left: -.5em;
	margin-top: -.5em;
	color: #fff;
	position: absolute;
	top: 50%;
	left: 50%;
	z-index: 20;
	transition: all .4s;
	opacity: 0;
	visibility: visible;
	transform: scale(.7)
}
.penci-gallery-item a::after {
	content: "";
	background: var(--pcaccent-cl);
	width: 100%;
	height: 100%;
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 10;
	transition: all .3s;
	visibility: visible;
	opacity: 0
}
.penci-gallery-item:hover i {
	opacity: 1;
	visibility: visible;
	transform: scale(1)
}
.penci-gallery-item a:hover:after {
	opacity: .6;
	visibility: visible
}
.penci-image-gallery-s2 .penci-galitem-1 {
	width: 50%;
	float: left
}
.penci-image-gallery-s2 .penci-post-smalls,
.penci-image-gallery-s2 .penci-post-smalls .penci-gallery-item {
	width: 50%;
	float: left
}
.penci-image-gallery-s3 .penci-gallery-big-item,
.penci-image-gallery-s4 .penci-gallery-big-item {
	width: 50%;
	float: left
}
.penci-image-gallery-s3 .penci-gallery-small-item,
.penci-image-gallery-s4 .penci-gallery-small-item {
	width: 33.3333%;
	float: left
}
.penci-login-register input[type=email],
.penci-login-register input[type=number],
.penci-login-register input[type=password],
.penci-login-register input[type=submit],
.penci-login-register input[type=text] {
	max-width: 100%;
	width: 100%
}
.penci-login-register p,
.post-entry .penci-login-register p {
	margin-bottom: 0
}
.penci-login-register p.login-submit {
	margin: 28px 0 0;
	clear: both
}
.penci-loginform-extra {
	margin-top: 15px
}
.penci-loginform-extra a:first-child {
	margin-right: 10px
}
.penci-login-form .penci-user-logged-in {
	text-align: center
}
.penci-user-logged-in .penci-login-header img {
	border-radius: 50%;
	width: 85px;
	height: 85px
}
.penci-user-logged-in .penci-login-header {
	text-align: center;
	margin-bottom: 15px
}
.penci-user-logged-in .penci-text-hello {
	opacity: .75
}
.penci-user-logged-in .penci-display_name {
	font-weight: 700
}
.penci-user-logged-in .penci-user-action-links a {
	display: inline-block;
	text-decoration: none;
	line-height: 30px;
	height: 30px;
	font-weight: 400;
	text-transform: none;
	font-size: 13px;
	float: left;
	width: 48%;
	font-family: var(--pchead-font);
	background: #f5f5f5;
	border-radius: 0;
	color: #313131;
	transition: .3s;
	cursor: pointer;
	text-align: center;
	margin: 0;
	padding: 0;
	max-width: 100%
}
.penci-user-logged-in .penci-user-action-links a:hover {
	color: #fff;
	background: var(--pcaccent-cl)
}
.penci-user-logged-in .penci-user-action-links i {
	margin-right: 5px
}
.penci-user-logged-in .penci-user-action-links a:first-child {
	margin-right: 4%
}
.penci-login-register .penci-login-wrap.hidden,
.penci-login-register .penci-register-wrap.hidden {
	display: none
}
.penci-login-register input.invalid {
	border-color: red !important
}
.penci-login-register .message-error {
	color: #a94442;
	background: #f2dede
}
.penci-login-register .message-success {
	color: #3c763d;
	background: #dff0d8
}
.penci-login-register .message {
	display: block;
	margin-top: 10px;
	padding: 5px 15px;
	text-align: left;
	clear: both
}
.penci-block_content {
	position: relative
}
.penci-block_content .penci-loading-icon {
	display: none
}
.penci-block_content.ajax-loading .penci-loading-icon {
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	left: 0;
	display: flex;
	align-items: center;
	justify-content: center
}
.penci-block_content.ajax-loading .penci-login-wrap,
.penci-block_content.ajax-loading .penci-register-wrap {
	opacity: .3
}
.penci-mailchimp-s1 .mc4wp-form,
.penci-mailchimp-s1 .widget input,
.penci-mailchimp-s4 .mc4wp-form {
	max-width: 100%
}
.penci-mailchimp-s2 .penci-header-signup-form {
	margin: 0;
	padding: 20px
}
.penci-mailchimp-s3 .footer-subscribe .mc4wp-form {
	max-width: 540px;
	margin: 0 auto
}
.penci-mailchimp-block .mc4wp-form input[type=submit]:not(:hover) {
	background: #313131;
	color: #fff
}
.penci-working-hours .penci-workingh-lists ul {
	margin: 0;
	padding: 0
}
.penci-working-hours .penci-workingh-lists li {
	list-style: none;
	line-height: 30px;
	color: #666;
	margin-left: 0;
	font-size: 15px
}
.penci-working-hours .penci-workingh-lists li:last-child {
	margin-bottom: 0 !important;
	padding-bottom: 0 !important
}
.penci-working-hours .penci-workingh-lists .penci-workingh-item-inner {
	position: relative;
	overflow: hidden
}
.penci-working-hours .penci-workingh-lists .penci-workingh-line1 {
	display: flex;
	align-items: flex-start
}
.penci-working-hours .penci-workingh-lists .penci-icontitle {
	flex: 1;
	overflow: hidden
}
.penci-working-hours .penci-workingh-lists .penci-listitem-icon {
	font-size: 14px;
	padding-right: 10px;
	padding-left: 1px
}
.penci-working-hours .penci-workingh-lists .penci-listitem-title {
	font-weight: 700;
	position: relative;
	line-height: 1.3
}
.penci-working-hours .penci-workingh-lists .penci-listitem-title:before {
	content: "";
	border-top: 1px dotted;
	position: absolute;
	bottom: 20%;
	left: 100%;
	margin-left: 10px;
	width: 2000px;
	opacity: .7
}
.penci-working-hours .penci-workingh-lists .penci-listitem-hours {
	float: right;
	z-index: 1;
	position: relative;
	padding-left: 10px
}
.penci-working-hours .penci-workingh-lists .penci-listitem-subtitle {
	display: block;
	line-height: 1.3;
	margin-bottom: 5px
}
.penci-working-hours .penci-workingh-lists .penci-listitem-hours,
.penci-working-hours .penci-workingh-lists .penci-listitem-title,
.penci-working-hours .penci-workingh-lists .penci-workingh-icon {
	line-height: inherit;
	color: inherit
}
.penci-progress-bar .penci-probar-items {
	margin: 0;
	padding: 0
}
.penci-progress-bar .penci-probar-items li {
	list-style: none;
	margin-left: 0;
	margin-bottom: 20px
}
.penci-progress-bar .penci-probar-items li:last-child {
	margin-bottom: 0 !important
}
.penci-progress-bar .penci-probar-items .penci-probar-text {
	line-height: 1.3;
	color: #111
}
.penci-progress-bar .penci-probar-items .penci-probar-point {
	font-weight: 700;
	text-transform: uppercase
}
.penci-progress-bar .penci-probar-items .penci-probar-score {
	float: right;
	text-align: right
}
.penci-progress-bar .penci-probar-items .penci-review-process {
	margin-top: 10px;
	overflow: hidden
}
.penci-progress-bar .penci-review-process {
	display: block;
	height: 13px;
	background-color: #e6e6e6;
	width: 100%;
	margin-top: 5px
}
.penci-progress-bar .penci-review-process span {
	display: block !important;
	height: 100%;
	width: 0;
	background-color: var(--pcaccent-cl)
}
.penci-progress-bar .penci-probar-animated {
	transition: width 1s linear;
	-moz-transition: width 1s linear;
	-webkit-transition: width 1s linear;
	-o-transition: width 1s linear;
	-webkit-animation: progress-bar-stripes 2s linear infinite;
	-moz-animation: progress-bar-stripes 2s linear infinite;
	-ms-animation: progress-bar-stripes 2s linear infinite;
	-o-animation: progress-bar-stripes 2s linear infinite;
	animation: progress-bar-stripes 2s linear infinite
}
.penci-progress-bar .penci-probar-striped {
	background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(.25, rgba(255, 255, 255, .15)), color-stop(.25, transparent), color-stop(.5, transparent), color-stop(.5, rgba(255, 255, 255, .15)), color-stop(.75, rgba(255, 255, 255, .15)), color-stop(.75, transparent), to(transparent));
	background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
	background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
	background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
	background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
	-webkit-background-size: 40px 40px;
	-moz-background-size: 40px 40px;
	-o-background-size: 40px 40px;
	background-size: 40px 40px
}
@-webkit-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0
	}
	to {
		background-position: 0 0
	}
}
@-moz-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0
	}
	to {
		background-position: 0 0
	}
}
@-ms-keyframes progress-bar-stripes {
	from {
		background-position: 40px 0
	}
	to {
		background-position: 0 0
	}
}
@-o-keyframes progress-bar-stripes {
	from {
		background-position: 0 0
	}
	to {
		background-position: 40px 0
	}
}
@keyframes progress-bar-stripes {
	from {
		background-position: 40px 0
	}
	to {
		background-position: 0 0
	}
}
.pcsoc-wrapper-outside {
	width: 100%;
	display: block;
	clear: both
}
.pcsoc-wrapper {
	display: -ms-flexbox;
	display: flex;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap;
	flex-direction: column;
	--pcsoc-space: 10px;
	--pcsoc-bspace: 10px;
	flex-direction: row;
	margin-left: calc(var(--pcsoc-space) * -1 / 2);
	margin-right: calc(var(--pcsoc-space) * -1 / 2)
}
.pcsocs-s4 {
	justify-content: center
}
.pcsoc-wrapper .pcsoc-item {
	color: var(--pctext-cl);
	text-decoration: none !important;
	line-height: 38px;
	display: -ms-flexbox;
	display: -ms-flexbox;
	display: block;
	font-size: 14px;
	transition: background-color .3s, border-color .3s, opacity .3s, color .3s;
	--pcsci-bg: #f5f5f5;
	--pcsci-hbg: #ccc;
	--pcsci-border: var(--pcborder-cl)
}
.pcsoc-wrapper .pcsoc-item:after,
.pcsoc-wrapper .pcsoc-item:before {
	clear: both;
	content: "";
	display: table
}
.pcsoc-wrapper .pcsoc-icon {
	font-size: 16px
}
.pcsoc-wrapper .pcsoc-counter {
	font-size: inherit;
	font-weight: 700;
	margin-right: 5px;
	text-transform: uppercase
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-counter.pcsoc-socname,
.pcsoc-wrapper.pcsocs-s4 .pcsoc-counter.pcsoc-socname {
	text-transform: capitalize
}
.pcsoc-wrapper .pcsoc-fan {
	font-size: inherit
}
.pcsoc-wrapper .pcsoc-item {
	background: var(--pcsci-bg);
	margin-bottom: var(--pcsoc-bspace)
}
.pcsoc-wrapper .pcsoc-item-wrap:last-child .pcsoc-item {
	margin-bottom: 0
}
.pcsoc-wrapper.pcsocs-s1,
.pcsoc-wrapper.pcsocs-s2 {
	white-space: nowrap
}
.pcsoc-wrapper .pcsoc-item:hover {
	background: var(--pcsci-hbg)
}
.pcsoc-wrapper.pcsocs-s1 .pcsoc-icon,
.pcsoc-wrapper.pcsocs-s2 .pcsoc-icon {
	width: 40px;
	text-align: center;
	line-height: inherit;
	display: inline-block;
	float: left
}
.pcsoc-wrapper.pcsocs-s1 .pcsoc-like,
.pcsoc-wrapper.pcsocs-s2 .pcsoc-like {
	float: right;
	margin: 0 10px
}
.pcsoc-wrapper.pcsocs-s2 .pcsoc-item,
.pcsoc-wrapper.pcsocs-s4 .pcsoc-item {
	background: 0 0
}
.pcsocs-s2 .pcsoc-icon {
	background: var(--pcsci-bg);
	margin-right: 15px;
	transition: background-color .3s, color .3s, border-color .3s
}
.pcsoc-wrapper .pcsoc-item-wrap {
	padding-left: calc(var(--pcsoc-space)/ 2);
	padding-right: calc(var(--pcsoc-space)/ 2)
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-item-wrap,
.pcsoc-wrapper.pcsocs-s4 .pcsoc-item-wrap {
	flex: 0 0 33.33333%;
	align-items: center;
	text-align: center
}
.pcsoc-wrapper.pcsocs-s4 {
	--pcsoc-space: 20px;
	--pcsoc-bspace: 20px
}
.pcsoc-wrapper.pcsocs-s4 .pcsoc-item-wrap {
	flex: unset
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-item {
	line-height: 1;
	padding: 12px 1px
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-item.empty-count {
	min-height: calc(100% - 10px);
	justify-content: center;
	display: flex;
	align-items: center;
	flex-direction: column
}
.pcsoc-wrapper.pcsocs-s4 .pcsoc-item {
	line-height: 1
}
.pcsocs-s3 .pcsoc-item>span,
.pcsocs-s4 .pcsoc-item>span {
	display: block;
	margin-left: 0;
	margin-right: 0
}
.pcsocs-s4 .pcsoc-item>span {
	margin-left: auto;
	margin-right: auto
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-icon {
	font-size: 28px;
	line-height: 32px
}
.pcsoc-icon i,
.pcsoc-icon i[class*=" penciicon-"],
.pcsoc-icon i[class^=penciicon-] {
	display: block;
	line-height: inherit;
	vertical-align: top
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-counter {
	margin-top: 6px;
	font-size: 18px
}
.pcsoc-wrapper.pcsocs-s3 .pcsoc-fan {
	margin-top: 6px;
	font-size: 12px
}
.pcsocs-s4 .pcsoc-icon {
	width: 60px;
	height: 60px;
	display: inline-block;
	vertical-align: top;
	line-height: 60px;
	background: var(--pcsci-bg);
	transition: background-color .3s, color .3s, border-color .3s;
	font-size: 22px
}
.pcsocs-s2 .pcsoc-item:hover>.pcsoc-icon,
.pcsocs-s4 .pcsoc-item:hover>.pcsoc-icon {
	background: var(--pcsci-hbg)
}
.pcsoc-wrapper.pcsocs-s4 .pcsoc-counter {
	font-size: 18px;
	margin-top: 10px
}
.pcsoc-wrapper.pcsocs-s4 .pcsoc-fan {
	font-size: 12px;
	margin-top: 4px
}
.pcsocs-round.pcsocs-s1 .pcsoc-item,
.pcsocs-round.pcsocs-s2 .pcsoc-icon,
.pcsocs-round.pcsocs-s3 .pcsoc-item,
.pcsocs-round.pcsocs-s4 .pcsoc-icon {
	border-radius: 8px
}
.pcsocs-circle.pcsocs-s1 .pcsoc-item,
.pcsocs-circle.pcsocs-s2 .pcsoc-icon,
.pcsocs-circle.pcsocs-s3 .pcsoc-item,
.pcsocs-circle.pcsocs-s4 .pcsoc-icon {
	border-radius: 800px
}
.pcsocf-border .pcsc-brandflag {
	border: 1px solid var(--pcsci-border);
	background: 0 0
}
@media only screen and (min-width:1025px) {
	.pcsoc-wrapper.pcsocc-1 .pcsoc-item-wrap {
		flex: 0 0 100%
	}
	.pcsoc-wrapper.pcsocc-2 .pcsoc-item-wrap {
		flex: 0 0 50%
	}
	.pcsoc-wrapper.pcsocc-3 .pcsoc-item-wrap {
		flex: 0 0 33.3333%
	}
	.pcsoc-wrapper.pcsocc-4 .pcsoc-item-wrap {
		flex: 0 0 25%
	}
	.pcsocc-2 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-3 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-3 .pcsoc-item-wrap:nth-last-child(3) .pcsoc-item,
	.pcsocc-4 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-4 .pcsoc-item-wrap:nth-last-child(3) .pcsoc-item,
	.pcsocc-4 .pcsoc-item-wrap:nth-last-child(4) .pcsoc-item {
		margin-bottom: 0
	}
}
@media only screen and (max-width:1024px) {
	.pcsoc-wrapper.pcsocc-tabcol-1 .pcsoc-item-wrap {
		flex: 0 0 100%
	}
	.pcsoc-wrapper.pcsocc-tabcol-2 .pcsoc-item-wrap {
		flex: 0 0 50%
	}
	.pcsoc-wrapper.pcsocc-tabcol-3 .pcsoc-item-wrap {
		flex: 0 0 33.3333%
	}
	.pcsoc-wrapper.pcsocc-tabcol-4 .pcsoc-item-wrap {
		flex: 0 0 25%
	}
	.pcsocc-tabcol-2 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-tabcol-3 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-tabcol-3 .pcsoc-item-wrap:nth-last-child(3) .pcsoc-item,
	.pcsocc-tabcol-4 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-tabcol-4 .pcsoc-item-wrap:nth-last-child(3) .pcsoc-item,
	.pcsocc-tabcol-4 .pcsoc-item-wrap:nth-last-child(4) .pcsoc-item {
		margin-bottom: 0
	}
}
@media only screen and (max-width:479px) {
	.pcsoc-wrapper.pcsocc-mocol-1 .pcsoc-item-wrap {
		flex: 0 0 100%
	}
	.pcsoc-wrapper.pcsocc-mocol-2 .pcsoc-item-wrap {
		flex: 0 0 50%
	}
	.pcsoc-wrapper.pcsocc-mocol-3 .pcsoc-item-wrap {
		flex: 0 0 33.3333%
	}
	.pcsocc-mocol-2 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-mocol-3 .pcsoc-item-wrap:nth-last-child(2) .pcsoc-item,
	.pcsocc-mocol-3 .pcsoc-item-wrap:nth-last-child(3) .pcsoc-item {
		margin-bottom: 0
	}
}
.pcsoccl-brandbg .pcsc-brandflag,
.pcsoccl-brandbg .pcsc-brandflag i,
.pcsoccl-brandbg .pcsc-brandflag span {
	color: #fff !important;
	border: none !important
}
.pcsocshadow .pcsc-brandflag {
	box-shadow: 0 1px 2px rgba(0, 0, 0, .075)
}
.pcsoccl-brandbg.pcsocs-s1 .pcsoc-item:hover,
.pcsoccl-brandbg.pcsocs-s2 .pcsoc-item:hover .pcsoc-icon,
.pcsoccl-brandbg.pcsocs-s3 .pcsoc-item:hover,
.pcsoccl-brandbg.pcsocs-s4 .pcsoc-item:hover .pcsoc-icon {
	opacity: .8
}
.pcsoc-wrapper-outside.source-customizer .pcsoc-wrapper.pcsocs-s3 .pcsoc-item.empty-count {
	flex-direction: column;
	min-height: unset
}
.pcsoc-wrapper-outside.source-customizer .pcsoc-wrapper.pcsocs-s3 .pcsoc-counter,
.pcsoc-wrapper-outside.source-customizer .pcsoc-wrapper.pcsocs-s4 .pcsoc-counter {
	font-size: 14px;
	font-weight: 400
}
.penci-teammb-bsc {
	text-align: center;
	--pcteammb-w: 28px
}
.penci-teammb-item {
	overflow: hidden
}
.penci-teammb-bsc .penci-teammb-inner {
	padding: 30px 15px
}
.penci-teammb-s1 .penci-teammb-inner {
	border: 1px solid #dedede
}
.penci-teammb-s1 .penci-teammb-img,
.penci-teammb-s2 .penci-teammb-img {
	width: 150px;
	height: 150px;
	border-radius: 50%;
	max-width: 100%;
	margin-bottom: 21px
}
.penci-teammb-s1 .penci-teammb-img:before,
.penci-teammb-s2 .penci-teammb-img:before {
	padding-top: 100%
}
.penci-teammb-bsc .penci-team_member_name {
	font-size: 20px;
	margin-top: 10px;
	margin-bottom: 0
}
.penci-team_member_desc {
	margin-top: 15px;
	line-height: 1.5
}
.penci-team_member_socails {
	margin-top: 7px;
	overflow: hidden
}
.penci-team_member_pos {
	color: #999;
	line-height: 1;
	margin-top: 10px
}
.penci-teammb-bsc .penci-team_member_socails {
	display: flex;
	align-items: center;
	justify-content: center;
	flex-wrap: wrap;
	line-height: 1
}
.penci-teammb-bsc .penci-team_member_socails .penci-social-item {
	margin: 8px 8px 0 8px;
	text-decoration: none
}
.pcteam-shape .penci-team_member_socails .penci-social-item {
	margin-left: 5px;
	margin-right: 5px
}
.pcteam-shape .penci-social-item i {
	width: var(--pcteammb-w);
	height: var(--pcteammb-w);
	display: inline-flex;
	align-items: center;
	justify-content: center;
	vertical-align: top;
	transition: all .3s;
	border: 1px solid transparent
}
.pcsc-shape-round .penci-social-item i {
	border-radius: 6px
}
.pcsc-shape-circle .penci-social-item i {
	border-radius: 50%
}
.pcsc-st-filled .penci-social-item i {
	background: #ececec;
	color: var(--pctext-cl)
}
.pcsc-st-bordered .penci-social-item i {
	border-color: var(--pcborder-cl);
	color: var(--pctext-cl)
}
.penci-social-colored .penci-social-item i {
	color: #fff !important;
	border: none !important
}
.penci-teammb-bsc .penci-team_member_socails .penci-social-item:first-child {
	margin-left: 0 !important
}
.penci-teammb-bsc .penci-team_member_socails .penci-social-item:last-child {
	margin-right: 0 !important
}
.penci-teammb-s2 .penci-teammb-inner {
	background-color: #f5f5f5;
	border: none;
	border-radius: 15px;
	padding-top: 40px;
	padding-bottom: 40px
}
.penci-teammb-s3 .penci-teammb-inner {
	background-color: #f5f5f5;
	padding: 0
}
.penci-teammb-s3 .penci-teammb-img {
	width: 100%;
	display: block
}
.penci-teammb-s3 .penci-teammb-img:before {
	padding-top: 66.6667%
}
.penci-teammb-s3 .penci-team_item__info {
	padding: 15px 20px 30px
}
.penci-teammb-s4 .penci-teammb-inner {
	background-color: #fff;
	box-shadow: 0 15px 30px 0 rgba(0, 0, 0, .1);
	padding: 0;
	position: relative
}
.penci-teammb-s4 .penci-teammb-img:before {
	padding-top: 120%
}
.penci-teammb-s4 .penci-team_item__info {
	padding: 20px 10px 20px;
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 100;
	transform: translateY(35px);
	transition: all .3s
}
.penci-teammb-s4 .penci-social-wrap .penci-social-item {
	width: auto;
	height: auto;
	background: 0 0 !important
}
.penci-teammb-s4 .penci-team_member_desc {
	color: #fff;
	margin-top: 10px
}
.penci-teammb-s4 .penci-social-wrap .penci-social-item,
.penci-teammb-s4 .penci-team_member_name,
.penci-teammb-s4 .penci-team_member_pos {
	color: #fff
}
.penci-teammb-s4 .penci-team_member_socails .penci-social-item {
	margin-right: 10px;
	margin-left: 10px;
	font-size: 15px
}
.penci-teammb-s4 .penci-social-wrap .penci-social-item:hover {
	color: var(--pcaccent-cl)
}
.penci-teammb-s4 .penci-teammb-img:after {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	z-index: 1;
	bottom: 0;
	right: 0;
	background: linear-gradient(to bottom, transparent 50%, #000 90%);
	opacity: .6;
	transition: opacity .3s
}
.penci-teammb-s4 .penci-teammb-item:hover .penci-team_item__info,
.penci-teammb-s5 .penci-teammb-item .penci-team_item__info {
	transform: translateY(0)
}
.penci-teammb-s4.penci-teammb-bsc .penci-team_member_socails {
	opacity: 0;
	transition: opacity .3s
}
.penci-teammb-s4 .penci-teammb-item:hover .penci-team_member_socails,
.penci-teammb-s5 .penci-teammb-item .penci-team_member_socails {
	opacity: 1
}
.penci-testimonail {
	text-align: center;
	position: relative
}
.penci-smalllist.penci-testimonails {
	--pcsl-hgap: 30px;
	--pcsl-bgap: 30px;
	--pcsl-between: 30px
}
.penci-testimonail .penci-testi-bq-icon:before {
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box
}
.penci-testi-s1 .penci-testimonail .penci-testi-blockquote {
	font-size: 23px;
	font-weight: 500;
	font-style: italic;
	line-height: 1.5;
	color: #111;
	clear: both;
	position: relative;
	text-align: center;
	background-color: #f5f5f5;
	padding: 39px 30px 35px;
	margin-top: 24px
}
.penci-testi-s1 .penci-testimonail .penci-testi-bq-icon {
	width: 48px;
	height: 48px;
	position: absolute;
	top: -24px;
	left: 50%;
	margin-left: -24px
}
.penci-testi-bq-icon:before {
	content: "\f101";
	font-family: penciicon;
	font-weight: 400;
	font-style: normal
}
.penci-testi-s1 .penci-testimonail .penci-testi-bq-icon:before {
	display: block;
	text-align: center;
	border-radius: 50%;
	margin: 0;
	width: 48px;
	height: 48px;
	font-size: 21px;
	line-height: 48px;
	background-color: var(--pcaccent-cl);
	color: #fff;
	z-index: 2
}
.penci-testi-rating {
	color: #ffb74d;
	font-size: 18px;
	line-height: 1;
	margin-top: 15px
}
.penci-testi-rating i:not(:last-child) {
	margin-right: 3px
}
.penci-testi-blockquote {
	line-height: 1.5
}
.penci-testi-avatar {
	width: 60px;
	height: 60px;
	border-radius: 50%;
	overflow: hidden;
	margin: 25px auto 0;
	background: #e6e9ec
}
.penci-testi-s4 .penci-testi-avatar {
	margin-top: 0
}
.penci-testi-s4 .penci-testi-blockquote {
	margin-top: 12px;
	position: relative
}
.penci-testimonails .penci-testi-avatar img {
	width: 100%;
	height: 100%;
	display: block;
	object-fit: cover
}
.penci-testi-name,
.post-entry h3.penci-testi-name {
	font-size: 16px;
	margin-top: 18px;
	margin-bottom: 0
}
.penci-testi-company {
	font-size: 13px;
	margin-top: 10px;
	line-height: 1.3;
	color: var(--pcmeta-cl)
}
.penci-testi-company .testiname {
	font-weight: 700;
	color: var(--pctext-cl)
}
.penci-testi-company span:last-child {
	margin-left: 5px
}
.penci-testi-s2 .penci-testimonail {
	text-align: left
}
.penci-testi-s2 .penci-testimonail .penci-testi-blockquote {
	border: 1px solid var(--pcborder-cl);
	background-color: var(--pcbg-cl);
	border-radius: 15px;
	padding: 30px 30px 56px
}
.penci-testi-s2 .penci-testimonail .penci-testi-bq-icon:before {
	display: block;
	text-align: left;
	border-radius: 50%;
	margin: 0;
	width: 48px;
	height: 48px;
	font-size: 42px;
	line-height: 48px;
	z-index: 2;
	color: var(--pcaccent-cl)
}
.penci-testi-s2 .penci-testi-avatar {
	margin-left: 30px;
	margin-top: -30px;
	position: relative;
	z-index: 10
}
.penci-testi-s2 .penci-testi-rating {
	margin-top: 5px
}
.penci-testi-s2 .penci-testi-company,
.penci-testi-s2 .penci-testi-name {
	margin-left: 30px
}
.penci-testi-s3 .penci-testimonail .penci-testi-bq-icon:before {
	display: block;
	text-align: center;
	border-radius: 50%;
	margin: 0 auto;
	width: 48px;
	height: 48px;
	font-size: 21px;
	line-height: 48px;
	z-index: 2;
	border: 2px solid var(--pcaccent-cl);
	color: var(--pcaccent-cl)
}
.penci-testi-s3 .penci-testi-bq-icon {
	margin-bottom: 16px;
	display: block
}
.penci-testi-s3 .penci-testimonail .penci-testi-blockquote {
	font-size: 23px;
	font-style: italic;
	line-height: 1.5;
	color: #111;
	clear: both;
	position: relative;
	text-align: center
}
.penci-testi-s3 .penci-testi-name {
	text-transform: uppercase;
	color: var(--pcaccent-cl)
}
.penci-testi-s4.penci-testimonails {
	overflow: visible
}
.penci-testi-s4 .pc-testiinner {
	padding: 20px;
	box-shadow: 0 0 4px rgba(0, 0, 0, .15)
}
.pctesti-head,
.penci-testi-s4.pcimgpos-left .pc-testiinner,
.penci-testi-s4.pcimgpos-right .pc-testiinner {
	display: flex;
	align-items: flex-start;
	flex-direction: row
}
.pctesti-head {
	align-items: center
}
.penci-testi-s4.pcimgpos-right .pc-testiinner {
	flex-direction: row-reverse
}
.pcimgpos-left .penci-testi-rating,
.pcimgpos-right .penci-testi-rating {
	margin-top: 0
}
.pctesti-head .pc-testiava,
.penci-testi-s4 .pc-testiava {
	flex: 0 0 auto
}
.pctesti-head .pctesticont,
.penci-testi-s4 .pctesticont {
	flex: 1 1 auto
}
.penci-testi-s4.pcimgpos-left .pctesticont {
	text-align: left
}
.penci-testi-s4.pcimgpos-right .pctesticont {
	text-align: right
}
.pctesti-head .pc-testiava,
.penci-testi-s4.pcimgpos-left .pc-testiava {
	margin-right: 20px
}
.penci-testi-s4.pcimgpos-right .pc-testiava {
	margin-left: 20px
}
.penci-testi-s4 .owl-stage-outer,
.penci-testi-s4 .penci-owl-carousel:not(.penci-owl-loaded) {
	padding-top: 6px;
	padding-bottom: 6px
}
.penci-testi-s4 .penci-testi-bq-inner,
.penci-testi-s5 .penci-testi-bq-inner {
	position: relative
}
.penci-testi-s4 .penci-testi-bq-icon:before,
.penci-testi-s5 .penci-testi-bq-icon:before {
	position: absolute;
	display: inline-block;
	font-size: 26px;
	color: rgba(0, 0, 0, .1);
	right: 0;
	top: -8px;
	transform: rotate(180deg)
}
.penci-testi-s4.pcimgpos-right .penci-testi-bq-icon:before {
	left: 0;
	right: auto;
	transform: none
}
.penci-testi-s4 .penci-testi-company span {
	display: inline-block
}
.penci-testi-s5 .penci-testimonail {
	text-align: left
}
.penci-testi-s5 .penci-testi-blockquote {
	padding: 20px;
	background: #f5f5f5;
	margin-bottom: 20px;
	position: relative
}
.penci-testi-s5 .penci-testi-blockquote:after {
	content: "";
	position: absolute;
	bottom: -11px;
	left: 15px;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 11px 10px 0 10px;
	border-color: #f5f5f5 transparent transparent transparent;
	z-index: 3
}
.penci-testi-s5 .penci-testi-avatar,
.penci-testi-s5 .penci-testi-name,
.post-entry .penci-testi-s5 h3.penci-testi-name {
	margin-top: 0
}
.penci-testi-s5 .penci-testi-company,
.penci-testi-s5 .penci-testi-rating {
	margin-top: 5px
}
.penci-media-obj {
	display: -webkit-box;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-box-align: start;
	-webkit-align-items: flex-start;
	-ms-flex-align: start;
	align-items: flex-start
}
.penci-media-obj .penci-mobj-img {
	margin-right: 20px;
	position: relative
}
.penci-media-obj .penci-mobj-body {
	flex: 1
}
.penci-media-obj.penci-mobj-right .penci-mobj-img {
	-webkit-box-ordinal-group: 2;
	-webkit-order: 1;
	-ms-flex-order: 1;
	order: 1;
	margin-right: 0;
	margin-left: 20px
}
.penci-video_playlist .penci-block_content {
	position: relative;
	display: flex;
	flex-wrap: wrap
}
.penci-video_playlist .penci-playlist-title {
	background: var(--pcaccent-cl);
	color: #fff;
	min-height: 70px;
	width: 100%;
	padding: 0 15px;
	line-height: 17px;
	font-size: 20px;
	z-index: 9
}
.penci-video_playlist .penci-playlist-title .playlist-title-icon {
	font-size: 27px;
	float: left;
	margin-right: 10px;
	height: 70px;
	line-height: 70px;
	width: 40px;
	text-align: center;
	font-weight: 400
}
.penci-video_playlist .penci-playlist-title a {
	color: inherit
}
.penci-video_playlist .penci-playlist-title .fa {
	padding-right: 5px
}
.penci-video_playlist .penci-playlist-title h2 {
	padding-top: 14px;
	font-size: 18px;
	clear: none;
	color: inherit;
	margin: 0
}
.penci-video_playlist .penci-playlist-title .penci-videos-number {
	font-size: 11px;
	display: block;
	float: left
}
.penci-video_playlist .penci-video-play {
	background-color: #111;
	position: relative;
	width: 66%;
	float: left
}
.penci-video_playlist .penci-video-nav {
	width: 34%;
	height: 100%;
	float: right;
	position: absolute;
	top: 0;
	right: 0;
	border-width: 0 1px 1px 0;
	background: #f5f5f5;
	overflow: hidden
}
.penci-video_playlist .penci-custom-scroll {
	overflow-y: auto;
	height: 100%
}
.penci-video_playlist .penci-custom-scroll::-webkit-scrollbar {
	width: 6px;
	background: #dedede
}
.penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-thumb {
	background-color: var(--pcaccent-cl);
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0
}
.penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-corner {
	background-color: #dedede
}
.penci-video_playlist .fluid-width-video-wrapper {
	padding-top: 56.25% !important
}
.penci-video_playlist .penci-video-play {
	background-color: #111;
	position: relative;
	width: 66%;
	float: left
}
.penci-video_playlist .penci-video-play .video-player-wrapper {
	position: relative;
	z-index: 2
}
.penci-video_playlist .penci-video-play .loader-overlay {
	z-index: 1
}
.penci-video_playlist .penci-video-play .video-frame {
	visibility: hidden
}
.penci-video_playlist .penci-video-play iframe {
	width: 100%
}
.penci-video_playlist .fluid-width-video-wrapper {
	position: relative;
	z-index: 2
}
.fluid-width-video-wrapper embed,
.fluid-width-video-wrapper iframe,
.fluid-width-video-wrapper object {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.penci-video_playlist .penci-video-nav .penci-video-thumbnail {
	width: 100px;
	height: 56px;
	float: left
}
.penci-video_playlist .penci-video-thumbnail:after {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	opacity: 0;
	z-index: 1;
	transition: opacity .3s ease
}
.penci-video_playlist .penci-video-nav .penci-video-thumbnail:hover:after {
	opacity: .3
}
.penci-video_playlist .penci-video-nav .playlist-panel-item {
	float: left;
	width: 20px;
	text-align: left;
	line-height: 56px;
	font-size: 13px;
	color: #111
}
.penci-video_playlist .penci-video-nav .penci-video-playlist-item {
	padding: 12px 15px;
	display: block;
	overflow: hidden;
	cursor: pointer;
	border-bottom: 1px solid #dedede;
	transition: all .3s
}
.penci-video_playlist .penci-video-nav .penci-video-playlist-item:hover {
	background: #dedede
}
.penci-video_playlist .penci-video-playlist-item .penci-video-play-icon {
	display: none;
	color: var(--pcaccent-cl)
}
.penci-video_playlist .penci-video-playlist-item .penci-video-paused-icon {
	display: none
}
.penci-video_playlist .penci-video-playlist-item.is-playing .penci-video-play-icon {
	display: block
}
.penci-video_playlist .penci-video-playlist-item.is-playing .penci-video-number {
	display: none
}
.penci-video_playlist .penci-video-playlist-item.is-paused .penci-video-paused-icon {
	display: block
}
.penci-video_playlist .penci-video-playlist-item.is-paused .penci-video-number {
	display: none
}
.penci-video_playlist .penci-video-playlist-item .penci-video-title {
	font-size: 13px;
	font-weight: 400;
	line-height: 1.3;
	font-family: inherit;
	width: 100%;
	display: block;
	float: left;
	margin-top: -2px;
	transition: all .3s;
	color: #000
}
.penci-video_playlist .penci-video-playlist-item .penci-video-title:hover {
	color: var(--pcaccent-cl)
}
.penci-video_playlist .penci-video-playlist-item .penci-video-duration {
	float: left;
	font-size: 11px;
	color: #888;
	margin-top: 5px;
	line-height: 1
}
.pencisc-column-1.penci-video_playlist .penci-video-nav {
	width: 100%;
	position: relative
}
.pencisc-column-1.penci-video_playlist .penci-video-play {
	width: 100%
}
.pencisc-column-1.penci-video_playlist .penci-video-nav .penci-video-thumbnail,
.pencisc-column-2.penci-video_playlist .penci-video-nav .penci-video-thumbnail {
	width: 75px;
	height: 42.18px
}
.pencisc-column-1.penci-video_playlist .penci-video-nav .penci-video-playlist-nav {
	min-height: 100px;
	max-height: 283px
}
.pencisc-column-1.penci-video_playlist .penci-video-nav .playlist-panel-item,
.pencisc-column-2.penci-video_playlist .penci-video-nav .playlist-panel-item {
	position: absolute;
	bottom: 0;
	left: 0;
	font-size: 10px;
	width: 20px;
	height: 20px;
	text-align: center;
	vertical-align: middle;
	line-height: 20px;
	z-index: 10;
	background: var(--pcaccent-cl);
	color: #fff
}
.penci-media-carousels {
	overflow: hidden
}
.penci-advanced-carousel-mg {
	margin-left: -5px;
	margin-right: -5px;
	display: block;
	clear: both
}
.penci-media-carousels .penci-image-holder[style*=background-image] {
	background-color: transparent
}
.penci-media-carousels .overlay-icon-format {
	opacity: 1;
	transform: scale(1);
	-webkit-transform: scale(1);
	-moz-transform: scale(1);
	transition: all .3s
}
.pc-ctpos-on .overlay-icon-format {
	top: 10px;
	right: 10px;
	z-index: 10;
	margin: 0;
	left: auto
}
.penci-media-carousels .penci-media-inner {
	padding: 0 5px
}
.penci-media-carousels .penci-media-inct {
	display: -ms-flexbox;
	display: flex;
	flex-direction: column;
	position: relative
}
.penci-media-carousels .penci-media-content {
	text-align: center;
	margin-top: 20px
}
.penci-media-img {
	position: relative
}
.penci-media-img>a {
	display: block
}
.penci-media-carousels.pc-ctpos-above .penci-media-img {
	order: 3
}
.penci-media-carousels.pc-ctpos-above .penci-media-content {
	order: 1;
	margin-top: 0;
	margin-bottom: 20px
}
.penci-media-carousels.pc-ctpos-on .penci-media-content {
	margin: 0;
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	width: 100%;
	height: 100%;
	display: -ms-flexbox;
	display: flex;
	flex-direction: row;
	z-index: 9;
	align-items: flex-end
}
.pc-ctpos-on .penci-media-content .pc-media-ctinner {
	width: 100%;
	padding: 15px 10px;
	position: relative;
	z-index: 2
}
.pc-media-ctinner {
	position: relative
}
.pc-ctpos-on .penci-media-content>a,
.penci-media-carousels .pc-adcr-overlay,
.penci-media-carousels .pc-media-ctinner:before {
	position: absolute;
	font-size: 0;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	display: block;
	z-index: 9
}
.penci-media-carousels .pc-media-ctinner:before {
	z-index: -1;
	content: ""
}
.pc-adcr-overlay,
.penci-media-carousels .pc-media-ctinner:before {
	opacity: .5;
	transition: all .3s
}
.penci-media-carousels .penci-media-inct:hover .pc-media-ctinner:before .penci-media-inct:hover .pc-adcr-overlay {
	opacity: .7
}
.penci-media-carousels .penci-media-stit {
	line-height: 1.4;
	margin-bottom: 5px;
	font-size: 13px;
	color: #666
}
.penci-media-carousels .penci-media-title {
	font-size: 18px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	margin: 0
}
.penci-media-carousels .penci-media-desc {
	margin-top: 8px;
	line-height: 1.6
}
.penci-media-rmbtn i,
.penci-media-rmbtn svg {
	color: inherit;
	font-size: inherit
}
.penci-media-carousels .pc-icpos-left i,
.penci-media-carousels .pc-icpos-left svg {
	margin-right: 5px
}
.penci-media-carousels .pc-icpos-right i,
.penci-media-carousels .pc-icpos-right svg {
	margin-left: 5px
}
.penci-weather-widget {
	overflow: hidden;
	color: #111;
	position: relative
}
.penci-weather-widget.loading span.penci-wuser-gps svg {
	animation: penci-spin .4s infinite linear
}
.penci-weather-city {
	font-size: 24px;
	font-weight: 700;
	line-height: 1;
	margin-bottom: 7px
}
.penci-weather-condition {
	font-size: 14px;
	line-height: 1;
	text-transform: capitalize;
	opacity: .8
}
.penci-location-icon {
	position: absolute;
	top: 0;
	right: 10px;
	font-size: 22px;
	opacity: .6;
	z-index: 1
}
.penci-location-icon:hover {
	cursor: pointer;
	opacity: .9
}
.penci-weather-temperature {
	padding: 3px 0;
	display: inline-block;
	width: 100%;
	float: left;
	text-align: center
}
@media screen and (max-width:1018px) {
	.penci-weather-temperature {
		margin-bottom: -6px;
		padding: 0
	}
}
.penci-weather-temp-wrap {
	display: inline-block
}
.penci-weather-now {
	text-align: center;
	line-height: 1;
	font-weight: 300;
	align-content: center;
	width: 30%;
	-webkit-touch-callout: none;
	-webkit-user-select: none;
	-khtml-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none
}
@media screen and (max-width:1018px) {
	.penci-weather-now {
		padding: 28px 0;
		position: relative;
		left: -10px;
		width: 90px;
		margin-left: 12px
	}
}
@media screen and (min-width:768px) and (max-width:1018px) {
	.penci-weather-now {
		margin-left: 0
	}
}
@media screen and (max-width:767px) {
	.penci-weather-now {
		width: 100px
	}
}
.penci-weather-now .penci-big-degrees {
	font-size: 40px
}
@media screen and (max-width:1018px) {
	.penci-weather-now .penci-big-degrees {
		font-size: 32px
	}
}
.penci-weather-now .penci-circle {
	font-size: 30px;
	position: relative;
	top: -6px;
	opacity: .6;
	line-height: 1;
	vertical-align: top
}
.penci-weather-now .penci-weather-unit {
	font-size: 16px;
	position: relative;
	top: -4px;
	font-weight: 400;
	opacity: .6;
	left: -2px;
	line-height: 1;
	vertical-align: top
}
.penci-weather-now:hover {
	cursor: pointer
}
.penci-weather-lo-hi {
	width: 20%;
	text-align: center
}
.penci-weather-lo-hi__content {
	padding: 15px 0
}
.penci-weather-lo-hi__content .penci-circle {
	padding-left: 3px
}
.penci-weather-degrees-wrap {
	padding: 15px 0;
	text-align: right;
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between
}
@media screen and (max-width:1018px) {
	.penci-weather-degrees-wrap {
		padding: 10px
	}
}
.penci-weather-degrees-wrap i {
	position: relative;
	top: 1px;
	font-size: 16px;
	color: #b3b3b3;
	right: 5px
}
.penci-weather-degrees-wrap .penci-small-degrees {
	font-size: 12px
}
.penci-weather-degrees-wrap .penci-circle {
	font-size: 18px;
	position: relative;
	right: 3px;
	top: 3px
}
.penci-weather-information {
	font-size: 12px;
	position: relative;
	padding: 5px 0;
	display: inline-block;
	width: 100%;
	vertical-align: top;
	opacity: .6;
	margin-top: 19px;
	border-top: 1px solid #ececec;
	border-bottom: 1px solid #ececec
}
.penci-weather-information i {
	font-size: 16px;
	position: relative;
	top: 2px;
	margin-right: 5px
}
.penci-weather-section {
	float: left;
	width: 33%
}
.penci_humidty {
	text-align: right;
	padding-right: 10px
}
.penci_wind {
	text-align: center
}
.penci_clouds {
	text-align: left;
	padding-left: 10px
}
.penci-weather-week {
	padding: 15px 8px;
	width: 100%;
	text-align: center;
	line-height: 1;
	position: relative;
	display: block;
	margin-bottom: -5px;
	clear: both;
	overflow: hidden
}
.penci-weather-week:before {
	content: "";
	width: 100%;
	height: 100%;
	position: absolute;
	top: 0;
	left: 0;
	background-color: var(--pcaccent-cl);
	opacity: .07
}
.penci-weather-days {
	width: 20%;
	float: left;
	text-align: center;
	text-transform: uppercase;
	line-height: 1
}
.penci-weather-days .penci-day {
	margin-bottom: 8px;
	font-size: 11px;
	opacity: .5
}
.penci-weather-days .penci-day-degrees {
	font-size: 20px;
	position: relative;
	left: 4px;
	line-height: 14px;
	opacity: .7
}
.penci-weather-days .penci-circle {
	position: relative;
	right: 5px
}
.penci-weather-days .penci-day {
	margin-top: 8px;
	font-size: 11px;
	opacity: .5
}
.penci-weather-set-location {
	display: none;
	position: absolute;
	top: 0
}
.penci-weather-set-location .penci-location-set-input {
	height: 20px;
	font-size: 20px;
	font-weight: 700;
	text-transform: uppercase;
	border: 0;
	padding: 0 10px
}
.penci-weather-set-location .penci-location-set-input:focus~label {
	top: -20px;
	font-size: 11px;
	opacity: .5
}
.penci-show-location {
	display: block !important
}
.penci-show-location label {
	position: absolute;
	top: 0;
	left: 10px;
	font-size: 13px;
	opacity: .6;
	pointer-events: none;
	-webkit-transition: all .2s ease;
	-moz-transition: all .2s ease;
	-o-transition: all .2s ease;
	transition: all .2s ease
}
.penci-weather-animated-icon {
	width: 45%;
	position: relative;
	text-align: center
}
.penci-weather-animated-icon i {
	width: 70px;
	font-size: 70px;
	opacity: .4;
	top: 15px;
	left: 0;
	right: auto
}
.penci_facebook_widget .penci-block_content {
	text-align: center
}
.penci_facebook_widget .fb_iframe_widget {
	max-width: 340px
}
.weather-icon {
	position: relative;
	margin: 0 auto .1em;
	width: 1em;
	height: .9em;
	font-size: 35px
}
.penci-weather-animated-icon .weather-icon {
	font-size: 75px
}
.penci-weather-widget [class*=" icon-"]:after,
.penci-weather-widget [class*=" icon-"]:before,
.penci-weather-widget [class^=icon-]:after,
.penci-weather-widget [class^=icon-]:before {
	font-family: weathericons
}
.icon-thunder-animi {
	position: absolute;
	width: 100%;
	height: 100%
}
.icon-thunder-animi:after,
.icon-thunder-animi:before {
	content: "\f010";
	position: absolute;
	width: 100%;
	z-index: 2;
	font-size: 3em;
	left: 40%;
	-webkit-transform: translateX(-50%) translateY(-30%);
	-ms-transform: translateX(-50%) translateY(-30%);
	transform: translateX(-50%) translateY(-30%)
}
.icon-thunder-animi:after {
	color: orange;
	z-index: 2;
	font-size: 2.5em;
	top: 90%
}
.icon-moon,
.icon-rainy-animi,
.icon-rainy-animi-2,
.icon-rainy-animi-4,
.icon-rainy-animi-5,
.icon-windysnow-animi,
.icon-windysnow-animi-2 {
	position: absolute;
	width: 100%;
	height: 100%
}
.icon-rainy-animi-2:after,
.icon-rainy-animi-2:before,
.icon-rainy-animi-4:after,
.icon-rainy-animi-4:before,
.icon-rainy-animi-5:after,
.icon-rainy-animi-5:before,
.icon-rainy-animi:after,
.icon-rainy-animi:before,
.icon-windysnow-animi-2:after,
.icon-windysnow-animi-2:before,
.icon-windysnow-animi:after,
.icon-windysnow-animi:before {
	content: "\f036";
	position: absolute;
	z-index: 2;
	opacity: .6
}
.icon-rainy-animi-2:after,
.icon-rainy-animi-4:after,
.icon-rainy-animi-5:after,
.icon-rainy-animi:after,
.icon-windysnow-animi-2:after,
.icon-windysnow-animi:after {
	opacity: 0;
	-webkit-animation-fill-mode: forwards;
	animation-fill-mode: forwards
}
.animi-icons-wrap {
	font-size: .14em;
	position: absolute;
	z-index: 2;
	left: 48%;
	bottom: 0;
	-webkit-transform: translateX(-50%);
	-ms-transform: translateX(-50%);
	transform: translateX(-50%);
	width: 2.5em;
	height: 2.5em
}
.icon-rainy-animi-2:after,
.icon-rainy-animi-2:before,
.icon-rainy-animi-4:after,
.icon-rainy-animi-4:before,
.icon-rainy-animi-5:after,
.icon-rainy-animi-5:before,
.icon-rainy-animi:after,
.icon-rainy-animi:before {
	content: "\f078";
	top: calc(50% - .43em);
	left: 0;
	right: auto;
	width: .96em;
	height: .96em;
	color: #fff
}
.icon-rainy-animi-2:after,
.icon-rainy-animi-2:before {
	right: 0;
	left: auto;
	top: calc(50% - .43em)
}
.icon-rainy-animi-4:after,
.icon-rainy-animi-4:before {
	left: calc(50% - .43em);
	top: calc(100% - .96em)
}
.icon-rainy-animi-5:after,
.icon-rainy-animi-5:before {
	left: calc(50% - .43em);
	top: 0
}
.drizzle-icons .icon-rainy-animi-2:after,
.drizzle-icons .icon-rainy-animi-2:before,
.drizzle-icons .icon-rainy-animi-4:after,
.drizzle-icons .icon-rainy-animi-4:before,
.drizzle-icons .icon-rainy-animi-5:after,
.drizzle-icons .icon-rainy-animi-5:before,
.drizzle-icons .icon-rainy-animi:after,
.drizzle-icons .icon-rainy-animi:before {
	-webkit-transform: rotate(30deg);
	-ms-transform: rotate(30deg);
	transform: rotate(30deg)
}
.icon-windysnow-animi-2:after,
.icon-windysnow-animi-2:before,
.icon-windysnow-animi:after,
.icon-windysnow-animi:before {
	content: "\f021";
	width: 100%;
	height: 100%;
	font-size: 1.8em;
	top: 0;
	left: .3em
}
.icon-windysnow-animi-2:after,
.icon-windysnow-animi:after {
	width: 2em;
	height: 2em
}
.icon-windysnow-animi-2:after,
.icon-windysnow-animi-2:before {
	font-size: 1em;
	top: 1.5em;
	right: .7em;
	left: auto
}
.icon-windysnow-animi-2:after {
	width: 2em;
	height: 2em;
	left: -.5em
}
.icon-moon:after {
	content: "\f02e";
	position: absolute;
	font-size: .65em;
	left: 0;
	right: 0;
	top: .2em
}
.icon-moon:before {
	display: none
}
.icon-moon-animi:before {
	content: "\f02e";
	position: absolute;
	right: -.3em;
	font-size: .35em;
	top: .2em
}
.icon-sun:after {
	content: "\f00d";
	position: absolute;
	color: orange;
	font-size: .9em;
	left: 0;
	right: 0
}
.icon-sun-animi:after {
	content: "\f00d";
	position: absolute;
	color: orange;
	right: -.3em;
	top: .07em;
	font-size: .4em
}
.basecloud:before,
.icon-cloud:after {
	font-family: FontAwesome !important;
	content: "\f0c2" !important;
	font-size: .86em;
	position: absolute;
	left: 0;
	right: 0;
	z-index: 2;
	color: var(--pcaccent-cl);
	text-shadow: var(--pcbg-cl) 2px 0 0, var(--pcbg-cl) 1.75517px .958851px 0, var(--pcbg-cl) 1.0806px 1.68294px 0, var(--pcbg-cl) .141474px 1.99499px 0, var(--pcbg-cl) -.832294px 1.81859px 0, var(--pcbg-cl) -1.60229px 1.19694px 0, var(--pcbg-cl) -1.97998px .28224px 0, var(--pcbg-cl) -1.87291px -.701566px 0, var(--pcbg-cl) -1.30729px -1.5136px 0, var(--pcbg-cl) -.421592px -1.95506px 0, var(--pcbg-cl) .567324px -1.91785px 0, var(--pcbg-cl) 1.41734px -1.41108px 0, var(--pcbg-cl) 1.92034px -.558831px 0
}
.basecloud:before {
	left: 50%;
	right: auto;
	-webkit-transform: translateX(-50%);
	-ms-transform: translateX(-50%);
	transform: translateX(-50%)
}
.icon-basecloud-bg:after {
	content: "\f07d";
	z-index: 1
}
.icon-cloud-behind:after {
	font-size: .48em;
	content: "\f041";
	position: absolute;
	left: -.2em;
	top: .4em;
	z-index: 1;
	opacity: .6
}
.icon-mist:before {
	content: "\f021";
	position: absolute;
	left: 0;
	right: 0
}
.icon-mist-animi:before {
	content: "\f021";
	position: absolute;
	left: 0;
	right: 0;
	display: none
}
.is-animated .icon-thunder-animi:before {
	-webkit-animation: flashing 2s ease-out infinite;
	animation: flashing 2s ease-out infinite
}
.is-animated .icon-thunder-animi:after {
	-webkit-animation: flashing-reverse 2s steps(1) infinite;
	animation: flashing-reverse 2s steps(1) infinite
}
.is-animated .icon-rainy-animi:after {
	-webkit-animation: rain-animi-effect .2s ease-out infinite;
	animation: rain-animi-effect .2s ease-out infinite
}
.is-animated .icon-rainy-animi-2:after {
	-webkit-animation: rain-animi-effect .25s ease-out infinite;
	animation: rain-animi-effect .25s ease-out infinite
}
.is-animated .icon-rainy-animi-4:after {
	-webkit-animation: rain-animi-effect .35s ease-out infinite;
	animation: rain-animi-effect .35s ease-out infinite
}
.is-animated .icon-rainy-animi-5:after {
	-webkit-animation: rain-animi-effect .4s ease-out infinite;
	animation: rain-animi-effect .4s ease-out infinite
}
.is-animated .drizzle-icons .icon-rainy-animi:after {
	-webkit-animation: drizzle-animi-effect 2.2s ease-out infinite;
	animation: drizzle-animi-effect 2.2s ease-out infinite
}
.is-animated .drizzle-icons .icon-rainy-animi-2:after {
	-webkit-animation: drizzle-animi-effect 2.3s ease-out infinite;
	animation: drizzle-animi-effect 2.3s ease-out infinite
}
.is-animated .drizzle-icons .icon-rainy-animi-4:after {
	-webkit-animation: drizzle-animi-effect 2.5s ease-out infinite;
	animation: drizzle-animi-effect 2.5s ease-out infinite
}
.is-animated .drizzle-icons .icon-rainy-animi-5:after {
	-webkit-animation: drizzle-animi-effect 2.6s ease-out infinite;
	animation: drizzle-animi-effect 2.6s ease-out infinite
}
.is-animated .showers-icons .icon-rainy-animi:after {
	-webkit-animation: drizzle-animi-effect .2s ease-out infinite;
	animation: drizzle-animi-effect .2s ease-out infinite
}
.is-animated .showers-icons .icon-rainy-animi-2:after {
	-webkit-animation: drizzle-animi-effect .23s ease-out infinite;
	animation: drizzle-animi-effect .23s ease-out infinite
}
.is-animated .showers-icons .icon-rainy-animi-4:after {
	-webkit-animation: drizzle-animi-effect .18s ease-out infinite;
	animation: drizzle-animi-effect .18s ease-out infinite
}
.is-animated .showers-icons .icon-rainy-animi-5:after {
	-webkit-animation: drizzle-animi-effect .44s ease-out infinite;
	animation: drizzle-animi-effect .44s ease-out infinite
}
.is-animated .icon-windysnow-animi-2:after,
.is-animated .icon-windysnow-animi:after {
	-webkit-animation: rain-animi-effect-with-rotate 2s ease-out infinite;
	animation: rain-animi-effect-with-rotate 2s ease-out infinite
}
.is-animated .icon-windysnow-animi-2:after {
	-webkit-animation: rain-animi-effect-with-rotate 1.5s ease-out infinite;
	animation: rain-animi-effect-with-rotate 1.5s ease-out infinite
}
.is-animated .icon-moon:after {
	-webkit-animation: penci-float-y 2s linear infinite;
	animation: penci-float-y 2s linear infinite
}
.is-animated .icon-moon-animi:before {
	-webkit-animation: penci-float-y 2s linear infinite;
	animation: penci-float-y 2s linear infinite
}
.is-animated .icon-sun:after {
	-webkit-animation: penci-spin 8s infinite linear;
	animation: penci-spin 8s infinite linear
}
.is-animated .icon-sun-animi:after {
	-webkit-animation: penci-spin 8s infinite linear;
	animation: penci-spin 8s infinite linear
}
.is-animated .icon-cloud-behind:after {
	-webkit-animation: passing 2s linear infinite;
	animation: passing 2s linear infinite
}
.is-animated .icon-mist:before {
	-webkit-animation: penci-float-x 2s infinite ease;
	animation: penci-float-x 2s infinite ease
}
.is-animated .icon-mist-animi:before {
	display: inline-block;
	-webkit-animation: burst 2s infinite linear;
	animation: burst 2s infinite linear
}
.penci-weather-widget .icon-basecloud-bg:after {
	color: #1db523
}
@-webkit-keyframes rain-animi-effect {
	0% {
		opacity: 1
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(3em);
		transform: translateY(3em)
	}
}
@keyframes rain-animi-effect {
	0% {
		opacity: 1
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(3em);
		transform: translateY(3em)
	}
}
@-webkit-keyframes rain-animi-effect-with-rotate {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0) rotate(0);
		transform: translateY(0) rotate(0)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(1em) rotate(360deg);
		transform: translateY(1em) rotate(360deg)
	}
}
@keyframes rain-animi-effect-with-rotate {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0) rotate(0);
		transform: translateY(0) rotate(0)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(1em) rotate(360deg);
		transform: translateY(1em) rotate(360deg)
	}
}
@-webkit-keyframes drizzle-animi-effect {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0) translateX(0) rotate(10deg);
		transform: translateY(0) translateX(0) rotate(10deg)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(3em) translateX(-3em) rotate(20deg);
		transform: translateY(3em) translateX(-3em) rotate(20deg)
	}
}
@keyframes drizzle-animi-effect {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0) translateX(0) rotate(10deg);
		transform: translateY(0) translateX(0) rotate(10deg)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(3em) translateX(-3em) rotate(20deg);
		transform: translateY(3em) translateX(-3em) rotate(20deg)
	}
}
@-webkit-keyframes penci-float-y {
	0% {
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	50% {
		-webkit-transform: translateY(-6px);
		transform: translateY(-6px)
	}
	100% {
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@keyframes penci-float-y {
	0% {
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	50% {
		-webkit-transform: translateY(-6px);
		transform: translateY(-6px)
	}
	100% {
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@-webkit-keyframes penci-spin {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg)
	}
}
@keyframes penci-spin {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg)
	}
}
@-webkit-keyframes passing {
	0% {
		-webkit-transform: translateX(50%);
		transform: translateX(50%);
		opacity: 0
	}
	50% {
		-webkit-transform: translateX(0);
		transform: translateX(0);
		opacity: 1
	}
	100% {
		-webkit-transform: translateX(-50%);
		transform: translateX(-50%);
		opacity: 0
	}
}
@keyframes passing {
	0% {
		-webkit-transform: translateX(50%);
		transform: translateX(50%);
		opacity: 0
	}
	50% {
		-webkit-transform: translateX(0);
		transform: translateX(0);
		opacity: 1
	}
	100% {
		-webkit-transform: translateX(-50%);
		transform: translateX(-50%);
		opacity: 0
	}
}
@-webkit-keyframes burst {
	0% {
		opacity: .6
	}
	50% {
		-webkit-transform: scale(1.8);
		transform: scale(1.8);
		opacity: 0
	}
	100% {
		opacity: 0
	}
}
@keyframes burst {
	0% {
		opacity: .6
	}
	50% {
		-webkit-transform: scale(1.8);
		transform: scale(1.8);
		opacity: 0
	}
	100% {
		opacity: 0
	}
}
@-webkit-keyframes penci-float-x {
	0% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	50% {
		-webkit-transform: translateX(-6px);
		transform: translateX(-6px)
	}
	100% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@keyframes penci-float-x {
	0% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	50% {
		-webkit-transform: translateX(-6px);
		transform: translateX(-6px)
	}
	100% {
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@-webkit-keyframes flashing {
	0%,
	100%,
	50% {
		opacity: 1
	}
	25%,
	75% {
		opacity: 0
	}
}
@keyframes flashing {
	0%,
	100%,
	50% {
		opacity: 1
	}
	25%,
	75% {
		opacity: 0
	}
}
@-webkit-keyframes flashing-reverse {
	0%,
	100%,
	50% {
		opacity: 0
	}
	25%,
	75% {
		opacity: 1
	}
}
@keyframes flashing-reverse {
	0%,
	100%,
	50% {
		opacity: 0
	}
	25%,
	75% {
		opacity: 1
	}
}
span.penci-wuser-gps {
	position: absolute;
	top: 0;
	right: 0;
	opacity: .5;
	cursor: pointer
}
span.penci-wuser-gps svg {
	width: 30px;
	height: 30px
}
.penci-pricing-item {
	color: #888;
	text-align: center;
	padding: 20px;
	font-size: 15px;
	box-sizing: content-box;
	overflow: hidden;
	position: relative
}
.penci-pricing_featured.penci-pricing-f-hheight {
	padding-top: 50px;
	padding-bottom: 50px;
	transform: translateY(-30px);
	position: relative
}
@media (min-width:768px) {
	.penci-pricing_featured.penci-pricing-f-scale {
		background: var(--pcbg-cl);
		transform: scale(1.15);
		-webkit-transform: scale(1.15);
		position: relative;
		z-index: 3
	}
}
.penci-pricing_featured .penci-pricing-ribbon {
	position: absolute;
	height: 60px;
	width: 38px;
	background: var(--pcaccent-cl);
	color: #fff;
	border-bottom-left-radius: 20px;
	border-bottom-right-radius: 20px;
	right: 15px;
	top: 0;
	padding-bottom: 15px;
	display: flex;
	align-items: flex-end;
	justify-content: center;
	font-size: 18px;
	z-index: 5
}
.penci-pricing_featured .penci-pricing-ribbon-text {
	position: absolute;
	top: 18px;
	right: -67px;
	padding: 4px 0;
	width: 200px;
	background-color: #ff6618;
	color: #fff;
	transform: rotate(40deg);
	text-align: center;
	font-size: 12px;
	line-height: 1.3em;
	z-index: 5;
	text-transform: uppercase;
	font-family: var(--pchead-font)
}
.penci-pricing-item.penci-pricing-s1 {
	border: 1px solid var(--pcborder-cl)
}
.penci-pricing-item.penci-pricing-s2 {
	box-shadow: 0 15px 30px 0 rgba(0, 0, 0, .1);
	background-color: #ffff;
	border-radius: 15px
}
.penci-pricing-item.penci-pricing-s2 .penci-pricing-btn {
	border-radius: 10px
}
.penci-pricing-item:after {
	content: "";
	display: table;
	width: 100%
}
.penci-pricing-item .penci-pricing-inner {
	position: relative
}
.penci-pricing-item .penci-pricing-image {
	width: 150px;
	text-align: center;
	margin: 0 auto 20px;
	overflow: hidden
}
.penci-pricing-item .penci-pricing-image img {
	height: auto;
	display: inline-block;
	vertical-align: top
}
.penci-pricing-item .penci-pricing-icon {
	text-align: center;
	font-size: 50px;
	margin-bottom: 20px;
	line-height: 1
}
.penci-pricing-item .penci-pricing-icon i {
	font-size: inherit;
	color: inherit;
	display: inline-block;
	vertical-align: top
}
.penci-pricing-item .penci-pricing-header {
	margin-bottom: 20px
}
.penci-pricing-fheader .penci-pricing-header {
	margin-top: -20px;
	margin-right: -20px;
	margin-left: -20px;
	padding: 20px 0;
	background: #fff000
}
.penci-pricing_featured.penci-pricing-f-hheight.penci-pricing-fheader .penci-pricing-header {
	padding-top: 50px;
	margin-top: -50px
}
.penci-pricing-item .penci-pricing-title {
	font-size: 36px;
	font-weight: 700;
	line-height: 1
}
.penci-pricing-item .penci-pricing-subtitle {
	color: #888;
	line-height: 1.3;
	margin-top: 10px
}
.penci-pricing-item .penci-price-unit,
.penci-pricing-item .penci-pricing-title {
	color: #111
}
.penci-pricing-item .penci-pricing-price {
	font-size: 48px;
	line-height: 1;
	display: inline-block
}
.penci-pricing-item .penci-pricing-unit {
	display: block
}
.penci-pricing-oneline .penci-pricing-unit {
	display: inline-block
}
.penci-pricing-item .penci-pricing-featured {
	margin-top: 20px;
	margin-bottom: 30px;
	font-size: 16px
}
.penci-pricing-btn-above .penci-pricing-featured {
	margin-bottom: 5px
}
.penci-pricing-btn-above .penci-pricing-pbutton {
	margin-top: 20px
}
.penci-pricing-item .penci-pricing-featured ol,
.penci-pricing-item .penci-pricing-featured ul {
	margin: 0;
	padding: 0
}
.penci-pricing-item .penci-pricing-featured li {
	margin-left: 0;
	list-style: none;
	margin-bottom: 10px
}
.penci-pricing-item .penci-pricing-featured a,
.penci-pricing-item .penci-pricing-featured div,
.penci-pricing-item .penci-pricing-featured li,
.penci-pricing-item .penci-pricing-featured ol,
.penci-pricing-item .penci-pricing-featured p,
.penci-pricing-item .penci-pricing-featured span,
.penci-pricing-item .penci-pricing-featured strong,
.penci-pricing-item .penci-pricing-featured ul {
	font-size: inherit;
	font-family: inherit;
	font-weight: inherit;
	letter-spacing: inherit;
	text-transform: inherit;
	font-style: inherit;
	text-decoration: inherit;
	line-height: 1.3
}
.penci-pricing-item .penci-pricing-featured li:last-child {
	margin-bottom: 0
}
.penci-pricing-item .penci-pricing-btn {
	display: block;
	width: 100%;
	font-size: 15px;
	box-sizing: border-box;
	max-width: 100%;
	text-decoration: none !important;
	margin-left: auto;
	margin-right: auto;
	color: #fff
}
.penci-pricing-btn-borders .penci-pricing-btn {
	background: 0 0 !important;
	border: 2px solid;
	color: var(--pctext-cl)
}
.penci-pricing-btn-borders .penci-pricing-btn:hover {
	border-color: var(--pcaccent-cl);
	color: var(--pcaccent-cl)
}
@media (max-width:767px) {
	.penci-pricing_featured.penci-pricing-f-hheight {
		transform: translateY(0);
		padding-top: 20px;
		padding-bottom: 20px
	}
	.penci-pricing_featured.penci-pricing-f-hheight.penci-pricing-fheader .penci-pricing-header {
		padding-top: 20px;
		margin-top: -20px
	}
}
.pcbtn-wrapper {
	display: block
}
.pcbtn-align-left {
	text-align: left
}
.pcbtn-align-center {
	text-align: center
}
.pcbtn-align-right {
	text-align: right
}
.pcbtn-wrapper a.pcbtn {
	display: inline-block;
	text-decoration: none;
	background: #f2f2f2;
	color: #333;
	position: relative;
	font-family: var(--pchead-font);
	font-size: 16px;
	vertical-align: top;
	transition: color .3s, transform .3s
}
.pcbtn-wrapper a.pcbtn:before {
	content: "";
	z-index: 1;
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	width: 100%;
	height: 100%;
	display: block;
	opacity: 0;
	transition: all .3s
}
.pcbtn-wrapper a.pcbtn:hover:before {
	opacity: 1
}
.pcbtn-bordered .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bordered:before {
	border: 2px solid
}
.pcbtn-bstyle-dotted .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-dotted:before {
	border-style: dotted
}
.pcbtn-bstyle-dashed .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-dashed:before {
	border-style: dashed
}
.pcbtn-bstyle-double .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-double:before {
	border-style: double
}
.pcbtn-bstyle-groove .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-groove:before {
	border-style: groove
}
.pcbtn-bstyle-ridge .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-ridge:before {
	border-style: ridge
}
.pcbtn-bstyle-inset .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-inset:before {
	border-style: inset
}
.pcbtn-bstyle-outset .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-outset:before {
	border-style: outset
}
.pcbtn-bstyle-gradient .pcbtn-wrapperin,
.pcbtn-wrapper a.pcbtn-bstyle-gradient:before {
	border-image: linear-gradient(360deg, var(--pcaccent-cl), #bbb);
	border-image: -webkit-linear-gradient(360deg, var(--pcaccent-cl), #bbb);
	border-image-slice: 1
}
.pcbtn-align-justify a.pcbtn {
	display: block;
	width: 100%
}
@media (max-width:1024px) {
	.pcbtn-talign-left {
		text-align: left
	}
	.pcbtn-talign-center {
		text-align: center
	}
	.pcbtn-talign-right {
		text-align: right
	}
	.pcbtn-talign-center a.pcbtn,
	.pcbtn-talign-left a.pcbtn,
	.pcbtn-talign-right a.pcbtn {
		width: auto;
		display: inline-block
	}
	.pcbtn-talign-justify a.pcbtn {
		display: block;
		width: 100%
	}
}
@media (max-width:767px) {
	.pcbtn-malign-left {
		text-align: left
	}
	.pcbtn-malign-center {
		text-align: center
	}
	.pcbtn-malign-right {
		text-align: right
	}
	.pcbtn-malign-center a.pcbtn,
	.pcbtn-malign-left a.pcbtn,
	.pcbtn-malign-right a.pcbtn {
		width: auto;
		display: inline-block
	}
	.pcbtn-malign-justify a.pcbtn {
		display: block;
		width: 100%
	}
}
.pcbtn-wrapperin {
	text-align: center;
	padding: 10px 20px;
	display: block
}
.pcbtn-align-justify .pcbtn-wrapperin,
.pcbtn-align-justify .pcbtn-wrapperin span {
	width: 100%
}
.pcbtn-content svg {
	width: 16px;
	height: auto;
	vertical-align: middle;
	transition: fill .3s
}
.pcbtn-icon-left span span i,
.pcbtn-icon-left span span svg {
	margin-right: 5px
}
.pcbtn-icon-right span span i,
.pcbtn-icon-right span span svg {
	margin-left: 5px
}
.pcbtn-wrapperin span {
	display: block;
	line-height: 1.3
}
.pcbtn-wrapperin span.pcbtn-content {
	text-transform: uppercase;
	font-weight: 500;
	z-index: 5;
	position: relative;
	transition: all .3s
}
.pcbtn-wrapperin span.pcbtn-subtext {
	margin: 5px 0 0 0;
	font-size: 12px;
	z-index: 5;
	position: relative
}
.penci-ctslide-wrap {
	height: 400px;
	position: relative
}
.penci-ctslide-wrap:before {
	display: block;
	width: 100%;
	background: 0 0 !important;
	box-shadow: none !important
}
.penci-custom-slide {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0
}
.penci-ctslide-inner {
	height: 100%;
	width: 100%;
	z-index: 10
}
.penci-ctslide-bg,
.penci-ctslider-bg-overlay {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 10;
	-webkit-background-size: cover;
	background-size: cover;
	background-position: center;
	background-repeat: no-repeat;
	min-width: 100%;
	min-height: 100%;
	-webkit-transition-property: -webkit-transform;
	transition-property: -webkit-transform;
	-o-transition-property: transform;
	transition-property: transform;
	transition-property: transform, -webkit-transform;
	-webkit-transition-duration: 10s;
	-o-transition-duration: 10s;
	transition-duration: 10s
}
.penci-ctslider-featimg {
	position: absolute;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 15;
	background: 0 0 !important
}
.penci-ctslide-inner,
.penci-ctslider-content {
	position: relative;
	z-index: 50
}
.penci-ctslide-inner {
	display: flex
}
.penci-slides-wrap .owl-item.active .penci-ctslide-bg {
	-webkit-animation-timing-function: linear;
	animation-timing-function: linear;
	-webkit-animation-duration: 20s;
	animation-duration: 20s
}
.penci-slides-wrap .owl-item.active .penci-ctslide-bg.penci-ctslider-ken-in {
	-webkit-transform: scale(1.2);
	-ms-transform: scale(1.2);
	transform: scale(1.2);
	-webkit-animation-name: penci-ken-burns-in;
	animation-name: penci-ken-burns-in
}
.penci-slides-wrap .owl-item.active .penci-ctslide-bg.penci-ctslider-ken-out {
	-webkit-transform: scale(1);
	-ms-transform: scale(1);
	transform: scale(1);
	-webkit-animation-name: penci-ken-burns-out;
	animation-name: penci-ken-burns-out
}
.penci-slides-wrap .penci-ctslider-content {
	padding: 30px;
	width: 100%
}
.penci-v-poswrap-top .penci-ctslide-inner {
	-webkit-box-align: start;
	-webkit-align-items: flex-start;
	-ms-flex-align: start;
	align-items: flex-start
}
.penci-v-poswrap-bottom .penci-ctslide-inner {
	-webkit-box-align: end;
	-webkit-align-items: flex-end;
	-ms-flex-align: end;
	align-items: flex-end
}
.penci-v-poswrap-middle .penci-ctslide-inner {
	-webkit-box-align: center;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center
}
.penci-h-poswrap-left .penci-ctslide-inner {
	-webkit-box-pack: start;
	-webkit-justify-content: flex-start;
	-ms-flex-pack: start;
	justify-content: flex-start
}
.penci-h-poswrap-right .penci-ctslide-inner {
	-webkit-box-pack: end;
	-webkit-justify-content: flex-end;
	-ms-flex-pack: end;
	justify-content: flex-end
}
.penci-h-poswrap-center .penci-ctslide-inner {
	-webkit-box-pack: center;
	-webkit-justify-content: center;
	-ms-flex-pack: center;
	justify-content: center
}
.xpenci-slides-wrap div:not(.lslide)>.penci-ctslide-inner {
	display: none
}
.penci-slides-wrap .pencislider-caption,
.penci-slides-wrap .pencislider-title {
	color: #fff
}
.penci-slides-wrap .penci-slider_btnwrap,
.penci-slides-wrap .pencislider-caption,
.penci-slides-wrap .pencislider-title {
	opacity: 0;
	-webkit-animation-fill-mode: both;
	-moz-animation-fill-mode: both;
	-ms-animation-fill-mode: both;
	-o-animation-fill-mode: both;
	animation-fill-mode: both;
	-webkit-animation-duration: .65s;
	-moz-animation-duration: .65s;
	-ms-animation-duration: .65s;
	-o-animation-duration: .65s;
	animation-duration: .65s
}
.penci-slides-wrap .pencislider-title {
	font-size: 30px;
	line-height: 1.2em;
	text-transform: uppercase;
	margin: 0 0 15px 0
}
.penci-slides-wrap .pencislider-caption {
	font-size: 16px;
	line-height: 1.4;
	margin: 0 0 25px 0
}
.penci-slides-wrap .penci-ctslider-content>:nth-child(1) {
	animation-delay: calc(var(--pcfs-delay) + .3s)
}
.penci-slides-wrap .penci-ctslider-content>:nth-child(2) {
	animation-delay: calc(var(--pcfs-delay) + .5s)
}
.penci-slides-wrap .penci-ctslider-content>:nth-child(3) {
	animation-delay: calc(var(--pcfs-delay) + .7s)
}
.penci-slides-wrap .pencislider-caption-overlay .pslider-bgoverlay-inner,
.penci-slides-wrap .pencislider-title-overlay .pslider-bgoverlay-inner {
	position: relative;
	padding: 5px 12px;
	display: inline-block;
	vertical-align: top
}
.penci-slides-wrap .pencislider-caption-overlay .pslider-bgoverlay-inner:before,
.penci-slides-wrap .pencislider-title-overlay .pslider-bgoverlay-inner:before {
	content: "";
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	left: 0
}
.penci-slides-wrap .pencislider-caption-overlay .pslider-bgoverlay-inner span,
.penci-slides-wrap .pencislider-title-overlay .pslider-bgoverlay-inner span {
	position: relative;
	z-index: 10;
	padding: 0;
	margin: 0
}
.penci-slides-wrap .penci-slider_btnwrap {
	margin: 0;
	background: 0 0;
	padding: 0;
	vertical-align: top;
	animation-delay: 1.3s;
	-webkit-animation-delay: 1.3s
}
.penci-slider_btnwrap .pencislider-btn {
	display: inline-block;
	background: 0 0;
	border: 1px solid #fff;
	color: #fff;
	line-height: 1;
	height: 36px;
	padding: 0 20px;
	border-radius: 0;
	font-size: 12px;
	font-weight: 600;
	width: auto
}
.penci-slider_btnwrap .pencislider-btn>span {
	width: 100%;
	height: 100%;
	display: flex;
	justify-content: center;
	align-items: center;
	white-space: nowrap
}
.penci-slider_btnwrap .pencislider-btn:hover {
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	color: #fff;
	text-decoration: none
}
.penci-slider_btnwrap .pencislider-btn:not(:last-child) {
	margin-right: 15px
}
@keyframes penci-ken-burns-in {
	0% {
		transform: scale(1)
	}
	100% {
		transform: scale(1.2)
	}
}
@keyframes penci-ken-burns-out {
	0% {
		transform: scale(1.2)
	}
	100% {
		transform: scale(1)
	}
}
.penci-slides-wrap .active .penci-fadeInDown .penci-slider_btnwrap,
.penci-slides-wrap .active .penci-fadeInDown .pencislider-caption,
.penci-slides-wrap .active .penci-fadeInDown .pencislider-title {
	-webkit-animation-name: pencifadeInDown;
	-moz-animation-name: pencifadeInDown;
	-o-animation-name: pencifadeInDown;
	animation-name: pencifadeInDown
}
.penci-slides-wrap .active .penci-fadeInUp .penci-slider_btnwrap,
.penci-slides-wrap .active .penci-fadeInUp .pencislider-caption,
.penci-slides-wrap .active .penci-fadeInUp .pencislider-title {
	-webkit-animation-name: pencifadeInUp;
	-moz-animation-name: pencifadeInUp;
	-o-animation-name: pencifadeInUp;
	animation-name: pencifadeInUp
}
.penci-slides-wrap .active .penci-fadeInLeft .penci-slider_btnwrap,
.penci-slides-wrap .active .penci-fadeInLeft .pencislider-caption,
.penci-slides-wrap .active .penci-fadeInLeft .pencislider-title {
	-webkit-animation-name: pencifadeInLeft;
	-moz-animation-name: pencifadeInLeft;
	-o-animation-name: pencifadeInLeft;
	animation-name: pencifadeInLeft
}
.penci-slides-wrap .active .penci-fadeInRight .penci-slider_btnwrap,
.penci-slides-wrap .active .penci-fadeInRight .pencislider-caption,
.penci-slides-wrap .active .penci-fadeInRight .pencislider-title {
	-webkit-animation-name: pencifadeInRight;
	-moz-animation-name: pencifadeInRight;
	-o-animation-name: pencifadeInRight;
	animation-name: pencifadeInRight
}
@-webkit-keyframes pencifadeInUp {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInUp {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, 40px, 0);
		transform: translate3d(0, 40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-webkit-keyframes pencifadeInLeft {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-50px, 0, 0);
		transform: translate3d(-50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInLeft {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(-50px, 0, 0);
		transform: translate3d(-50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-webkit-keyframes pencifadeInRight {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(50px, 0, 0);
		transform: translate3d(50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInRight {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(50px, 0, 0);
		transform: translate3d(50px, 0, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@-webkit-keyframes pencifadeInDown {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -40px, 0);
		transform: translate3d(0, -40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes pencifadeInDown {
	0% {
		opacity: 0;
		-webkit-transform: translate3d(0, -40px, 0);
		transform: translate3d(0, -40px, 0)
	}
	100% {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
.popUpfadeInDown {
	animation-name: fadeInDown
}
@keyframes fadeInDown {
	from {
		opacity: 0;
		transform: translate3d(0, -100%, 0)
	}
	to {
		opacity: 1;
		transform: none
	}
}
@keyframes popUpfadeInDown {
	from {
		opacity: 0;
		transform: translate3d(0, -80px, 0)
	}
	to {
		opacity: 1;
		transform: none
	}
}
.penci-page-header-wrap {
	background: #dfdfdf;
	color: #111;
	overflow: hidden;
	padding-top: 80px;
	padding-bottom: 80px;
	margin-bottom: 60px;
	background-size: cover;
	background-position: center center;
	background-repeat: no-repeat;
	text-align: center
}
.penci-body-epageheader #header,
.penci-body-epageheader .penci-header-signup-form {
	margin-bottom: 0;
	margin-top: 0
}
.penci-page-header-wrap .container.penci-breadcrumb {
	margin-top: 0;
	width: 100%;
	margin-bottom: 0
}
.penci-page-header-wrap .penci-page-header-title {
	position: relative;
	text-transform: uppercase;
	font-size: 30px;
	font-weight: 600;
	color: #111;
	line-height: 1;
	padding: 0 0 14px;
	margin: 0 0 23px
}
.penci-page-header-wrap .penci-page-header-title:before {
	content: "";
	position: absolute;
	border-top: 2px solid;
	width: 40px;
	bottom: 0;
	left: 50%;
	color: inherit;
	opacity: .2;
	margin-left: -20px
}
.penci-page-header-wrap.penci-phhide-bread .penci-page-header-title {
	margin-bottom: 0 !important
}
.penci-page-header-wrap.penci-phhide-line .penci-page-header-title {
	padding-bottom: 0 !important
}
.penci-page-header-wrap.penci-phhide-line .penci-page-header-title:before {
	content: none
}
.penci-page-header-wrap.penci-pheader-left {
	text-align: left
}
.penci-page-header-wrap.penci-pheader-left .penci-page-header-title:before {
	left: 0;
	margin-left: 0
}
.penci-page-header-wrap.penci-pheader-center {
	text-align: center
}
.penci-page-header-wrap.penci-pheader-center .penci-page-header-title:before {
	left: 50%;
	margin-left: -20px
}
.penci-page-header-wrap.penci-pheader-right {
	text-align: right
}
.penci-page-header-wrap.penci-pheader-right .penci-page-header-title:before {
	left: auto;
	right: 0
}
.penci-latest-posts-left .grid-header-box,
.penci-latest-posts-left .header-list-style,
.penci-latest-posts-left .header-standard {
	text-align: left
}
.penci-latest-posts-left .grid-header-box:after,
.penci-latest-posts-left .header-list-style:after,
.penci-latest-posts-left .header-standard.standard-overlay-meta:after,
.penci-latest-posts-left .header-standard:after,
.penci-latest-posts-left .list-post .header-list-style:after,
.penci-latest-posts-left .list-post.list-boxed-post .header-list-style:after,
.penci-latest-posts-left.penci-latest-posts-mixed .grid-header-box:after {
	left: 0;
	margin-left: 0;
	right: auto
}
.penci-latest-posts-left .header-standard.standard-overlay-meta {
	padding-left: 20px !important;
	padding-right: 10px
}
.penci-latest-posts-left .header-standard.standard-overlay-meta:after {
	left: 20px;
	right: auto
}
.penci-latest-posts-left .grid-overlay-meta .grid-header-box {
	padding-left: 10px;
	padding-right: 5px
}
.container .penci-latest-posts-left .penci-grid li.magazine-layout.grid-overlay-meta .grid-header-box:after,
.penci-latest-posts-left .grid-overlay-meta .grid-header-box:after {
	left: 10px;
	right: auto
}
.penci-latest-posts-left.penci-latest-posts-grid .grid-overlay-meta .grid-header-box,
.penci-latest-posts-left.penci-latest-posts-grid-2 .grid-overlay-meta .grid-header-box {
	margin-left: 0;
	padding-left: 0
}
.penci-latest-posts-right.penci-latest-posts-grid .grid-overlay-meta .grid-header-box,
.penci-latest-posts-right.penci-latest-posts-grid-2 .grid-overlay-meta .grid-header-box {
	margin-right: 0;
	padding-right: 0
}
.penci-latest-posts-center .grid-header-box,
.penci-latest-posts-center .header-list-style,
.penci-latest-posts-center .header-standard {
	text-align: center
}
.penci-latest-posts-center .grid-header-box:after,
.penci-latest-posts-center .header-list-style:after,
.penci-latest-posts-center .header-standard.standard-overlay-meta:after,
.penci-latest-posts-center .header-standard:after,
.penci-latest-posts-center .list-post .header-list-style:after,
.penci-latest-posts-center .list-post.list-boxed-post .header-list-style:after,
.penci-latest-posts-center.penci-latest-posts-mixed .grid-header-box:after {
	left: 50%;
	right: auto;
	margin-left: -30px
}
.penci-latest-posts-center .header-standard.standard-overlay-meta {
	padding-left: 10px;
	padding-right: 10px
}
.penci-latest-posts-right .grid-header-box,
.penci-latest-posts-right .header-list-style,
.penci-latest-posts-right .header-standard {
	text-align: right
}
.penci-latest-posts-right .grid-header-box:after,
.penci-latest-posts-right .header-list-style:after,
.penci-latest-posts-right .header-standard.standard-overlay-meta:after,
.penci-latest-posts-right .header-standard:after,
.penci-latest-posts-right .list-post .header-list-style:after,
.penci-latest-posts-right .list-post.list-boxed-post .header-list-style:after,
.penci-latest-posts-right.penci-latest-posts-mixed .grid-header-box:after {
	left: auto;
	margin-left: 0;
	right: 0;
	margin-right: 0
}
.penci-latest-posts-right .grid-overlay-meta .grid-header-box {
	padding-right: 10px;
	padding-left: 5px
}
.container .penci-latest-posts-right .penci-grid li.magazine-layout.grid-overlay-meta .grid-header-box:after,
.penci-latest-posts-right .grid-overlay-meta .grid-header-box:after {
	left: auto;
	right: 10px
}
.penci-latest-posts-right .header-standard.standard-overlay-meta {
	padding-left: 10px;
	padding-right: 20px !important
}
.penci-latest-posts-right .header-standard.standard-overlay-meta:after {
	left: auto;
	right: 20px
}
.penci-grid-excerpt-left .penci-featured-infor .item-content,
.penci-grid-excerpt-left .penci-grid .grid-mixed .mixed-detail .item-content,
.penci-grid-excerpt-left .penci-grid li .item .item-content,
.penci-grid-excerpt-left .penci-masonry .item-masonry .item-content,
.penci-std-continue-left .penci-more-link,
.penci-std-excerpt-left .penci-grid .mixed-detail .item-content,
.penci-std-excerpt-left .standard-main-content {
	text-align: left
}
.penci-grid-excerpt-center .penci-featured-infor .item-content,
.penci-grid-excerpt-center .penci-grid .grid-mixed .mixed-detail .item-content,
.penci-grid-excerpt-center .penci-grid li .item .item-content,
.penci-grid-excerpt-center .penci-masonry .item-masonry .item-content,
.penci-std-continue-center .penci-more-link,
.penci-std-excerpt-center .penci-grid .mixed-detail .item-content,
.penci-std-excerpt-center .standard-main-content {
	text-align: center
}
.penci-grid-excerpt-right .penci-featured-infor .item-content,
.penci-grid-excerpt-right .penci-grid .grid-mixed .mixed-detail .item-content,
.penci-grid-excerpt-right .penci-grid li .item .item-content,
.penci-grid-excerpt-right .penci-masonry .item-masonry .item-content,
.penci-std-continue-right .penci-more-link,
.penci-std-excerpt-right .penci-grid .mixed-detail .item-content,
.penci-std-excerpt-right .standard-main-content {
	text-align: right
}
.penci-std-continue-left .penci-more-link a.more-link:before,
.penci-std-continue-right .penci-more-link a.more-link:after {
	content: none
}
.penci-std-continue-center .penci-more-link a.more-link:after,
.penci-std-continue-center .penci-more-link a.more-link:before,
.penci-std-continue-left .penci-more-link a.more-link:after,
.penci-std-continue-right .penci-more-link a.more-link:before {
	content: ""
}
@media only screen and (max-width:1400px) and (min-width:961px) {
	.penci-two-sidebar .container.penci-breadcrumb {
		width: 100%;
		padding: 0 10px
	}
}
@media only screen and (max-width:960px) and (min-width:768px) {
	.penci-two-sidebar .container.penci-breadcrumb {
		width: 726px
	}
}
@media only screen and (max-width:767px) and (min-width:480px) {
	.penci-two-sidebar .container.penci-breadcrumb {
		width: 480px
	}
}
@media only screen and (max-width:479px) {
	.penci-two-sidebar .container.penci-breadcrumb {
		width: 100%
	}
	.penci-slides-wrap .penci-ctslider-content {
		padding: 10px
	}
	.btn-twoline .penci-slider_btnwrap {
		white-space: pre-line
	}
	.btn-twoline .penci-slider_btnwrap .pencislider-btn:not(:last-child) {
		margin-right: 0 !important
	}
	.btn-twoline .penci-slider_btnwrap .pencislider-btn.pencislider-btn-2 {
		margin-top: 15px
	}
}
@media only screen and (min-width:768px) {
	.penci-latest-posts-el.penci-latest-posts-boxed-1 .list-boxed-post .item,
	.penci-latest-posts-el.penci-latest-posts-standard-boxed-1 .list-boxed-post .item {
		display: flex;
		flex-wrap: wrap;
		align-items: center;
		justify-content: center
	}
	.penci-latest-posts-el.penci-latest-posts-boxed-1 .list-boxed-post .item .content-list-right,
	.penci-latest-posts-el.penci-latest-posts-standard-boxed-1 .list-boxed-post .item .content-list-right {
		height: auto;
		min-height: 0
	}
	.penci-latest-posts-el.penci-latest-posts-boxed-1 .list-boxed-post:nth-child(2n+2) .item .content-list-right,
	.penci-latest-posts-el.penci-latest-posts-standard-boxed-1 .list-boxed-post:nth-of-type(2n+2) .item .content-list-right {
		order: 1
	}
	.penci-latest-posts-el.penci-latest-posts-boxed-1 .list-boxed-post:nth-child(2n+2) .item .thumbnail,
	.penci-latest-posts-el.penci-latest-posts-standard-boxed-1 .list-boxed-post:nth-of-type(2n+2) .item .thumbnail {
		order: 2
	}
}
.penci-latest-posts-el .penci-pagination {
	margin-top: 30px;
	margin-bottom: 0
}
.penci-latest-posts-el.penci-latest-posts-boxed-2 .penci-grid li.list-boxed-post-2:last-child {
	margin-bottom: 0 !important
}
.penci-latest-posts-el.penci-latest-posts-boxed-1 .penci-wrapper-data>.list-boxed-post:last-child,
.penci-latest-posts-el.penci-latest-posts-classic .penci-wrapper-data>article:last-child,
.penci-latest-posts-el.penci-latest-posts-classic-boxed-1 .penci-wrapper-data>.list-boxed-post:last-child,
.penci-latest-posts-el.penci-latest-posts-classic-grid .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-classic-grid-2 .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-classic-list .penci-wrapper-data>.list-post:last-child,
.penci-latest-posts-el.penci-latest-posts-featured .penci-wrapper-data>.grid-featured:last-child,
.penci-latest-posts-el.penci-latest-posts-grid .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-grid-2 .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-list .penci-wrapper-data>.list-post:last-child,
.penci-latest-posts-el.penci-latest-posts-mixed .penci-grid>li:last-child,
.penci-latest-posts-el.penci-latest-posts-mixed-2 .penci-grid>li:last-child,
.penci-latest-posts-el.penci-latest-posts-overlay .penci-wrapper-data>.grid-overlay:last-child,
.penci-latest-posts-el.penci-latest-posts-photography .penci-grid>.typography-style:last-child,
.penci-latest-posts-el.penci-latest-posts-standard .penci-wrapper-data>article:last-child,
.penci-latest-posts-el.penci-latest-posts-standard-boxed-1 .penci-wrapper-data>.list-boxed-post:last-child,
.penci-latest-posts-el.penci-latest-posts-standard-grid .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-standard-grid-2 .penci-wrapper-data>.grid-style:last-child,
.penci-latest-posts-el.penci-latest-posts-standard-list .penci-wrapper-data>.list-post:last-child {
	margin-bottom: 0 !important
}
@media only screen and (min-width:961px) {
	.penci-latest-posts-el.penci-latest-posts-classic-grid .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-classic-grid .penci-wrapper-data>.grid-style:nth-last-of-type(3),
	.penci-latest-posts-el.penci-latest-posts-classic-grid-2 .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-grid .penci-wrapper-data>.grid-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-grid .penci-wrapper-data>.grid-style:nth-last-child(3),
	.penci-latest-posts-el.penci-latest-posts-grid-2 .penci-wrapper-data>.grid-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-mixed .penci-grid>li.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-mixed-2 .penci-grid>li.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-mixed-2.penci-el-mixed-s1 .penci-grid>li.grid-style:nth-last-of-type(3),
	.penci-latest-posts-el.penci-latest-posts-mixed.penci-el-mixed-s1 .penci-grid>li.grid-style:nth-last-of-type(3),
	.penci-latest-posts-el.penci-latest-posts-photography .penci-grid>.typography-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-standard-grid .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-standard-grid .penci-wrapper-data>.grid-style:nth-last-of-type(3),
	.penci-latest-posts-el.penci-latest-posts-standard-grid-2 .penci-wrapper-data>.grid-style:nth-last-of-type(2) {
		margin-bottom: 0 !important
	}
}
@media only screen and (max-width:960px) and (min-width:768px) {
	.penci-latest-posts-el.penci-latest-posts-classic-grid .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-classic-grid-2 .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-grid .penci-wrapper-data>.grid-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-grid-2 .penci-wrapper-data>.grid-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-mixed .penci-grid>li.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-mixed-2 .penci-grid>li.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-photography .penci-grid>.typography-style:nth-last-child(2),
	.penci-latest-posts-el.penci-latest-posts-standard-grid .penci-wrapper-data>.grid-style:nth-last-of-type(2),
	.penci-latest-posts-el.penci-latest-posts-standard-grid-2 .penci-wrapper-data>.grid-style:nth-last-of-type(2) {
		margin-bottom: 0 !important
	}
}
@media only screen and (max-width:1200px) and (min-width:961px) {
	.container.two-sidebar .penci-sidebar-left,
	.layout-12_14_14 .penci-sidebar-left,
	.layout-14_12_14 .penci-sidebar-left,
	.layout-14_14_12 .penci-sidebar-right,
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1 {
		display: none !important
	}
	.container.two-sidebar .penci-sidebar-content,
	.layout-12_14_14 .penci-vc-sidebar,
	.layout-14_12_14 .penci-vc-sidebar,
	.layout-14_14_12 .penci-vc-sidebar,
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3 {
		width: 29.06%
	}
	.layout-14_14_12 .penci-main-content,
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-50.penci-ercol-order-3,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-50.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2 {
		width: 70.94%
	}
	.container.two-sidebar #main,
	.layout-12_14_14 .penci-main-content,
	.layout-14_12_14 .penci-main-content {
		padding-left: 0;
		width: 70.94%
	}
}
@media only screen and (max-width:1200px) and (min-width:768px) {
	.penci-repons-elsection.penci-structure-34 .elementor-row {
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-repons-elsection.penci-structure-34 .elementor-column.elementor-col-16.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-34 .elementor-column.elementor-col-16.penci-ercol-order-3 {
		width: 50%
	}
	.penci-repons-elsection.penci-structure-34 .elementor-column.elementor-col-66.penci-ercol-order-2 {
		width: 100%;
		order: 1
	}
	.penci-repons-elsection.penci-structure-34 .elementor-column.elementor-col-16.penci-ercol-order-3 {
		order: 3
	}
	.penci-repons-elsection.penci-structure-34 .elementor-column.elementor-col-16.penci-ercol-order-1 {
		order: 2
	}
}
@media only screen and (max-width:1400px) {
	.penci-repons-elsection.penci-structure-50 .elementor-row,
	.penci-repons-elsection.penci-structure-60 .elementor-row {
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-repons-elsection.penci-structure-50 .elementor-column.penci-ercol-20,
	.penci-repons-elsection.penci-structure-60 .elementor-column.penci-ercol-16 {
		width: 33.3333%
	}
}
@media only screen and (max-width:1170px) {
	.penci-repons-elsection.penci-structure-40 .elementor-row {
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-repons-elsection.penci-structure-40 .elementor-column.penci-ercol-25,
	.penci-repons-elsection.penci-structure-50 .elementor-column.penci-ercol-20,
	.penci-repons-elsection.penci-structure-60 .elementor-column.penci-ercol-16 {
		width: 50%
	}
}
@media only screen and (max-width:960px) {
	.container.two-sidebar #main,
	.container.two-sidebar .penci-sidebar-content {
		width: 100%
	}
	.container.two-sidebar #main {
		order: 1
	}
	.penci-vc-row .penci-vc-column {
		width: 100%;
		padding-left: 10px;
		padding-right: 10px
	}
	.penci-countdown-show5 .penci-countdown-section,
	.penci-countdown-show6 .penci-countdown-section,
	.penci-countdown-show7 .penci-countdown-section {
		width: 33.33333%
	}
	.penci-image-gallery-s2 .penci-galitem-1 {
		width: 100%;
		float: left
	}
	.penci-image-gallery-s2 .penci-post-smalls {
		width: 100%
	}
	.penci-image-gallery-s2 .penci-post-smalls .penci-gallery-item {
		width: 50%;
		float: left
	}
	.penci-video_playlist .penci-video-nav,
	.penci-video_playlist .penci-video-play {
		width: 100%;
		float: none;
		position: relative
	}
	.penci-video_playlist .penci-video-nav .playlist-panel-item {
		position: absolute;
		bottom: 0;
		left: 0;
		font-size: 10px;
		width: 20px;
		height: 20px;
		text-align: center;
		vertical-align: middle;
		line-height: 20px;
		z-index: 10;
		background: #111;
		color: #fff
	}
	.penci-repons-elsection.penci-structure-21 .elementor-row,
	.penci-repons-elsection.penci-structure-22 .elementor-row,
	.penci-repons-elsection.penci-structure-30 .elementor-row {
		-webkit-flex-wrap: wrap;
		-ms-flex-wrap: wrap;
		flex-wrap: wrap
	}
	.penci-repons-elsection.penci-structure-21 .elementor-column.penci-ercol-33,
	.penci-repons-elsection.penci-structure-21 .elementor-column.penci-ercol-66,
	.penci-repons-elsection.penci-structure-22 .elementor-column.penci-ercol-33,
	.penci-repons-elsection.penci-structure-22 .elementor-column.penci-ercol-66,
	.penci-repons-elsection.penci-structure-30 .elementor-column.penci-ercol-33 {
		width: 100%
	}
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1 {
		display: block;
		width: 50%
	}
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3 {
		width: 50%
	}
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-50.penci-ercol-order-3,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-50.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2 {
		width: 100%
	}
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3 {
		order: 2
	}
	.penci-repons-elsection.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2 {
		order: 1
	}
	.footer-subscribe .mc4wp-form .mdes {
		width: 100%;
		text-align: center;
		margin-left: 0
	}
}
@media only screen and (max-width:767px) {
	#main .penci-repons-elsection .elementor-column {
		width: 100% !important
	}
	#main .penci-repons-elsection .elementor-column:not(:last-child) {
		margin-bottom: 20px
	}
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-col-16+.elementor-column.elementor-col-66>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-col-25+.elementor-col-25+.elementor-col-50>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-col-50+.elementor-col-25+.elementor-col-25>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-col-50+.elementor-col-25>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column.elementor-col-25+.elementor-column.elementor-col-50>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column.elementor-col-33+.elementor-column.elementor-col-66>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column.elementor-col-66>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="16"]+.elementor-column[data-col="66"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="25"]+.elementor-column[data-col="25"]+.elementor-column[data-col="50"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="25"]+.elementor-column[data-col="50"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="33"]+.elementor-column[data-col="66"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="50"]+.elementor-column[data-col="25"]+.elementor-column[data-col="25"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="50"]+.elementor-column[data-col="25"]>.elementor-element-populated,
	.penci-repons-elsection .elementor-column-gap-default>.elementor-row>.elementor-column[data-col="66"]>.elementor-element-populated {
		padding-left: 10px;
		padding-right: 10px
	}
	.penci-countdown-show4 .penci-countdown-section,
	.penci-countdown-show5 .penci-countdown-section,
	.penci-countdown-show6 .penci-countdown-section,
	.penci-countdown-show7 .penci-countdown-section {
		width: 50%
	}
	.penci-con_sb1_sb2.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-con_sb2_sb1.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-sb1_con_sb2.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2,
	.penci-sb1_sb2_con.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-sb2_con_sb1.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2,
	.penci-sb2_sb1_con.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3 {
		order: 2
	}
	.penci-con_sb1_sb2.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-con_sb2_sb1.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-sb1_con_sb2.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-sb1_sb2_con.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2,
	.penci-sb2_con_sb1.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-sb2_sb1_con.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2 {
		order: 3
	}
	.penci-con_sb1_sb2.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2,
	.penci-con_sb2_sb1.penci-structure-33 .elementor-column.elementor-col-50.penci-ercol-order-2,
	.penci-sb1_con_sb2.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-sb1_sb2_con.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-sb2_con_sb1.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-sb2_sb1_con.penci-structure-33 .elementor-column.elementor-col-25.penci-ercol-order-1 {
		order: 1
	}
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-1,
	.penci-repons-elsection.penci-structure-31 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-2,
	.penci-repons-elsection.penci-structure-32 .elementor-column.elementor-col-25.penci-ercol-order-3,
	.penci-repons-elsection.penci-structure-40 .elementor-column.penci-ercol-25,
	.penci-repons-elsection.penci-structure-50 .elementor-column.penci-ercol-20,
	.penci-repons-elsection.penci-structure-60 .elementor-column.penci-ercol-16 {
		width: 100%
	}
	.penci-top-bar .pctopbar-item.penci-topbar-trending {
		display: none;
		padding: 0 10px
	}
}
@media only screen and (max-width:480px) {
	.penci-image-gallery-s2 .penci-post-smalls .penci-gallery-item {
		width: 100%;
		float: left
	}
	.penci-image-gallery-s3 .penci-gallery-big-item,
	.penci-image-gallery-s3 .penci-gallery-small-item,
	.penci-image-gallery-s4 .penci-gallery-big-item,
	.penci-image-gallery-s4 .penci-gallery-small-item {
		width: 100%;
		float: none
	}
}
.penci-grid .pc-hasmorepost,
.penci-grid .pc-nomorepost {
	display: none
}
.penci-grid[data-layout=grid-boxed-2] li .item,
.penci-grid[data-layout=grid-boxed] li .item {
	border: 1px solid var(--pcborder-cl);
	padding: 20px;
	height: 100%
}
.penci-grid[data-layout=grid-boxed-2] li .item {
	padding-bottom: 0
}
.penci-grid[data-layout=grid-boxed-2] li .item>.thumbnail,
.penci-grid[data-layout=grid-boxed] li .item>.thumbnail {
	margin-left: -21px;
	margin-right: -21px;
	margin-top: -21px;
	display: block;
	width: calc(100% + 42px)
}
.penci-grid[data-layout=grid-boxed-2] li .item {
	display: flex;
	flex-wrap: wrap
}
.penci-grid[data-layout=grid-boxed-2] li .item>div {
	order: 1;
	width: 100%
}
.penci-grid[data-layout=grid-boxed-2] li .item>.thumbnail {
	order: 2;
	margin-bottom: 0;
	margin-top: 0;
	align-content: end
}
.penci-grid[data-layout=grid-boxed-2] li .item>.item-content {
	margin-bottom: 30px
}
.penci-grid[data-layout=list-boxed-2] li.list-post,
.penci-grid[data-layout=list-boxed] li.list-post {
	padding-bottom: 0;
	border-bottom: 0
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item,
.penci-grid[data-layout=list-boxed] li.list-post .item {
	border: 1px solid var(--pcborder-cl);
	padding: 20px;
	display: flex;
	flex-wrap: wrap
}
.penci-grid[data-layout=list-boxed] li.list-post .item {
	padding-left: 0;
	border-left: 0
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item {
	padding-right: 0;
	border-right: 0
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item>.thumbnail,
.penci-grid[data-layout=list-boxed] li.list-post .item>.thumbnail {
	margin-top: -21px;
	margin-bottom: -21px
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item>.thumbnail .penci-image-holder,
.penci-grid[data-layout=list-boxed] li.list-post .item>.thumbnail .penci-image-holder {
	height: 100%
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item>div {
	order: 1
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item>.thumbnail {
	order: 2;
	margin-left: 0
}
.penci-grid[data-layout=list-boxed-2] li.list-post .item .content-list-right {
	padding-right: 30px;
	padding-left: 0
}
.penci-grid[data-layout="grid-boxed-3"] li .item {
	--pcheading-cl: #fff;
	--pcmeta-cl: #fff;
	padding: 20px;
	background: var(--pctext-cl);
	color: var(--pcbg-cl);
	position: relative;
	margin-left: 15px;
}
.penci-grid[data-layout="grid-boxed-3"] li.pchide-cat .item {
	margin-left: 0;
}
.penci-grid[data-layout="grid-boxed-3"] li .item .grid-header-box {
	position: static;
}
.penci-grid[data-layout="grid-boxed-3"] li .item .cat {
	position: absolute;
	top: 0;
	left: 0;
	transform: translate(calc(0px - 50% - 18px), 80px) rotate(-90deg);
	width: 100%;
	max-width: 170px;
	align-items: flex-start;
	justify-content: flex-end;
	display: flex;
	margin: 0;
}
.penci-grid[data-layout="grid-boxed-3"] li .item .cat a {
	margin-bottom: 0;
	font-weight: var(--pchead-wei);
}
.penci-grid[data-layout="grid-boxed-3"] li .item .grid-post-box-meta span {
	color: var(--pcmeta-cl);
	opacity: 0.5;
}
.penci-grid[data-layout="grid-boxed-3"] li .item .grid-post-box-meta span a {
	color: var(--pcmeta-cl);
}
.penci-grid[data-layout="grid-boxed-3"] .grid-header-box:after,
.penci-grid[data-layout="grid-boxed-3"]
	.penci-post-box-meta.penci-post-box-grid:before {
	display: none;
}
.penci-grid[data-layout="grid-boxed-3"]
	.penci-post-box-meta.penci-post-box-grid {
	background: rgba(255, 255, 255, 0.1);
	padding: 20px;
	margin: 20px -20px -20px;
}
.penci-grid[data-layout="grid-boxed-3"]
	.penci-post-box-meta.penci-post-box-grid
	.penci-post-share-box {
	background: transparent;
}
.penci-grid[data-layout="grid-boxed-3"]
	.penci-post-box-meta.penci-post-box-grid
	.penci-post-share-box
	a {
	color: var(--pcmeta-cl);
}
.grid-boxed-4-item {
	box-shadow: 0 5px 15px rgba(0, 0, 0, 0.09)
}
.grid-boxed-4-item .item-content {
	padding-left: 20px;
	padding-right: 20px;
}
.grid-boxed-4-item .grid-header-box {
	padding: 20px;
}
.penci-grid li.grid-boxed-4-item .item .item-content {
	padding-bottom: 0;
	padding-top: 0;
}
.grid-boxed-4-item .grid-header-box {
	--mask:
	  radial-gradient(8.41px at 50% calc(100% - 11.4px),#000 99%,#0000 101%) calc(50% - 8px) 0/16px 100%,
	  radial-gradient(8.41px at 50% calc(100% + 7.4px),#0000 99%,#000 101%) 50% calc(100% - 4px)/16px 100% repeat-x;
	-webkit-mask: var(--mask);
	mask: var(--mask);
	background: #f1f1f1;
}
.penci-grid li.grid-boxed-4-item .item > .thumbnail {
	margin-bottom: 0;
}  
.grid-boxed-4-item .grid-header-box {
	text-align: left;
}
.grid-boxed-4-item .penci-btn-readmore {
	padding: 12px 20px;
}
.grid-boxed-4-item .penci-post-box-meta:before {
	display: none;
}
.grid-boxed-4-item .penci-post-box-meta {
	padding: 10px 0;
	border-top: 1px dotted var(--pcborder-cl) !important;
}
.grid-boxed-4-item .item {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	height: 100%;
}
.grid-boxed-4-item .penci-readmore-btn,
.grid-boxed-4-item .penci-post-box-meta {
	flex: 100%;
}
.grid-boxed-4-item .penci-post-box-meta {
	align-self: end;
}
.penci-grid4-date {
	position: absolute;
	bottom: 0;
  	left: 0;
	z-index: 2;
	color: #fff;
	background: var(--pcaccent-cl);
	padding-right: 10px;
	text-transform: uppercase;
	font-size: 12px;
}
.penci-grid4-date span {
	display: inline-block;
	padding: 5px 10px;
	background: #000;
	margin-right: 10px;
	font-size: 18px;
	vertical-align: middle;
}
@media only screen and (min-width:961px) {
	.container.penci_sidebar .penci-grid[data-cols="2"]>li,
	.penci-grid[data-cols="2"]>li {
		width: calc((100% - var(--pcrgap))/ 2);
		margin-bottom: 40px
	}
	.container.penci_sidebar .penci-grid[data-cols="3"]>li,
	.penci-grid[data-cols="3"]>li {
		width: calc((100% - var(--pcrgap) * 2)/ 3);
		margin-bottom: 40px
	}
	.container.penci_sidebar .penci-grid[data-cols="4"]>li,
	.penci-grid[data-cols="4"]>li {
		width: calc((100% - var(--pcrgap) * 3)/ 4);
		margin-bottom: 40px
	}
	.container.penci_sidebar .penci-grid[data-cols="5"]>li,
	.penci-grid[data-cols="5"]>li {
		width: calc((100% - var(--pcrgap) * 4)/ 5);
		margin-bottom: 40px
	}
}
@media only screen and (min-width:961px) and (max-width:1169px) {
	.container .penci-grid[data-cols="4"]>li,
	.container .penci-grid[data-cols="5"]>li {
		width: calc((100% - var(--pcrgap) * 2)/ 3);
		margin-bottom: 40px
	}
	.container.penci_sidebar .penci-grid[data-cols="4"]>li,
	.container.penci_sidebar .penci-grid[data-cols="5"]>li {
		width: calc((100% - var(--pcrgap))/ 2);
		margin-bottom: 40px
	}
}
@media only screen and (max-width:961px) {
	.container.penci_sidebar .penci-grid[data-cols="1"]>li,
	.penci-grid[data-cols="1"]>li {
		width: 100%
	}
	.container.penci_sidebar .penci-grid[data-cols="2"]>li,
	.penci-grid[data-cols="2"]>li {
		width: calc((100% - var(--pcrgap))/ 2)
	}
}
@media only screen and (min-width:768px) and (max-width:1024px) {
	.container.penci_sidebar .penci-grid[data-tcols="1"]>li,
	.penci-grid[data-tcols="1"]>li {
		width: 100% !important
	}
	.container.penci_sidebar .penci-grid[data-tcols="2"]>li,
	.penci-grid[data-tcols="2"]>li {
		width: calc((100% - var(--pcrgap))/ 2) !important
	}
	.container.penci_sidebar .penci-grid[data-tcols="3"]>li,
	.penci-grid[data-tcols="3"]>li {
		width: calc((100% - var(--pcrgap) * 2)/ 3) !important
	}
	.container.penci_sidebar .penci-grid[data-tcols="4"]>li,
	.penci-grid[data-tcols="4"]>li {
		width: calc((100% - var(--pcrgap) * 3)/ 4) !important
	}
	.container.penci_sidebar .penci-masonry[data-cols="3"] .item-masonry,
	.container.penci_sidebar .penci-masonry[data-cols="4"] .item-masonry,
	.container.penci_sidebar .penci-masonry[data-cols="5"] .item-masonry,
	.penci-masonry[data-cols="3"] .item-masonry,
	.penci-masonry[data-cols="4"] .item-masonry,
	.penci-masonry[data-cols="5"] .item-masonry {
		width: 50%
	}
	.penci-masonry[data-tcols="1"] .item-masonry {
		width: 100% !important
	}
	.penci-masonry[data-tcols="2"] .item-masonry {
		width: 50% !important
	}
	.penci-masonry[data-tcols="3"] .item-masonry {
		width: calc(100% / 3) !important
	}
}
@media only screen and (max-width:767px) {
	.penci-grid[data-layout=list-boxed] li.list-post .item .content-list-right {
		border: 1px solid var(--pcborder-cl);
		padding: 20px;
		border-top: 0
	}
	.penci-grid[data-layout=list-boxed] li.list-post .item>.thumbnail {
		margin-top: 0;
		margin-bottom: 0
	}
	.penci-grid[data-layout=list-boxed] li.list-post .item {
		border: 0;
		padding: 0
	}
	.penci-grid[data-layout=list-boxed-2] li.list-post .item .content-list-right {
		border: 1px solid var(--pcborder-cl);
		padding: 20px;
		border-bottom: 0
	}
	.penci-grid[data-layout=list-boxed-2] li.list-post .item>.thumbnail {
		margin-top: 0;
		margin-bottom: 0
	}
	.penci-grid[data-layout=list-boxed-2] li.list-post .item {
		border: 0;
		padding: 0
	}
	ul.penci-grid {
		--pcrgap: 20px
	}
}
.menu-item-has-label .menu-label {
	font-size: 9px;
	font-weight: 600;
	line-height: 12px;
	position: absolute;
	z-index: 1;
	top: calc(50% - 25px);
	left: 100%;
	display: inline-block;
	margin-left: -20px;
	padding: 2px 4px;
	vertical-align: middle;
	white-space: nowrap;
	letter-spacing: .3px;
	text-transform: uppercase;
	color: #fff;
	background-color: var(--pcaccent-cl)
}
#sidebar-nav .menu-item-has-label .menu-label,
.pc-dropdown-menu .menu-item-has-label .menu-label,
.penci-menu-hbg .menu-item-has-label .menu-label {
	left: auto
}
.menu-item-has-label .menu-label.label-style-1:before,
.menu-item-has-label .menu-label.label-style-2:before {
	position: absolute;
	top: 100%;
	left: 10px;
	content: "";
	border: 4px solid;
	border-color: var(--pcaccent-cl);
	border-right-width: 7px;
	border-right-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-width: 0
}
.menu-item-has-label .menu-label.label-style-2:before {
	left: 0
}
.menu-item-has-label .menu-label.label-style-4:before {
	position: absolute;
	right: 50%;
	bottom: -4px;
	left: 50%;
	margin-left: -4px;
	content: "";
	border-width: 4px 4px 0 4px;
	border-style: solid;
	border-color: var(--pcaccent-cl);
	border-right-color: transparent !important;
	border-bottom-color: transparent !important;
	border-left-color: transparent !important
}
.penci-mega-content-container {
	text-align: initial
}
.desktop-meta-bg-hidden {
	display: none
}
@media only screen and (min-width:767px) and (max-width:1169px) {
	.tablet-meta-bg-hidden {
		display: none
	}
}
@media only screen and (max-width:767px) {
	.mobile-meta-bg-hidden {
		display: none
	}
}
.biggrid-archive-wrapper .grid-post-box-meta {
	overflow: hidden
}
.featured-list-title {
	margin-bottom: 30px
}
.penci-dropdown-menu {
	position: absolute;
	visibility: hidden;
	opacity: 0;
	z-index: 9999;
	box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-webkit-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	-moz-box-shadow: 0 3px 3px rgba(190, 190, 190, .6);
	border-top: 1px solid #ececec;
	margin-top: 0;
	background-color: #fff;
	background-size: cover;
	background-repeat: no-repeat;
	background-position: center center
}
.penci-dropdown-menu.penci-mega-full-width {
	left: 0
}
.penci-dropdown-menu.penci-mega-custom-width {
	left: auto;
	right: auto
}
#navigation .penci-dropdown-menu.penci-mega-custom-width .container,
.navigation .penci-dropdown-menu.penci-mega-custom-width .container {
	display: block
}
.penci-dropdown-menu .post-entry {
	line-height: unset;
	margin-bottom: 0
}
#navigation .penci-dropdown-menu,
.navigation .penci-dropdown-menu {
	max-width: 100vw;
	display: none
}
#navigation .penci-dropdown-menu .container,
#navigation .penci-dropdown-menu .penci-megamenu,
.navigation .penci-dropdown-menu .container,
.navigation .penci-dropdown-menu .penci-megamenu {
	display: block
}
#navigation .penci-mega-custom-width .container,
.navigation .penci-mega-custom-width .container {
	width: 100%
}
.penci-dropdown-menu.loading {
	min-height: 150px
}
.penci-dropdown-menu:before,
.penci-megamenu:before {
	opacity: 0;
	background-color: inherit;
	transition: all .2s ease;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	content: "";
	position: absolute;
	min-height: 0
}
.penci-dropdown-menu.loading:before,
.penci-megamenu.loading:before {
	opacity: 1;
	z-index: 8
}
.penci-dropdown-menu:after,
.penci-megamenu:after {
	opacity: 0;
	transition: opacity .2s ease;
	content: "";
	display: inline-block;
	border: 1px solid #bbb;
	border-left-color: #000;
	border-top-color: #000;
	border-radius: 50%;
	vertical-align: middle;
	position: absolute;
	top: 50%;
	left: 50%;
	margin-top: -12px;
	margin-left: -12px;
	width: 24px;
	height: 24px
}
@keyframes penci-menu-rotate {
	100% {
		transform: rotate(360deg)
	}
}
.penci-dropdown-menu.loading:after,
.penci-megamenu.loading:after {
	opacity: 1;
	z-index: 9;
	animation: penci-menu-rotate .35s infinite linear
}
.button-popup-content,
.penci-age-verify,
.penci-epopup-content,
.penci-popup-content {
	position: relative;
	width: 100%;
	max-width: 650px;
	margin-right: auto;
	margin-left: auto;
	background-color: #fff;
	padding: 40px;
	text-align: center;
	display: none
}
.mfp-wrap .button-popup-content,
.mfp-wrap .penci-age-verify,
.mfp-wrap .penci-epopup-content,
.mfp-wrap .penci-popup-content {
	display: block
}
.penci-age-verify .penci-age-verify-buttons {
	margin-top: 30px
}
.penci-age-verify .penci-age-verify-buttons .button {
	display: inline-block;
	padding: 0 15px;
	line-height: 35px;
	background-color: var(--pcaccent-cl);
	color: #fff;
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
	transition: .3s all ease-in-out
}
.penci-age-verify .penci-age-verify-buttons .button.penci-age-verify-forbidden {
	color: var(--pctext-cl);
	background-color: #f1f1f1
}
.penci-age-verify .penci-age-verify-buttons .button:hover {
	opacity: .8
}
.penci-age-verify.penci-forbidden .penci-age-verify-buttons,
.penci-age-verify.penci-forbidden .penci-age-verify-text {
	display: none
}
.pc-fho-wrap {
	position: relative;
	--gap: 20px;
	--vgap: 20px;
	--maingap: 30px;
	--iconw: 25%;
	--iconsz: 150px;
	--iconbd: 5px;
	--obg: rgba(0, 0, 0, 0.5);
	--ohbg: rgba(0, 0, 0, 0.8);
	--sobg: rgba(0, 0, 0, 0);
	--sohbg: rgba(0, 0, 0, 0.5);
	z-index: 1;
	max-width: 100%;
	margin-left: auto;
	margin-right: auto
}
.pc-fho-wrap .mp-link {
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	position: absolute;
	background-size: cover;
	z-index: 1;
	display: block;
	text-indent: -99999999px
}
.pc-fho-wrap .mp-link:not(.penci-lazy) {
	background-color: rgba(0, 0, 0, .5)
}
.pc-fho-container {
	width: 100%;
	margin-left: auto;
	margin-right: auto;
	max-width: var(--pcctain)
}
.pc-fho-wrap .mp-link:before {
	content: "";
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	position: absolute;
	background-color: var(--obg);
	z-index: 2;
	transition: .3s background-color ease-in-out
}
.pc-fho-wrap .mp-link:hover:before {
	background-color: var(--ohbg)
}
.pc-fho-wrap .pc-fho-mpct {
	position: relative;
	z-index: 2
}
.pc-fho-wrap .pc-fho-mpct:hover~.mp-link:before {
	background-color: var(--ohbg)
}
.pc-fho-wrap .pc-fho-bg-wrap {
	padding: 60px
}
.pc-fho-wrap .pc-fho-mpct {
	margin-left: calc(var(--maingap)/ 2 * -1);
	margin-right: calc(var(--maingap)/ 2 * -1);
	display: flex;
	display: -webkit-flex;
	display: -ms-flexbox;
	-webkit-flex-flow: row wrap;
	flex-flow: row wrap;
	align-items: center
}
.pc-fho-wrap .pc-fho-mpct .pc-fho-mc,
.pc-fho-wrap .pc-fho-mpct .pc-fho-mi {
	padding-left: calc(var(--maingap)/ 2);
	padding-right: calc(var(--maingap)/ 2)
}
.pc-fho-wrap .pc-fho-mpct .pc-fho-mi {
	flex: 0 0 var(--iconw);
	align-items: center;
	display: flex
}
.pc-fho-wrap .pc-fho-mpct .pc-fho-mc {
	flex: 0 0 calc(100% - var(--iconw))
}
.pc-fho-wrap .pc-fho-mpct .pc-fho-mc.bct-fullwidth {
	flex: 0 0 100% !important
}
.pc-fho-wrap .pc-fho-mc .pc-fho-mt h3 {
	font-size: 55px;
	line-height: 1.1;
	margin-bottom: 0
}
.pc-fho-wrap .pc-fho-mc .pc-fho-mm a,
.pc-fho-wrap .pc-fho-mc .pc-fho-mt a {
	color: #fff;
	text-decoration: none
}
.pc-fho-wrap .pc-fho-mi-i {
	max-width: var(--iconsz);
	height: var(--iconsz);
	border: var(--iconbd) solid #fff;
	background: rgba(0, 0, 0, .1);
	color: #fff;
	border-radius: 50%;
	text-align: center;
	width: 100%
}
.pc-fho-wrap .pc-fho-mi-i a {
	color: inherit
}
.pc-fho-wrap .pc-fho-mi-i i {
	font-size: 70px;
	line-height: calc(var(--iconsz) - (var(--iconbd) * 2))
}
.pc-fho-wrap .pc-fho-msli {
	margin-left: calc(var(--gap)/ 2 * -1);
	margin-right: calc(var(--gap)/ 2 * -1);
	margin-top: 60px
}
.pc-fho-wrap .pc-fho-msli .pc-fho-msli-inner-ct {
	display: flex;
	display: -webkit-flex;
	display: -ms-flexbox;
	-webkit-flex-flow: row wrap;
	flex-flow: row wrap;
	align-items: flex-start;
	overflow: hidden
}
.pc-fho-wrap .pc-fho-msli .pc-fho-li {
	position: relative;
	z-index: 3;
	padding-left: calc(var(--gap)/ 2);
	padding-right: calc(var(--gap)/ 2)
}
.pc-fho-msli-inner-ct:not(.penci-owl-carousel) .pc-fho-li {
	margin-bottom: var(--vgap)
}
.pc-fho-wrap .pc-fho-msli.columns-1 .pc-fho-li {
	flex: 0 0 100%
}
.pc-fho-wrap .pc-fho-msli.columns-2 .pc-fho-li {
	flex: 0 0 50%
}
.pc-fho-wrap .pc-fho-msli.columns-3 .pc-fho-li {
	flex: 0 0 33.3333333333%
}
.pc-fho-wrap .pc-fho-msli.columns-4 .pc-fho-li {
	flex: 0 0 25%
}
.pc-fho-wrap .pc-fho-msli.columns-5 .pc-fho-li {
	flex: 0 0 20%
}
.pc-fho-wrap .pc-fho-msli.columns-6 .pc-fho-li {
	flex: 0 0 16.6666666667%
}
.pc-fho-msli-inner-ct>.pc-fho-li:last-child {
	margin-bottom: 0 !important
}
@media only screen and (min-width:1170px) {
	.pc-fho-msli.columns-2 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.columns-3 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.columns-3 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(4),
	.pc-fho-msli.columns-5 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.columns-5 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.columns-5 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(4),
	.pc-fho-msli.columns-5 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(5),
	.pc-fho-msli.columns-6 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.columns-6 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.columns-6 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(4),
	.pc-fho-msli.columns-6 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(5),
	.pc-fho-msli.columns-6 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(6) {
		margin-bottom: 0
	}
}
@media only screen and (min-width:768px) and (max-width:1169px) {
	.pc-fho-msli.tablet-columns-2 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.tablet-columns-3 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.tablet-columns-3 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.tablet-columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2),
	.pc-fho-msli.tablet-columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(3),
	.pc-fho-msli.tablet-columns-4 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(4) {
		margin-bottom: 0
	}
}
@media only screen and (max-width:767px) {
	.pc-fho-msli.mobile-columns-2 .pc-fho-msli-inner-ct>.pc-fho-li:nth-last-child(2) {
		margin-bottom: 0
	}
}
.pc-fho-wrap .pc-fho-cat a,
.pc-fho-wrap .pc-fho-cat a:hover {
	text-decoration: none
}
.pc-fho-wrap .pc-fho-list-img {
	margin-bottom: 15px
}
.pc-fho-wrap .pc-fho-list-img a {
	display: block
}
.pc-fho-wrap .pc-fho-li .icon-post-format {
	top: 50%;
	right: auto;
	left: 50%;
	width: 38px;
	height: 38px;
	line-height: 34px;
	font-size: 18px;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	margin: -18px 0 0 -18px
}
.pc-fho-slolay {
	position: absolute;
	top: 0;
	width: 100%;
	height: 100%;
	left: 0;
	display: block;
	z-index: 1;
	background: var(--sobg);
	transition: all .3s
}
.pc-fho-wrap .pc-fho-list-img:hover .pc-fho-slolay {
	background: var(--sohbg)
}
.pc-fho-wrap .pc-fho-li .icon-post-format i.penci-faicon {
	line-height: inherit
}
.pc-fho-wrap .pc-fho-li .pc-fho-list-img:hover .icon-post-format {
	opacity: 0;
	transform: scale(.5);
	-webkit-transform: scale(.5);
	-moz-transform: scale(.5)
}
.pc-fho-wrap .pc-fho-li .penci-piechart.penci-piechart-small {
	top: 10px;
	right: 10px
}
.pc-fho-wrap .pc-fho-lt h3 {
	margin-bottom: 0;
	font-size: 18px;
	line-height: 1.3
}
.pc-fho-cat {
	line-height: 1;
	margin-bottom: 4px
}
.pc-fho-wrap .grid-post-box-meta {
	margin-top: 5px
}
.pc-fho-mpct .grid-post-box-meta a,
.pc-fho-mpct .grid-post-box-meta span,
.pc-fho-wrap .cat>a.penci-cat-name,
.pc-fho-wrap .pc-fho-lm a,
.pc-fho-wrap .pc-fho-lm span,
.pc-fho-wrap .pc-fho-lt a {
	color: #fff;
	text-decoration: none
}
@media only screen and (min-width:768px) and (max-width:1169px) {
	.pc-fho-wrap .pc-fho-msli.tablet-columns-2 .pc-fho-li {
		flex: 0 0 50%
	}
	.pc-fho-wrap .pc-fho-msli.tablet-columns-3 .pc-fho-li {
		flex: 0 0 33.3333333333%
	}
	.pc-fho-wrap .pc-fho-msli.tablet-columns-4 .pc-fho-li {
		flex: 0 0 25%
	}
	.pc-fho-wrap .pc-fho-mc .pc-fho-mt h3 {
		font-size: 42px
	}
}
@media only screen and (min-width:768px) {
	.pc-fho-wrap .pc-fho-mp {
		background: unset !important
	}
}
@media only screen and (max-width:767px) {
	.pc-fho-wrap .mp-link {
		display: none
	}
	.pc-fho-wrap .pc-fho-bg-wrap {
		padding: 0;
		background: unset !important
	}
	.pc-fho-wrap .pc-fho-mp {
		padding: 40px 20px;
		background-size: cover;
		position: relative
	}
	.pc-fho-wrap .pc-fho-mp:before {
		content: "";
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		position: absolute;
		background-color: var(--obg);
		z-index: 2;
		transition: .3s background-color ease-in-out
	}
	.pc-fho-wrap .pc-fho-mp:hover:before {
		background-color: var(--ohbg)
	}
	.pc-fho-wrap .pc-fho-mpct .pc-fho-mi {
		flex: 0 0 100%;
		margin-bottom: var(--maingap)
	}
	.pc-fho-wrap .pc-fho-mpct .pc-fho-mc {
		flex: 0 0 100%;
		text-align: center
	}
	.pc-fho-wrap .pc-fho-mc .pc-fho-mt h3 {
		font-size: 20px;
		line-height: 1.2
	}
	.pc-fho-wrap .pc-fho-msli .pc-fho-li {
		flex: 0 0 50%;
		margin-bottom: 30px
	}
	.pc-fho-wrap .pc-fho-mi-i i {
		font-size: 28px
	}
	.pc-fho-wrap {
		--iconsz: 60px;
		--iconbd: 2px;
		--maingap: 20px
	}
	.pc-fho-wrap .pc-fho-msli {
		margin-top: 30px
	}
	.pc-fho-wrap .pc-fho-msli.mobile-columns-1 .pc-fho-li {
		flex: 0 0 100%
	}
	.pc-fho-wrap .pc-fho-lm a {
		color: var(--pctext-cl)
	}
	.pc-fho-wrap .pc-fho-lm span {
		color: var(--pcmeta-cl)
	}
	.pc-fho-wrap .pc-fho-li .cat>a.penci-cat-name {
		color: var(--pcaccent-cl)
	}
	.pc-fho-wrap .pc-fho-lt a {
		color: var(--pcheading-cl)
	}
}
.pctmp-term-list .term-labels {
	display: inline-block
}
.pctmp-term-list .pctmp-term-item,
.pctmp-term-list li {
	display: inline-block
}
.pctmp-term-list li .count {
	margin-left: 5px
}
.elementor-widget-penci-single-related-posts .post-related {
	border: 0
}
.elementor-widget-penci-single-comment-form h3.comment-reply-title {
	border-top: 0 !important;
	padding-top: 0 !important
}
.pcmt-icon {
	display: inline-block;
	vertical-align: baseline
}
.tags-share-box.pcnew-share,
.tags-share-box.share-box-border-bot.pcnew-share,
.tags-share-box.tags-share-box-bot.pcnew-share,
.tags-share-box.tags-share-box-top.pcnew-share {
	border-top: 0;
	border-bottom: 0;
	padding-top: 0;
	padding-bottom: 0;
	margin-bottom: 15px
}
.tags-share-box.post-share {
	top: 0
}
.pcnew-share .post-share-item {
	margin: 0 4px 0 4px
}
.tags-share-box.disable-btnplus {
	white-space: normal;
	opacity: 1 !important
}
.tags-share-box.post-share.disable-btnplus .auto-hidden {
	display: inline-block !important
}
.tags-share-box.post-share.disable-btnplus .post-share-expand {
	display: none !important;
	visibility: hidden !important
}
.pcnew-share.penci-icon-full .post-share-item i,
.pcnew-share:not(.penci-icon-full) .post-share-item {
	position: relative;
	display: inline-block;
	margin: 0 4px 8px;
	height: 40px;
	min-width: 40px;
	line-height: 40px;
	font-size: 14px;
	text-align: center;
	vertical-align: middle;
	color: #fff;
	overflow: hidden
}
body:not(.rtl) .tags-share-box.post-share.disable-btnplus .post-share-item {
	margin-left: 0 !important;
	margin-right: 8px
}
body.rtl .tags-share-box.post-share.disable-btnplus .post-share-item {
	margin-right: 0 !important;
	margin-left: 8px
}
.tags-share-box-n1.penci-social-colored a i.fa-heart,
.tags-share-box-n10.penci-social-colored a i.fa-heart,
.tags-share-box-n12.penci-social-colored a i.fa-heart,
.tags-share-box-n19.penci-social-colored a i.fa-heart,
.tags-share-box-n20.penci-social-colored a i.fa-heart,
.tags-share-box-n3.penci-social-colored a i.fa-heart,
.tags-share-box-n5.penci-social-colored a i.fa-heart,
.tags-share-box-n8.penci-social-colored a i.fa-heart {
	background-color: transparent !important
}
.pcnew-share .post-share-item:not(.post-share-plike) i {
	z-index: 1
}
.pcnew-share.penci-icon-full .post-share-item i {
	margin: 0
}
.pcnew-share.full-border.penci-icon-full.border-style .post-share-item.post-share-plike i {
	vertical-align: top
}
.pcnew-share .post-share-item {
	transition: opacity .3s ease-in-out
}
.pcnew-share .post-share-item:hover {
	opacity: .85
}
.tags-share-box.pcnew-share {
	padding-right: 0
}
.pcnew-share .post-share a {
	margin: 0 0 0 5px
}
.pcnew-share .post-share-item i,
.pcnew-share.penci-icon-full .post-share-item i {
	margin-bottom: 0
}
.pcnew-share.border-style:not(.penci-icon-full) .post-share-item,.pcnew-share.full-border .post-share-item,.pcnew-share.penci-icon-full.border-style .post-share-item i {
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 0
}
.pcnew-share.full-border.penci-icon-full.border-style .post-share-item i {
	margin: 0;
	border-width: 0
}
.show-txt.border-style.full-border a .dt-share {
	border: 0;
	margin: 0;
	padding: 0 15px
}
.pcnew-share.full-border .post-share-item {
	padding-left: 0;
	padding-right: 0
}
.pcnew-share.size-large .post-share-item,
.pcnew-share.size-large.penci-icon-full .post-share-item i {
	height: 60px;
	min-width: 60px;
	line-height: 60px;
	font-size: 18px;
	vertical-align: top
}
.pcnew-share.size-large.penci-icon-full.txt-below .post-share-item i {
	line-height: 75px
}
.pcnew-share.size-large.penci-icon-full .post-share-item.post-share-plike i {
	width: auto;
	min-width: unset
}
.rounder .post-share-item,
.rounder .post-share-item i {
	border-radius: 50px
}
.pcnew-share .post-share-plike {
	background-color: #000;
	padding-left: 10px
}
.pcnew-share.border-style .post-share-plike {
	background-color: transparent;
	color: #000;
	border: 1px solid var(--pcborder-cl)
}
.pcnew-share.border-style:not(.tags-share-box-n20) .post-share-plike i {
	border: 0 !important
}
.pcnew-share .post-share-plike .post-share-item,
.pcnew-share.penci-icon-full .post-share-plike .post-share-item i {
	width: auto
}
.pcnew-share a.penci-post-like:after {
	display: none
}
.pcnew-share.post-share {
	position: initial
}
.show-txt.post-share a .dt-share {
	position: static;
	padding: 0;
	margin: 0 0 0 8px;
	opacity: 1;
	visibility: visible;
	background-color: transparent;
	font-size: 13px;
	width: auto;
	max-width: unset
}
.show-txt.focus-icon.post-share a .dt-share {
	border: 0
}
.show-txt.focus-icon .post-share-item i {
	background-color: rgba(0, 0, 0, .5);
	height: 40px;
	min-width: 40px;
	line-height: 40px
}
.show-txt.focus-icon .post-share-item.post-share-plike i {
	background-color: transparent;
	min-width: unset
}
.show-txt a:not(.single-like-button) {
	padding-left: 12px;
	padding-right: 12px
}
.show-txt.focus-icon a {
	padding-left: 0
}
.show-txt.rounder a {
	padding-left: 20px;
	padding-right: 20px
}
.show-txt.rounder a.single-like-button {
	padding-left: 0;
	padding-right: 0
}
.show-txt.post-share a .dt-share:after,
.show-txt.post-share a .dt-share:before {
	display: none
}
.show-shadow:not(.show-txt).post-share .post-share-item.post-share-plike,
.show-shadow:not(.show-txt).post-share .post-share-item:not(.post-share-plike) i {
	-webkit-box-shadow: inset 0 -3px 0 0 rgba(0, 0, 0, .31);
	box-shadow: inset 0 -3px 0 0 rgba(0, 0, 0, .31)
}
.show-shadow.show-txt.post-share .post-share-item {
	-webkit-box-shadow: inset 0 -3px 0 0 rgba(0, 0, 0, .31);
	box-shadow: inset 0 -3px 0 0 rgba(0, 0, 0, .31)
}
.show-txt.txt-below.size-large.post-share a {
	position: relative;
	line-height: 50px;
	height: 90px
}
.show-txt.txt-below.pcnew-share.size-large .post-share-item.post-share-plike,
.show-txt.txt-below.pcnew-share.size-large .post-share-item.post-share-plike i {
	line-height: 90px;
	height: 90px
}
.show-txt.txt-below.pcnew-share.size-large .post-share-item.post-share-plike i {
	background-color: transparent !important
}
.show-txt.txt-below.size-large.post-share a i {
	font-size: 22px
}
.show-txt.txt-below.post-share a .dt-share {
	display: block;
	position: absolute;
	bottom: 5px;
	left: 0;
	right: 0;
	z-index: 2;
	color: #fff;
	margin: 0;
	padding: 0;
	border: 0;
	line-height: 1
}
.show-txt.border-style.post-share a .dt-share {
	color: #000;
	border-color: rgba(0, 0, 0, .1)
}
.no-spacing .post-share-item,
.no-spacing .post-share-item i,
.pcnew-share.penci-icon-full.no-spacing .post-share-item i {
	margin-left: 0;
	margin-right: 0
}
.black-ver .post-share-item,
.black-ver .post-share-item i {
	background-color: #000;
	color: #fff
}
.black-ver .post-share-item.post-share-plike i {
	background-color: transparent !important
}
.tags-share-box-n19.pcnew-share.border-style .post-share-item i,
.tags-share-box-n20 .post-share-item i,
.tags-share-box-n20.pcnew-share.border-style .post-share-item i {
	position: relative;
	color: #fff
}
.tags-share-box-n19.pcnew-share.border-style .post-share-item.post-share-plike,
.tags-share-box-n20.pcnew-share.border-style .post-share-item.post-share-plike {
	padding-left: 12px;
	padding-right: 12px
}
.tags-share-box-n19.pcnew-share.border-style .post-share-item.post-share-plike i,
.tags-share-box-n20.pcnew-share.border-style .post-share-item.post-share-plike i {
	padding-right: 5px;
	background-color: transparent
}
.tags-share-box-n19 .count-number-like,
.tags-share-box-n20 .count-number-like {
	float: right;
	padding: 0
}
.tags-share-box-n20.pcnew-share.penci-icon-full .post-share-item i {
	overflow: visible
}
.tags-share-box-n20 .post-share-item i:after {
	content: "";
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 6px 0 6px 5px;
	border-color: transparent transparent transparent transparent;
	border-left-color: inherit;
	position: absolute;
	top: 50%;
	bottom: 50%;
	left: 100%;
	transform: translateY(-50%)
}
.tags-share-box-n20 .post-share-item.post-share-plike i:after {
	display: none
}
.pcnew-share .post-share-plike {
	height: 40px;
	display: inline-block;
	line-height: 40px;
	overflow: hidden
}
.pcnew-share .penci-social-share-text {
	min-width: 40px;
	height: 40px;
	line-height: 40px;
	border: 1px solid var(--pcborder-cl);
	display: inline-block;
	padding: 0 15px;
	margin-right: 12px;
	position: relative;
	vertical-align: top !important;
	font-weight: 700;
	text-transform: uppercase;
	font-size: 13px
}
.pcnew-share .post-share-plike i,
.pcnew-share.penci-icon-full .post-share-item.post-share-plike i {
	min-width: unset
}
.pcnew-share .post-share-plike {
	padding-left: 12px;
	padding-right: 12px
}
.pcnew-share.border-style.show-txt .penci-social-share-text,
.pcnew-share.border-style.show-txt .post-share-plike {
	height: 42px;
	line-height: 42px
}
.pcnew-share .penci-social-share-text:after,
.pcnew-share .penci-social-share-text:before {
	content: "";
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 8px 0 8px 8px;
	border-color: transparent transparent transparent var(--pcborder-cl);
	position: absolute;
	top: 50%;
	bottom: 50%;
	left: 100%;
	transform: translateY(-50%)
}
.pcnew-share .penci-social-share-text:after {
	border-width: 6px 0 6px 6px;
	border-color: transparent transparent transparent var(--pcbg-cl)
}
.size-large.pcnew-share .penci-social-share-text {
	height: 60px;
	line-height: 60px
}
.size-large.pcnew-share.show-txt.txt-below .penci-social-share-text {
	height: 90px;
	line-height: 90px
}
.penci-social-share-text {
	vertical-align: middle
}
.penci-social-share-text i {
	display: inline-block;
	vertical-align: middle;
	margin-right: 8px;
	font-size: 14px;
	transform: translateY(-1px)
}
.tags-share-box-n19.post-share a.penci-post-like,
.tags-share-box-n20.post-share a.penci-post-like {
	padding-right: 0;
	padding-left: 0;
	margin-left: 0;
	background-color: var(--pcaccent-cl);
	color: #fff
}
.pcnew-share.penci-social-colored .post-share-plike i.fa-heart-o {
	background: 0 0 !important
}
.pcnew-share.penci-social-colored .post-share-item.post-share-plike {
	background-color: var(--pcaccent-cl)
}
.pcnew-share.penci-social-colored .post-share-item.post-share-plike .count-number-like,
.post-share.tags-share-box-n14 .count-number-like {
	color: #fff
}
.post-meta-share {
	position: relative;
}
.post-meta-share:hover .penci-pshare-dropdown {
	visibility: visible;
	opacity: 1;
	transform: translateY(10px);
}
.post-meta-share .post-share-text:before {
	content: '\f1e0';
	font-family: 'FontAwesome';
	margin-right: 5px;
}  
.penci-pshare-dropdown a:hover {
	background: #f1f1f1;
}
.penci-pshare-dropdown {
	display: block;
	position: absolute;
	z-index: 9;
	background: #fff;
	padding: 0;
	top: 100%;
	left: 12px;
	width: 170px;
	opacity: 0;
	visibility: hidden;
	transition: 0.3s all ease-in-out;
	transform: translateY(40px);
	box-shadow: 0px 4px 8px rgba(174, 174, 174, 0.5);
}
.penci-pshare-dropdown a {
	display: flex;
	align-items: center;
	padding: 10px 20px;
	border-bottom: 1px solid var(--pcborder-cl);
	color: var(--pcheading-cl);
}
.penci-pshare-dropdown a i {
	transform: unset !important;
}
.penci-pshare-dropdown a span,
.penci-header-text-white .post-box-meta-single .penci-pshare-dropdown a span{
	color: inherit;
}
.penci-pshare-dropdown a:hover {
	color: var(--pcaccent-cl);
}
.penci-pshare-dropdown a i {
	margin-right: 5px;
}
.penci-pshare-dropdown a:nth-last-child(-n + 2) {
	border-bottom: 0;
}
.penci-pshare-dropdown .post-share-expand {
	display: none;
}
.penci-social-colored a i.fa-facebook,
.penci-social-colored a i.fa-facebook-f,
.penci-social-colored a i.penciicon-facebook {
	border-left-color: #0d47a1 !important
}
.penci-social-colored a i.fa-twitter,
.penci-social-colored a i.penciicon-twitter,
.penci-social-colored a i.penciicon-x-twitter {
	border-left-color: #40c4ff !important
}
.penci-social-colored a i.fa-google-plus {
	border-left-color: #eb4026 !important
}
.penci-social-colored a i.fa-instagram,
.penci-social-colored a i.penciicon-instagram {
	border-left-color: #4d7a9e !important
}
.penci-social-colored a i.fa-pinterest,
.penci-social-colored a i.penciicon-pinterest {
	border-left-color: #bd081c !important
}
.penci-social-colored a i.fa-linkedin,
.penci-social-colored a i.fa-linkedin-in,
.penci-social-colored a i.penciicon-linkedin {
	border-left-color: #0077b5 !important
}
.penci-social-colored a i.fa-flickr,
.penci-social-colored a i.penciicon-flickr {
	border-left-color: #ff0084 !important
}
.penci-social-colored a i.fa-behance,
.penci-social-colored a i.penciicon-behance {
	border-left-color: #053eff !important
}
.penci-social-colored a i.fa-tumblr,
.penci-social-colored a i.penciicon-tumblr {
	border-left-color: #34465d !important
}
.penci-social-colored a i.fa-youtube,
.penci-social-colored a i.fa-youtube-play,
.penci-social-colored a i.penciicon-youtube {
	border-left-color: red !important
}
.penci-social-colored a i.fa-envelope,
.penci-social-colored a i.fa-envelope-o,
.penci-social-colored a i.penciicon-email {
	border-left-color: #0084ff !important
}
.penci-social-colored a i.fa-vk,
.penci-social-colored a i.penciicon-vk {
	border-left-color: #5181b8 !important
}
.penci-social-colored a i.fa-pocket {
	border-left-color: #ef4056 !important
}
.penci-social-colored a i.fa-skype {
	border-left-color: #00aff0 !important
}
.penci-social-colored a i.fa-heart {
	border-left-color: #000 !important
}
.penci-social-colored a i.fa-vine,
.penci-social-colored a i.penciicon-vine {
	border-left-color: #00b98a !important
}
.penci-social-colored a i.fa-soundcloud,
.penci-social-colored a i.penciicon-soundcloud {
	border-left-color: #f76201 !important
}
.penci-social-colored a i.fa-snapchat,
.penci-social-colored a i.fa-snapchat-ghost,
.penci-social-colored a i.penciicon-snapchat {
	border-left-color: #f6f600 !important
}
.penci-social-colored a i.fa-spotify,
.penci-social-colored a i.penciicon-spotify {
	border-left-color: #22c95c !important
}
.penci-social-colored a i.fa-github,
.penci-social-colored a i.penciicon-github {
	border-left-color: #302f2f !important
}
.penci-social-colored a i.fa-stack-overflow,
.penci-social-colored a i.penciicon-stack-overflow {
	border-left-color: #f7a000 !important
}
.penci-social-colored a i.fa-twitch,
.penci-social-colored a i.penciicon-twitch {
	border-left-color: #613fa0 !important
}
.penci-social-colored a i.fa-vimeo,
.penci-social-colored a i.fa-vimeo-v,
.penci-social-colored a i.penciicon-vimeo {
	border-left-color: #00a8e8 !important
}
.penci-social-colored a i.fa-steam,
.penci-social-colored a i.penciicon-steam {
	border-left-color: #bcbab8 !important
}
.penci-social-colored a i.fa-xing,
.penci-social-colored a i.penciicon-xing {
	border-left-color: #007c7c !important
}
.penci-social-colored a i.fa-whatsapp,
.penci-social-colored a i.penciicon-whatsapp {
	border-left-color: #00e676 !important
}
.penci-social-colored a i.fa-heart-o {
	border-left-color: var(--pcaccent-cl) !important
}
.penci-social-colored a i.fa-telegram,
.penci-social-colored a i.penciicon-telegram {
	border-left-color: #289fd9 !important
}
.penci-social-colored a i.fa-reddit-alien,
.penci-social-colored a i.penciicon-reddit {
	border-left-color: #f74300 !important
}
.penci-social-colored a i.fa-odnoklassniki,
.penci-social-colored a i.penciicon-odnoklassniki {
	border-left-color: #f18f00 !important
}
.penci-social-colored a i.fa-500px {
	border-left-color: #0af !important
}
.penci-social-colored a i.fa-stumbleupon,
.penci-social-colored a i.penciicon-stumbleupon {
	border-left-color: #eb4823 !important
}
.penci-social-colored a i.fa-weixin,
.penci-social-colored a i.penciicon-wechat {
	border-left-color: #0fc91c !important
}
.penci-social-colored a i.fa-weibo,
.penci-social-colored a i.penciicon-sina-weibo {
	border-left-color: #df152c !important
}
.penci-social-colored a i.fa-rss,
.penci-social-colored a i.penciicon-rss {
	border-left-color: #f0941a !important
}
.penci-social-colored a i.fa-line,
.penci-social-colored a i.penci-icon-line,
.penci-social-colored a i.penciicon-line,
.penci-social-colored a i.penciicon-line-1 {
	border-left-color: #01b901 !important
}
.penci-social-colored a i.fa-viber,
.penci-social-colored a i.penci-icon-viber,
.penci-social-colored a i.penciicon-viber,
.penci-social-colored a i.penciicon-viber-1 {
	border-left-color: #7d51a0 !important
}
.penci-social-colored a i.fa-discord,
.penci-social-colored a i.penci-icon-discord,
.penci-social-colored a i.penciicon-discord,
.penci-social-colored a i.penciicon-discord-1 {
	border-left-color: #7289da !important
}
.penci-social-colored a i.fa-slack,
.penci-social-colored a i.penciicon-slack {
	border-left-color: #611f69 !important
}
.penci-social-colored a i.fa-mixcloud {
	border-left-color: #f3b2a6 !important
}
.penci-social-colored a i.fa-goodreads,
.penci-social-colored a i.penci-icon-goodreads,
.penci-social-colored a i.penciicon-goodreads {
	border-left-color: #8a5724 !important
}
.penci-social-colored a i.fa-tripadvisor,
.penci-social-colored a i.penciicon-tripadvisor {
	border-left-color: #34e0a1 !important
}
.penci-social-colored a i.fa-tiktok,
.penci-social-colored a i.penci-icon-tiktok,
.penci-social-colored a i.penciicon-tik-tok,
.penci-social-colored a i.penciicon-tik-tok-1 {
	border-left-color: #fe2c55 !important
}
.penci-social-colored a i.penciicon-douban-logo {
	border-left-color: #00b51d !important
}
.penci-social-colored a i.penciicon-qq-social-logo-of-a-penguin {
	border-left-color: #4292ff !important
}
.penci-social-colored a i.penciicon-letter-d {
	border-left-color: #000 !important
}
.penci-social-colored a i.penciicon-blogger,
.penci-social-colored a i.penciicon-blogger-1 {
	border-left-color: #ed7800 !important
}
.penci-social-colored a i.fa-delicious {
	border-left-color: #0078f0 !important
}
.penci-social-colored a i.penciicon-deviantart,
.penci-social-colored a i.penciicon-deviantart-1 {
	border-left-color: #01ca3a !important
}
.penci-social-colored a i.fa-digg {
	border-left-color: #005be2 !important
}
.penci-social-colored a i.penciicon-evernote,
.penci-social-colored a i.penciicon-evernote-1 {
	border-left-color: #00a32c !important
}
.penci-social-colored a i.penciicon-forrst,
.penci-social-colored a i.penciicon-forrst-1 {
	border-left-color: #054958 !important
}
.penci-social-colored a i.penciicon-grooveshark,
.penci-social-colored a i.penciicon-grooveshark-1 {
	border-left-color: #f75421 !important
}
.penci-social-colored a i.penciicon-lastfm {
	border-left-color: #e31b23 !important
}
.penci-social-colored a i.penciicon-myspace,
.penci-social-colored a i.penciicon-myspace-logo {
	border-left-color: #0037c1 !important
}
.penci-social-colored a i.fa-paypal,
.penci-social-colored a i.penciicon-brand {
	border-left-color: #0070ba !important
}
.penci-social-colored a i.fa-skype,
.penci-social-colored a i.penciicon-skype {
	border-left-color: #00aff0 !important
}
.penci-social-colored a i.fa-windows,
.penci-social-colored a i.penciicon-windows {
	border-left-color: #00adef !important
}
.penci-social-colored a i.fa-wordpress,
.penci-social-colored a i.penciicon-wordpress-logo {
	border-left-color: #21759b !important
}
.penci-social-colored a i.penciicon-yahoo-logo {
	border-left-color: #6001d2 !important
}
.penci-social-colored a i.penciicon-y {
	border-left-color: #fc401d !important
}
.penci-social-colored a i.fa-get-pocket {
	border-left-color: #e83c53 !important
}
.pcnew-share.border-style .post-share-item i {
	color: #000
}
.post-box-meta-single .pcmt-icon {
	text-align: center !important;
	margin-right: 5px
}
.post-box-meta-single .pcmt-icon i {
	vertical-align: baseline;
	line-height: inherit
}
.post-box-meta-single.style-s1 .pcmt-icon,
.post-box-meta-single.style-s2 .pcmt-icon,
.post-box-meta-single.style-s3 .pcmt-icon,
.post-box-meta-single.style-s4 .pcmt-icon {
	width: 24px;
	height: 24px;
	line-height: 24px
}
.post-box-meta-single.style-s1 .pcmt-icon {
	background-color: #000;
	color: #fff
}
.post-box-meta-single.style-s2 .pcmt-icon {
	background-color: #000;
	color: #fff;
	border-radius: 50px !important
}
.post-box-meta-single.style-s3 .pcmt-icon {
	background-color: #000;
	color: #fff;
	position: relative
}
.post-box-meta-single.style-s3 .pcmt-icon:after {
	content: "";
	position: absolute;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 4px 0 4px 3px;
	border-color: transparent transparent transparent #000;
	top: 50%;
	bottom: auto;
	left: 100%;
	transform: translateY(-50%)
}
.post-box-meta-single.style-s4 .pcmt-icon {
	border: 1px solid var(--pcborder-cl) !important;
	position: relative
}
.post-box-meta-single.style-s4 .pcmt-icon:before {
	content: "";
	position: absolute;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 4px 0 4px 4px;
	border-color: transparent transparent transparent #fff;
	top: calc(50% - 4px);
	bottom: 50%;
	right: -4px;
	z-index: 2
}
.post-box-meta-single.style-s4 .pcmt-icon:after {
	content: "";
	position: absolute;
	width: 0;
	height: 0;
	border-style: solid;
	border-width: 6px 0 6px 6px;
	border-color: transparent transparent transparent var(--pcborder-cl);
	top: calc(50% - 6px);
	bottom: 50%;
	right: -6px;
	z-index: 1
}
.tags-share-box.post-share .auto-hidden {
	display: none !important
}
.tags-share-box.post-share .auto-hidden.active {
	display: inline-block !important
}
.pcnew-share .post-share-item {
	margin-bottom: 8px !important
}
.pctmp-term-list.label-style-s1 .term-labels,
.pctmp-term-list.term-style-s1 .pctmp-term-item {
	text-transform: uppercase;
	color: var(--pcmeta-cl);
	padding: 6px 12px 5px;
	margin-right: 8px;
	margin-bottom: 8px;
	display: inline-block;
	font-size: 11px;
	background: 0 0;
	border: 1px solid var(--pcborder-cl);
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
	outline: 0;
	font-weight: 400;
	line-height: 1.2
}
.pctmp-term-list .term-labels i,
.pctmp-term-list .term-labels svg {
	vertical-align: middle;
	margin-right: 3px
}
.pctmp-term-list .term-labels svg {
	width: auto;
	max-height: 10px;
	display: inline-block
}
.pctmp-term-list.label-style-s2 .term-labels,
.pctmp-term-list.label-style-s3 .term-labels,
.pctmp-term-list.label-style-s4 .term-labels,
.pctmp-term-list.term-style-s2 .pctmp-term-item,
.pctmp-term-list.term-style-s3 .pctmp-term-item,
.pctmp-term-list.term-style-s4 .pctmp-term-item {
	padding: 6px 12px;
	border: 1px solid var(--pcborder-cl);
	color: #000;
	margin-left: 8px;
	margin-bottom: 8px;
	text-transform: uppercase;
	font-size: 11px
}
.pctmp-term-list.label-style-s3 .term-labels,
.pctmp-term-list.term-style-s3 .pctmp-term-item {
	border-radius: 50px
}
.pctmp-term-list.label-style-s4 .term-labels,
.pctmp-term-list.term-style-s4 .pctmp-term-item {
	border: 0;
	border-bottom: 2px solid var(--pcborder-cl);
	background-color: #f1f1f1
}
.pctmp-term-list .pctmp-term-item.current-item,
.pctmp-term-list .pctmp-term-item:hover,
.pctmp-term-list.term-style-s4 .pctmp-term-item.current-item,
.pctmp-term-list.term-style-s4 .pctmp-term-item:hover {
	border-color: var(--pcaccent-cl);
	background-color: var(--pcaccent-cl);
	color: #fff
}
.tags-share-box.post-share {
	position: relative;
	background: var(--pcbg-cl);
	z-index: 1;
}
.item.hentry .post-share-item.post-share-expand,
.item.hentry .post-share-item.post-share-plike,
.penci-featured-share-box .post-share-expand {
	display: none !important
}
.post-share-item.post-share-expand {
	visibility: hidden
}
body:not(.rtl) .post-share-item.post-share-expand {
	margin-right: 0 !important
}
body.rtl .post-share-item.post-share-expand {
	margin-left: 0 !important
}
.post-share-item.post-share-expand.showing {
	visibility: visible
}
.post-share-item.post-share-expand.hidden {
	display: none
}
.pcnew-share.size-large.penci-icon-full .post-share-item.post-share-expand i,
.penci-social-colored .post-share-item.post-share-expand i,
.tags-share-box.tags-share-box-s2 .post-share-item.post-share-expand {
	background-color: var(--pctext-cl);
	color: var(--pcbg-cl)
}
.pcnew-share.size-large.penci-icon-full .post-share-item.post-share-expand i:after,
.penci-social-colored .post-share-item.post-share-expand i:after {
	display: none
}
.tags-share-box.tags-share-box-s2 .post-share-item.post-share-plike .count-number-like,
.tags-share-box.tags-share-box-s2 .post-share-item.post-share-plike a {
	color: #fff
}
.pcnew-share:not(.penci-icon-full) .post-share-item.post-share-expand {
	padding-left: 0;
	padding-right: 0;
	font-size: 15px
}
.tags-share-box-s1 .post-share-item {
	background-color: transparent !important
}
.tags-share-box.tags-share-box-2_3 .post-share-expand i {
	transform: translateY(-1px)
}
.pcnew-share .post-share-expand i {
	transform: translateY(1px)
}
.pcnew-share.penci-icon-full .post-share-expand i {
	transform: none
}
.pcnew-share.no-spacing .post-share-expand i {
	transform: none
}
.tags-share-box {
	white-space: nowrap;
	opacity: 0;
	transition: opacity .15s ease-in-out
}
.tags-share-box.showing-hidden {
	white-space: normal
}
.tags-share-box.tags-share-box-s1 {
	opacity: 1;
	white-space: normal
}
.tags-share-box .new-ver-share:hover {
	z-index: 4
}
.tags-share-box .post-share-item.post-share-plike a:after {
	display: none
}
.show-txt.txt-below.size-large.post-share a.post-share-expand,
.show-txt.txt-below.size-large.post-share a.post-share-expand i {
	line-height: 90px
}
.penci-social-colored a i.fa-get-pocket {
	background: #e83c53
}
.pcsb-cml .post-comments .post-title-box {
	padding-top: 0;
	border-top: 0
}
.penci-standard-cat.s1 .penci-cat-name:after,
.penci-standard-cat.s2 .penci-cat-name:after,
.penci-standard-cat.s3 .penci-cat-name:after,
.penci-standard-cat.s4 .penci-cat-name:after {
	display: none
}
.penci-standard-cat.s1 .cat>.penci-cat-name,
.penci-standard-cat.s2 .cat>.penci-cat-name,
.penci-standard-cat.s3 .cat>.penci-cat-name,
.penci-standard-cat.s4 .cat>.penci-cat-name {
	padding: 2px 8px;
	background: #fff;
	color: var(--pcheading-cl);
	border-radius: 3px;
	display: inline-block;
	box-shadow: 1px 1px 1px rgba(55, 55, 55, .5)
}
.penci-standard-cat.s2 .cat>.penci-cat-name {
	background-color: var(--pcaccent-cl);
	color: #fff
}
.penci-standard-cat.s3 .cat>.penci-cat-name {
	background-color: #000;
	color: #fff
}
.penci-standard-cat.s4 .cat>.penci-cat-name {
	background-color: transparent;
	border: 1px solid var(--pcheading-cl);
	color: var(--pcheading-cl);
	padding: 2px 8px
}
.penci-standard-cat.s1 .cat>.penci-cat-name:hover,
.penci-standard-cat.s2 .cat>.penci-cat-name:hover,
.penci-standard-cat.s3 .cat>.penci-cat-name:hover {
	opacity: .85
}
.penci-standard-cat.s4 .cat>.penci-cat-name:hover {
	border-color: var(--pcaccent-cl);
	background-color: var(--pcaccent-cl);
	color: #fff
}
.penci-toc-wrapper {
	border: 1px solid var(--pcborder-cl);
	padding: 20px 25px 15px;
	margin-bottom: 20px;
	max-width: 320px;
	width: 100%;
	background-color: var(--pcbg-cl)
}
.penci-aw-sticky .entry-content .penci-toc-wrapper {
	display: none;
}
@media only screen and (max-width:767px) {
	.penci-toc-wrapper {
		max-width: unset !important
	}
}
.penci-toc-wrapper.penci-toc-default {
	max-width: unset
}
.penci-sticky-toc {
	position: fixed;
	transition: .3s all ease-in-out;
	max-width: 270px;
	width: 100%;
	top: 120px;
	z-index: 99999
}
.penci-sticky-toc.sticky-disable {
	display: none
}
.penci-sticky-toc.sticky-bottom {
	top: auto;
	bottom: 40px
}
.penci-sticky-toc.sticky-left {
	opacity: 0;
	visibility: hidden;
	left: 10px
}
.penci-sticky-toc {
	opacity: 0;
	visibility: hidden;
	transition: .3s all ease-in-out
}
.penci-sticky-toc.tocSticky {
	opacity: 1;
	visibility: visible
}
.penci-sticky-toc.sticky-right {
	right: 10px
}
.tocSticky .dis-toggle.penci-toc-wrapper.hide-table .penci-toc-head {
	margin-bottom: 15px
}
.penci-toc-wrapper .penci-toc-title {
	padding-right: 30px
}
@media only screen and (max-width:767px) {
	.penci-toc-container-wrapper {
		z-index: 1
	}
	.penci-sticky-toc {
		top: 120px;
		bottom: 0;
		z-index: 999999
	}
	.penci-sticky-toc.sticky-left {
		left: 15px
	}
	.penci-sticky-toc.sticky-right {
		right: 15px
	}
	.penci-sticky-toc.sticky-bottom {
		bottom: 120px;
		top: auto
	}
	.penci-sticky-toc.hide-table {
		z-index: 1;
		max-width: 50px
	}
	.penci-toc-container-wrapper.tocSticky.sticky-right .penci-toc-wrapper.hide-table {
		position: absolute;
		right: 0
	}
	.penci-toc-container-wrapper.tocSticky .penci-toc-wrapper.hide-table .penci-toc-title {
		max-width: 0;
		display: block;
		visibility: hidden;
		max-height: 0
	}
	.penci-toc-container-wrapper.tocSticky .penci-toc-wrapper span.penci-toc-title-toggle {
		top: 14px
	}
	.penci-toc-container-wrapper.tocSticky .penci-toc-wrapper.hide-table {
		padding: 10px
	}
	.penci-toc-container-wrapper.tocSticky .penci-toc-wrapper.hide-table span.penci-toc-title-toggle {
		top: 0;
		right: 0;
		transform: unset
	}
}
.penci-toc-wrapper.s2 {
	border-radius: 5px;
	background-color: var(--pcbg-cl);
	box-shadow: 0 1px 4px 3px rgba(0, 0, 0, .05)
}
.penci-toc-wrapper .penci-toc-title {
	margin: 0;
	font-size: 18px;
	font-weight: var(--pchead-wei)
}
.penci-toc-wrapper .penci-toc-head {
	position: relative;
	margin-bottom: 15px;
	min-height: 28px
}
.penci-toc-wrapper.s3 .penci-toc-head {
	margin-bottom: 5px
}
.penci-toc-wrapper .penci-toc-title-toggle {
	width: 28px;
	height: 28px;
	background-color: var(--pcmeta-cl);
	color: var(--pcbg-cl);
	position: absolute;
	line-height: 28px;
	right: 0;
	display: inline-block;
	vertical-align: middle;
	text-align: center;
	top: 50%;
	transform: translateY(-50%)
}
.penci-toc-wrapper.s2 .penci-toc-title-toggle {
	border-radius: 5px;
	background-color: var(--pcaccent-cl);
	color: #fff
}
.penci-toc-wrapper .penci-toc-title-toggle:hover {
	text-decoration: none
}
.penci-toc-wrapper .penci-toc-title-toggle:before {
	font-family: penciicon !important;
	font-size: 13px;
	content: "\f174"
}
.penci-toc-wrapper.show-table .penci-toc-title-toggle:before {
	content: "\f175"
}
.penci-toc-wrapper.hide-table .penci-toc-title-toggle:before {
	content: "\f174"
}
.penci-toc-wrapper.dis-toggle .penci-toc-title-toggle:before {
	font-size: 16px;
	content: "\f172" !important
}
.penci-toc-wrapper.hide-table .penci-toc-head {
	margin-bottom: 0
}
.penci-toc-wrapper .penci-toc>ul {
	border-top: 0;
	padding-top: 5px;
	margin-top: 5px
}
.post-entry .penci-toc-wrapper ul,
.post-entry .penci-toc-wrapper ul>li {
	list-style: none;
	margin: 0;
	padding-left: 0;
	padding-right: 0
}
.penci-toc-wrapper.counter-flat .penci-toc ul li {
	border-top: 1px solid var(--pcborder-cl)
}
.penci-toc-wrapper ul li {
	margin-bottom: 0
}
.penci-toc-wrapper.style-number ul,
.penci-toc-wrapper.style-number ul li {
	list-style: decimal outside;
	padding-left: 10px
}
.penci-toc-wrapper.style-bullets ul,
.penci-toc-wrapper.style-bullets ul li {
	list-style: square outside;
	padding-left: 10px
}
.penci-toc-wrapper.style-number ul li::marker {
	font-weight: 700
}
.post-entry .penci-toc ul {
	list-style: none;
	margin: 0;
	padding: 0
}
.post-entry .penci-toc ul li a {
	padding-top: 8px;
	padding-bottom: 8px
}
.post-entry .penci-toc ul ul {
	padding: 0 0 2px 10px;
	border-top: 1px solid var(--pcborder-cl)
}
.post-entry .penci-toc ul ul ul {
	border: 0
}
nav.penci-toc {
	max-height: calc(100vh - 230px);
	overflow: auto
}
.entry-content nav.penci-toc {
	max-height: 500px
}
.penci-toc ul ul {
	padding-left: 10px
}
.penci-toc>ul>li:not(:first-child),
.penci-toc>ul>li:not(:last-child) {
	border-top: 1px solid var(--pcborder-cl)
}
.penci-toc ul li:last-child>a {
	border: 0
}
.penci-toc ul ul li:last-child>a {
	border-bottom: 0
}
.penci-toc ul li:last-child {
	border-bottom: 0
}
.penci-toc ul a {
	display: block;
	padding: 2px 0;
	font-size: 14px;
	font-weight: 700;
	color: var(--pctext-cl);
	opacity: .82;
	text-decoration: none;
	transition: all .3s
}
.penci-toc ul a:hover,
.penci-toc ul li.active>a {
	text-decoration: none;
	color: var(--pcaccent-cl);
	opacity: 1
}
.penci-toc ul ul a {
	font-size: 14px;
	font-weight: 400
}
.penci-toc-wrapper .penci-toc ul,
.penci-toc-wrapper.counter-numeric .penci-toc>ul {
	counter-reset: item
}
.penci-toc-wrapper.counter-decimal .penci-toc ul li a:before {
	content: counters(item, ".") ". ";
	display: inline-block;
	counter-increment: item;
	margin-right: .2em
}
.penci-toc-wrapper.counter-roman .penci-toc ul li a:before {
	content: counters(item, ".", upper-roman) ". ";
	counter-increment: item;
	margin-right: .2em
}
.penci-toc-wrapper.counter-numeric .penci-toc ul li a:before {
	content: counters(item, ".") " ";
	counter-increment: item;
	margin-right: .2em
}
.penci-toc-wrapper.s3 {
	background-color: #f1f1f1
}
.penci-toc-wrapper.s3 ul,
.penci-toc-wrapper.s3 ul li,
.penci-toc-wrapper.s3 ul li a {
	border: 0 !important;
	padding-bottom: 1px;
	padding-top: 1px
}
.penci-toc-wrapper.penci-toc-wrap-left {
	float: left;
	margin: 0 30px 20px 0
}
.penci-toc-wrapper.penci-toc-wrap-right {
	float: right;
	margin: 0 0 20px 30px
}
.sticky-wrapper .penci-toc-wrapper {
	left: 30px
}
.showing-hidden .post-share-expand i.penciicon-add:before {
	content: "\f178"
}
.pcsb-ptitle .header-standard {
	margin-bottom: 0;
	overflow: hidden
}
.pcsb-ptitle .header-standard.align-left {
	text-align: left
}
.pcsb-ptitle .header-standard.align-left:after {
	left: 30px
}
.pcsb-ptitle .header-standard.align-right {
	text-align: right
}
.pcsb-ptitle .header-standard.align-right:after {
	right: 0;
	left: auto
}
.pcsb-share .tags-share-box {
	margin-bottom: 0
}
.pcsb-share .tags-share-box.post-share {
	position: relative;
	top: 0
}
.pcab-adesc .post-entry p,
.pcab-atitle .post-entry p {
	line-height: 1.6
}
.pcab-abrcrb .container.penci-breadcrumb,
.pcab-adesc .post-entry,
.pcab-adesc .post-entry>p:last-child,
.pcab-atitle .archive-box,
.pcab-atitle .post-entry>p:last-child {
	margin-bottom: 0
}
.pcab-atitle .post-entry.pcdcp-after {
	margin: 15px 0 0
}
.pcab-atitle .post-entry.pcdcp-before {
	margin: 0 0 15px
}
.pcab-abrcrb .container.penci-breadcrumb {
	margin-top: 0
}
.pcsb-brcrb .container.penci-breadcrumb,
.pcsb-ft .post-image,
.pcsb-meta .post-box-meta-single,
.pcsb-pnavi .post-pagination {
	margin-top: 0;
	margin-bottom: 0;
	border: 0
}
.pcsb-brcrb .container {
	width: 100%;
}
.pcsb-pnavi .post-pagination {
	padding-top: 0;
	padding-bottom: 0
}
.pcsb-pnavi .post-pagination.default-ratio .penci-post-nav-thumb {
	height: 56px !important
}
.pcsb-ft-o .container.penci-breadcrumb {
	margin-top: 0
}
.pcsb-ft-o .header-standard.header-classic {
	margin-bottom: 0
}
.pcsb-ft-o .post-image {
	margin-bottom: 0
}
.pcsb-ft-o .penci-move-title-above:after {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	background: #000;
	z-index: 1;
	bottom: 0;
	right: 0;
	background: linear-gradient(to bottom, transparent 50%, #000 90%);
	opacity: .7;
	transition: .3s
}
.pcsb-ft-o .cat>a.penci-cat-name,
.pcsb-ft-o .container.penci-breadcrumb i,
.pcsb-ft-o .container.penci-breadcrumb span,
.pcsb-ft-o .container.penci-breadcrumb span a,
.pcsb-ft-o .header-standard .author-post span,
.pcsb-ft-o .header-standard .author-post span a,
.pcsb-ft-o .header-standard .post-title,
.pcsb-ft-o .header-standard h2,
.pcsb-ft-o .header-standard h2 a,
.pcsb-ft-o .pc_titlebig_standard,
.pcsb-ft-o .pc_titlebig_standard a,
.pcsb-ft-o .penci-container-inside.penci-breadcrumb i,
.pcsb-ft-o .penci-container-inside.penci-breadcrumb span,
.pcsb-ft-o .penci-container-inside.penci-breadcrumb span a,
.pcsb-ft-o .post-box-meta-single a,
.pcsb-ft-o .post-box-meta-single span,
.pcsb-ft-o .post-box-meta-single span i {
	color: #fff
}
.pcsb-ft-o h2.penci-psub-title {
	letter-spacing: 0;
	text-transform: none;
	font-size: 18px;
	line-height: 1.3;
	margin: 8px 0
}
.pcsb-share .tags-share-box,
.pcsb-share .tags-share-box.center-box {
	border: 0;
	padding: 0;
	margin: 0
}
.elementor-widget-penci-single-related-posts .post-related {
	padding: 0
}
.post-box-meta-single .author-url img {
	vertical-align: middle;
	border-radius: 50%
}
.gradient-enable .post-title span,
.gradient-enable.penci-psub-title span {
	-webkit-background-clip: text;
	-webkit-text-fill-color: transparent
}
.pcsb-pnavi .post-pagination .next-post,
.pcsb-pnavi .post-pagination .prev-post {
	display: flex;
	align-items: center
}
.pcsb-pnavi .post-pagination .next-post {
	flex-direction: row-reverse
}
@media only screen and (max-width:767px) {
	.pcsb-pnavi .post-pagination .next-post,
	.pcsb-pnavi .post-pagination .prev-post {
		width: 100% !important;
		text-align: center;
		display: block
	}
	.pcsb-pnavi .post-pagination h5,
	.pcsb-pnavi .post-pagination h5.next-title {
		padding: 0
	}
}
.post-share.pcnew-share .count-number-like,
.post-share.tags-share-box-2_3.post-share .count-number-like,
.tags-share-box.tags-share-box-2_3.post-share .post-share-item .penci-post-like {
	color: #fff
}
.post-share.pcnew-share.border-style .count-number-like {
	color: var(--pcheading-cl)
}
.pcab-abox .title-bar {
	position: relative;
	padding-bottom: 15px;
	overflow: hidden
}
.pcab-abox .title-bar:after {
	content: "";
	position: absolute;
	width: 60px;
	height: 1px;
	background: var(--pcaccent-cl);
	display: block;
	bottom: 0
}
.pcab-abox .title-bar.align-center:after {
	left: 50%;
	margin-left: -30px
}
.pcab-abox .title-bar.align-center {
	text-align: center
}
.pcab-abox .title-bar.align-left {
	text-align: left
}
.pcab-abox .title-bar.align-left:after {
	left: 0
}
.pcab-abox .title-bar.align-right {
	text-align: right
}
.pcab-abox .title-bar.align-right:after {
	right: 0
}
.max-lv-1 ul ul {
	display: none
}
.max-lv-2 ul ul ul {
	display: none
}
.max-lv-3 ul ul ul ul {
	display: none
}
.max-lv-4 ul ul ul ul ul {
	display: none
}
.max-lv-5 ul ul ul ul ul ul {
	display: none
}
.pccustom-template-enable #header,
.pccustom-template-enable .pc-wrapbuilder-header,
.single-archive-template #header,
.single-custom-post-template #header,
.single-custom-post-template .pc-wrapbuilder-header {
	margin-bottom: 0 !important
}
.pccustom-template-enable .clear-footer,
.single-archive-template .clear-footer,
.single-custom-post-template .clear-footer {
	height: 0;
	margin-bottom: 0
}
.pcsb-athor .abio-style-2,
.pcsb-athor .abio-style-3,
.pcsb-athor .abio-style-4,
.pcsb-cmf #respond,
.pcsb-cmf .comment-respond,
.pcsb-mct .post-entry {
	margin-bottom: 0 !important
}
.pcsb-athor .post-author:not(:last-child) {
	margin-bottom: 30px
}
.pcsb-cmf .no-comment-yet h3.comment-reply-title {
	padding-top: 0 !important;
	border-top: 0
}
.pcsb-athor .abio-style-1 {
	border: none;
	padding: 0
}
@media only screen and (max-width:767px) {
	.pcsb-athor .abio-style-1.post-author .author-img,
	.pcsb-athor .abio-style-2.post-author .author-img {
		float: none;
		display: block;
		margin-left: auto;
		margin-right: auto
	}
	.pcsb-athor .abio-style-1.post-author .author-content,
	.pcsb-athor .abio-style-2.post-author .author-content {
		margin-left: 0 !important;
		text-align: center;
		margin-top: 10px
	}
}
.header-search-style-overlay .show-search {
	display: block !important;
	visibility: hidden;
	opacity: 0;
	transition: .3s all;
	transform: scale(.95)
}
body.search-open .header-search-style-overlay .show-search.active {
	visibility: visible;
	opacity: 1;
	transform: scale(1)
}
.header-search-style-overlay .show-search {
	position: fixed;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	background-color: rgba(0, 0, 0, .95);
	z-index: 99999999;
	width: 100vw;
	height: 100vh !important
}
.header-search-style-overlay .show-search .penci-search-form,
.header-search-style-overlay .show-search form.pc-searchform {
	width: 100%;
	max-width: 600px;
	margin-left: auto;
	margin-right: auto;
	padding-left: 15px;
	padding-right: 15px;
	top: 50%;
	transform: translateY(-50%);
	position: relative;
	transition: .3s transform ease-in-out
}
.header-search-style-overlay .show-search .penci-search-form.has-search-items {
	transform: translateY(calc((50% + 125px) * -1))
}
.header-search-style-overlay .show-search form.pc-searchform .pc-searchform-inner {
	padding: 5px 0;
	border-bottom: 1px solid rgba(255, 255, 255, .2)
}
.header-search-style-overlay .show-search form.pc-searchform.penci-ajax-search .pc-searchform-inner {
	width: 100%
}
.header-search-style-overlay .show-search .penci-search-form input.s,
.header-search-style-overlay .show-search form.pc-searchform input.search-input {
	position: static;
	color: #fff;
	font-size: 38px;
	line-height: 75px;
	font-weight: 700;
	width: 90%
}
.header-search-style-overlay .show-search .penci-search-form form {
	border: 0;
	padding: 0
}
.header-search-style-overlay .show-search .penci-search-form form button {
	border: 0;
	background: 0 0;
	padding: 0
}
.header-search-style-overlay .show-search .search-results-wrapper {
	top: 10px;
	transform: translateY(-45px);
	--pcajs_tcl: #fff;
	--pcbg-cl: #000;
	--pcborder-cl: rgba(255, 251, 2, 0.25);
	--pcajs_bcl: rgba(255, 255, 255, 0.1)
}
.header-search-style-overlay .show-search .search-results-wrapper .view-all-results {
	background-color: #000;
	color: var(--pcajs_tcl)
}
.header-search-style-overlay .show-search .search-results-wrapper .view-all-results:hover {
	color: var(--pcaccent-cl)
}
.header-search-style-overlay .show-search .search-results-wrapper .penci-dropdown-results {
	background-color: transparent
}
@media only screen and (min-width:1170px) {
	.header-search-style-overlay .show-search .search-results-wrapper .penci-search-results .autocomplete-suggestion {
		flex: 1 1 50%;
		max-width: 50%;
		padding: 5px 20px
	}
}
.header-search-style-overlay .show-search .search-results-wrapper .penci-dropdown-results .autocomplete-suggestions {
	background-color: #121212
}
.header-search-style-default .show-search.pcajx-search-loading .penci-search-form form button {
	padding: 0;
	transition: unset
}
.autocomplete-suggestions {
	max-height: 300px;
	overflow-y: auto;
	overflow-x: hidden
}
.pcbds-overlay .search-results-wrapper .penci-dropdown-results.penci-opened {
	box-shadow: none !important;
	-moz-box-shadow: none !important;
	-webkit-box-shadow: none !important
}
.header-search-style-overlay .penci-search-form.penci-ajax-search form button:after {
	width: 24px;
	height: 24px;
	top: calc(50% - 12px);
	margin: 0 0 0 -13px
}
.header-search-style-overlay .show-search .penci-search-form form button:after,
.header-search-style-overlay .show-search .penci-search-form form button:before {
	font-size: 22px;
	line-height: 22px
}
.header-search-style-overlay .penci-search-form form.penci-ajax-search .pc-eajxsearch button:after {
	content: "\f108" !important;
	font-family: penciicon !important;
	display: block;
	visibility: visible;
	animation: none;
	border: 0;
	margin: 0;
	right: 0;
	top: 50%;
	left: auto;
	color: var(--pctext-cl);
	opacity: .9
}
.header-search-style-overlay .penci-search-form form.penci-ajax-search.search-loading .pc-eajxsearch button:after {
	visibility: hidden;
	display: none;
	opacity: 0
}
.header-search-style-overlay .show-search form.pc-searchform::placeholder {
	color: #fff
}
.header-search-style-overlay .show-search a.close-search {
	color: #fff;
	font-size: 32px;
	top: 30px;
	right: 30px;
	background: 0 0 !important;
	margin: 0 !important;
	padding: 0 !important;
	border: 0 !important;
	height: auto !important;
	line-height: unset !important;
	width: auto;
	transition: .3s all ease-in-out
}
@media only screen and (max-width:767px) {
	.header-search-style-overlay .show-search a.close-search {
		top: 15px;
		right: 15px
	}
	.header-search-style-overlay .show-search form.pc-searchform input.search-input {
		font-size: 28px;
		padding-top: 10px;
		padding-bottom: 10px
	}
}
.header-search-style-overlay .show-search a.close-search:hover {
	opacity: .85
}
body.pchds-overlay.search-open {
	overflow: hidden
}
.penci_nav_row .show-search.active,
body.pchds-overlay.search-open .show-search {
	display: block !important
}
.penci_search_box_widget input[type=text] {
	margin: 0
}
.penci_search_box_widget .penci-search-form form {
	border: 0;
	padding: 0
}
.penci_search_box_widget .search-style-text-button.penci-search-form form button:after {
	display: none
}
.pcnav-lgroup {
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	left: auto;
	display: flex;
	flex-wrap: wrap;
	align-items: center;
	align-content: center;
	flex-direction: row;
	justify-content: end;
	opacity: 0;
	z-index: 9;
	padding: 0 12px
}
.pcnav-lgroup .hidden-item {
	visibility: hidden;
	width: 1px
}
.pcalign-right .pcnav-lgroup {
	right: auto;
	left: 0;
	justify-content: start
}
.pciconp-right.pcalign-left.style-15 .pcnav-lgroup {
	right: 36px
}
.pciconp-left.pcalign-right.style-15 .pcnav-lgroup {
	left: 36px
}
.pcnav-lgroup.loaded {
	opacity: 1
}
.pcnav-lgroup ul {
	list-style: none;
	margin: 0;
	padding: 0;
	white-space: normal
}
.pcnav-lgroup ul ul {
	position: absolute;
	top: 100%;
	right: 0;
	width: 190px;
	background-color: rgba(255, 255, 255, .9);
	border: 1px solid var(--pcborder-cl);
	margin: 4px 0 0;
	padding: 10px 15px;
	z-index: 9;
	opacity: 0;
	visibility: hidden;
	text-align: right
}
.pcalign-right .pcnav-lgroup ul ul {
	right: auto;
	left: 0;
	text-align: left
}
.pcnav-lgroup ul li:hover>ul {
	opacity: 1;
	visibility: visible;
	display: block !important
}
.pcnav-lgroup ul li {
	display: inline-block;
	margin: 0;
	padding: 0;
	position: relative;
	line-height: unset;
	list-style: none
}
.pcnav-lgroup ul li.pcaj-next {
	margin-left: 4px
}
.pcnav-lgroup ul.pcflx>li:last-child>a {
	padding-right: 0 !important
}
.pcnav-lgroup ul.pcflx>li:first-child>a {
	padding-left: 0 !important
}
.pcalign-right .pcnav-lgroup ul li.pcaj-next {
	margin-right: 0
}
.pcnav-lgroup ul.pcflx-nav {
	padding-left: 15px
}
@media only screen and (max-width: 767px) {
	.pcnav-lgroup {
		padding-left: 0;
		padding-right: 0;
		left: auto;
		right: 12px;
	}
	.pcalign-right .pcnav-lgroup {
		right: auto;
		left: 12px;
	}
	.pcnav-lgroup ul.pcflx-nav {
		padding-left: 10px;
	  	margin-top: -3px;
	}
  }
.pcnav-lgroup ul li.pcaj-nav-item a {
	padding-left: 0;
	padding-right: 0;
	vertical-align: middle;
	font-size: 13px
}
.pcnav-lgroup ul li.pcaj-nav-item a i {
	line-height: inherit;
	vertical-align: middle
}
.pcnav-lgroup ul li.pcaj-nav-item a.disable {
	pointer-events: none;
	opacity: .4 !important;
	cursor: default
}
.pcnav-lgroup ul li.pc-more-items>a:after {
	font-family: FontAwesome;
	content: "\f107";
	display: inline-block;
	margin-left: 3px;
	font-size: 13px;
	opacity: inherit
}
.pcnav-lgroup ul li {
	color: var(--pcheading-cl)
}
.pcnav-lgroup ul li a {
	display: inline-block;
	padding: 0 10px;
	color: inherit;
	opacity: .6;
	transition: all .3s;
	text-decoration: none;
	font-size: 14px
}
.pcnav-lgroup ul li i {
	color: inherit
}
.pcnav-lgroup ul li:hover>a,
.pcnav-lgroup ul li>a.clactive {
	opacity: 1;
	color: var(--pcaccent-cl)
}
.pcnav-lgroup ul ul li a {
	line-height: 1.3;
	display: block;
	padding: 3px 0
}
.pcnav-lgroup ul ul li a:hover {
	color: var(--pcaccent-cl)
}
.pcnav-lgroup ul ul li {
	display: block;
	padding: 2px 0
}
.pcnav-lgroup ul ul li:last-child {
	border: 0
}
.loading-posts.pctb-ajax-ldp {
	position: relative
}
.loading-posts.pctb-ajax-ldp:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 200;
	background: #fff;
	opacity: .65;
	display: block
}
.penci-biggrid .penci-pagination {
	order: 9999999
}
.penci-homepage-title.style-4 .pcnav-lgroup {
	background-color: transparent
}
.penci-homepage-title.style-4 .pcnav-lgroup>ul {
	background-color: var(--pcbg-cl)
}
.penci-homepage-title.style-4.pcalign-right .pcnav-lgroup>ul {
	padding-right: 15px
}
.penci-homepage-title.style-4.pcalign-center .pcnav-lgroup>ul,
.penci-homepage-title.style-4.pcalign-left .pcnav-lgroup>ul {
	padding-left: 15px
}
.penci-homepage-title.style-10 .pcnav-lgroup,
.penci-homepage-title.style-11 .pcnav-lgroup,
.penci-homepage-title.style-12 .pcnav-lgroup,
.penci-homepage-title.style-13 .pcnav-lgroup,
.penci-homepage-title.style-14 .pcnav-lgroup,
.penci-homepage-title.style-16 .pcnav-lgroup,
.penci-homepage-title.style-17 .pcnav-lgroup,
.penci-homepage-title.style-4 .pcnav-lgroup,
.penci-homepage-title.style-5 .pcnav-lgroup,
.penci-homepage-title.style-6 .pcnav-lgroup,
.penci-homepage-title.style-7 .pcnav-lgroup,
.penci-homepage-title.style-9 .pcnav-lgroup {
	padding: 0
}
.pcftaj-ld {
	position: relative;
	overflow: hidden
}
.pcftaj-ld .penci-loader-effect {
	display: block
}
.pcftaj-ld:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 200;
	background: var(--pcbg-cl);
	opacity: .65;
	display: block
}
.penci-loader-effect {
	width: 40px;
	height: 40px;
	margin: 0 auto;
	margin-top: -20px;
	margin-left: -20px;
	display: none;
	position: absolute;
	top: 50%;
	left: 50%;
	z-index: 300
}
.penci-portfolio .penci-loader-effect {
	top: 50px;
}
@media (max-width:767px) {
	.penci-loader-effect {
		top: 135px
	}
}
.penci-loading-animation:after,
.penci-loading-animation:before {
	content: "";
	position: absolute
}
.penci-loading-animation-1 .penci-loading-animation,
.penci-loading-animation-1 .penci-loading-animation:after,
.penci-loading-animation-1 .penci-loading-animation:before,
.penci-loading-animation-5 .penci-loading-animation,
.penci-loading-animation-6 .penci-loading-animation:before,
.penci-loading-animation-7 .penci-loading-animation,
.penci-loading-animation-8 .penci-loading-animation,
.penci-loading-animation-9 .penci-loading-circle-inner:before {
	background-color: var(--pcaccent-cl)
}
.penci-load-thecube {
	transform: rotateZ(45deg);
	-webkit-transform: rotateZ(45deg);
	-moz-transform: rotateZ(45deg)
}
.penci-load-thecube .penci-load-cube {
	position: relative;
	transform: rotateZ(45deg);
	-webkit-transform: rotateZ(45deg);
	-moz-transform: rotateZ(45deg)
}
.penci-load-thecube .penci-load-cube {
	float: left;
	width: 50%;
	height: 50%;
	position: relative;
	transform: scale(1.1);
	-webkit-transform: scale(1.1);
	-moz-transform: scale(1.1)
}
.penci-load-thecube .penci-load-cube:before {
	content: "";
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	animation: penci-load-fold-thecube 1.44s infinite linear both;
	-webkit-animation: penci-load-fold-thecube 1.44s infinite linear both;
	-moz-animation: penci-load-fold-thecube 1.44s infinite linear both;
	transform-origin: 100% 100%;
	-webkit-transform-origin: 100% 100%;
	-moz-transform-origin: 100% 100%
}
.penci-load-thecube .penci-load-c2 {
	transform: scale(1.1) rotateZ(90deg);
	-webkit-transform: scale(1.1) rotateZ(90deg);
	-moz-transform: scale(1.1) rotateZ(90deg)
}
.penci-load-thecube .penci-load-c3 {
	transform: scale(1.1) rotateZ(180deg);
	-ms-transform: scale(1.1) rotateZ(180deg);
	-webkit-transform: scale(1.1) rotateZ(180deg);
	-moz-transform: scale(1.1) rotateZ(180deg)
}
.penci-load-thecube .penci-load-c4 {
	transform: scale(1.1) rotateZ(270deg);
	-webkit-transform: scale(1.1) rotateZ(270deg);
	-moz-transform: scale(1.1) rotateZ(270deg)
}
.penci-load-thecube .penci-load-c2:before {
	animation-delay: 175ms;
	-webkit-animation-delay: 175ms;
	-moz-animation-delay: 175ms
}
.penci-load-thecube .penci-load-c3:before {
	animation-delay: .36s;
	-webkit-animation-delay: .36s;
	-moz-animation-delay: .36s
}
.penci-load-thecube .penci-load-c4:before {
	animation-delay: 535ms;
	-webkit-animation-delay: 535ms;
	-moz-animation-delay: 535ms
}
@keyframes penci-load-fold-thecube {
	0%,
	10% {
		transform: perspective(77px) rotateX(-180deg);
		opacity: 0
	}
	25%,
	75% {
		transform: perspective(77px) rotateX(0);
		opacity: 1
	}
	100%,
	90% {
		transform: perspective(77px) rotateY(180deg);
		opacity: 0
	}
}
@-webkit-keyframes penci-load-fold-thecube {
	0%,
	10% {
		-webkit-transform: perspective(77px) rotateX(-180deg);
		opacity: 0
	}
	25%,
	75% {
		-webkit-transform: perspective(77px) rotateX(0);
		opacity: 1
	}
	100%,
	90% {
		-webkit-transform: perspective(77px) rotateY(180deg);
		opacity: 0
	}
}
.penci-three-bounce {
	text-align: center;
	position: relative
}
.penci-three-bounce .one,
.penci-three-bounce .three,
.penci-three-bounce .two {
	display: inline-block;
	width: 15px;
	height: 15px;
	border-radius: 100%;
	background-color: var(--pcaccent-cl);
	-webkit-animation: pencibouncedelay 1s infinite ease-in-out both;
	animation: pencibouncedelay 1s infinite ease-in-out both
}
.penci-three-bounce .one {
	-webkit-animation-delay: -.32s;
	animation-delay: -.32s
}
.penci-three-bounce .two {
	-webkit-animation-delay: -.16s;
	animation-delay: -.16s;
	margin: 0 5px
}
@-webkit-keyframes pencibouncedelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1)
	}
}
@keyframes pencibouncedelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		transform: scale(1);
		-webkit-transform: scale(1)
	}
}
.penci-loading-animation-1 {
	width: 50px;
	height: 40px;
	text-align: center;
	font-size: 10px;
	margin-left: -25px;
	margin-top: -20px
}
.penci-loading-animation-1>div {
	background-color: var(--pcaccent-cl);
	height: 100%;
	width: 6px;
	margin: 0 1px;
	display: inline-block;
	-webkit-animation: pencistretchdelay 1s infinite ease-in-out;
	animation: pencistretchdelay 1s infinite ease-in-out
}
.penci-loading-animation-1 .rect2 {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}
.penci-loading-animation-1 .rect3 {
	-webkit-animation-delay: -.8s;
	animation-delay: -.8s
}
.penci-loading-animation-1 .rect4 {
	-webkit-animation-delay: -.7s;
	animation-delay: -.7s
}
@-webkit-keyframes pencistretchdelay {
	0%,
	100%,
	40% {
		-webkit-transform: scaleY(.4)
	}
	20% {
		-webkit-transform: scaleY(1)
	}
}
@keyframes pencistretchdelay {
	0%,
	100%,
	40% {
		transform: scaleY(.4);
		-webkit-transform: scaleY(.4)
	}
	20% {
		transform: scaleY(1);
		-webkit-transform: scaleY(1)
	}
}
body {
	--pc-loader-2:var(--pcaccent-cl)
}
.penci-loading-animation-2 {
	-webkit-transform: scale(.5);
	-ms-transform: scale(.5);
	transform: scale(.5)
}
.penci-loading-animation-2 .penci-loading-animation {
	margin: 26px auto;
	width: 1em;
	height: 1em;
	border-radius: 50%;
	position: relative;
	-webkit-animation: loader-2 .85s infinite linear;
	animation: loader-2 .85s infinite linear
}
@-webkit-keyframes loader-2 {
	0%,
	100% {
		box-shadow: 0 -3em 0 .2em var(--pc-loader-2), 2em -2em 0 0 var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 0 var(--pc-loader-2)
	}
	12.5% {
		box-shadow: 0 -3em 0 0 var(--pc-loader-2), 2em -2em 0 .2em var(--pc-loader-2), 3em 0 0 0 var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	25% {
		box-shadow: 0 -3em 0 -.5em var(--pc-loader-2), 2em -2em 0 0 var(--pc-loader-2), 3em 0 0 .2em var(--pc-loader-2), 2em 2em 0 0 var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	37.5% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 0 var(--pc-loader-2), 2em 2em 0 .2em var(--pc-loader-2), 0 3em 0 0 var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	50% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 0 var(--pc-loader-2), 0 3em 0 .2em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	62.5% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 0 var(--pc-loader-2), -2em 2em 0 .2em var(--pc-loader-2), -3em 0 0 0 var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	75% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 .2em var(--pc-loader-2), -2em -2em 0 0 var(--pc-loader-2)
	}
	87.5% {
		box-shadow: 0 -3em 0 0 var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 0 var(--pc-loader-2), -2em -2em 0 .2em var(--pc-loader-2)
	}
}
@keyframes loader-2 {
	0%,
	100% {
		box-shadow: 0 -3em 0 .2em var(--pc-loader-2), 2em -2em 0 0 var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 0 var(--pc-loader-2)
	}
	12.5% {
		box-shadow: 0 -3em 0 0 var(--pc-loader-2), 2em -2em 0 .2em var(--pc-loader-2), 3em 0 0 0 var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	25% {
		box-shadow: 0 -3em 0 -.5em var(--pc-loader-2), 2em -2em 0 0 var(--pc-loader-2), 3em 0 0 .2em var(--pc-loader-2), 2em 2em 0 0 var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	37.5% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 0 var(--pc-loader-2), 2em 2em 0 .2em var(--pc-loader-2), 0 3em 0 0 var(--pc-loader-2), -2em 2em 0 -1em var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	50% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 0 var(--pc-loader-2), 0 3em 0 .2em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 -1em var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	62.5% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 0 var(--pc-loader-2), -2em 2em 0 .2em var(--pc-loader-2), -3em 0 0 0 var(--pc-loader-2), -2em -2em 0 -1em var(--pc-loader-2)
	}
	75% {
		box-shadow: 0 -3em 0 -1em var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 .2em var(--pc-loader-2), -2em -2em 0 0 var(--pc-loader-2)
	}
	87.5% {
		box-shadow: 0 -3em 0 0 var(--pc-loader-2), 2em -2em 0 -1em var(--pc-loader-2), 3em 0 0 -1em var(--pc-loader-2), 2em 2em 0 -1em var(--pc-loader-2), 0 3em 0 -1em var(--pc-loader-2), -2em 2em 0 0 var(--pc-loader-2), -3em 0 0 0 var(--pc-loader-2), -2em -2em 0 .2em var(--pc-loader-2)
	}
}
.penci-loading-animation-3 {
	-webkit-transform: scale(.55);
	-ms-transform: scale(.55);
	transform: scale(.55)
}
.penci-loading-animation-3 .penci-loading-animation {
	margin: 26px auto;
	width: 16px;
	height: 16px;
	border-radius: 50%;
	position: relative;
	-webkit-animation: loader-3 .7s infinite ease;
	animation: loader-3 .7s infinite ease
}
@-webkit-keyframes loader-3 {
	0%,
	100% {
		box-shadow: 0 -2.6em 0 0 #3f51b5, 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .5), -1.8em -1.8em 0 0 rgba(63, 81, 181, .7)
	}
	12.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .7), 1.8em -1.8em 0 0 #3f51b5, 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .5)
	}
	25% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .5), 1.8em -1.8em 0 0 rgba(63, 81, 181, .7), 2.5em 0 0 0 #3f51b5, 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	37.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .5), 2.5em 0 0 0 rgba(63, 81, 181, .7), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	50% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .5), 1.75em 1.75em 0 0 rgba(63, 81, 181, .7), 0 2.5em 0 0 #3f51b5, -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	62.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .5), 0 2.5em 0 0 rgba(63, 81, 181, .7), -1.8em 1.8em 0 0 #3f51b5, -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	75% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .5), -1.8em 1.8em 0 0 rgba(63, 81, 181, .7), -2.6em 0 0 0 #3f51b5, -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	87.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .5), -2.6em 0 0 0 rgba(63, 81, 181, .7), -1.8em -1.8em 0 0 #3f51b5
	}
}
@keyframes loader-3 {
	0%,
	100% {
		box-shadow: 0 -2.6em 0 0 #3f51b5, 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .5), -1.8em -1.8em 0 0 rgba(63, 81, 181, .7)
	}
	12.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .7), 1.8em -1.8em 0 0 #3f51b5, 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .5)
	}
	25% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .5), 1.8em -1.8em 0 0 rgba(63, 81, 181, .7), 2.5em 0 0 0 #3f51b5, 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	37.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .5), 2.5em 0 0 0 rgba(63, 81, 181, .7), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	50% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .5), 1.75em 1.75em 0 0 rgba(63, 81, 181, .7), 0 2.5em 0 0 #3f51b5, -1.8em 1.8em 0 0 rgba(63, 81, 181, .2), -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	62.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .5), 0 2.5em 0 0 rgba(63, 81, 181, .7), -1.8em 1.8em 0 0 #3f51b5, -2.6em 0 0 0 rgba(63, 81, 181, .2), -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	75% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .5), -1.8em 1.8em 0 0 rgba(63, 81, 181, .7), -2.6em 0 0 0 #3f51b5, -1.8em -1.8em 0 0 rgba(63, 81, 181, .2)
	}
	87.5% {
		box-shadow: 0 -2.6em 0 0 rgba(63, 81, 181, .2), 1.8em -1.8em 0 0 rgba(63, 81, 181, .2), 2.5em 0 0 0 rgba(63, 81, 181, .2), 1.75em 1.75em 0 0 rgba(63, 81, 181, .2), 0 2.5em 0 0 rgba(63, 81, 181, .2), -1.8em 1.8em 0 0 rgba(63, 81, 181, .5), -2.6em 0 0 0 rgba(63, 81, 181, .7), -1.8em -1.8em 0 0 #3f51b5
	}
}
.penci-loading-animation-4 {
	width: auto;
	height: auto;
	margin-top: 0;
	margin-left: 0
}
.penci-loading-animation-4 .penci-loading-animation {
	font-size: 30px;
	overflow: hidden;
	width: 1em;
	height: 1em;
	border-radius: 50%;
	margin: 0 auto;
	margin-top: -.5em;
	margin-left: -.5em;
	position: relative;
	-webkit-animation: loader-4 1s infinite ease;
	animation: loader-4 1s infinite ease
}
@-webkit-keyframes loader-4 {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0);
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
	5%,
	95% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
	10%,
	59% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.087em -.825em 0 -.42em var(--pcaccent-cl), -.173em -.812em 0 -.44em var(--pcaccent-cl), -.256em -.789em 0 -.46em var(--pcaccent-cl), -.297em -.775em 0 -.477em var(--pcaccent-cl)
	}
	20% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.338em -.758em 0 -.42em var(--pcaccent-cl), -.555em -.617em 0 -.44em var(--pcaccent-cl), -.671em -.488em 0 -.46em var(--pcaccent-cl), -.749em -.34em 0 -.477em var(--pcaccent-cl)
	}
	48% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.377em -.74em 0 -.42em var(--pcaccent-cl), -.645em -.522em 0 -.44em var(--pcaccent-cl), -.775em -.297em 0 -.46em var(--pcaccent-cl), -.82em -.09em 0 -.477em var(--pcaccent-cl)
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg);
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
}
@keyframes loader-4 {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0);
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
	5%,
	95% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
	10%,
	59% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.087em -.825em 0 -.42em var(--pcaccent-cl), -.173em -.812em 0 -.44em var(--pcaccent-cl), -.256em -.789em 0 -.46em var(--pcaccent-cl), -.297em -.775em 0 -.477em var(--pcaccent-cl)
	}
	20% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.338em -.758em 0 -.42em var(--pcaccent-cl), -.555em -.617em 0 -.44em var(--pcaccent-cl), -.671em -.488em 0 -.46em var(--pcaccent-cl), -.749em -.34em 0 -.477em var(--pcaccent-cl)
	}
	48% {
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), -.377em -.74em 0 -.42em var(--pcaccent-cl), -.645em -.522em 0 -.44em var(--pcaccent-cl), -.775em -.297em 0 -.46em var(--pcaccent-cl), -.82em -.09em 0 -.477em var(--pcaccent-cl)
	}
	100% {
		-webkit-transform: rotate(360deg);
		transform: rotate(360deg);
		box-shadow: 0 -.83em 0 -.4em var(--pcaccent-cl), 0 -.83em 0 -.42em var(--pcaccent-cl), 0 -.83em 0 -.44em var(--pcaccent-cl), 0 -.83em 0 -.46em var(--pcaccent-cl), 0 -.83em 0 -.477em var(--pcaccent-cl)
	}
}
.penci-loading-animation-5 {
	width: 58px;
	height: 20px;
	position: absolute;
	margin-top: -10px;
	margin-left: -29px
}
.penci-loading-animation-7 .penci-loading-animation {
	width: 33%;
	height: 33%;
	float: left;
	-webkit-animation: loader-7 1.1s infinite ease-in-out;
	animation: loader-7 1.1s infinite ease-in-out
}
.penci-loading-animation-7 .penci-loading-animation-inner-1 {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}
.penci-loading-animation-7 .penci-loading-animation-inner-2 {
	-webkit-animation-delay: .3s;
	animation-delay: .3s
}
.penci-loading-animation-7 .penci-loading-animation-inner-3 {
	-webkit-animation-delay: .4s;
	animation-delay: .4s
}
.penci-loading-animation-7 .penci-loading-animation-inner-4 {
	-webkit-animation-delay: .1s;
	animation-delay: .1s
}
.penci-loading-animation-7 .penci-loading-animation-inner-5 {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}
.penci-loading-animation-7 .penci-loading-animation-inner-6 {
	-webkit-animation-delay: .3s;
	animation-delay: .3s
}
.penci-loading-animation-7 .penci-loading-animation-inner-7 {
	-webkit-animation-delay: 0s;
	animation-delay: 0s
}
.penci-loading-animation-7 .penci-loading-animation-inner-8 {
	-webkit-animation-delay: .1s;
	animation-delay: .1s
}
.penci-loading-animation-7 .penci-loading-animation-inner-9 {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}
@-webkit-keyframes loader-7 {
	0%,
	100%,
	70% {
		-webkit-transform: scale3D(1, 1, 1);
		transform: scale3D(1, 1, 1)
	}
	35% {
		-webkit-transform: scale3D(0, 0, 1);
		transform: scale3D(0, 0, 1)
	}
}
@keyframes loader-7 {
	0%,
	100%,
	70% {
		-webkit-transform: scale3D(1, 1, 1);
		transform: scale3D(1, 1, 1)
	}
	35% {
		-webkit-transform: scale3D(0, 0, 1);
		transform: scale3D(0, 0, 1)
	}
}
.penci-loading-animation-8 .penci-loading-animation {
	width: 10px;
	height: 10px;
	position: absolute;
	top: 0;
	left: 0;
	-webkit-animation: loader-8 1.6s ease-in-out -1.8s infinite both;
	animation: loader-8 1.6s ease-in-out -1.8s infinite both
}
.penci-loading-animation-8 .penci-loading-animation-inner-2 {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}
@-webkit-keyframes loader-8 {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	25% {
		-webkit-transform: translateX(30px) rotate(-90deg) scale(.5);
		transform: translateX(30px) rotate(-90deg) scale(.5)
	}
	50% {
		-webkit-transform: translateX(30px) translateY(30px) rotate(-179deg);
		transform: translateX(30px) translateY(30px) rotate(-179deg)
	}
	50.1% {
		-webkit-transform: translateX(30px) translateY(30px) rotate(-180deg);
		transform: translateX(30px) translateY(30px) rotate(-180deg)
	}
	75% {
		-webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5);
		transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5)
	}
	100% {
		-webkit-transform: rotate(-360deg);
		transform: rotate(-360deg)
	}
}
@keyframes loader-8 {
	0% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	25% {
		-webkit-transform: translateX(30px) rotate(-90deg) scale(.5);
		transform: translateX(30px) rotate(-90deg) scale(.5)
	}
	50% {
		-webkit-transform: translateX(30px) translateY(30px) rotate(-179deg);
		transform: translateX(30px) translateY(30px) rotate(-179deg)
	}
	50.1% {
		-webkit-transform: translateX(30px) translateY(30px) rotate(-180deg);
		transform: translateX(30px) translateY(30px) rotate(-180deg)
	}
	75% {
		-webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5);
		transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5)
	}
	100% {
		-webkit-transform: rotate(-360deg);
		transform: rotate(-360deg)
	}
}
.penci-loading-circle {
	margin: 0 auto;
	width: 40px;
	height: 40px;
	position: relative
}
.penci-loading-circle .penci-loading-circle-inner {
	width: 100%;
	height: 100%;
	position: absolute;
	left: 0;
	top: 0
}
.penci-loading-circle .penci-loading-circle-inner:before {
	content: "";
	display: block;
	margin: 0 auto;
	width: 15%;
	height: 15%;
	border-radius: 100%;
	-webkit-animation: penciLoadingCircleBounceDelay .7s infinite ease-in-out both;
	animation: penciLoadingCircleBounceDelay .7s infinite ease-in-out both
}
.penci-loading-circle .penci-loading-circle2 {
	-webkit-transform: rotate(30deg);
	-ms-transform: rotate(30deg);
	transform: rotate(30deg)
}
.penci-loading-circle .penci-loading-circle3 {
	-webkit-transform: rotate(60deg);
	-ms-transform: rotate(60deg);
	transform: rotate(60deg)
}
.penci-loading-circle .penci-loading-circle4 {
	-webkit-transform: rotate(90deg);
	-ms-transform: rotate(90deg);
	transform: rotate(90deg)
}
.penci-loading-circle .penci-loading-circle5 {
	-webkit-transform: rotate(120deg);
	-ms-transform: rotate(120deg);
	transform: rotate(120deg)
}
.penci-loading-circle .penci-loading-circle6 {
	-webkit-transform: rotate(150deg);
	-ms-transform: rotate(150deg);
	transform: rotate(150deg)
}
.penci-loading-circle .penci-loading-circle7 {
	-webkit-transform: rotate(180deg);
	-ms-transform: rotate(180deg);
	transform: rotate(180deg)
}
.penci-loading-circle .penci-loading-circle8 {
	-webkit-transform: rotate(210deg);
	-ms-transform: rotate(210deg);
	transform: rotate(210deg)
}
.penci-loading-circle .penci-loading-circle9 {
	-webkit-transform: rotate(240deg);
	-ms-transform: rotate(240deg);
	transform: rotate(240deg)
}
.penci-loading-circle .penci-loading-circle10 {
	-webkit-transform: rotate(270deg);
	-ms-transform: rotate(270deg);
	transform: rotate(270deg)
}
.penci-loading-circle .penci-loading-circle11 {
	-webkit-transform: rotate(300deg);
	-ms-transform: rotate(300deg);
	transform: rotate(300deg)
}
.penci-loading-circle .penci-loading-circle12 {
	-webkit-transform: rotate(330deg);
	-ms-transform: rotate(330deg);
	transform: rotate(330deg)
}
.penci-loading-circle .penci-loading-circle2:before {
	-webkit-animation-delay: -1.1s;
	animation-delay: -1.1s
}
.penci-loading-circle .penci-loading-circle3:before {
	-webkit-animation-delay: -1s;
	animation-delay: -1s
}
.penci-loading-circle .penci-loading-circle4:before {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}
.penci-loading-circle .penci-loading-circle5:before {
	-webkit-animation-delay: -.8s;
	animation-delay: -.8s
}
.penci-loading-circle .penci-loading-circle6:before {
	-webkit-animation-delay: -.7s;
	animation-delay: -.7s
}
.penci-loading-circle .penci-loading-circle7:before {
	-webkit-animation-delay: -.6s;
	animation-delay: -.6s
}
.penci-loading-circle .penci-loading-circle8:before {
	-webkit-animation-delay: -.5s;
	animation-delay: -.5s
}
.penci-loading-circle .penci-loading-circle9:before {
	-webkit-animation-delay: -.4s;
	animation-delay: -.4s
}
.penci-loading-circle .penci-loading-circle10:before {
	-webkit-animation-delay: -.3s;
	animation-delay: -.3s
}
.penci-loading-circle .penci-loading-circle11:before {
	-webkit-animation-delay: -.2s;
	animation-delay: -.2s
}
.penci-loading-circle .penci-loading-circle12:before {
	-webkit-animation-delay: -.1s;
	animation-delay: -.1s
}
@-webkit-keyframes penciLoadingCircleBounceDelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1);
		transform: scale(1)
	}
}
@keyframes penciLoadingCircleBounceDelay {
	0%,
	100%,
	80% {
		-webkit-transform: scale(0);
		transform: scale(0)
	}
	40% {
		-webkit-transform: scale(1);
		transform: scale(1)
	}
}
@-webkit-keyframes PenciSlideInUp {
	from {
		-webkit-transform: translate3d(0, 15px, 0);
		transform: translate3d(0, 15px, 0);
		opacity: 0
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0);
		opacity: 1
	}
}
@keyframes PenciSlideInUp {
	from {
		-webkit-transform: translate3d(0, 15px, 0);
		transform: translate3d(0, 15px, 0);
		opacity: 0
	}
	to {
		-webkit-transform: translate3d(0, 0, 0);
		transform: translate3d(0, 0, 0);
		opacity: 1
	}
}
.penci-ajrs-animate {
	opacity: 0;
	-webkit-animation: PenciSlideInUp .3s forwards 1;
	animation: PenciSlideInUp .3s forwards 1;
	-webkit-animation-delay: .1s;
	animation-delay: .1s
}
.penci-smalllist-wrapper .penci-pagination {
	margin-top: 20px;
	margin-bottom: 0
}
.pcajx-nopost {
	padding: 5px;
	border: 1px solid var(--pcborder-cl);
	text-align: center;
	border-radius: 5px;
	font-weight: 700;
	text-transform: uppercase;
	font-size: 12px;
	background: #f1f1f1
}
.featured-area.text-align-right .penci-featured-content .feat-text,
.featured-area.text-align-right .penci-featured-content-right .feat-text-right,
.featured-area.text-align-right .penci-slide-overlay .penci-mag-featured-content {
	text-align: right
}
.featured-area.text-align-left .penci-featured-content .feat-text,
.featured-area.text-align-left .penci-featured-content-right .feat-text-right,
.featured-area.text-align-left .penci-slide-overlay .penci-mag-featured-content {
	text-align: left
}
.featured-area.text-align-left .penci-featured-content .feat-text,
.featured-area.text-align-right .penci-featured-content .feat-text {
	padding-left: 20px;
	padding-right: 20px
}
.featured-area.text-align-left .penci-slider4-overlay .penci-featured-content .feat-text,
.featured-area.text-align-right .penci-slider4-overlay .penci-featured-content .feat-text,
.featured-style-29.text-align-left .penci-featured-content .feat-text,
.featured-style-29.text-align-right .penci-featured-content .feat-text,
.featured-style-38.text-align-left .penci-featured-content .feat-text,
.featured-style-38.text-align-right .penci-featured-content .feat-text {
	padding-left: 0;
	padding-right: 0
}
.featured-area.text-align-center .penci-featured-content-right .feat-text-right,
.featured-area.text-align-center .penci-slide-overlay .penci-mag-featured-content {
	text-align: center
}
.featured-area.text-align-left.featured-style-29 .penci-featured-content .feat-text h3:before {
	left: 0;
	margin-left: 0
}
.featured-area.vertical-align-top .penci-featured-content,
.featured-area.vertical-align-top .penci-featured-content-right .feat-text-right,
.featured-area.vertical-align-top .penci-slide-overlay .penci-mag-featured-content {
	top: 0;
	transform: none;
	margin-top: 20px
}
.featured-area.vertical-align-middle .penci-slide-overlay .penci-mag-featured-content {
	top: 50%;
	transform: translateY(-50%);
	bottom: auto
}
.featured-area.vertical-align-bottom .penci-featured-content,
.featured-area.vertical-align-bottom .penci-featured-content-right .feat-text-right,
.featured-area.vertical-align-bottom .penci-slide-overlay .penci-mag-featured-content {
	top: auto;
	bottom: 0;
	transform: none;
	margin-bottom: 20px
}
.featured-area.text-align-right.featured-style-29 .penci-featured-content .feat-text h3:before {
	left: auto;
	right: 0;
	margin-left: 0
}
.featured-area.horizontal-align-left .penci-featured-content,
.featured-area.horizontal-align-right .penci-featured-content {
	display: flex;
	flex-wrap: wrap
}
.featured-area.horizontal-align-left .penci-featured-content {
	justify-content: start
}
.featured-area.horizontal-align-right .penci-featured-content {
	justify-content: end
}
.featured-area.horizontal-align-left .penci-featured-content .feat-text,
.featured-area.horizontal-align-right .penci-featured-content .feat-text {
	margin: 0
}
.pc-cscomments.move-top h3.comment-reply-title {
	border-top: 0 !important;
	padding-top: 0 !important
}
.pc-cscomments.move-top .post-title-box {
	border-top: 1px solid var(--pcborder-cl);
	padding-top: 30px;
	margin-top: 30px
}
.pc-widget-user-lists ul li {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	align-items: center
}
.pc-widget-user-lists .pc-uw-ava {
	padding-right: 15px
}
.pc-widget-user-lists .pc-uw-ava img {
	width: 100%;
	height: auto
}
.pc-widget-user-lists .name a {
	font-size: 16px;
	line-height: 1.3
}
.pc-widget-user-lists .name a:hover {
	text-decoration: none
}
.pc-widget-user-lists .count {
	display: block;
	margin-top: 5px;
	color: var(--pcmeta-cl);
	line-height: 1
}
.penci_posts_tabs_widget .tabs {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 15px;
	margin-bottom: 20px;
	overflow: hidden
}
.penci_posts_tabs_widget .tabs ul>li {
	border: 0;
	padding: 0;
	margin: 0;
	float: left
}
.penci_posts_tabs_widget.el ul {
	padding-left: 0;
	margin-bottom: 0
}
.penci_posts_tabs_widget.el ul li {
	list-style: none
}
.penci_posts_tabs_widget .tabs ul {
	display: flex
}
.penci_posts_tabs_widget .default-tabs .tabs ul {
	justify-content: space-between
}
.penci_posts_tabs_widget .box-tabs .tabs ul>li {
	float: none;
	flex-grow: 1;
	flex-basis: 0;
	text-align: center
}
.penci_posts_tabs_widget .box-tabs .tabs ul>li:not(:last-child) {
	margin-right: 0
}
.penci_posts_tabs_widget .box-tabs .tabs {
	border-bottom: 0;
	padding-bottom: 0
}
.penci_posts_tabs_widget .box-tabs .tabs ul>li a {
	display: block;
	border: 1px solid var(--pcborder-cl);
	border-right-width: 0;
	padding: 15px 2px
}
.penci_posts_tabs_widget .box-tabs .tabs ul>li.active a {
	background: rgba(136, 136, 136, .1)
}
.penci_posts_tabs_widget .box-tabs .tabs ul>li:last-child a {
	border-right-width: 1px
}
.penci_posts_tabs_widget .show-icon .tabs ul>li a:before {
	font-family: FontAwesome;
	display: inline-block;
	margin-right: 5px
}
.penci_posts_tabs_widget .show-icon .tabs ul>li.li-tab-recent a:before {
	content: "\f0f6"
}
.penci_posts_tabs_widget .show-icon .tabs ul>li.li-tab-popular a:before {
	content: "\f06d"
}
.penci_posts_tabs_widget .show-icon .tabs ul>li.li-tab-comments a:before {
	content: "\f086"
}
.penci_posts_tabs_widget .tabs ul>li a {
	text-transform: uppercase;
	font-weight: 700;
	text-decoration: none
}
.penci_posts_tabs_widget .tabs ul>li:not(:last-child) {
	margin-right: 20px
}
.penci_posts_tabs_widget .tabs-content>div,
.penci_posts_tabs_widget .tabs>li {
	display: none
}
.penci_posts_tabs_widget .tabs-content>div.active {
	display: block
}
.penci_posts_tabs_widget .tabs>li.active {
	display: inline-block
}
.penci_posts_tabs_widget .tabs ul>li.active a {
	color: var(--pcaccent-cl)
}
.penci_posts_tabs_widget .recent-comments li {
	display: flex;
	flex-direction: row;
	align-items: center;
	margin-bottom: 15px;
	padding-bottom: 15px
}
.penci_posts_tabs_widget .recent-comments .avatar {
	flex: 0 0 50px;
	margin-right: 15px
}
.penci_posts_tabs_widget .author-info {
	line-height: 1.5;
	display: block;
	color: var(--pcmeta-cl)
}
.pc-widget-advanced-tax.tax-style-1 ul li a {
	background-color: transparent !important
}
.penci_snapchat_widget .pc-snapchat-badge {
	display: block;
	background-repeat: no-repeat;
	background-position: center;
	font-size: 0;
	line-height: 0;
	border: 3px solid var(--pcborder-cl);
	overflow: hidden;
	width: 170px;
	height: 170px;
	margin: 0 auto;
	border-radius: 20px;
	transition: all .25s;
	position: relative;
	background-color: transparent !important
}
.penci_snapchat_widget.pcsnapal-left .pc-snapchat-badge {
	margin-right: auto;
	margin-left: 0
}
.penci_snapchat_widget.pcsnapal-right .pc-snapchat-badge {
	margin-right: 0;
	margin-left: auto
}
.penci_snapchat_widget .pc-snapchat-badge-over {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background-color: transparent !important;
	z-index: 3
}
.penci_snapchat_widget .pc-snapchat-avatar {
	position: absolute;
	width: 60px;
	height: 60px;
	top: 50%;
	left: 50%;
	right: 50%;
	transform: translateX(-50%) translateY(-50%);
	border-radius: 20px;
	background-color: transparent;
	z-index: 1
}
.penci_snapchat_widget .pc-snapchat-badge.is-circle,
.penci_snapchat_widget .pc-snapchat-badge.is-circle .pc-snapchat-avatar {
	border-radius: 100%
}
.penci_snapchat_widget .pc-snapchat-wrapper a:hover {
	color: var(--pcaccent-cl);
	text-decoration: none
}
.penci_snapchat_widget .pc-snapchat-wrapper .pc-snapchat-id,
.penci_snapchat_widget .pc-snapchat-wrapper .pc-snapchat-name {
	text-align: center;
	display: block
}
.penci_snapchat_widget.pcsnapal-left .pc-snapchat-wrapper .pc-snapchat-id,
.penci_snapchat_widget.pcsnapal-left .pc-snapchat-wrapper .pc-snapchat-name {
	text-align: left
}
.penci_snapchat_widget.pcsnapal-right .pc-snapchat-wrapper .pc-snapchat-id,
.penci_snapchat_widget.pcsnapal-right .pc-snapchat-wrapper .pc-snapchat-name {
	text-align: right
}
.penci_snapchat_widget .pc-snapchat-wrapper .pc-snapchat-name {
	margin-top: 10px;
	font-size: 20px;
	font-weight: 700
}
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-list .tiktok-feed-item {
	padding: 6px !important
}
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-list .tiktok-feed-item .tiktok-feed-icon>span,
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-list .tiktok-feed-item .tiktok-feed-video-mask-content>span {
	font-weight: 400 !important;
	font-size: 13px !important
}
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-actions {
	margin-bottom: 0;
	margin-right: -5px;
	margin-left: -5px
}
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-actions .tiktok-feed-button {
	width: 100%;
	margin: 0
}
.penci_tiktok_widget .tiktok-feed-feed .tiktok-feed-actions .tiktok-feed-button:hover {
	box-shadow: 0 8px 19px -4px #ff5374
}
.pc-tiktok-avatar a {
	width: 70px;
	height: 70px;
	display: block;
	position: relative;
	float: left;
	margin-right: 15px
}
.pc-tiktok-avatar img {
	border-radius: 50%
}
.pc-tiktok-username {
	display: block;
	font-size: 1.35em
}
.pc-tiktok-verified {
	background-color: #20d5ec;
	color: #fff;
	border-radius: 50%;
	font-size: 12px;
	padding: 4px;
	margin: 0 5px
}
.pc-tiktok-desc {
	margin-top: 8px
}
.pc-tiktok-counts {
	padding: 10px 0
}
.pc-tiktok-counts li {
	display: inline-block;
	padding: 0 10px 0 0
}
.pc-tiktok-counts .counts-number {
	font-weight: 700
}
.pc-tiktok-counts span:last-child {
	opacity: .7;
	font-size: 90%
}
.penci_comments_widget ul li {
	display: flex
}
.penci_comments_widget ul li .post-widget-thumbnail {
	align-self: center
}
.penci_comments_widget ul li .comment-body {
	padding-left: 15px;
	align-self: center
}
.penci-tweets-lists .penci-tweet:not(:last-child) {
	margin-bottom: 15px;
	padding-bottom: 15px;
	border-bottom: 1px solid var(--pcborder-cl)
}
.penci-tweets-lists .tweet-intents span:after,
.penci-tweets-lists .tweet-intents-inner:after,
.penci-tweets-lists .tweet-intents-inner:before {
	display: none
}
.penci-tweets-lists .tweet-intents-inner a:hover {
	text-decoration: none;
	opacity: .85
}
.penci-tweets-lists .tweet-intents-inner>span:not(:last-child) {
	margin-right: 10px
}
.penci-tweets-lists .tweet-date {
	line-height: 1;
	display: block
}
.penci-tweets-lists .penci-tweet {
	position: relative
}
.penci-tweets-lists .penci-tweet:before {
	font-family: FontAwesome;
	position: absolute;
	top: 0;
	font-size: 24px;
	content: "\f099";
	right: 0;
	color: #2196f3;
	opacity: .6
}
.penci-tweets-lists .tweet-intents-inner>span a {
	color: var(--pcmeta-cl)
}
.pc-widget-advanced-tax.tax-style-1.hlmark .category-item-count {
	display: inline-block;
	padding: 2px 3px;
	background-color: var(--pcaccent-cl);
	color: #fff;
	font-size: 11px;
	border-radius: 2px
}
.pc-widget-advanced-tax.tax-style-2 ul {
	margin: 0;
	padding: 0
}
.pc-widget-advanced-tax.tax-style-2 ul li {
	display: inline-block
}
.elementor-widget-penci-advanced-categories .pc-widget-advanced-tax.tax-style-3 select {
	padding: 10px 15px;
	border: 1px solid var(--pcborder-cl);
	background: 0 0
}
.wpcf7 .ajax-loader {
	display: none
}
.wpcf7 form.submitting .ajax-loader {
	display: inline-block
}
.pc-widget-user-lists ul,
.widget.pcel-acat .pc-widget-advanced-tax>ul {
	padding-left: 0;
	margin-bottom: 0
}
.pc-widget-user-lists.el .name {
	margin-bottom: 5px
}
.pc-widget-user-lists.el ul li:not(:last-child) {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 5px;
	margin-bottom: 5px
}
.pc-widget-user-lists.el ul li:last-child {
	margin: 0;
	padding: 0
}
.penci_comments_widget.el ul {
	padding-left: 0;
	margin-bottom: 0
}
.penci_comments_widget.el ul li:last-child {
	margin-bottom: 0;
	padding-bottom: 0
}
.post-entry.blockquote-style-1 .tiktok-embed,
.post-entry.blockquote-style-2 .tiktok-embed,
.tiktok-embed {
	padding: 0;
	margin: 0;
	border: 0
}
.post-entry.blockquote-style-1 .tiktok-embed:after,
.post-entry.blockquote-style-1 .tiktok-embed:before,
.post-entry.blockquote-style-2 .tiktok-embed:after,
.post-entry.blockquote-style-2 .tiktok-embed:before,
.tiktok-embed:after,
.tiktok-embed:before {
	display: none
}
.pc-wstories {
	--gap: 5px;
	overflow: hidden
}
.pc-wstories-wrapper .pc-wstories-list {
	margin-left: calc(var(--gap) * -1);
	margin-right: calc(var(--gap) * -1);
	display: flex;
	flex-wrap: wrap;
	flex-direction: row
}
.pc-wstories-wrapper .pc-wstories-list.slider {
	margin-left: 0;
	margin-right: 0
}
.pc-wstories-wrapper .pc-wstories-list.one-row {
	flex-wrap: nowrap;
	overflow-x: auto;
	cursor: grab
}
.pc-wstories-wrapper .pc-webstory-item {
	width: 8.3333333333%;
	padding-left: var(--gap);
	padding-right: var(--gap);
	cursor: pointer;
	transition: opacity .2s;
	-webkit-transition: opacity .2s;
	-moz-transition: opacity .2s
}
.pc-wstories-wrapper .slider .pc-webstory-item {
	width: 100%
}
.pc-wstories-wrapper .grid .pc-webstory-item {
	margin-bottom: var(--gap)
}
.pc-wstories-wrapper .grid {
	margin-bottom: calc(var(--gap) * -1)
}
.pc-wstories-wrapper .pc-wstories-list.one-row .pc-webstory-item {
	width: 100px;
	flex: 0 0 100px;
	cursor: grab
}
.pc-wstories-wrapper .pc-webstory-thumb-wrapper {
	border-radius: 50%;
	overflow: hidden;
	background-color: var(--pcaccent-cl);
	padding: 2px;
	cursor: pointer
}
.pc-wstories-wrapper .pc-webstory-item.seen .pc-webstory-thumb-wrapper {
	background-color: gray
}
.pc-wstories-wrapper .pc-webstory-thumb {
	border-radius: 50%;
	border: 2px solid var(--pcbg-cl)
}
.pc-wstories-wrapper .pc-webstory-thumb:before {
	padding-top: 100%
}
.pc-wstories-wrapper .pc-webstory-item-title {
	display: block
}
.pc-wstories-wrapper .pc-webstory-item-title h4 {
	text-align: center;
	font-size: 14px;
	margin: 5px 0 0;
	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap
}
.pc-wstories-popup-wrapper {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 9999999;
	opacity: 0;
	visibility: hidden;
	transition: .3s all ease-in-out;
	background-color: #000
}
.pc-wstories-popup-content {
	opacity: 0;
	visibility: hidden;
	transition: .3s all ease-in-out
}
.pc-wstories-popup-content iframe {
	width: 100vw;
	height: 100vh
}
.pc-wstories-popup-wrapper.loading,
.pc-wstories-popup-wrapper.show,
.pc-wstories-popup-wrapper.show .pc-wstories-popup-content {
	opacity: 1;
	visibility: visible
}
.pc-wstories-popup-wrapper.loading .penci-loader-effect {
	display: block
}
.pc-wstories-popup-wrapper .pc-wstories-popup-toolbar {
	position: absolute;
	top: 30px;
	left: 30px;
	z-index: 99999999
}
.pc-wstories-popup-wrapper .pc-ws-btn {
	cursor: pointer;
	color: #fff;
	font-size: 14px;
	display: inline-block;
	margin-right: 30px
}
.pc-wstories-popup-wrapper .pc-story-info {
	cursor: initial
}
.pc-wstories-popup-wrapper .pc-ws-btn.disable {
	pointer-events: none;
	opacity: .3
}
body.pc-webstories-show {
	overflow: hidden
}
.pc-wstories-wrapper .pc-wstories-list.slider {
	display: block;
	overflow: hidden
}
.yt-video-place .fluid-width-video-wrapper,
.yt-video-place iframe {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 9;
	width: 100%;
	height: 100%
}
.penci-search-form form.penci-ajax-search button,
.penci-search-form form.penci-ajax-search input {
	border: 0
}
.penci-search-form form.penci-ajax-search {
	display: flex;
	align-self: center;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
	padding: 0
}
.penci-search-form form.penci-ajax-search .pc-eajxsearch button {
	height: 40px
}
.penci-search-form form.penci-ajax-search input {
	font-family: inherit;
	border: 1px solid var(--pcborder-cl)
}
.penci-search-form form.penci-ajax-search button {
	font-size: 0;
	position: relative;
	padding-right: 20px;
	padding-left: 20px;
	border-left: 1px solid var(--pcborder-cl);
	background-color: var(--pcaccent-cl);
	color: #fff
}
.search-style-text-button form.penci-ajax-search button {
	font-size: 13px
}
.search-style-default form.penci-ajax-search .searchsubmit {
	display: block;
	background: 0 0;
	margin: 0;
	border: 0;
	position: absolute;
	top: 0;
	bottom: 0;
	right: 0;
	color: inherit
}
.search-style-default form.penci-ajax-search .searchsubmit:before {
	border-color: #f1f1f1;
	border-left-color: var(--pcmeta-cl)
}
.search-style-text-button form.search-loading button span {
	opacity: 0
}
.search-style-text-button form.penci-ajax-search button:before {
	visibility: visible
}
.search-style-text-button form.penci-ajax-search button:after {
	display: none
}
@keyframes lds-dual-ring {
	100% {
		transform: rotate(360deg)
	}
}
.header-search-style-default .pcajx-search-loading.show-search a.close-search i:after,
.header-search-style-overlay .show-search .penci-search-form form button:after,
.penci-search-form form.penci-ajax-search button:before {
	font-family: inherit !important;
	line-height: 0;
	position: absolute;
	z-index: 2;
	top: calc(50% - 7px);
	right: 50%;
	left: 50%;
	display: block;
	visibility: hidden;
	width: 14px;
	height: 14px;
	margin: 0 0 0 -9px;
	content: " " !important;
	animation: lds-dual-ring .5s linear infinite;
	vertical-align: middle;
	opacity: 1;
	border: 1px solid rgba(255, 255, 255, .5);
	border-left-color: var(--pcbg-cl);
	border-radius: 50%
}
.penci-search-form form.penci-ajax-search button:after {
	font-family: penciicon;
	font-size: 16px;
	line-height: 16px;
	content: "\f108"
}
.penci-search-form form.penci-ajax-search .pc-eajxsearch button:after {
	display: none
}
.penci-search-form .search-loading.penci-ajax-search button:after,
.penci-search-form .search-loading.penci-ajax-search button>span {
	visibility: hidden
}
.header-search-style-overlay .show-search .penci-search-form .search-loading.penci-ajax-search button:after,
.penci-search-form .search-loading.penci-ajax-search button:before {
	visibility: visible
}
.header-search-style-overlay .show-search.active form.pc-searchform.penci-ajax-search .searchsubmit {
	display: block;
	position: absolute;
	top: 0;
	bottom: 0;
	right: 10px;
	height: 100%
}
.header-search-style-overlay .show-search.active form.pc-searchform.penci-ajax-search button:before {
	top: calc(50% - 12px);
	width: 24px;
	height: 24px;
	margin: 0 0 0 -20px
}
.search-results-wrapper {
	position: relative;
	top: 0
}
.search-results-wrapper .penci-dropdown-results {
	position: absolute;
	z-index: 30;
	top: 0;
	right: 0;
	left: 0;
	border-bottom: 1px solid var(--pcajs_bcl);
	background-color: var(--pcajs_bgcl);
	opacity: 0
}
.search-results-wrapper .penci-dropdown-results.penci-opened {
	opacity: 1
}
.search-results-wrapper .autocomplete-suggestions {
	width: 100%;
	border: 0;
	background-color: var(--pcajs_bgcl);
	position: relative;
	max-height: 300px;
	box-shadow: none
}
.search-results-wrapper .autocomplete-suggestions .autocomplete-suggestion {
	white-space: normal;
	color: var(--pctext-cl)
}
.search-results-wrapper .no-found-msg {
	font-size: var(--pcajs_nfz);
	line-height: 1.2;
	text-align: center;
	display: block;
	width: 100%;
	font-weight: 700;
	padding: 0 20px
}
.header-search-style-overlay .show-search.active .search-results-wrapper .no-found-msg {
	color: rgba(255, 255, 255, .7);
	text-align: center
}
.widget.penci_search_box_widget .search-results-wrapper .no-found-msg {
	color: var(--pctext-cl)
}
.widget.penci_search_box_widget .search-loading button span {
	color: transparent
}
.search-results-wrapper .penci-dropdown-results.penci-opened,
.widget.penci_search_box_widget .penci-opened .penci-search-results-wrapper {
	-moz-box-shadow: 0 2px 3px rgba(190, 190, 190, .4);
	-webkit-box-shadow: 0 2px 3px rgba(190, 190, 190, .4);
	box-shadow: 0 2px 3px rgba(190, 190, 190, .4)
}
.penci-scroll-content {
	overflow: hidden;
	overflow-y: visible
}
.penci-ajax-search .inner-hbg-search-form {
	display: flex;
	flex: 1 1 100%;
	justify-content: space-between
}
.search-results-wrapper .autocomplete-suggestions {
	display: flex;
	flex-wrap: wrap;
	left: 0;
	width: 100%;
	border-top: 0;
	padding: 10px 0
}
.header-search-style-default .penci-search-form form button,
.header-search-style-default .show-search a.close-search {
	transition: all .3s ease-in-out
}
.header-search-style-default .pcajx-search-loading.show-search a.close-search i:before {
	visibility: hidden
}
.header-search-style-default .penci-search-form form button {
	opacity: 0
}
.header-search-style-default .pcajx-search-loading.show-search a.close-search i:after {
	visibility: visible;
	border-color: #f1f1f1;
	border-left-color: var(--pcmeta-cl)
}
.header-search-style-default .pcajx-search-loading.show-search .penci-search-form form button {
	opacity: 1
}
.header-search-style-default .pcajx-search-loading.show-search .penci-search-form form button:before {
	border-color: var(--pcmeta-cl);
	border-left-color: var(--pctext-cl)
}
.header-search-style-default .search-results-wrapper .no-found-msg {
	text-align: left
}
.penci-search-results .autocomplete-suggestion {
	line-height: 1;
	display: flex;
	flex: 1 1 100%;
	max-width: 100%;
	padding: 5px 20px;
	cursor: pointer;
	transition: all .3s ease
}
@media only screen and (min-width:1170px) {
	.header-search-style-default .penci-search-results .autocomplete-suggestion {
		flex: 1 1 25%;
		max-width: 25%
	}
}
@media only screen and (min-width:768px) and (max-width:1169px) {
	.header-search-style-default .penci-search-results .autocomplete-suggestion {
		flex: 1 1 50%;
		max-width: 50%
	}
}
.penci-search-results .autocomplete-suggestion .suggestion-thumb {
	flex: 0 0 auto;
	max-width: 70px;
	width: 70px;
	margin-right: 15px;
	padding: 5px 0
}
.penci-search-results .autocomplete-suggestion .suggestion-thumb i {
	position: absolute;
	width: 24px;
	height: 24px;
	line-height: 24px;
	left: 50%;
	top: 50%;
	margin: -11px 0 0 -11px;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	font-size: 12px;
	transition: all .25s;
	-webkit-transition: all .25s;
	-moz-transition: all .25s;
	border: 1px solid rgba(255, 255, 255, .9);
	background: rgba(0, 0, 0, .4);
	color: rgba(255, 255, 255, .9);
	text-align: center
}
.penci-search-results .autocomplete-suggestion .suggestion-content {
	display: flex;
	flex-wrap: wrap;
	flex-direction: column;
	align-self: center
}
.penci-search-results .autocomplete-suggestion .suggestion-thumb .penci-image-holder:before {
	padding-top: 100%
}
.penci-search-results .autocomplete-suggestion .penci-post-title {
	font-size: var(--pcajs_tfz);
	line-height: initial;
	margin: 0;
	color: var(--pcajs_tcl)
}
.penci-search-results .autocomplete-suggestion .penci-post-title a {
	color: var(--pcajs_tcl)
}
.penci-search-results .autocomplete-suggestion .penci-post-title a:hover,
.penci-search-results .autocomplete-suggestion.autocomplete-selected .penci-post-title,
.penci-search-results .autocomplete-suggestion:hover .penci-post-title {
	color: var(--pcajs_thcl)
}
.penci-search-results .autocomplete-suggestion .post-date {
	color: var(--pcajs_mcl);
	font-size: var(--pcajs_mfz);
	margin-top: 7px
}
.penci-search-results .autocomplete-suggestion.autocomplete-selected .post-date,
.penci-search-results .autocomplete-suggestion:hover .post-date {
	color: var(--pcajs_mhcl)
}
.penci-search-results .autocomplete-suggestion .price {
	color: var(--pcaccent-cl);
	font-weight: var(--pchead-wei)
}
.penci-search-results .autocomplete-suggestion .suggestion-sku {
	font-size: var(--pcajs_mfz)
}
.penci-search-results .autocomplete-suggestion del {
	font-size: 80%
}
.penci-search-results .autocomplete-suggestion ins {
	text-decoration: none
}
.penci-search-results .autocomplete-suggestion.suggestion-divider {
	flex-basis: 100% !important;
	width: 100%;
	cursor: default;
	background-color: var(--pcajs_bcl)
}
.autocomplete-suggestion.suggestion-divider h5 {
	margin-bottom: 0;
	text-transform: uppercase
}
.view-all-results {
	font-weight: var(--pchead-wei);
	line-height: 40px;
	flex: 1 1 100%;
	height: 40px;
	margin-bottom: -1px;
	cursor: pointer;
	transition: all .25s ease;
	text-align: center;
	border-top: 1px solid var(--pcajs_bcl);
	font-size: 13px
}
.view-all-results a {
	color: var(--pcajs_ncl)
}
.pcbds-overlay .view-all-results a {
	color: #fff
}
.pcbds-overlay .view-all-results a:hover,
.view-all-results a:hover {
	color: var(--pcaccent-cl)
}
.header-search-style-default .penci-search-form form {
	border: 0
}
.header-search-style-default .search-results-wrapper .penci-dropdown-results {
	border: 0;
	top: 1px
}
.header-search-style-default .search-results-wrapper .penci-search-form form input {
	width: unset
}
.header-search-style-default .penci-search-form,
.header-search-style-default .penci-search-form form button,
.header-search-style-default .penci-search-form form input,
.header-search-style-default .searchform {
	height: 100%
}
.header-search-style-default .penci-search-form form button,
.header-search-style-default .penci-search-form form input {
	width: unset
}
.header-search-style-default .penci-search-form form.penci-ajax-search input {
	width: calc(100% - 60px)
}
.header-search-style-default .penci-search-form form button {
	background-color: transparent;
	color: var(--pcheading-cl);
	border: 0
}
.header-search-style-default .penci-search-form form.penci-ajax-search button {
	visibility: hidden
}
.autocomplete-suggestions::-webkit-scrollbar {
	width: 2px
}
.autocomplete-suggestions::-webkit-scrollbar-track {
	background-color: var(--pcbg-cl)
}
.autocomplete-suggestions::-webkit-scrollbar-thumb {
	background-color: var(--pcmeta-cl)
}
.pcsb-csf .post-box-meta-single {
	margin: 0
}
.pcsb-csf .post-box-meta-single img {
	vertical-align: middle
}
.pcsml-el .pcsml-item {
	position: relative
}
.pcsml-el .post-entry {
	margin-bottom: 0
}
.pcsml-el .pcsml-ad .pcsml-placeholder-title:before {
	content: "Smart List Ad" !important
}
.pcsml-el {
	margin-bottom: 0
}
.pcsml-el .pcsml-ad {
	clear: both;
	text-align: center
}
.pcsml-el .pcsml-ad>div {
	margin-top: 0
}
.pcsml-el .pcsml-ad img {
	margin: 0;
	width: 100%
}
.pcsml-el .pcsml-ad .adsbygoogle {
	margin-top: 0;
	position: relative;
	left: 50%;
	-webkit-transform: translateX(-50%);
	transform: translateX(-50%)
}
.pcsml-desc {
	display: block
}
.pcsml-el .pcsml-ad .pcsml-placeholder-title:before {
	content: "Smart List Ad"
}
.pcsml-title-wrapper {
	width: 100%
}
.pcsml-title-wrapper h1,
.pcsml-title-wrapper h2,
.pcsml-title-wrapper h3,
.pcsml-title-wrapper h4,
.pcsml-title-wrapper h5,
.pcsml-title-wrapper h6 {
	margin: 0
}
.pcsml-item-number span {
	display: block;
	background-color: var(--pcheading-cl);
	font-weight: 700;
	text-align: center;
	color: var(--pcbg-cl)
}
.pcsml-item-title {
	font-weight: 700
}
.pcsml-figure img {
	display: inline-block;
	vertical-align: top
}
.pcsml-caption {
	font-style: italic;
	font-size: 12px;
	line-height: 18px;
	margin-top: 5px;
	margin-bottom: 20px
}
.pcsml_style_1 .pcsml-item-number,
.pcsml_style_1 .pcsml-item-title {
	display: table-cell
}
.pcsml_style_1 .pcsml-item-title {
	vertical-align: middle
}
.pcsml_style_1 .pcsml-item {
	margin-bottom: 50px
}
.pcsml_style_1 .pcsml-title-wrapper {
	margin-bottom: 20px;
	position: relative
}
.pcsml_style_1 h1,
.pcsml_style_1 h2,
.pcsml_style_1 h3,
.pcsml_style_1 h4,
.pcsml_style_1 h5,
.pcsml_style_1 h6 {
	margin: 2px 0 0
}
.pcsml_style_1 .pcsml-item-number span {
	padding: 0 5px;
	font-size: 22px;
	line-height: 36px;
	min-width: 36px
}
.pcsml_style_1 .pcsml-item-title {
	width: 100%;
	padding-left: 15px;
	font-size: 22px;
	line-height: 1.3
}
.pcsml_style_2 .pcsml-info {
	overflow: hidden
}
.pcsml_style_2 .pcsml-item-number,
.pcsml_style_2 .pcsml-item-title {
	display: table-cell
}
.pcsml_style_2 .pcsml-item-title {
	vertical-align: middle
}
.pcsml_style_2 .pcsml-item {
	width: 100%;
	padding: 30px 0;
	border-bottom: 1px solid var(--pcborder-cl)
}
.pcsml_style_2 .pcsml-item:first-child {
	padding-top: 9px
}
.pcsml_style_2 .pcsml-item:last-of-type {
	border-bottom: none
}
.pcsml_style_2 .pcsml-item-number span {
	font-size: 18px;
	min-width: 32px;
	min-height: 32px;
	line-height: 32px
}
.pcsml_style_2 .pcsml-item-title {
	font-size: 18px;
	line-height: 24px;
	padding-left: 14px
}
.pcsml_style_2 .pcsml-figure {
	vertical-align: top;
	width: 170px
}
.pcsml_style_2 .pcsml-caption {
	line-height: 14px;
	margin-bottom: 0
}
.pcsml_style_2 .pcsml-desc {
	margin-top: 11px
}
@media only screen and (min-width:768px) {
	.pcsml_style_2 .pcsml-item {
		display: flex
	}
	.pcsml_style_2 .pcsml-figure,
	.pcsml_style_2 .pcsml-info {
		display: table-cell
	}
	.pcsml_style_2 .pcsml-info {
		flex: 1
	}
	.pcsml_style_2 .pcsml-figure {
		padding-left: 20px
	}
}
@media only screen and (max-width:767px) {
	.pcsml_style_2 {
		text-align: center
	}
	.pcsml_style_2 .pcsml-figure,
	.pcsml_style_2 h1,
	.pcsml_style_2 h2,
	.pcsml_style_2 h3,
	.pcsml_style_2 h4,
	.pcsml_style_2 h5,
	.pcsml_style_2 h6 {
		display: inline-block
	}
}
.pcsml_style_3 .pcsml-item {
	margin-bottom: 50px
}
.pcsml_style_3 .pcsml-figure {
	position: relative
}
.pcsml_style_3 figcaption div:before {
	content: "";
	position: absolute;
	bottom: 0;
	left: 0;
	display: block;
	height: 150%;
	width: 100%;
	background: -webkit-linear-gradient(top, rgba(0, 0, 0, 0) 0, rgba(0, 0, 0, .9) 100%);
	background: linear-gradient(to bottom, rgba(0, 0, 0, 0) 0, rgba(0, 0, 0, .9) 100%);
	z-index: -1
}
.pcsml_style_3 figcaption div:empty {
	display: none
}
.pcsml_style_3 .pcsml-caption {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	text-align: right;
	color: var(--pcbg-cl);
	margin-bottom: 0;
	padding: 12px 16px;
	z-index: 1
}
.pcsml_style_3 .pcsml-item-number {
	position: absolute;
	top: 0;
	left: 0;
	z-index: 1
}
.pcsml_style_3 .pcsml-item-number span {
	background-color: rgba(0, 0, 0, .8);
	min-width: 44px;
	min-height: 44px;
	font-family: var(--pchead-font);
	font-size: 26px;
	line-height: 44px
}
.pcsml_style_3 h1,
.pcsml_style_3 h2,
.pcsml_style_3 h3,
.pcsml_style_3 h4,
.pcsml_style_3 h5,
.pcsml_style_3 h6 {
	margin: 0
}
.pcsml_style_3 .pcsml-title-wrapper {
	margin-bottom: 17px;
	margin-top: 20px
}
.pcsml_style_3 .pcsml-item-title {
	font-size: 22px;
	line-height: 26px
}
.pcsml_style_3 .pcsml-desc {
	margin-top: 0
}
.pcsml-pagination {
	text-align: center;
	margin-bottom: 26px
}
.pcsml-button {
	font-family: var(--pchead-font);
	line-height: 40px;
	background-color: var(--pcheading-cl);
	color: #fff !important;
	padding: 11px 24px;
	font-size: 16px;
	font-style: normal;
	text-align: center;
	-webkit-transition: background-color .2s ease 0s;
	transition: background-color .2s ease 0s;
	cursor: pointer;
	margin: 0 10px;
	text-decoration: none !important
}
.pcsml-button:hover {
	background-color: var(--pcaccent-cl)
}
.pcsml-button .penciicon-left-chevron {
	font-size: 12px;
	position: relative;
	top: 1px;
	padding-right: 16px
}
.pcsml-button .penciicon-right-chevron {
	font-size: 12px;
	position: relative;
	top: 1px;
	padding-left: 16px
}
.pcsm-disable {
	opacity: .5;
	cursor: default;
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none
}
.pcsm-disable:hover {
	background-color: var(--pcheading-cl)
}
.pcsml_style_4 .pcsml-item-number,
.pcsml_style_4 .pcsml-item-title {
	display: table-cell
}
.pcsml_style_4 .pcsml-item-title {
	vertical-align: middle
}
.pcsml_style_4 .pcsml-ad .adsbygoogle,
.pcsml_style_4 .pcsml-ad .pcsml-placeholder-title,
.pcsml_style_4 .pcsml-ad>div {
	margin-bottom: 16px
}
.pcsml_style_4 {
	position: relative
}
.pcsml_style_4 h1,
.pcsml_style_4 h2,
.pcsml_style_4 h3,
.pcsml_style_4 h4,
.pcsml_style_4 h5,
.pcsml_style_4 h6 {
	margin: 2px 0 0
}
.pcsml_style_4 .pcsml-title-wrapper {
	margin-bottom: 21px
}
.pcsml_style_4 .pcsml-item-number span {
	min-width: 37px;
	min-height: 37px;
	font-size: 22px;
	line-height: 37px
}
.pcsml_style_4 .pcsml-item-title {
	margin-top: 5px;
	padding-left: 19px;
	font-size: 22px;
	line-height: 26px
}
.pcsml_style_4 .pcsml-figure {
	text-align: center;
	display: table;
	margin-left: auto;
	margin-right: auto
}
.pcsml_style_4 .pcsml-figure img {
	width: 100%
}
.pcsml_style_4 .pcsml-desc {
	margin-top: 0
}
.pcsml_style_4 .pcsml-pagination {
	margin-top: 26px
}
@media only screen and (max-width:767px) {
	.pcsml_style_4 {
		margin-top: 20px
	}
	.pcsml_style_4 h1,
	.pcsml_style_4 h2,
	.pcsml_style_4 h3,
	.pcsml_style_4 h4,
	.pcsml_style_4 h5,
	.pcsml_style_4 h6 {
		text-align: center;
		margin: 0
	}
	.pcsml_style_4 .pcsml-title-wrapper {
		margin-bottom: 10px
	}
	.pcsml_style_4 .pcsml-item-number {
		display: inline-block
	}
	.pcsml_style_4 .pcsml-item-title {
		display: inline-block;
		width: 100%;
		margin-top: 10px;
		padding-left: 0
	}
}
.pcsml-pagination {
	text-align: center;
	margin-bottom: 26px
}
.pcsml-button {
	font-family: var(--pchead-font);
	display: inline-block;
	line-height: 41px;
	padding: 0 20px;
	background-color: var(--pcheading-cl);
	color: var(--pcbg-cl);
	font-size: 16px;
	font-style: normal;
	text-align: center;
	-webkit-transition: background-color .2s ease 0s;
	transition: background-color .2s ease 0s;
	cursor: pointer;
	margin: 0 10px
}
.pcsml-button:hover {
	color: var(--pcbg-cl);
	background-color: var(--pcaccent-cl)
}
.pcsml-button .penciicon-left-chevron {
	font-size: 14px;
	position: relative;
	top: 1px;
	padding-right: 11px
}
.pcsml-button .penciicon-right-chevron {
	font-size: 14px;
	position: relative;
	top: 1px;
	padding-left: 11px
}
.pcsm-disable {
	opacity: .5;
	cursor: default;
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none
}
.pcsm-disable:hover {
	background-color: var(--pcheading-cl)
}
.pcsml_style_5 {
	position: relative;
	margin-bottom: 30px
}
@media only screen and (max-width:767px) {
	.pcsml_style_5 {
		margin-top: 20px
	}
}
.pcsml_style_5 .pcsml-ad .pcsml-placeholder-title,
.pcsml_style_5 .pcsml-ad>div {
	margin-bottom: 26px
}
.pcsml_style_5 .pcsml-ad .adsbygoogle {
	margin-bottom: 21px
}
.pcsml_style_5 .pcsml-item .pcsml-pagination {
	position: relative;
	display: inline-block;
	margin-bottom: 26px
}
.pcsml_style_5 .pcsml-head {
	position: relative
}
.pcsml_style_5 h1,
.pcsml_style_5 h2,
.pcsml_style_5 h3,
.pcsml_style_5 h4,
.pcsml_style_5 h5,
.pcsml_style_5 h6 {
	margin-top: 0;
	margin-bottom: 18px;
	padding: 0 120px;
	min-height: 42px;
	text-align: center;
	line-height: 1
}
.pcsml_style_5 .pcsml-item-title {
	display: inline-block;
	margin-top: 6px;
	margin-bottom: 8px;
	width: 100%;
	font-size: 22px;
	line-height: 28px
}
.pcsml_style_5 .pcsml-desc {
	margin-top: 0
}
.pcsml_style_5 .pcsml-figure img {
	margin-top: 26px;
	width: 100%
}
.pcsml_style_5 .pcsml-figure {
	text-align: center;
	display: table;
	margin-left: auto;
	margin-right: auto
}
.pcsml_style_5 .pcsml-caption {
	text-align: left
}
.pcsml_style_5 .pcsml-pagination {
	display: inline-block;
	width: 100%;
	top: 0;
	margin-bottom: 0
}
.pcsml_style_5 .pcsml-pagination .pcsml-button {
	margin: 0
}
.pcsml_style_5 .pcsml-pagination .pcsm-back {
	float: left
}
.pcsml_style_5 .pcsml-pagination .pcsm-next {
	float: right
}
@media only screen and (min-width:768px) and (max-width:1018px) {
	.pcsml_style_5 .pcsml-item-title {
		margin-top: 10px;
		line-height: 24px;
		font-size: 19px
	}
}
@media only screen and (max-width:767px) {
	.pcsml_style_5 .pcsml-item .pcsml-pagination {
		margin-bottom: 0
	}
	.pcsml_style_5 h1,
	.pcsml_style_5 h2,
	.pcsml_style_5 h3,
	.pcsml_style_5 h4,
	.pcsml_style_5 h5,
	.pcsml_style_5 h6 {
		margin-bottom: 0;
		padding: 0;
		min-height: 0
	}
	.pcsml_style_5 .pcsml-item-title {
		margin-top: 10px;
		text-align: left;
		line-height: 30px;
		font-weight: 500;
		font-size: 26px
	}
}
@media only screen and (min-width:767px) {
	.pcsml_style_5 .pcsml-head .pcsml-pagination {
		position: absolute;
		top: 50%;
		-webkit-transform: translateY(-50%);
		transform: translateY(-50%)
	}
}
.pcsml-dropdown-wrap {
	text-align: center;
	border: 1px solid var(--pcborder-cl);
	margin-bottom: 30px;
	clear: both
}
.pcsml-dropdown-wrap .pcsml-dropdown {
	height: 30px;
	padding: 0 35px 0 10px;
	margin: 10px 0;
	overflow: hidden;
	background-color: var(--pcbg-cl);
	border: none;
	box-shadow: none;
	-webkit-appearance: none;
	appearance: none;
	outline: 0;
	font-family: var(--pchead-font);
	max-width: 100%;
	text-overflow: ellipsis;
	cursor: pointer;
	font-size: 16px
}
.pcsml-dropdown-wrap .pcsml-dropdown option {
	font-size: 14px
}
.pcsml-dropdown-wrap .pcsml-dropdown::-ms-expand {
	display: none
}
.pcsml-dropdown-wrap .pcsml-container {
	display: inline-block;
	position: relative;
	width: 50%
}
.pcsml-dropdown-wrap .pcsml-container:before {
	content: "";
	width: 0;
	height: 0;
	position: absolute;
	top: 50%;
	right: 16px;
	z-index: 0;
	border-left: 5px solid transparent;
	border-right: 5px solid transparent;
	border-top: 5px solid #000;
	pointer-events: none;
	transform: translateY(-40%)
}
.pcsml-dropdown-wrap .pcsml-button {
	font-family: var(--pchead-font);
	line-height: 40px;
	font-size: 16px;
	font-style: normal;
	text-align: center;
	-webkit-transition: background-color .2s ease 0s;
	transition: background-color .2s ease 0s;
	cursor: pointer;
	padding: 2px 18px;
	margin: 0;
	background-color: transparent;
	color: var(--pctext-cl) !important
}
.pcsml-dropdown-wrap .pcsml-button i {
	font-size: 12px;
	position: relative;
	top: 1px
}
.pcsml-dropdown-wrap .pcsml-button .penciicon-left-chevron {
	padding-right: 6px
}
.pcsml-dropdown-wrap .pcsml-button .penciicon-right-chevron {
	padding-left: 6px
}
.pcsml-dropdown-wrap .pcsml-button:hover {
	text-decoration: none !important;
	color: var(--pcaccent-cl)
}
.pcsml-dropdown-wrap .pcsm-disable {
	opacity: .5;
	cursor: default;
	-webkit-user-select: none;
	user-select: none
}
.pcsml-dropdown-wrap .pcsm-disable:hover {
	color: var(--pcheading-cl)
}
.pcsml-dropdown-wrap .pcsm-next {
	text-align: right;
	width: 25%;
	display: inline-block
}
.pcsml-dropdown-wrap .pcsm-back {
	text-align: left;
	width: 25%;
	display: inline-block
}
@media only screen and (min-width:768px) and (max-width:1018px) {
	.pcsml-dropdown-wrap .pcsml-dropdown {
		max-width: 50%
	}
}
@media only screen and (max-width:767px) {
	.pcsml-dropdown-wrap .pcsml-dropdown option {
		text-align: left
	}
	.pcsml-dropdown-wrap .pcsml-button {
		width: 15%
	}
	.pcsml-dropdown-wrap .pcsml-container {
		width: 70%
	}
	.pcsml-dropdown-wrap .pcsml-button i {
		display: inline;
		top: 0
	}
	.pcsml-dropdown-wrap .pcsml-button span {
		display: none
	}
}
.pcsml_style_6 .pcsml-ad>div {
	margin-bottom: 15px
}
.pcsml_style_6 .pcsml-ad .adsbygoogle {
	margin-bottom: 15px
}
.pcsml_style_6 .pcsml-ad .pcsml-placeholder-title {
	margin-bottom: 15px
}
.pcsml_style_6 {
	position: relative
}
.pcsml_style_6 .pcsml-title-wrapper {
	margin-bottom: 15px
}
.pcsml_style_6 .pcsml-title-wrapper h1,
.pcsml_style_6 .pcsml-title-wrapper h2,
.pcsml_style_6 .pcsml-title-wrapper h3,
.pcsml_style_6 .pcsml-title-wrapper h4,
.pcsml_style_6 .pcsml-title-wrapper h5,
.pcsml_style_6 .pcsml-title-wrapper h6 {
	margin: 5px 0 0;
	line-height: 30px
}
.pcsml_style_6 .pcsml-item-title {
	font-size: 22px;
	line-height: 26px
}
.pcsml_style_6 .pcsml-desc {
	margin-top: 0;
	margin-bottom: 25px
}
.pcsml_style_6 .pcsml-desc .aligncenter {
	margin-top: 20px
}
.pcsml-desc p:empty {
	display: none
}
.post-entry .pcsml-desc>ol:last-child,
.post-entry .pcsml-desc>p:last-child,
.post-entry .pcsml-desc>ul:last-child {
	margin-bottom: 0
}
.widget .penci-pagination {
	margin-top: 20px;
	margin-bottom: 0
}
.widget .penci-pagination a {
	text-decoration: none
}
.penci-pagination.penci-ajax-nav .pcajx-btn {
	align-items: center;
	display: flex;
	min-width: 35px;
	font-size: 12px;
	border: 1px solid var(--pcborder-cl);
	cursor: pointer;
	transition: .3s all ease-in-out;
	padding: 0 10px
}
.penci-pagination.penci-ajax-nav .pcnav-title {
	padding: 0 5px;
	font-size: 12px;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	text-transform: uppercase
}
.penci-pagination.penci-ajax-nav .pcajx-btn:not(.disable):hover {
	border-color: var(--pcaccent-cl);
	background-color: var(--pcaccent-cl);
	color: #fff
}
.penci-pagination.penci-ajax-nav .pcajx-btn.disable {
	opacity: .5
}
.penci-pagination.penci-ajax-nav .pcajx-btn.disable:hover {
	cursor: not-allowed
}
.penci-pagination.penci-ajax-nav .pcajx-btn i {
	line-height: 30px
}
.penci-custom-slides .penci-owl-carousel.pcdots-number .penci-owl-dots,
.penci-owl-carousel.pcdots-number .penci-owl-dots {
	counter-reset: penci-dots-counter
}
.penci-custom-slides .penci-owl-carousel.pcdots-number .penci-owl-dot span,
.penci-owl-carousel.pcdots-number .penci-owl-dot span {
	width: auto;
	height: auto;
	background: 0 0;
	border: none;
	font-family: var(--pchead-font);
	white-space: nowrap;
	line-height: 1;
	font-weight: var(--pchead-wei);
	color: #fff;
	margin-left: 10px;
	margin-right: 10px;
	font-size: 14px
}
.penci-custom-slides .penci-owl-carousel.pcdots-number.line .penci-owl-dot span,
.penci-owl-carousel.pcdots-number.line .penci-owl-dot span {
	margin-left: 0;
	margin-right: 0
}
.penci-custom-slides .penci-owl-carousel.pcdots-number:not(.line) .penci-owl-dot span:before,
.penci-owl-carousel.pcdots-number:not(.line) .penci-owl-dot span:before {
	counter-increment: penci-dots-counter;
	content: "0"counter(penci-dots-counter)
}
.penci-custom-slides .penci-owl-carousel.pcdots-number .penci-owl-dot span:after,
.penci-owl-carousel.pcdots-number .penci-owl-dot span:after {
	content: "";
	width: 15px;
	height: 2px;
	background-color: currentColor;
	transition: width .3s ease;
	vertical-align: middle;
	display: inline-block;
	margin: 0 0 0 5px
}
.penci-custom-slides .penci-owl-carousel.pcdots-number .penci-owl-dot.active span:after,
.penci-owl-carousel.pcdots-number .penci-owl-dot.active span:after {
	width: 30px
}
.penci-custom-slides.penci-jarallax {
	width: auto;
	padding-top: 0
}
.widget .penci-pagination.penci-ajax-nav {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between
}
.widget {
	position: relative
}
.widget .pcwgajx-ld-wrapper {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 9;
	visibility: hidden
}
.widget.ajx-loading .pcwgajx-ld-wrapper {
	visibility: visible
}
.widget.ajx-loading ul {
	opacity: .5
}
.widget.ajx-loading .penci-loader-effect {
	display: block
}
@-webkit-keyframes pcani-dash {
	0% {
		stroke-dasharray: 0 1500
	}
	15% {
		stroke-dasharray: 1500 1500
	}
	85% {
		opacity: 1
	}
	90% {
		stroke-dasharray: 1500 1500;
		opacity: 0
	}
	100% {
		stroke-dasharray: 0 1500;
		opacity: 0
	}
}
@keyframes pcani-dash {
	0% {
		stroke-dasharray: 0 1500
	}
	15% {
		stroke-dasharray: 1500 1500
	}
	85% {
		opacity: 1
	}
	90% {
		stroke-dasharray: 1500 1500;
		opacity: 0
	}
	100% {
		stroke-dasharray: 0 1500;
		opacity: 0
	}
}
@-webkit-keyframes pcani-pulse {
	0% {
		-webkit-transform: translateY(-50%) scale(1);
		transform: translateY(-50%) scale(1);
		opacity: 1
	}
	40% {
		-webkit-transform: translateY(-50%) scale(.9);
		transform: translateY(-50%) scale(.9);
		opacity: 0
	}
	100% {
		-webkit-transform: translateY(-50%) scale(0);
		transform: translateY(-50%) scale(0);
		opacity: 0
	}
}
@keyframes pcani-pulse {
	0% {
		-webkit-transform: translateY(-50%) scale(1);
		transform: translateY(-50%) scale(1);
		opacity: 1
	}
	40% {
		-webkit-transform: translateY(-50%) scale(.9);
		transform: translateY(-50%) scale(.9);
		opacity: 0
	}
	100% {
		-webkit-transform: translateY(-50%) scale(0);
		transform: translateY(-50%) scale(0);
		opacity: 0
	}
}
@-webkit-keyframes pcani-swirl-in {
	0% {
		opacity: 0;
		-webkit-transform: translateZ(-20px) rotateX(90deg);
		transform: translateZ(-20px) rotateX(90deg)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateZ(-20px) rotateX(-10deg);
		transform: translateZ(-20px) rotateX(-10deg)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateZ(-20px) rotateX(0);
		transform: translateZ(-20px) rotateX(0)
	}
}
@keyframes pcani-swirl-in {
	0% {
		opacity: 0;
		-webkit-transform: translateZ(-20px) rotateX(90deg);
		transform: translateZ(-20px) rotateX(90deg)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateZ(-20px) rotateX(-10deg);
		transform: translateZ(-20px) rotateX(-10deg)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateZ(-20px) rotateX(0);
		transform: translateZ(-20px) rotateX(0)
	}
}
@-webkit-keyframes pcani-blinds-in {
	0% {
		-webkit-transform: rotateY(180deg);
		transform: rotateY(180deg)
	}
	100% {
		-webkit-transform: rotateY(0);
		transform: rotateY(0)
	}
}
@keyframes pcani-blinds-in {
	0% {
		-webkit-transform: rotateY(180deg);
		transform: rotateY(180deg)
	}
	100% {
		-webkit-transform: rotateY(0);
		transform: rotateY(0)
	}
}
@-webkit-keyframes pcani-wave-up {
	0% {
		-webkit-transform: scale(0);
		transform: scale(0);
		opacity: 0
	}
	60% {
		-webkit-transform: scale(1.2);
		transform: scale(1.2);
		opacity: 1
	}
	100% {
		-webkit-transform: scale(1);
		transform: scale(1);
		opacity: 1
	}
}
@keyframes pcani-wave-up {
	0% {
		-webkit-transform: scale(0);
		transform: scale(0);
		opacity: 0
	}
	60% {
		-webkit-transform: scale(1.2);
		transform: scale(1.2);
		opacity: 1
	}
	100% {
		-webkit-transform: scale(1);
		transform: scale(1);
		opacity: 1
	}
}
@-webkit-keyframes pcani-flip-in {
	0% {
		-webkit-transform: rotateX(180deg);
		transform: rotateX(180deg);
		opacity: 0
	}
	35% {
		-webkit-transform: rotateX(120deg);
		transform: rotateX(120deg);
		opacity: 0
	}
	65% {
		opacity: 0
	}
	100% {
		-webkit-transform: rotateX(360deg);
		transform: rotateX(360deg);
		opacity: 1
	}
}
@keyframes pcani-flip-in {
	0% {
		-webkit-transform: rotateX(180deg);
		transform: rotateX(180deg);
		opacity: 0
	}
	35% {
		-webkit-transform: rotateX(120deg);
		transform: rotateX(120deg);
		opacity: 0
	}
	65% {
		opacity: 0
	}
	100% {
		-webkit-transform: rotateX(360deg);
		transform: rotateX(360deg);
		opacity: 1
	}
}
@-webkit-keyframes pcani-flip-out {
	0% {
		-webkit-transform: rotateX(0);
		transform: rotateX(0);
		opacity: 1
	}
	35% {
		-webkit-transform: rotateX(-40deg);
		transform: rotateX(-40deg);
		opacity: 0
	}
	65% {
		opacity: 0
	}
	100% {
		-webkit-transform: rotateX(180deg);
		transform: rotateX(180deg);
		opacity: 0
	}
}
@keyframes pcani-flip-out {
	0% {
		-webkit-transform: rotateX(0);
		transform: rotateX(0);
		opacity: 1
	}
	35% {
		-webkit-transform: rotateX(-40deg);
		transform: rotateX(-40deg);
		opacity: 0
	}
	65% {
		opacity: 0
	}
	100% {
		-webkit-transform: rotateX(180deg);
		transform: rotateX(180deg);
		opacity: 0
	}
}
@-webkit-keyframes pcani-drop-in-in {
	0% {
		opacity: 0;
		-webkit-transform: translateZ(100px);
		transform: translateZ(100px)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateZ(0);
		transform: translateZ(0)
	}
}
@keyframes pcani-drop-in-in {
	0% {
		opacity: 0;
		-webkit-transform: translateZ(100px);
		transform: translateZ(100px)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateZ(0);
		transform: translateZ(0)
	}
}
@-webkit-keyframes pcani-drop-in-out {
	0% {
		opacity: 1;
		-webkit-transform: translateZ(0);
		transform: translateZ(0)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateZ(-100px);
		transform: translateZ(-100px)
	}
}
@keyframes pcani-drop-in-out {
	0% {
		opacity: 1;
		-webkit-transform: translateZ(0);
		transform: translateZ(0)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateZ(-100px);
		transform: translateZ(-100px)
	}
}
@-webkit-keyframes pcani-slide-right-in {
	0% {
		opacity: 0;
		-webkit-transform: translateX(-100%);
		transform: translateX(-100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateX(10%);
		transform: translateX(10%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@keyframes pcani-slide-right-in {
	0% {
		opacity: 0;
		-webkit-transform: translateX(-100%);
		transform: translateX(-100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateX(10%);
		transform: translateX(10%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@-webkit-keyframes pcani-slide-right-out {
	0% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateX(110%);
		transform: translateX(110%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateX(100%);
		transform: translateX(100%)
	}
}
@keyframes pcani-slide-right-out {
	0% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateX(110%);
		transform: translateX(110%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateX(100%);
		transform: translateX(100%)
	}
}
@-webkit-keyframes pcani-slide-left-in {
	0% {
		opacity: 0;
		-webkit-transform: translateX(100%);
		transform: translateX(100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateX(-10%);
		transform: translateX(-10%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@keyframes pcani-slide-left-in {
	0% {
		opacity: 0;
		-webkit-transform: translateX(100%);
		transform: translateX(100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateX(-10%);
		transform: translateX(-10%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
}
@-webkit-keyframes pcani-slide-left-out {
	0% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateX(-110%);
		transform: translateX(-110%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateX(-100%);
		transform: translateX(-100%)
	}
}
@keyframes pcani-slide-left-out {
	0% {
		opacity: 1;
		-webkit-transform: translateX(0);
		transform: translateX(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateX(-110%);
		transform: translateX(-110%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateX(-100%);
		transform: translateX(-100%)
	}
}
@-webkit-keyframes pcani-slide-up-in {
	0% {
		opacity: 0;
		-webkit-transform: translateY(100%);
		transform: translateY(100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateY(-20%);
		transform: translateY(-20%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@keyframes pcani-slide-up-in {
	0% {
		opacity: 0;
		-webkit-transform: translateY(100%);
		transform: translateY(100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateY(-20%);
		transform: translateY(-20%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@-webkit-keyframes pcani-slide-up-out {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateY(-120%);
		transform: translateY(-120%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(-100%);
		transform: translateY(-100%)
	}
}
@keyframes pcani-slide-up-out {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateY(-120%);
		transform: translateY(-120%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(-100%);
		transform: translateY(-100%)
	}
}
@-webkit-keyframes pcani-slide-down-in {
	0% {
		opacity: 0;
		-webkit-transform: translateY(-100%);
		transform: translateY(-100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateY(20%);
		transform: translateY(20%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@keyframes pcani-slide-down-in {
	0% {
		opacity: 0;
		-webkit-transform: translateY(-100%);
		transform: translateY(-100%)
	}
	60% {
		opacity: 1;
		-webkit-transform: translateY(20%);
		transform: translateY(20%)
	}
	100% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
}
@-webkit-keyframes pcani-slide-down-out {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateY(120%);
		transform: translateY(120%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(100%);
		transform: translateY(100%)
	}
}
@keyframes pcani-slide-down-out {
	0% {
		opacity: 1;
		-webkit-transform: translateY(0);
		transform: translateY(0)
	}
	60% {
		opacity: 0;
		-webkit-transform: translateY(120%);
		transform: translateY(120%)
	}
	100% {
		opacity: 0;
		-webkit-transform: translateY(100%);
		transform: translateY(100%)
	}
}
@-webkit-keyframes pcani-bounce-in {
	0%,
	20%,
	40%,
	60%,
	80%,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03)
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97)
	}
	to {
		opacity: 1;
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
@keyframes pcani-bounce-in {
	0%,
	20%,
	40%,
	60%,
	80%,
	to {
		-webkit-animation-timing-function: cubic-bezier(.215, .61, .355, 1);
		animation-timing-function: cubic-bezier(.215, .61, .355, 1)
	}
	0% {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
	20% {
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	40% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	60% {
		opacity: 1;
		-webkit-transform: scale3d(1.03, 1.03, 1.03);
		transform: scale3d(1.03, 1.03, 1.03)
	}
	80% {
		-webkit-transform: scale3d(.97, .97, .97);
		transform: scale3d(.97, .97, .97)
	}
	to {
		opacity: 1;
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
@-webkit-keyframes pcani-bounce-out {
	20% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	50%,
	55% {
		opacity: 0;
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
}
@keyframes pcani-bounce-out {
	20% {
		-webkit-transform: scale3d(.9, .9, .9);
		transform: scale3d(.9, .9, .9)
	}
	50%,
	55% {
		opacity: 0;
		-webkit-transform: scale3d(1.1, 1.1, 1.1);
		transform: scale3d(1.1, 1.1, 1.1)
	}
	to {
		opacity: 0;
		-webkit-transform: scale3d(.3, .3, .3);
		transform: scale3d(.3, .3, .3)
	}
}
@-webkit-keyframes pcani-swing-in {
	20% {
		-webkit-transform: rotate(15deg);
		transform: rotate(15deg)
	}
	40% {
		-webkit-transform: rotate(-10deg);
		transform: rotate(-10deg)
	}
	60% {
		-webkit-transform: rotate(5deg);
		transform: rotate(5deg)
	}
	80% {
		-webkit-transform: rotate(-5deg);
		transform: rotate(-5deg)
	}
	to {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
}
@keyframes pcani-swing-in {
	20% {
		-webkit-transform: rotate(15deg);
		transform: rotate(15deg)
	}
	40% {
		-webkit-transform: rotate(-10deg);
		transform: rotate(-10deg)
	}
	60% {
		-webkit-transform: rotate(5deg);
		transform: rotate(5deg)
	}
	80% {
		-webkit-transform: rotate(-5deg);
		transform: rotate(-5deg)
	}
	to {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
}
@-webkit-keyframes pcani-swing-out {
	20% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	40% {
		-webkit-transform: rotate(-5deg);
		transform: rotate(-5deg)
	}
	60% {
		-webkit-transform: rotate(10deg);
		transform: rotate(10deg)
	}
	80% {
		-webkit-transform: rotate(-15deg);
		transform: rotate(-15deg)
	}
	to {
		-webkit-transform: rotate(15deg);
		transform: rotate(15deg)
	}
}
@keyframes pcani-swing-out {
	20% {
		-webkit-transform: rotate(0);
		transform: rotate(0)
	}
	40% {
		-webkit-transform: rotate(-5deg);
		transform: rotate(-5deg)
	}
	60% {
		-webkit-transform: rotate(10deg);
		transform: rotate(10deg)
	}
	80% {
		-webkit-transform: rotate(-15deg);
		transform: rotate(-15deg)
	}
	to {
		-webkit-transform: rotate(15deg);
		transform: rotate(15deg)
	}
}
@-webkit-keyframes pcani-rubber-band-in {
	0% {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
	30% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	40% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	75% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	to {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
@keyframes pcani-rubber-band-in {
	0% {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
	30% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	40% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	75% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	to {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
@-webkit-keyframes pcani-rubber-band-out {
	0% {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
	30% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	40% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	75% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	to {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
@keyframes pcani-rubber-band-out {
	0% {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
	30% {
		-webkit-transform: scale3d(1.05, .95, 1);
		transform: scale3d(1.05, .95, 1)
	}
	40% {
		-webkit-transform: scale3d(.95, 1.05, 1);
		transform: scale3d(.95, 1.05, 1)
	}
	50% {
		-webkit-transform: scale3d(1.15, .85, 1);
		transform: scale3d(1.15, .85, 1)
	}
	65% {
		-webkit-transform: scale3d(.75, 1.25, 1);
		transform: scale3d(.75, 1.25, 1)
	}
	75% {
		-webkit-transform: scale3d(1.25, .75, 1);
		transform: scale3d(1.25, .75, 1)
	}
	to {
		-webkit-transform: scaleX(1);
		transform: scaleX(1)
	}
}
.penci-animated-headline {
	--pcaccent-cl-dk: var(--pcheading-cl);
	position: relative
}
.penci-animated-headline .pc-textlink {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 2
}
.penci-animated-headline {
	-webkit-transition: all .3s ease;
	transition: all .3s ease
}
.penci-animated-headline a {
	text-decoration: none;
	color: var(--pcaccent-cl)
}
.penci-animated-headline .penci-animated-text {
	padding: 0;
	margin: 0;
	display: inline-block
}
.penci-animated-headline .penci-animated-text .normal-text {
	z-index: 1;
	position: relative;
	vertical-align: bottom;
	font-size: 43px;
	font-weight: 500;
	line-height: 1.2
}
.penci-animated-headline .penci-animated-text .normal-text.style-gradient {
	background: var(--pcaccent-cl-dk);
	background: -webkit-gradient(linear, left top, left bottom, from(var(--pcaccent-cl)), to(var(--pcaccent-cl-dk)));
	background: linear-gradient(180deg, var(--pcaccent-cl) 0, var(--pcaccent-cl-dk) 100%);
	-moz-text-fill-color: transparent;
	-o-text-fill-color: transparent;
	-webkit-text-fill-color: transparent;
	background-clip: text;
	-webkit-background-clip: text
}
.penci-animated-headline .penci-animated-text .dynamic-wrapper {
	overflow: visible;
	text-align: inherit;
	display: inline-block;
	position: relative;
	vertical-align: bottom
}
.penci-animated-headline .penci-animated-text .dynamic-wrapper.style-gradient .dynamic-text {
	background: var(--pcaccent-cl-dk);
	background: -webkit-gradient(linear, left top, left bottom, from(var(--pcaccent-cl)), to(var(--pcaccent-cl-dk)));
	background: linear-gradient(180deg, var(--pcaccent-cl) 0, var(--pcaccent-cl-dk) 100%);
	-moz-text-fill-color: transparent;
	-o-text-fill-color: transparent;
	-webkit-text-fill-color: transparent;
	background-clip: text;
	-webkit-background-clip: text
}
.penci-animated-headline .penci-animated-text .dynamic-wrapper.style-gradient .dynamic-text .dynamic-text-letter {
	background: var(--pcaccent-cl-dk);
	background: -webkit-gradient(linear, left top, left bottom, from(var(--pcaccent-cl)), to(var(--pcaccent-cl-dk)));
	background: linear-gradient(180deg, var(--pcaccent-cl) 0, var(--pcaccent-cl-dk) 100%);
	-moz-text-fill-color: transparent;
	-o-text-fill-color: transparent;
	-webkit-text-fill-color: transparent;
	background-clip: text;
	-webkit-background-clip: text
}
.penci-animated-headline .penci-animated-text .dynamic-text {
	display: inline-block;
	position: relative;
	top: 0;
	left: 0;
	z-index: 1;
	font-size: 43px;
	font-weight: 500;
	line-height: 1.2
}
.penci-animated-headline .penci-animated-text svg {
	position: absolute;
	left: 0;
	overflow: visible
}
.penci-animated-headline .penci-animated-text svg path {
	fill: none;
	stroke-dasharray: 1500;
	-webkit-animation: pcani-dash 10s infinite;
	animation: pcani-dash 10s infinite
}
.penci-animated-headline .penci-animated-text svg path.style-color {
	stroke: var(--pcaccent-cl)
}
.penci-animated-headline .penci-animated-text svg path:nth-of-type(2) {
	-webkit-animation-delay: .3s;
	animation-delay: .3s
}
.penci-animated-headline .penci-animated-text svg linearGradient stop:nth-of-type(1) {
	stop-color: var(--pcaccent-cl)
}
.penci-animated-headline .penci-animated-text svg linearGradient stop:nth-of-type(2) {
	stop-color: var(--pcaccent-cl-dk)
}
.penci-animated-headline[data-shape=underline-2] .penci-animated-text svg {
	top: auto;
	bottom: -50%;
	width: 100%;
	height: 100%
}
.penci-animated-headline[data-shape=underline-1] .penci-animated-text svg {
	top: auto;
	bottom: -50%;
	width: 100%;
	height: 100%
}
.penci-animated-headline[data-shape=heart] .penci-animated-text svg {
	top: -30px;
	bottom: -20px;
	width: calc(100% + 80px);
	height: calc(100% + 80px);
	left: -40px;
	right: -40px
}
.penci-animated-headline[data-shape=click] .penci-animated-text svg {
	top: auto;
	bottom: -10px;
	width: 50px;
	height: 50px;
	left: auto;
	right: -20px
}
.penci-animated-headline[data-shape=sparkle] .penci-animated-text svg {
	top: -10px;
	bottom: auto;
	width: 30px;
	height: 30px;
	left: auto;
	right: 0
}
.penci-animated-headline[data-shape=bolt] .penci-animated-text svg,
.penci-animated-headline[data-shape=check] .penci-animated-text svg,
.penci-animated-headline[data-shape=pan] .penci-animated-text svg {
	top: -20px;
	bottom: -20px;
	width: 100%;
	height: calc(100% + 40px);
	left: 0;
	right: 0
}
.penci-animated-headline[data-shape=line] .penci-animated-text svg {
	top: 15px;
	bottom: 0;
	width: calc(100% + 40px);
	height: calc(100%);
	left: -10px;
	right: -40px
}
.penci-animated-headline[data-shape=line-2] .penci-animated-text svg {
	top: -5px;
	bottom: 0;
	width: calc(100% + 40px);
	height: calc(100% + 20px);
	left: -20px;
	right: -20px
}
.penci-animated-headline[data-shape=line-1] .penci-animated-text svg {
	top: -5px;
	bottom: 0;
	width: calc(100% + 40px);
	height: calc(100% + 20px);
	left: -20px;
	right: -20px
}
.penci-animated-headline[data-shape=strikethrough] .penci-animated-text svg {
	top: 50%;
	width: 100%;
	height: 100%
}
.penci-animated-headline[data-shape="x"] .penci-animated-text svg,
.penci-animated-headline[data-shape=diagonal] .penci-animated-text svg,
.penci-animated-headline[data-shape=double] .penci-animated-text svg {
	top: 0;
	width: 100%;
	height: 100%
}
.penci-animated-headline[data-shape=curly] .penci-animated-text svg,
.penci-animated-headline[data-shape=double-underline] .penci-animated-text svg,
.penci-animated-headline[data-shape=underline-zigzag] .penci-animated-text svg,
.penci-animated-headline[data-shape=underline] .penci-animated-text svg {
	top: 90%;
	width: 100%;
	height: 100%
}
.penci-animated-headline[data-shape=circle] .penci-animated-text svg {
	top: 0;
	width: calc(100% + 20px);
	height: calc(100% + 20px);
	-webkit-transform: translate(-10px, -10px);
	transform: translate(-10px, -10px)
}
.penci-animated-headline[data-style=rotating] .penci-animated-text .dynamic-text:not(.show-text) {
	visibility: hidden;
	opacity: 0;
	display: none
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper:after {
	content: "";
	position: absolute;
	left: auto;
	right: 0;
	top: 50%;
	-webkit-transform: translateY(-50%);
	transform: translateY(-50%);
	height: 90%;
	width: 1px;
	background-color: var(--pctext-cl)
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper.cursor-blink:after {
	-webkit-animation: pcani-pulse 1s infinite;
	animation: pcani-pulse 1s infinite
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper.typing-delete {
	background: var(--pcaccent-cl)
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper.typing-delete.style-gradient .dynamic-text {
	color: var(--pctext-cl);
	background: 0 0;
	background-clip: border-box;
	-webkit-background-clip: border-box;
	-moz-text-fill-color: unset;
	-o-text-fill-color: unset;
	-webkit-text-fill-color: unset
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper.typing-delete.style-gradient .dynamic-text .dynamic-text-letter {
	background: 0 0;
	background-clip: border-box;
	-webkit-background-clip: border-box;
	-webkit-background-clip: border-box;
	-moz-text-fill-color: unset;
	-o-text-fill-color: unset;
	-webkit-text-fill-color: unset
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-wrapper.typing-delete .dynamic-text .dynamic-text-letter {
	color: var(--pctext-cl)
}
.penci-animated-headline[data-style=rotating][data-rotate=typing] .penci-animated-text .dynamic-text-letter:not(.show-letter) {
	display: none
}
.penci-animated-headline[data-style=rotating][data-rotate=swirl] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=swirl] .penci-animated-text .dynamic-text-letter {
	display: inline-block;
	-webkit-transform-style: preserve-3d;
	transform-style: preserve-3d;
	-webkit-transform: translateZ(-20px) rotateX(90deg);
	transform: translateZ(-20px) rotateX(90deg);
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=swirl] .penci-animated-text .dynamic-text-letter.show-letter {
	-webkit-animation: pcani-swirl-in .4s forwards;
	animation: pcani-swirl-in .4s forwards
}
.penci-animated-headline[data-style=rotating][data-rotate=blinds] {
	-webkit-transition: width .3s ease;
	transition: width .3s ease
}
.penci-animated-headline[data-style=rotating][data-rotate=blinds] .penci-animated-text .dynamic-text-letter {
	-webkit-transform: rotateY(180deg);
	transform: rotateY(180deg);
	display: inline-block;
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=blinds] .penci-animated-text .dynamic-text-letter.show-letter {
	-webkit-animation: pcani-blinds-in .6s forwards;
	animation: pcani-blinds-in .6s forwards
}
.penci-animated-headline[data-style=rotating][data-rotate=wave] {
	-webkit-transition: width .3s ease;
	transition: width .3s ease
}
.penci-animated-headline[data-style=rotating][data-rotate=wave] .penci-animated-text .dynamic-text-letter {
	-webkit-transform: scale(0);
	transform: scale(0);
	display: inline-block;
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=wave] .penci-animated-text .dynamic-text-letter.show-letter {
	-webkit-animation: pcani-wave-up .3s forwards;
	animation: pcani-wave-up .3s forwards
}
.penci-animated-headline[data-style=rotating][data-rotate=flip] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=flip] .penci-animated-text .dynamic-text {
	-webkit-transform-origin: 50% 100%;
	transform-origin: 50% 100%;
	-webkit-transform: rotateX(180deg);
	transform: rotateX(180deg);
	position: relative
}
.penci-animated-headline[data-style=rotating][data-rotate=flip] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-transform: rotateX(0);
	transform: rotateX(0);
	-webkit-animation: pcani-flip-in 1.2s;
	animation: pcani-flip-in 1.2s
}
.penci-animated-headline[data-style=rotating][data-rotate=flip] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-transform: rotateX(180deg);
	transform: rotateX(180deg);
	-webkit-animation: pcani-flip-out 1.2s;
	animation: pcani-flip-out 1.2s
}
.penci-animated-headline[data-style=rotating][data-rotate=drop-in] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	-webkit-perspective: 300px;
	perspective: 300px;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=drop-in] .penci-animated-text .dynamic-text {
	position: relative
}
.penci-animated-headline[data-style=rotating][data-rotate=drop-in] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-drop-in-in .6s;
	animation: pcani-drop-in-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=drop-in] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-drop-in-out .6s;
	animation: pcani-drop-in-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-left] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-left] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-slide-left-in .6s;
	animation: pcani-slide-left-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-left] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-slide-left-out .6s;
	animation: pcani-slide-left-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-right] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-right] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-slide-right-in .6s;
	animation: pcani-slide-right-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-right] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-slide-right-out .6s;
	animation: pcani-slide-right-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-up] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-up] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-slide-up-in .6s;
	animation: pcani-slide-up-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-up] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-slide-up-out .6s;
	animation: pcani-slide-up-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-down] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-down] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-slide-down-in .6s;
	animation: pcani-slide-down-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=slide-down] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-slide-down-out .6s;
	animation: pcani-slide-down-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=bounce] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=bounce] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-bounce-in .6s;
	animation: pcani-bounce-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=bounce] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-bounce-out .6s;
	animation: pcani-bounce-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=swing] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=swing] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-swing-in .6s;
	animation: pcani-swing-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=swing] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-swing-out .6s;
	animation: pcani-swing-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=rubber-band] .penci-animated-text .dynamic-wrapper {
	-webkit-transition: width .3s ease;
	transition: width .3s ease;
	overflow: hidden
}
.penci-animated-headline[data-style=rotating][data-rotate=rubber-band] .penci-animated-text .dynamic-text.show-text {
	position: relative;
	white-space: nowrap;
	-webkit-animation: pcani-rubber-band-in .6s;
	animation: pcani-rubber-band-in .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=rubber-band] .penci-animated-text .dynamic-text:not(.show-text) {
	display: inline-block;
	position: absolute;
	visibility: visible;
	-webkit-animation: pcani-rubber-band-out .6s;
	animation: pcani-rubber-band-out .6s
}
.penci-animated-headline[data-style=rotating][data-rotate=clip] .penci-animated-text .dynamic-wrapper {
	overflow: hidden;
	text-align: left
}
.penci-animated-headline[data-style=rotating][data-rotate=clip] .penci-animated-text .dynamic-wrapper:after {
	content: "";
	position: absolute;
	left: auto;
	right: 0;
	top: 0;
	height: 100%;
	width: 2px;
	background-color: var(--pctext-cl)
}
.penci-animated-headline[data-style=rotating][data-rotate=clip] .penci-animated-text .dynamic-text.show-text {
	white-space: nowrap
}
.penci-adblocker-popup-container {
	max-width: 550px;
	padding: 60px;
	background: var(--pcbg-cl);
	margin: 0 auto;
	text-align: center
}
.penci-adblocker-popup-container .penci-adblocker-adblock-icon {
	font-size: 50px;
	color: red
}
.penci-adblocker-popup-container h2 {
	margin: 15px 0;
	font-size: 24px
}
.penci-adblocker-popup-container .penci-adblock-message {
	font-size: 16px;
	line-height: 1.4
}
.penci-adblocker-popup-container .mfp-close {
	position: static;
	width: auto;
	font-size: 14px;
	padding: 0;
	margin: 15px auto 0;
	height: auto;
	line-height: unset
}
.pcac_page_container {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row
}
.pcac_page_container.full {
	display: block
}
.pcac_page_container .pcac_page_left {
	min-width: 270px;
	margin-right: 60px
}
body.rtl .pcac_page_container .pcac_page_left {
	margin-right: 0;
	margin-left: 60px
}
.pcac_page_container .pcac_author_info {
	border: 1px solid var(--pcborder-cl);
	padding: 30px;
	text-align: center
}
.pcac_page_container .pcac_author_info .avatar {
	border-radius: 50%
}
.pcac_page_container .pcac_account_nav,
.pcac_page_container .pcac_author_content {
	margin-top: 15px
}
.pcac_page_container .pcac_account_nav {
	border-top: 1px solid var(--pcborder-cl);
	padding-top: 15px
}
.pcac_page_container .pcac_account_nav li {
	margin: 0 0 10px
}
.pcac_page_container .pcac_account_nav li a {
	color: var(--pcheading-cl)
}
.pcac_page_container .pcac_account_nav li a:hover {
	color: var(--pcaccent-cl)
}
.pcac_page_container .pcac_account_nav li.active a {
	color: var(--pcaccent-cl);
	font-weight: 700
}
.pcac_page_container .pcac_page_right {
	width: calc(100% - 360px)
}
.pcac_page_container .pcac_account_title {
	font-size: 22px;
	margin: 0 0 30px;
	padding: 0 0 30px;
	border-bottom: 1px solid var(--pcborder-cl)
}
.pcac_page_container .form-group {
	margin-bottom: 30px
}
.pcac_page_container .form-group > label {
	display: inline-block;
	margin: 0 0 15px;
	font-size: 14px;
	font-weight: 700
}
.pcac_page_container .form-group .required {
	color: red
}
.pcac_page_container .form-group input,
.pcac_page_container .form-group select,
.penci-sidebar-content .form-group input,
.penci-sidebar-content .form-group select,
.penci_post_list_filter select {
	display: block;
	border: 1px solid var(--pcborder-cl);
	padding: 0 10px;
	line-height: 40px;
	transition: .25s ease;
	box-shadow: none;
	outline: 0;
	background: #fff
}
.penci_post_list_filter select {
	padding: 0 20px
}
.pcac_page_container .form-group select,
.penci-sidebar-content .form-group select,
.penci_post_list_filter select {
	height: 40px;
	background: 0 0
}
.pcac_page_container .form-group input:not([type=submit]):focus,.pcac_page_container .form-group select:focus,.pcac_page_container .form-group textarea:focus {
	border-color: #666;
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, .025)
}
.pcac_page_container .form-group input[type=submit],
.penci-sidebar-content .form-group input[type=submit] {
	background: var(--pcaccent-cl);
	color: #fff;
	font-weight: 700;
	font-size: 14px;
	cursor: pointer;
	border: 0;
	outline: 0;
	padding: 0 20px;
	width: auto
}
.pcac_page_container .form-group input[type=submit]:hover,
.penci-sidebar-content .form-group input[type=submit]:hover {
	opacity: .7
}
.pcac_page_container.full .form-group input {
	width: 100%
}
.pcac_page_container.full .title-field input {
	font-size: 18px;
	font-weight: 700
}
.pcac_page_container .row {
	margin-right: -15px;
	margin-left: -15px
}
.pcac_page_container .pccol_1,
.pcac_page_container .pccol_2 {
	width: 50%;
	float: left;
	position: relative;
	min-height: 1px;
	padding-right: 15px;
	padding-left: 15px
}
body.rtl .pcac_page_container .pccol_1,
body.rtl .pcac_page_container .pccol_2 {
	float: right
}
.pcac_page_container .pccol_1 {
	width: 100%
}
.pcac_page_container .pccol_1 h3 {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 30px;
	margin-bottom: 30px
}
.pcac_page_container .pccol_1 input,
.pcac_page_container .pccol_1 select,
.pcac_page_container .pccol_2 input,
.pcac_page_container .pccol_2 select {
	width: 100%
}
.pcac_page_container .alert {
	padding-left: 15px;
	margin-bottom: 15px;
	line-height: 40px;
	font-size: 14px;
	text-align: center;
	font-weight: 500
}
.pcac_page_container .alert-error {
	background: red;
	color: #fff
}
.pcac_page_container .alert-success {
	background: #dcffb4;
	color: #595959
}
.pcac_page_container .alert-compatibility {
	background: #fff5f6;
	position: absolute;
	top: 0;
	opacity: 0;
	visibility: hidden;
	width: auto;
	border-radius: 0;
	text-align: center
}
.penci-sidebar-content .form-group:not(.submit-field):not(.format-field) {
	border: 1px solid var(--pcborder-cl);
	padding: 30px;
	margin-bottom: 30px;
	background-color: #f9f9f9
}
.penci-sidebar-content .form-group.format-field .form-input-wrapper {
	border: 1px solid var(--pcborder-cl);
	padding: 30px;
	margin-bottom: 30px;
	background-color: #f9f9f9
}
.penci-sidebar-content .form-group label {
	display: block;
	font-weight: 700;
	margin-bottom: 10px
}
.penci-sidebar-content .form-group input,
.penci-sidebar-content .form-group select {
	width: 100%
}
.penci-post-tablist {
	list-style: none
}
.penci-post-tablist li {
	display: inline-block
}
.penci-post-tablist li a {
	display: inline-block;
	padding: 10px 15px;
	border: 1px solid var(--pcborder-cl);
	border-bottom: 0;
	color: var(--pcheading-cl);
	position: relative;
	top: 1px;
	font-weight: 700;
	font-size: 14px
}
.penci-post-tablist li a.active {
	background-color: #f9f9f9;
	color: var(--pcaccent-cl)
}
.pcft-posteditor .format-field .form-input-wrapper input {
	display: none
}
.pcft-posteditor .penci_upload_wrapper:not(.active) {
	display: none
}
.penci_post_list_meta {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between;
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 30px;
	margin-bottom: 30px;
	align-items: center
}
.pcac_page_container .penci-pagination {
	margin-top: 30px
}
.frontend-submit-button {
	margin: 30px -25px -25px
}
.frontend-submit-button .button {
	display: block;
	padding: 15px 20px;
	background: var(--pcaccent-cl);
	font-weight: 700;
	color: #fff;
	transition: .2s
}
.frontend-submit-button .button:hover {
	opacity: .7
}
@media only screen and (max-width:767px) {
	.pcac_page_container .pcac_page_left,
	.pcac_page_container .pcac_page_right {
		width: 100%
	}
	.pcac_page_container .pcac_page_left {
		margin-right: 0;
		margin-bottom: 30px
	}
}
.pcac_page_container .upload_preview_container {
	margin: 0 0 30px;
	position: relative;
	max-width: 80px
}
.pcac_page_container .upload_preview_container .remove {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	z-index: 9;
	cursor: pointer;
	bottom: 0;
	display: flex;
	justify-content: center;
	align-items: center
}
.pcac_page_container .upload_preview_container img {
	border-radius: 50%;
	max-height: 80px;
	width: auto
}
.pcac_page_container .penci-upload-img-btn {
	display: inline-block;
	padding: 0 10px;
	line-height: 30px;
	background-color: var(--pcheading-cl);
	color: var(--pcbg-cl);
	cursor: pointer;
	transition: .3s all
}
.pcac_page_container .penci-upload-img-btn:hover {
	opacity: .8
}
.penci_post_status.Pending {
	color: #c09853;
	font-weight: 700
}
.penci_post_status.Published {
	color: var(--pcaccent-cl);
	font-weight: 700
}
body.rtl .penci_account_posts .pcsl-inner .pcsl-content {
	padding: 0 var(--pcsl-between)
}
.penci_account_posts .pcsl-inner .sl-date {
	display: inline-block
}
body.pc-has-sorter .archive-box,
.archive-box.pc-has-sorter {
	display: flex;
	justify-content: space-between;
	align-items: center;
	margin-left: auto;
	margin-right: auto;
	max-width: 100%;
	align-items: start;
}
.penci_gsr_wrapper .gsst_b {
	padding: 0 5px
}
.penci_gsr_wrapper table.gsc-search-box td {
	vertical-align: middle
}
.penci_gsr_wrapper .gsc-input {
	padding: 0;
	line-height: 31px
}
.penci_gsr_wrapper .gsc-search-button-v2 {
	height: 42px;
	line-height: 42px;
	padding: 6px 27px
}
.penci_gsr_wrapper .gsc-search-button-v2 svg {
	width: 15px;
	height: 15px
}
.penci_gsr_wrapper .gsib_a {
	padding: 5px 15px 4px 15px
}
.penci_gsr_wrapper .gscb_a {
	line-height: 36px
}
.penci-patreon-badge-wrap {
	text-align: center
}
.penci-patreon-badge-wrap .button {
	display: block;
	background: #ff424d;
	font-weight: 700;
	font-size: 14px;
	border-radius: 100px;
	padding: 12px 5px;
	margin-top: 20px;
	text-decoration: none
}
.penci-patreon-badge-wrap .button:hover {
	background: #ff424d;
	text-decoration: none;
	color: #000
}
.penci-patreon-badge-wrap svg {
	height: 5rem;
	width: 5rem;
	display: inline-block;
	margin: 10px auto
}
.penci-patreon-badge-wrap svg [data-color="1"] {
	fill: #ff424d
}
.penci-patreon-badge-wrap svg [data-color="2"] {
	fill: #241e12
}
.widget .penci-buymeacoffee-badge-wrap {
	text-align: center
}
.widget .penci-buymeacoffee-badge-wrap a.button {
	display: block;
	background: #fd0;
	font-weight: 700;
	font-size: 14px;
	color: #000;
	border-radius: 100px;
	padding: 12px 5px;
	margin-top: 20px;
	text-decoration: none;
	transition: .3s all ease-in-out
}
.widget .penci-buymeacoffee-badge-wrap a.button:hover {
	background: #000;
	color: #fd0;
	text-decoration: none
}
.widget .penci-buymeacoffee-badge-wrap svg {
	height: 6rem;
	width: 6rem;
	display: inline-block;
	margin: 10px auto
}
.cancel-off-png,
.cancel-on-png,
.star-half-png,
.star-off-png,
.star-on-png {
	font-size: 1.8em
}
@font-face {
	font-family: raty;
	font-style: normal;
	font-weight: 400;
	src: url(fonts/raty.eot);
	src: url(fonts/raty.eot?#iefix) format("embedded-opentype");
	src: url(fonts/raty.svg#raty) format("svg");
	src: url(fonts/raty.ttf) format("truetype");
	src: url(fonts/raty.woff) format("woff")
}
.cancel-off-png,
.cancel-on-png,
.star-half-png,
.star-off-png,
.star-on-png {
	-moz-osx-font-smoothing: grayscale;
	-webkit-font-smoothing: antialiased;
	font-family: raty;
	font-style: normal;
	font-variant: normal;
	font-weight: 400;
	line-height: 1;
	speak: none;
	text-transform: none
}
.cancel-on-png:before {
	content: "\e600"
}
.cancel-off-png:before {
	content: "\e601"
}
.star-on-png:before {
	content: "\f005"
}
.star-off-png:before {
	content: "\f006"
}
.star-half-png:before {
	content: "\f123"
}
.thecomment .comment-text .penci-review-author span.author,
.thecomment .comment-text .penci-review-author span.author a,
.thecomment .comment-text .penci-review-author span.date {
	display: inline-block;
	margin: 0;
	text-transform: none
}
.thecomment .comment-text .penci-review-author span.author {
	margin-right: 5px;
	font-size: 14px
}
.thecomment .comment-text .penci-review-author span.author a {
	font-size: inherit
}
.penci-review-summary .pccm_rating_title,
.penci-review-summary .review_rated {
	display: inline-block;
	margin: 0
}
.penci-review-summary .review_rated {
	font-size: 7px;
	color: #ffb900;
	margin-right: 5px
}
.pcgl-thumb-slider:not(.slick-initialized) {
	margin-left: -5px;
	margin-right: -5px
}
.pcgl-thumb-slider .pcgl-thumb-item {
	padding: 0 5px;
	cursor: pointer;
	width: 100px
}
.pcgl-thumb-slider .swiper-wrapper {
	justify-content: center
}
.pcgl-thumb-slider:not(.slick-initialized) {
	white-space: nowrap;
	overflow: hidden
}
.pcgl-thumb-slider:not(.slick-initialized) .pcgl-thumb-item {
	opacity: 0;
	transition: .3s all ease-in-out
}
.pcgl-thumb-slider[data-cols="2"]:not(.slick-initialized) .pcgl-thumb-item {
	width: 50%
}
.pcgl-thumb-slider[data-cols="4"]:not(.slick-initialized) .pcgl-thumb-item {
	width: 25%
}
.pcgl-thumb-slider[data-cols="5"]:not(.slick-initialized) .pcgl-thumb-item {
	width: 20%
}
.pcgl-thumb-slider[data-cols="6"]:not(.slick-initialized) .pcgl-thumb-item {
	width: calc(100% / 6)
}
.penci-slick-carousel.pcthumb-s-msl:not(.slick-initialized) figure:not(:first-child) {
	display: none
}
.penci-slick-carousel.pcthumb-s-msl figure {
	margin: 0 auto;
	vertical-align: top;
	padding: 15px 15px 0
}
.penci-image-gallery-thumbnail-slider {
	background: #111;
	overflow: hidden
}
.elementor-widget-penci-image-gallery .penci-image-gallery-thumbnail-slider {
	padding: 0
}
.pcgl-thumb-slider.swiper {
	padding: 10px;
	border-bottom: 1px solid #222
}
.pcgl-thumb-slider .penci-image-holder {
	outline: solid 3px rgba(255, 255, 255, .5);
	outline-offset: -3px;
	min-height: 80px
}
.pcgl-thumb-slider .swiper-slide-thumb-active .penci-image-holder {
	outline: solid 3px #fff
}
.penci-image-gallery-3d {
	--item: 180px;
	--pd: 30px;
	margin: 0 auto;
	padding-top: var(--pd);
	height: calc(var(--item) * 2 + var(--pd));
}
@media only screen and (max-width: 767px){
	.penci-image-gallery-3d {
		--item: 140px;
		--pd: 15px;
	}
}
.inner-gallery-3d-container {
	margin: auto;
	width: var(--item);
	perspective: var(--pcctain);
	position: relative;
	padding-top: var(--pd);
}
.pcgallery-3d-wrap {
	width: 100%;
	position: absolute;
	float: right;
	animation: pcgallery-3d 15s infinite linear;
	transform-style: preserve-3d;
}
.pcgallery-3d-wrap:hover {
	animation-play-state: paused;
	cursor: pointer;
}
.pcgallery-3d-wrap .penci-gallery-ite {
	width: 100%;
	height: var(--item);
	border: 1px solid var(--pcborder-cl);
	overflow: hidden;
	position: absolute;
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(1) {
	transform: rotateY(0deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(2) {
	transform: rotateY(40deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(3) {
	transform: rotateY(80deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(4) {
	transform: rotateY(120deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(5) {
	transform: rotateY(160deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(6) {
	transform: rotateY(200deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(7) {
	transform: rotateY(240deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(8) {
	transform: rotateY(280deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(9) {
	transform: rotateY(320deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite:nth-child(10) {
	transform: rotateY(360deg) translateZ(300px);
}
.pcgallery-3d-wrap .penci-gallery-ite {
	position: absolute;
	box-shadow: 0px 13px 20px 3px rgba(55,55,55,0.1);
	border-radius: 1px;
	opacity: 1;
}
.pcgallery-3d-wrap .penci-gallery-ite img {
	image-rendering: auto;
	transition: all 300ms;
	width: 100%;
	height: 100%;
}
.pcgallery-3d-wrap .penci-gallery-ite img:hover {
	transform: scale(1.2);
	transition: all 300ms;
}
@keyframes pcgallery-3d {
	from {
		transform: rotateY(0deg);
	}
	to {
		transform: rotateY(360deg);
	}
}
.penci-slick-carousel-top-nav {
	color: #fff;
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: center;
	padding: 15px 10px 0;
	align-items: center
}
.pcslick-title-area h5 {
	color: #fff;
	margin: 0
}
.pcslick-nav button {
	padding: 0 5px;
	margin: 0;
	font-size: 16px;
	background: 0 0;
	vertical-align: middle;
	line-height: 1
}
.pcslick-nav-area {
	display: flex;
	flex-direction: row-reverse;
	align-items: center
}
.pcslick-nav {
	margin: 0 0 0 10px;
	line-height: 0
}
.slider-num {
	font-size: 13px;
	font-weight: 700
}
.elementor-widget-penci-image-gallery .penci-post-gallery-container.thumbnail-slider {
	margin-bottom: 0
}
.author-url .avatar,
.grid-post-box-meta img.avatar,
.penci-grid li .item .author-url .avatar,
.penci-masonry .item-masonry a .author-url .avatar {
	vertical-align: middle;
	border-radius: var(--pcava_bdr);
	display: inline-block;
	width: 22px;
	height: auto;
	margin: 0
}
.author-url .author-a-name,
.grid-post-box-meta .author-a-name {
	font-weight: inherit;
	margin-left: 5px
}
#penci-header-bookmark a:hover {
	color: var(--pcaccent-cl)
}
.penci-font-changer {
	font-weight: 700;
	position: relative
}
.penci-fchanger-pcontent {
	background: var(--pcbg-cl);
	border: 1px solid var(--pcborder-cl);
	border-radius: 2px;
	padding: 10px;
	position: relative;
	box-shadow: 0 10px 15px -3px rgba(0, 0, 0, .1), 0 10px 15px -3px rgba(0, 0, 0, .1)
}
.penci-fcpopup-ct-wrapper {
	position: absolute;
	top: 100%;
	width: 160px;
	transform: translateX(-50%);
	left: 50%;
	display: none;
	z-index: 99999;
	padding: 10px 0 0
}
.penci-fchanger-pcontent:after {
	content: "";
	position: absolute;
	border-style: solid;
	border-width: 0 5px 5px 5px;
	border-color: transparent transparent var(--pcbg-cl) transparent;
	top: -5px;
	left: 50%;
	right: 50%;
	margin-left: -2.5px;
	z-index: 5
}
.penci-fchanger-pcontent:before {
	content: "";
	position: absolute;
	border-style: solid;
	border-width: 0 7px 7px 7px;
	border-color: transparent transparent var(--pcborder-cl) transparent;
	top: -7px;
	left: 50%;
	right: 50%;
	margin-left: -4px;
	z-index: 4
}
.penci-fchanger-pcontent .penci-font-changer-reset {
	color: var(--pctext-cl);
	font-size: 12px;
	font-weight: 400;
	display: block;
	margin: 5px 0 0;
	cursor: pointer
}
.standard-post-special_wrapper .penci-fchanger-pcontent:after {
	content: "";
	position: absolute;
	border-style: solid;
	border-width: 5px 5px 0 5px;
	border-color: #fff transparent transparent transparent;
	top: auto;
	bottom: -5px;
	left: 50%;
	right: 50%;
	margin-left: -2.5px
}
.standard-post-special_wrapper .penci-fchanger-pcontent:before {
	content: "";
	position: absolute;
	border-style: solid;
	border-width: 7px 7px 0 7px;
	border-color: transparent transparent var(--pcborder-cl) transparent;
	top: auto;
	bottom: -7px;
	left: 50%;
	right: 50%;
	margin-left: -4px;
	z-index: 4
}
.penci-font-changer-popup.active .penci-fcpopup-ct-wrapper {
	display: block
}
.standard-post-special_wrapper .penci-fcpopup-ct-wrapper {
	top: auto;
	bottom: 100%;
	padding: 0 0 10px
}
.penci-font-changer-popup {
	position: relative;
	display: inline-block;
	text-align: center
}
.header-standard .post-box-meta-single .penci-font-changer span {
	cursor: pointer;
	color: inherit;
	margin: 0 5px;
	display: inline-block;
	opacity: .7;
	transition: all .3s ease-in-out;
	outline: 0
}
.header-standard .post-box-meta-single .penci-font-changer span:focus {
	opacity: 1
}
.header-standard .post-box-meta-single .penci-font-changer span:hover {
	color: var(--pcaccent-cl)
}
.header-standard .post-box-meta-single .penci-font-changer .pcf-changer-smaller {
	font-size: 12px
}
.header-standard .post-box-meta-single .penci-font-changer .pcf-changer-larer {
	font-size: 16px
}
.penci-header-wrap {
	position: relative;
	z-index: 999
}
.penci-header-wrap .pcscrollbar {
	position: absolute;
	bottom: -1px;
	left: 0;
	right: 0;
	height: 5px;
	background-color: var(--pcaccent-cl);
	z-index: 999;
	width: 0;
	opacity: 0;
	visibility: hidden;
	transition: opacity .3s, visibility .3s
}
.penci-header-wrap .pcscrollbar.active {
	opacity: 1;
	visibility: visible
}
.penci-header-wrap .pcscrollbar span {
	display: none
}
.slider-container {
	display: inline-block;
	vertical-align: middle;
	position: relative;
	top: 0
}
.slider-container .back-bar {
	height: 10px;
	position: relative
}
.slider-container .back-bar .selected-bar {
	position: absolute;
	height: 100%
}
.slider-container .back-bar .pointer {
	position: absolute;
	width: 10px;
	height: 10px;
	background-color: var(--pcmeta-cl);
	cursor: col-resize;
	opacity: 1;
	z-index: 2
}
.slider-container .back-bar .pointer.last-active {
	z-index: 3
}
.slider-container .back-bar .pointer-label {
	position: absolute;
	top: -17px;
	font-size: 10px;
	white-space: nowrap;
	line-height: 1
}
.penci-single-style-10 .slider-container .back-bar .pointer-label,
.penci-single-style-13 .slider-container .back-bar .pointer-label,
.standard-post-special_wrapper .slider-container .back-bar .pointer-label {
	color: #fff
}
.slider-container .back-bar .focused {
	z-index: 10
}
.slider-container .clickable-dummy {
	cursor: pointer;
	position: absolute;
	width: 100%;
	height: 100%;
	z-index: 1
}
.slider-container .scale {
	top: 2px;
	position: relative
}
.slider-container .scale span {
	position: absolute;
	height: 5px;
	border-left: 1px solid #999;
	font-size: 0
}
.slider-container .scale ins {
	font-size: 9px;
	text-decoration: none;
	position: absolute;
	left: 0;
	top: 5px;
	color: #999;
	line-height: 1
}
.slider-container.slider-readonly .clickable-dummy,
.slider-container.slider-readonly .pointer {
	cursor: auto
}
.penci-fs-slider .back-bar {
	height: 5px;
	border-radius: 2px;
	background-color: #eee
}
.pcdark-mode.pcdm-enable .penci-fs-slider .back-bar {
	background-color: #333
}
.penci-fs-slider .back-bar .selected-bar {
	background-color: var(--pcaccent-cl)
}
.penci-fs-slider .back-bar .pointer {
	width: 14px;
	height: 14px;
	top: -5px;
	-webkit-box-sizing: border-box;
	-moz-box-sizing: border-box;
	box-sizing: border-box;
	border-radius: 10px;
	background-color: var(--pcaccent-cl)
}
.penci-fs-slider .back-bar .pointer-label,
.penci-fs-slider .scale ins {
	color: var(--pctext-cl)
}
.penci-fs-slider .back-bar .focused {
	color: var(--pcheading-cl)
}
.penci-fs-slider .scale span {
	border-left: 1px solid var(--pcborder-cl)
}
.post-author.abio-style-5 {
	padding: 30px;
	margin-top: 30px;
	border: 1px solid var(--pcborder-cl);
	border-bottom: none !important
}
.post-author.abio-style-5 .bio-social {
	margin: 30px -35px -30px;
	padding: 20px 30px;
	border-top: 1px solid var(--pcborder-cl);
	clear: both
}
body.archive.author .post-author.abio-style-5 {
	border-bottom: 1px solid var(--pcborder-cl) !important;
}
.post-author.abio-style-5 .author-content:after {
	content: "";
	display: table;
	clear: both
}
.post-author.abio-style-5 .bio-social>a {
	margin-left: 5px;
	margin-right: 5px;
	color: var(--pctext-cl)
}
.post-author.abio-style-5 .bio-social>a:hover {
	color: var(--pcaccent-cl)
}
.author-top-tabs {
	clear: both;
	margin: -30px -40px 30px;
	padding: 0;
	border-bottom: 1px solid var(--pcborder-cl)
}
.author-top-tabs ul {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between
}
.author-top-tabs ul li {
	width: 50%
}
.author-top-tabs ul li a {
	display: block;
	padding: 20px 10px;
	text-align: center;
	position: relative;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.author-top-tabs ul li:first-child {
	border-right: 1px solid var(--pcborder-cl)
}
.author-top-tabs ul li a:before {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	height: 5px;
	background: 0 0;
	content: "";
	z-index: 9
}
.author-top-tabs ul li a.active:before {
	background: var(--pcaccent-cl)
}
.post-related-author {
	border: 0;
	padding: 0
}
.author-tab-content {
	display: none
}
.author-tab-content.active {
	display: block
}
.author-tab-content .penci-ilrelated-posts {
	margin: 0;
	padding: 0;
	border: 0
}
@media only screen and (max-width:767px) {
	.post-author.abio-style-5 .author-img {
		max-width: 70px;
		display: block;
		margin-left: auto;
		margin-right: auto;
		float: none
	}
	.post-author.abio-style-5 .author-content {
		text-align: center;
		margin: 15px auto 0
	}
	.post-author.abio-style-5 .bio-social {
		text-align: center
	}
}
.pccsi-img,
.pccsi-svg {
	vertical-align: middle !important;
	line-height: 100%;
	display: inline-flex !important;
	align-items: center;
	justify-content: center
}
.elementor .pccsi-img img,
.pccsi-img img {
	max-width: 17px;
	height: auto
}
.pccsi-svg svg path {
	transition: all .3s
}
.elementor .pccsi-svg svg,
.pccsi-svg svg {
	width: 12px;
	height: auto
}
.header-social a:hover svg path,
.main-nav-social a:hover svg path {
	fill: var(--pcaccent-cl)
}
.pcsoccl-brandtext i.pccsi-svg svg path,
.penci-social-textcolored a i.pccsi-svg svg path {
	fill: var(--pcci, var(--pcaccent-cl))
}
#header .inner-header-social .penci-faicon.penciicon-x-twitter,
.footer-socials .penci-faicon.penciicon-line,
.footer-socials .penci-faicon.penciicon-viber,
.footer-socials .penci-faicon.penciicon-x-twitter,
.header-style-header-1 .main-nav-social .penci-faicon.penciicon-x-twitter,
.pcnew-share.penci-icon-full .post-share-item .penci-faicon.penciicon-x-twitter,
.pcsoc-icon.pcsoci-twitter .penci-faicon.penciicon-x-twitter,
.penci-builder-element .penci-faicon.penciicon-x-twitter,
.penci-social-colored .penci-faicon.penciicon-line,
.penci-social-colored .penci-faicon.penciicon-viber,
.penci-social-colored .penci-faicon.penciicon-x-twitter,
.penci-social-square .penci-faicon.penciicon-line,
.penci-social-square .penci-faicon.penciicon-viber,
.penci-social-square .penci-faicon.penciicon-x-twitter,
.penci-team_member_socails .penci-faicon.penciicon-x-twitter,
.show-txt.focus-icon .post-share-item .penci-faicon.penciicon-x-twitter,
.single-product-share .new-ver-share .penci-faicon.penciicon-line,
.single-product-share .new-ver-share .penci-faicon.penciicon-viber,
.single-product-share .new-ver-share .penci-faicon.penciicon-x-twitter {
	transform: translateY(0)
}
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-line,
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-viber,
.single-post-share.tags-share-box-s1 .penci-faicon.penciicon-x-twitter {
	transform: translateY(2px)
}
body:not(.penci-disable-desc-collapse) .penci-category-description {
	position: relative;
	max-height: 120px;
	overflow: hidden
}
body:not(.penci-disable-desc-collapse) .penci-category-description.active {
	max-height: 99999px
}
.penci-category-description .penci-category-description-button {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0
}
.penci-category-description-button:before {
	content: "";
	position: absolute;
	inset-inline: 0;
	bottom: 0;
	z-index: 10;
	height: 80px;
	background: linear-gradient(to bottom, transparent 0, currentColor 40px);
	color: var(--pcbg-cl);
	z-index: 1
}
.penci-category-description.active .penci-category-description-button:before {
	display: none
}
.penci-category-description-button a {
	color: var(--pcheading-cl);
	display: inline-block;
	position: relative;
	z-index: 2;
	font-weight: 700;
	font-family: var(--pchead-font);
	font-size: 15px;
	line-height: 30px
}
.penci-category-description.active .penci-category-description-inner {
	padding-bottom: 30px
}
.penci-slick-featured-area.elsl-style-39 .penci-active-bg {
	opacity: 1 !important
}
.penci-slick-featured-area.elsl-style-39 .item {
	position: relative;
	padding: 120px
}
@media only screen and (max-width:767px) {
	.penci-slick-featured-area.elsl-style-39 .item {
		padding: 5px
	}
}
.penci-slick-featured-area.elsl-style-39 .item-inner-content {
	position: relative;
	z-index: 99;
	overflow: hidden
}
.penci-slick-featured-area.elsl-style-39 .penci-featured-content:before {
	content: "";
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: rgba(0, 0, 0, .3);
	position: absolute;
	z-index: 11
}
.penci-slick-featured-area.elsl-style-39 .item-inner-content .penci-slider39-suboverlay {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	width: 100%
}
.penci-slick-featured-area.elsl-style-39 .penci-featured-content .feat-text {
	z-index: 11
}
.penci-slick-featured-area.elsl-style-39 .penci-featured-content {
	left: 0;
	right: 0;
	width: auto;
	position: relative;
	top: 0;
	bottom: 0
}
.penci-slick-featured-area.elsl-style-39 .penci-slider39-overlay {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0
}
.penci-slick-featured-area.elsl-style-39 .penci-slider39-overlay:before {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	content: "";
	background: rgba(55, 55, 55, .8);
	z-index: 2
}
.penci-slider39-thumb {
	max-width: 550px;
	transform: translateY(-40px);
	margin: 0 auto
}
.penci-slider39-thumb .slick-thumb-item {
	padding: 0 10px;
	cursor: pointer
}
.featured-area .slick-slider .slick-arrow {
	width: 30px;
	height: 30px;
	text-align: center;
	line-height: 30px;
	border-radius: 50%;
	padding: 0;
	background: #fff;
	color: var(--pcheading-cl)
}
.featured-area .slick-slider .slick-arrow:before {
	font-size: 12px
}
.featured-area .slick-slider .slick-arrow.slick-next {
	right: 0;
	left: auto
}
.featured-area .slick-slider:hover .slick-arrow.slick-next {
	right: 15px;
	left: auto
}
@keyframes selectionSharerPopover-animation {
	from {
		opacity: 0
	}
	to {
		opacity: 1
	}
}
.penci-sharect {
	padding: 10px 6px;
	line-height: 0;
	transition: all .2s ease-in-out 0s;
	box-shadow: rgba(0, 0, 0, .15) 0 2px 15px 1px;
	position: absolute;
	border-radius: 3px
}
.penci-sharect .pcshare-item {
	display: inline-block;
	margin: 7px;
	cursor: pointer;
	transition: all .2s ease-in-out 0s
}
.penci-sharect i {
	color: #fff;
	font-size: 18px
}
.penci-sharect>div>div {
	vertical-align: top;
	margin: 0 10px !important
}
.penci-sharect-arrow {
	position: absolute;
	border-left: 7px solid transparent;
	border-right: 7px solid transparent;
	border-top: 7px solid #fff;
	bottom: -6px;
	left: 50%;
	right: 50%;
	transform: translateX(-50%);
	width: 0;
	height: 0
}
.entry-content ::selection {
	background-color: var(--pcheading-cl);
	color: #fff
}
.penci-social-fixed-share.post-share {
	position: fixed;
	left: 20px;
	top: 50%;
	transform: translateY(-50%);
	z-index: 99;
	width: 40px;
	white-space: break-spaces;
	display: none;
	margin-bottom: 0
}
.penci-social-fixed-share.post-share .post-share-item {
	font-size: 18px
}
.penci-social-fixed-share.post-share.pos-right {
	left: auto;
	right: 20px
}
.penci-social-fixed-share.share-style-1 .post-share-item {
	margin: 0 !important
}
.penci-single-block.inview .penci-social-fixed-share.post-share {
	opacity: 1;
	display: block
}
.penci-social-fixed-share.post-share .post-share-item:last-child {
	margin-bottom: 0 !important
}
.penci-social-fixed-share.share-style-2 .post-share-item,
.penci-social-fixed-share.share-style-3 .post-share-item {
	border-radius: 50%
}
.penci-social-fixed-share.share-style-3 .post-share-item {
	background: var(--pcbg-cl);
	border: 1px solid var(--pcborder-cl);
	box-shadow: 1px 1px 1px 0 rgba(55, 55, 55, .1);
	transition: .3s all ease-in-out;
	line-height: 38px
}
.penci-social-fixed-share.share-style-3 .post-share-item:hover {
	background: #f1f1f1
}
.widget .categories-block ul li {
	padding: 0;
	margin: 0;
	overflow: hidden
}
.categories-block .category-title {
	font-weight: 700;
	white-space: nowrap
}
.categories-block .category-count {
	border-radius: 100%;
	background-color: var(--pcaccent-cl);
	color: #fff;
	min-width: 34px;
	text-align: center;
	height: 34px;
	line-height: 34px;
	font-size: 12px;
	display: inline-block
}
.categories-block.categories-block-vertical li {
	text-align: center;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center
}
.categories-block.categories-block-vertical li a {
	-webkit-flex-direction: column;
	-ms-flex-direction: column;
	flex-direction: column;
	min-width: 210px;
	width: 100%
}
.categories-block.categories-block-horizontal a {
	gap: 10px
}
.categories-block.categories-block-horizontal .category-title {
	-webkit-flex-grow: 2;
	-ms-flex-positive: 2;
	flex-grow: 2
}
.categories-block ul {
	--gap: 10px;
	--col: 3;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	gap: var(--gap);
	-webkit-justify-content: center;
	-ms-flex-pack: center;
	justify-content: center
}
.categories-block.cols-2 ul {
	--col: 2;
}
.categories-block.cols-4 ul {
	--col: 4;
}
.categories-block.cols-5 ul {
	--col: 5;
}
.categories-block ul.categories-layout-scroll {
	overflow: auto;
	-webkit-justify-content: flex-start;
	-ms-flex-pack: start;
	justify-content: flex-start;
	padding-bottom: 30px
}
.categories-block ul.categories-layout-scroll li {
	min-width: 210px;
	text-align: center
}
.categories-block ul.categories-layout-scroll li a {
	min-width: 210px
}
.categories-block ul.categories-layout-wrap {
	-webkit-flex-wrap: wrap;
	-ms-flex-wrap: wrap;
	flex-wrap: wrap;
	-webkit-justify-content: flex-start;
	-ms-flex-pack: start;
	justify-content: flex-start
}
.categories-block ul.categories-layout-wrap.categories-wrap-1 li {
	-webkit-flex-basis: 60%;
	-ms-flex-preferred-size: 60%;
	flex-basis: 60%;
	background-color: rgba(0, 0, 0, .1);
	border: 0
}
.categories-block ul.categories-layout-wrap.categories-wrap-2 li {
	-webkit-flex-basis: 45%;
	-ms-flex-preferred-size: 45%;
	flex-basis: 45%
}
.categories-block ul.categories-layout-wrap.categories-wrap-3 li {
	-webkit-flex-basis: 30%;
	-ms-flex-preferred-size: 30%;
	flex-basis: 30%
}
.categories-block li {
	background: rgba(0, 0, 0, .02);
	transition: .15s;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	position: relative;
	-webkit-flex-grow: 1;
	-ms-flex-positive: 1;
	flex-grow: 1;
	border-radius: 5px
}
.categories-block li.has-bg {
	background-size: cover;
	background-repeat: no-repeat;
	background-position: center
}
.categories-block li.has-bg:after {
	content: "";
	position: absolute;
	display: block;
	left: 0;
	right: 0;
	bottom: 0;
	height: 100%;
	transition: opacity .2s;
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden;
	background-color: rgba(0, 0, 0, .6);
	border-radius: 5px
}
.categories-block li.has-bg:hover:after {
	opacity: .7
}
.categories-block li.has-bg .category-title {
	color: #fff;
	font-size: 16px
}
.categories-block li.has-bg .category-desc {
	color: #fff;
	text-align: center;
	font-size: 12px;
}
.categories-block li a {
	padding: 10px 20px;
	display: -webkit-flex;
	display: -ms-flexbox;
	display: flex;
	-webkit-align-items: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-flex-grow: 1;
	-ms-flex-positive: 1;
	flex-grow: 1;
	z-index: 1;
	gap: 5px
}
.categories-block li a:hover {
	text-decoration: none !important
}
.categories-block .penci-image-holder {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	transition: transform 1s, filter 2s ease-in-out;
	transform: scale(1.2)
}
.categories-block li:hover .penci-image-holder {
	transform: scale(1)
}
ul.pc-advanced-cat li {
	position: relative
}
ul.pc-advanced-cat li .indicator {
	position: absolute;
	top: 0;
	right: 0;
	font-size: 14px;
	cursor: pointer
}
ul.pc-advanced-cat.toggle-enable li .category-item-count {
	margin-right: 30px
}
.pc-cat-archive {
	margin-bottom: 60px
}
.pc-cat-archive ul {
	flex-wrap: wrap;
	justify-content: flex-start
}
.pc-cat-archive li {
	-webkit-flex-basis: calc((100% - (var(--gap) * (var(--col) - 1))) / var(--col));
	-ms-flex-preferred-size: calc((100% - (var(--gap) * (var(--col) - 1))) / var(--col));
	flex-basis: calc((100% - (var(--gap) * (var(--col) - 1))) / var(--col));
}
.pc-cat-archive li a {
	justify-content: center;
	flex-direction: column;
	min-width: 150px;
	width: 100%;
	position: relative;
	z-index: 3;
	padding: 20px 10px
}
.pc-cat-archive .category-count {
	background: var(--pcbg-cl);
	color: var(--pcheading-cl);
	font-size: 14px;
	box-shadow: 1px 1px 3px rgba(0, 0, 0, .6)
}
.popularpost_list,
.widget .popularpost_list {
	padding-left: 0
}
.popularpost_item {
	display: block;
	position: relative;
	margin-bottom: 20px;
	padding-left: 60px
}
.popularpost_list.columns-format {
	display: flex;
	flex-wrap: wrap;
	margin-bottom: 0
}
.popularpost_list.columns-format .popularpost_item {
	flex: 0 0 auto;
	width: calc(100% / 3);
	padding-right: 15px
}
.popularpost_list.columns-format.col-2 .popularpost_item {
	width: 50%
}
.popularpost_list.columns-format.col-4 .popularpost_item {
	width: 25%
}
.popularpost_list.columns-format.col-5 .popularpost_item {
	width: 20%
}
@media only screen and (max-width:960px) {
	.popularpost_list.columns-format.t-col-1 .popularpost_item {
		width: 100%;
		padding-right: 0
	}
	.popularpost_list.columns-format .popularpost_item,
	.popularpost_list.columns-format.t-col-2 .popularpost_item {
		width: 50%
	}
	.popularpost_list.columns-format.t-col-3 .popularpost_item {
		width: calc(100% / 3)
	}
}
@media only screen and (max-width:479px) {
	.popularpost_list.columns-format .popularpost_item,
	.popularpost_list.columns-format.m-col-1 .popularpost_item {
		width: 100%;
		padding-right: 0
	}
	.popularpost_list.columns-format.m-col-2 .popularpost_item {
		width: 50%
	}
}
.widget ul.popularpost_list.columns-format>li.popularpost_item:last-child {
	border-bottom: 1px solid var(--pcborder-cl);
	margin-bottom: 11px;
	padding-bottom: 12px
}
.popularpost_item .pcpopular_new_post_title {
	font-size: 14px;
	margin: 0 0 5px
}
.popularpost_item .pcpopular_new_post_title a {
	color: var(--pcheading-cl);
	font-size: inherit
}
.popularpost_item .pcpopular_new_post_title a:hover {
	text-decoration: none;
	color: var(--pcaccent-cl)
}
.popularpost_item .pcpopular_new_post_title a:before {
	content: attr(data-num);
	position: absolute;
	font-size: 18px;
	text-align: center;
	top: 0;
	left: 0;
	width: 24px;
	height: 24px;
	line-height: 24px;
	font-style: italic;
	background: #e6e6e6;
	padding: 10px;
	border-radius: 100%;
	box-sizing: content-box;
	-webkit-transition: all .3s;
	-o-transition: all .3s;
	transition: all .3s;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei)
}
.popularpost_item:hover .pcpopular_new_post_title a:before {
	background: var(--pcaccent-cl);
	color: #fff
}
.popularpost_item.first {
	padding-left: 0;
	padding-bottom: 15px;
	border-bottom: 3px solid var(--pcborder-cl)
}
.popularpost_item.first .pcpopular_new_post_title a::before {
	transform: scale(1.15)
}
.popularpost_list.columns-format .popularpost_item.first .pcpopular_new_post_title a::before {
	transform: none
}
.popularpost_item.first .pcpopular_new_post_title {
	font-size: 18px;
	font-weight: 700;
	margin: 15px auto 15px;
	line-height: 1.25;
	position: relative
}
.popularpost_item.first .pcpopular_new_post_title,
.popularpost_item.first .popularpost_meta {
	padding-left: 60px
}
.popularpost_meta {
	font-size: 13px;
	color: var(--pcmeta-cl)
}
.widget ul li .popularpost_meta a {
	font-size: inherit
}
.post-related .swiper-slide,
.swiper-multi-items .swiper-slide {
	transition-timing-function: cubic-bezier(.76, .09, .215, 1)
}
.slider-41-wrapper {
	display: flex;
	flex-direction: column;
	min-height: 310px
}
.slider-41-wrapper ul {
	margin-bottom: 0 !important
}
.slider-41-swiper {
	position: relative;
	flex-grow: 1;
	padding: 0;
	display: flex;
	margin-top: -1px;
	overflow: hidden
}
.slider-41-wrapper+.section,
.slider-41-wrapper+.section-wrap {
	z-index: 4
}
.slider-41-wrapper .actueel-header {
	flex-grow: 1;
	padding: 0;
	display: flex
}
.slider-41-item {
	padding-top: 120px;
	padding-bottom: 160px;
	display: flex;
	align-items: center;
	position: relative;
	flex-grow: 1
}
.slider-41-wrapper .container {
	width: calc(var(--pcctain) - 120px)
}
.slider-41-item .thumbnail {
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: calc(100% + 5px);
	border-radius: 5px;
	background: #000
}
.slider-41-item .thumbnail .dark-overlay {
	background: rgba(0, 0, 0, .5)
}
.slider-41-item .row .flex-col:nth-child(1) {
	display: flex;
	flex-direction: column;
	gap: 2em
}
.slider-41-item .small-title {
	color: #fff
}
.slider-41-item h3 {
	overflow: hidden;
	text-overflow: ellipsis;
	display: -webkit-box;
	-webkit-box-orient: vertical;
	-webkit-line-clamp: 2;
	line-clamp: 2;
	min-height: calc(2em * 1.15);
	color: #fff;
	font-size: 28px;
	font-weight: bolder
}
.slider-41-item h3 a {
	color: inherit;
	font-weight: inherit
}
.slider-41-item .row .flex-col:nth-child(1) .tags {
	padding-top: .3em
}
.slider-41-item .tags .single-tag {
	color: #fff
}
.slider-41-item .tags .single-tag.light-medium {
	background: #fff
}
.slider-41-item .row .flex-col:nth-child(2) {
	display: flex;
	flex-direction: column;
	gap: 2.5em
}
.slider-41-item .author-box {
	background: rgba(0, 0, 0, .75);
	padding: 15px;
	border-radius: 15px;
	max-width: 190px
}
.slider-41-item .author-box h4 {
	color: #fff
}
.slider-41-swiper .swiper-pagination {
	position: absolute
}
.slider-41-swiper .fixed-items {
	position: absolute;
	top: 0;
	left: 0;
	height: 100%;
	width: 100%;
	padding-top: 120px;
	padding-bottom: 120px
}
.slider-41-swiper .fixed-items .container {
	display: flex;
	justify-content: flex-end;
	flex-direction: column;
	height: 100%;
	position: relative
}
.slider-41-swiper .fixed-items .flex-col:nth-child(2) {
	display: flex;
	justify-content: flex-end
}
.slider-41-swiper .fixed-items .btn {
	z-index: 1;
	transform: translateY(120px)
}
.slider-41-swiper .readmore {
	background: #000;
	color: #fff;
	border-radius: 50px;
	padding: 0 15px;
	line-height: 35px;
	font-size: 13px;
	display: inline-block
}
.slider-41-swiper .featured-cat a {
	color: #fff
}
@media screen and (max-width:1024px) {
	.slider-41-item .row .flex-col:nth-child(2) {
		display: none
	}
	.slider-41-item .row .flex-col:nth-child(1) {
		gap: 1.5em
	}
	.slider-41-item h1 {
		-webkit-line-clamp: 3;
		line-clamp: 3;
		min-height: calc(3em * 1.15)
	}
	.slider-41-wrapper {
		min-height: 550px
	}
	.slider-41-item {
		padding-top: 120px;
		padding-bottom: 180px
	}
}
.featured-style-41 .swiper-container {
	display: flex;
	flex-wrap: wrap;
	flex-direction: column;
	position: relative;
	flex-grow: 1;
	width: 100%
}
.featured-style-41 .swiper-wrapper {
	flex-grow: 1;
	position: relative;
	width: 100%;
	-webkit-transform-style: preserve-3d;
	transition-timing-function: cubic-bezier(.5, 0, .1, 1);
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0)
}
.featured-style-41 .swiper-slide {
	position: relative;
	-webkit-backface-visibility: hidden;
	-webkit-transform: translateZ(0)
}
.featured-style-41 .swiper-container .swiper-pagination {
	position: relative;
	width: 100%;
	display: flex;
	bottom: unset;
	left: unset;
	gap: .5em
}
.featured-style-41 .swiper-container .swiper-pagination-bullet {
	height: 1em;
	position: relative;
	border-radius: 0;
	margin: unset;
	width: 100%;
	background-color: transparent;
	display: flex;
	opacity: 1;
	flex-direction: column;
	justify-content: center
}
.featured-style-41 .swiper-container .swiper-pagination-bullet::before {
	content: "";
	width: 100%;
	height: 1px;
	background-color: rgba(255, 255, 255, .7);
	opacity: .4;
	position: absolute
}
.featured-style-41 .swiper-container .progress {
	height: 2px;
	position: absolute;
	width: 100%;
	background-color: rgba(255, 255, 255, 1);
	transform: scaleX(0);
	transform-origin: left top;
	opacity: 0;
	transition: opacity .3s ease-in-out
}
.featured-style-41 .swiper-container .swiper-pagination-bullet-active .progress {
	opacity: 1
}
.slider-41-item .overlay {
	position: absolute;
	top: 0;
	left: 0;
	height: 100%;
	width: 100%
}
.slider-41-item img.overlay,
.slider-41-item video.overlay {
	object-fit: cover
}
.slider-41-item .penci-fslider-fmeta .featured-slider-excerpt {
	margin-top: 30px
}
.slider-41-item .readmore-btn {
	padding-bottom: 60px
}
.featured-style-41 .row {
	display: flex;
	flex-wrap: wrap;
	position: relative
}
.featured-style-41 .row.split.split-30-70,
.featured-style-41 .row.split.split-70-30 {
	justify-content: space-between
}
.featured-style-41 .row.split.split-30-70 .flex-col:nth-child(2),
.featured-style-41 .row.split.split-70-30 .flex-col:nth-child(1) {
	width: calc(70% - (60px * .5))
}
.featured-style-41 .row.split.split-30-70 .flex-col:nth-child(1),
.featured-style-41 .row.split.split-70-30 .flex-col:nth-child(2) {
	width: calc(30% - (60px * .5))
}
@media only screen and (max-width:1024px) {
	.featured-style-41 .row.split.split-30-70 .flex-col:nth-child(1),
	.featured-style-41 .row.split.split-30-70 .flex-col:nth-child(2),
	.featured-style-41 .row.split.split-70-30 .flex-col:nth-child(1),
	.featured-style-41 .row.split.split-70-30 .flex-col:nth-child(2) {
		width: calc(100vw - 60px);
		padding-left: 30px;
		padding-right: 30px
	}
}
.slider-40-wrapper {
	text-align: center;
	background-size: cover;
	margin-bottom: 0;
	height: 840px;
	position: relative;
	overflow: hidden
}
.featured-style-40 .nav-slider {
	margin: 0;
	position: absolute;
	left: -60px;
	right: -60px;
	z-index: 1
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper {
		height: 720px
	}
}
@media (max-width:767px) {
	.slider-40-wrapper {
		height: 480px
	}
}
.slider-40-wrapper .container-bg-slider-40 {
	position: absolute;
	left: 0;
	top: 0;
	right: 0;
	bottom: 0;
	z-index: 5
}
.slider-40-wrapper .container-bg-slider-40 .item-bg-slider-40 {
	position: absolute;
	left: 0;
	top: 0;
	right: 0;
	bottom: 0;
	overflow: hidden
}
.slider-40-wrapper .container-bg-slider-40 .item-bg-slider-40:first-child {
	z-index: 4
}
.slider-40-wrapper .container-bg-slider-40 .item-bg-slider-40 .item-bg-slider-40-content {
	position: absolute;
	z-index: 2;
	left: 0;
	top: 0;
	right: 0;
	bottom: 0
}
.slider-40-wrapper .list-slider-creative {
	position: relative;
	width: 1000px;
	height: 565px
}
@media (max-width:1020px) {
	.slider-40-wrapper .list-slider-creative {
		width: 700px;
		height: 400px;
		margin-left: auto;
		margin-right: auto
	}
}
@media (max-width:767px) {
	.slider-40-wrapper .list-slider-creative {
		width: 100%;
		height: 300px
	}
}
.slider-40-wrapper .list-slider-creative .item-slider-creative {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 2;
	overflow: hidden
}
.slider-40-wrapper .list-slider-creative .item-slider-creative:first-child {
	z-index: 3
}
.slider-40-wrapper .list-slider-creative .item-slider-creative .img-container {
	background-size: cover;
	background-repeat: no-repeat;
	background-position: center center
}
.slider-40-wrapper .list-slider-creative .item-slider-creative .img-container:before {
	content: "";
	z-index: 1;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	margin: auto;
	background-color: rgba(0, 0, 0, .6);
	transition: opacity .3s ease-in-out
}
.slider-40-wrapper .list-slider-creative .item-slider-creative .content-item-creative {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0
}
.slider-40-wrapper .container-slider-40 {
	width: 1000px;
	margin: 80px auto 0;
	position: relative;
	z-index: 10
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper .container-slider-40 {
		width: 100%
	}
}
@media (max-width:767px) {
	.slider-40-wrapper .container-slider-40 {
		width: 100%
	}
}
.slider-40-wrapper .header-creative {
	position: relative
}
.slider-40-wrapper .see-all {
	position: absolute;
	right: 0;
	bottom: -2px
}
@media (max-width:767px) {
	.slider-40-wrapper .see-all.visible-xs {
		position: inherit;
		right: 0;
		bottom: 0;
		margin-top: 35px
	}
}
.slider-40-wrapper .see-all:hover {
	color: #44c8e6
}
.slider-40-wrapper .galery-slider-40 {
	position: relative
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper .galery-slider-40 {
		margin-top: 27px
	}
	.featured-style-40 .nav-slider {
		left: 30px;
		right: 30px
	}
}
@media (max-width:767px) {
	.slider-40-wrapper .galery-slider-40 .slider-creative {
		margin-bottom: 0;
		padding: 0 60px
	}
	.featured-style-40 .nav-slider {
		left: 10px;
		right: 10px
	}
}
.slider-40-wrapper .galery-slider-40 .slider-creative .nav-slider-slider-40 {
	top: 50%;
	transform: translateY(-50%)
}
.slider-40-wrapper .galery-slider-40 .slider-creative .nav-slider-slider-40 .nav-slider-button .icon-arrow-left {
	margin: 0
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper .galery-slider-40 .slider-creative .nav-slider-slider-40 {
		left: 10px;
		right: 10px
	}
}
@media (max-width:767px) {
	.slider-40-wrapper .galery-slider-40 .container-thumb-creative {
		overflow-y: scroll;
		position: relative;
		width: 100%;
		bottom: -25px;
		left: 0
	}
}
.slider-40-wrapper .nav-thumb-creative {
	width: 690px;
	padding: 10px 5px 0;
	background-color: #fff;
	margin: 0 auto;
	overflow: hidden;
	position: absolute;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 99
}
.slider-40-wrapper .nav-thumb-creative .swiper-slide {
	width: 25%
}
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .thumb-container {
	display: none
}
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .thumb-container:nth-child(1),
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .thumb-container:nth-child(2),
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .thumb-container:nth-child(3),
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .thumb-container:nth-child(4) {
	display: block
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper .nav-thumb-creative {
		padding: 10px;
		width: 100%
	}
}
@media (max-width:767px) {
	.slider-40-wrapper .nav-thumb-creative {
		left: 0;
		bottom: 0;
		position: inherit
	}
}
.slider-40-wrapper .nav-thumb-creative .thumb-container {
	position: relative;
	overflow: hidden;
	text-align: center;
	display: block
}
.slider-40-wrapper .nav-thumb-creative .thumb-container .penci-image-holder {
	width: 100%;
	height: auto;
	position: relative;
	z-index: 3;
	-webkit-transition: transform .3s ease-in-out;
	-o-transition: transform .3s ease-in-out;
	transition: transform .3s ease-in-out;
	display: inline-block;
	vertical-align: middle
}
.slider-40-wrapper .penci-image-holder:before {
	padding-top: 66.6667% !important
}
.slider-40-wrapper .nav-thumb-creative .thumb-container:after {
	content: "";
	opacity: 0;
	visibility: hidden;
	width: 100%;
	height: 100%;
	background-color: var(--pcaccent-cl);
	position: absolute;
	left: 0;
	top: 0;
	-webkit-transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	-o-transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	z-index: 5
}
.slider-40-wrapper .nav-thumb-creative .thumb-container:hover:after {
	visibility: visible;
	opacity: .5
}
@media (max-width:1020px) and (min-width:767px) {
	.slider-40-wrapper .nav-thumb-creative .thumb-container+.thumb-container {
		margin-left: 9px
	}
}
.slider-40-wrapper .nav-thumb-creative .swiper-slide.active .penci-image-holder {
	-webkit-transform: scale(.95, .93);
	-ms-transform: scale(.95, .93);
	-o-transform: scale(.95, .93);
	transform: scale(.95, .93)
}
.slider-40-wrapper .nav-thumb-creative .swiper-slide.active .thumb-container:after,
.slider-40-wrapper .nav-thumb-creative .swiper-slide.active:hover .thumb-container:after {
	opacity: 1;
	visibility: visible;
	z-index: 0
}
.slider-40-wrapper .nav-thumb-creative .thumb-container:hover .thumb-container:after {
	z-index: 4;
	-webkit-transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	-o-transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	transition: opacity .3s ease-in-out, visibility .3s ease-in-out;
	opacity: .6;
	visibility: visible
}
.slider-40-wrapper .bg-img-slider-40-background,
.slider-40-wrapper .bg-img-slider-40-behind {
	overflow: hidden;
	height: 100%;
	width: 100%;
	position: absolute;
	left: 0;
	right: 0;
	background-size: cover;
	background-position: center
}
.slider-40-wrapper .nav-slider-button {
	height: 34px;
	width: 34px;
	border-radius: 50%;
	float: left;
	text-align: center;
	transition: all .3s ease-in-out;
	line-height: 34px;
	padding: 0;
	background: #fff;
	color: #010101;
	opacity: .8
}
.slider-40-wrapper .nav-slider-button:hover {
	opacity: 1
}
.slider-40-wrapper .nav-slider-button i {
	font-size: 12px;
	color: inherit;
	line-height: inherit
}
.slider-40-wrapper .next-button {
	right: 0;
	float: right
}
.slider-40-wrapper .nav-thumb-creative .swiper-slide-inner {
	padding-left: 5px;
	padding-right: 5px
}
.slider-40-wrapper .nav-thumb-creative:not(.penci-owl-loaded) .swiper-slide:nth-child(4) {
	margin-right: 0
}
.penci-43-slider-item {
	width: 100%;
	background-size: cover;
	display: flex;
	flex-wrap: wrap;
	align-content: center;
	position: relative;
	z-index: 5;
	overflow: hidden
}
@media (max-width:1020px) and (min-width:767px) {
	.penci-43-slider-item {
		height: 400px
	}
}
.penci-43-slider-item .img-container {
	width: 100%;
	position: absolute;
	height: 100%;
	left: 0;
	top: 0;
	overflow: hidden
}
.penci-43-slider-item .img-container .img-responsive {
	margin: 0 auto
}
.penci-43-slider-item .img-container:before {
	content: "";
	z-index: 1;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	margin: auto;
	background-color: rgba(0, 0, 0, .15)
}
.penci-43-slider-item .img-container img {
	-webkit-transition: transform 2s ease-in-out;
	-o-transition: transform 2s ease-in-out;
	transition: transform 2s ease-in-out
}
.penci-43-slider-item>div {
	width: 700px;
	margin: 0 auto;
	position: relative;
	z-index: 4
}
.penci-43-slider-item div .featured-cat a {
	color: #fff
}
.penci-43-slider-item .featured-slider-excerpt {
	margin-top: 15px
}
.penci-43-slider-item .featured-slider-excerpt p {
	margin-bottom: 0
}
@media (max-width:1020px) and (min-width:767px) {
	.penci-43-slider-item div {
		width: 550px
	}
}
@media (max-width:767px) {
	.penci-43-slider-item>div:last-child {
		width: 100%;
		padding: 10px
	}
	.penci-43-slider-item div .number-tv {
		display: block;
		margin-bottom: 14px
	}
}
@media (max-width:767px) and (max-width:767px) {
	.penci-43-slider-item div .number-tv {
		margin-bottom: 3px
	}
}
.penci-43-slider-item .title-part {
	font-size: 42px;
	margin: 0;
	font-weight: var(--pchead-wei);
	line-height: 1.2;
	color: #fff
}
.penci-43-slider-item .penci-fslider-fmeta {
	margin-top: 6px
}
.penci-43-slider-item .title-part a {
	color: inherit;
	font-size: inherit
}
.penci-43-slider-item .title-part a:hover {
	text-decoration: none
}
@media only screen and (max-width:1170px) {
	.penci-43-slider-item .title-part {
		font-size: 36px
	}
}
@media only screen and (max-width:960px) {
	.penci-43-slider-item .title-part {
		font-size: 30px
	}
	.penci-43-slider-item .featured-slider-excerpt {
		display: none
	}
}
@media only screen and (max-width:767px) {
	.penci-43-slider-item .title-part {
		font-size: 24px
	}
}
@media only screen and (max-width:479px) {
	.penci-43-slider-item .title-part {
		font-size: 20px
	}
}
.featured-area.featured-style-39 .penci-slider38-overlay {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background: rgba(0, 0, 0, .5);
	z-index: 3
}
.featured-area.featured-style-39 .penci-image-holder {
	max-height: 450px
}
.featured-area.featured-style-39 .penci-featured-content .feat-text {
	max-width: calc(100% - 390px);
	margin: 0;
	text-align: center
}
@media only screen and (max-width:767px) {
	.featured-area.featured-style-39 .penci-featured-content .feat-text {
		max-width: 100%
	}
}
.featured-area.featured-style-39 .penci-featured-content {
	z-index: 4
}
.featured-area.featured-style-39 .penci-slider39-thumb {
	position: absolute;
	bottom: 0;
	top: 40px;
	right: 0;
	z-index: 99;
	padding: 30px;
	width: 370px;
	height: 100%;
	background-color: rgba(0, 0, 0, .7);
	overflow: hidden
}
@media only screen and (max-width:1170px) {
	.featured-area.featured-style-39 .penci-featured-content .feat-text {
		max-width: calc(100% - 320px)
	}
	.featured-area.featured-style-39 .penci-slider39-thumb {
		width: 320px
	}
}
@media only screen and (max-width:767px) {
	.featured-area.featured-style-39 .penci-slider39-thumb {
		display: none
	}
}
.featured-area.featured-style-39 .penci-slider39-thumb .owl-thumb-item h3 {
	font-size: 16px;
	color: #fff;
	margin: 0;
	line-height: 1.3;
	margin-left: 90px;
	opacity: .75
}
.featured-area.featured-style-39 .penci-slider39-thumb .owl-thumb-item {
	cursor: pointer
}
.featured-area.featured-style-39 .penci-slider39-thumb .swiper-slide-thumb-active.owl-thumb-item h3 {
	opacity: 1
}
.featured-area.featured-style-39 .featured-slider-excerpt,
.featured-area.featured-style-39 .featured-slider-excerpt p {
	text-align: center
}
.featured-area.featured-style-39 .penci-slider39-thumb .owl-thumb-item .penci-image-holder {
	width: 70px;
	height: 70px;
	border: 1px solid rgba(255, 255, 255, .5);
	float: left
}
.featured-area.featured-style-39 .penci-slider39-thumb .active .owl-thumb-item .penci-image-holder {
	border-color: var(--pcaccent-cl)
}
.penci-owl-carousel-slider[data-direction=vertical]:not(.penci-owl-loaded)>div:first-child {
	display: flex;
	flex-direction: column
}
.penci-owl-carousel-slider[data-direction=vertical]:not(.penci-owl-loaded) .swiper-slide {
	flex-shrink: 0;
	width: 100% !important;
	height: auto;
	margin-bottom: 30px;
	position: relative;
	transition-property: transform;
	float: none !important
}
.swiper-mark-item {
	overflow: hidden;
	transition: all .4s ease
}
.penci-swiper-mask {
	position: relative;
	z-index: 1
}
.featured-style-45 .swiper-slide {
	overflow: hidden;
	color: #fff;
	min-height: 550px;
	transition: all .4s ease
}
.featured-style-45 .slide-inner {
	width: 100%;
	height: 100%;
	position: absolute;
	left: 0;
	top: 0;
	z-index: 1;
	background-size: cover;
	background-position: center;
	display: flex;
	justify-content: center;
	align-items: center;
	text-align: left
}
.featured-style-45 .penci-featured-content {
	top: 60px;
	left: 60px;
	bottom: 60px;
	transform: unset;
	max-width: 420px;
	display: flex;
	align-items: center;
}
.featured-style-45 .penci-featured-content .feat-text {
	max-width: 100%;
	text-align: left;
	padding: 60px;
	border-radius: 5px;
	overflow: hidden;
}
.featured-style-45 .penci-featured-content .featured-slider-overlay {
	background: rgba(255, 255, 255, 0.15);
	backdrop-filter: blur(2px) saturate(180%);
	border: 1px solid rgba(255, 255, 255, 0.8);
	border-radius: 5px;
	box-shadow: 0 8px 32px rgba(31, 38, 135, 0.2), 
				inset 0 4px 20px rgba(255, 255, 255, 0.3);
}
.featured-style-45 .swiper-slide .penci-image-holder:before {
	padding-top: 45%;
}
.swiper-button-disabled {
	cursor: not-allowed !important;
	opacity: .5 !important
}
.post-image.stick-video-enable {
	position: fixed;
	max-width: var(--pcajs_fvw);
	width: 100%;
	height: auto;
	z-index: 99999;
	margin: 0;
	overflow: visible
}
@media only screen and (max-width:767px) {
	.post-image.stick-video-enable {
		max-width: var(--pcajs_fvmw)
	}
}
.post-image.stick-video-enable.top-right {
	top: 40px;
	right: 40px
}
.post-image.stick-video-enable.bottom-right {
	bottom: 40px;
	right: 40px
}
.post-image.stick-video-enable.top-left {
	top: 40px;
	left: 40px
}
.post-image.stick-video-enable.bottom-left {
	bottom: 40px;
	left: 40px
}
.post-image.stick-video-enable .standard-post-special_wrapper {
	display: none
}
.swiper-button-lock {
	display: none !important
}
.swiper-fade .item {
	opacity: 0;
	visibility: hidden
}
.swiper-fade .item.swiper-slide-visible {
	opacity: 1;
	visibility: visible
}
.stick-video-enable-remove {
	width: 30px;
	height: 30px;
	border-radius: 50%;
	background: #000;
	color: #fff;
	line-height: 30px;
	text-align: center;
	font-size: 12px;
	position: absolute;
	top: -5px;
	right: -5px;
	z-index: 99999;
	cursor: pointer;
	transition: all .3s ease-in-out
}
.stick-video-enable-remove:hover {
	background: var(--pcaccent-cl);
	color: #fff
}
.stick-video-enable-remove i {
	line-height: inherit !important
}
.swiper-cards .swiper-slide {
	opacity: .5
}
.swiper-cards .swiper-slide.active {
	opacity: 1
}
.featured-style-28 .swiper-slide {
	width: fit-content !important
}
.penci-sponsored-label {
	display: inline-block;
	padding: 1px 5px;
	background-color: var(--pcaccent-cl);
	color: var(--pcbg-cl) !important;
	margin: 0 5px 0 0 !important
}
.penci-sponsored-label:before {
	content: attr(data-text)
}
.penci-sponsored-logo img {
	display: inline-block;
	max-height: 20px;
	width: auto;
	vertical-align: middle;
	margin-left: 5px
}
.penci-csublist.cat {
	margin-top: 10px
}
.penci-csublist.cat>a.penci-cat-name {
	font-size: 16px
}
.penci-mtp-filters-wrapper {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	--spacing: 30px;
	--sidebar: 25%;
	--listspc: 0
}
.penci-mtp-filters-terms {
	width: var(--sidebar);
	padding-right: var(--spacing)
}
.penci-mtp-filters-posts {
	width: calc(100% - var(--sidebar));
	border-left: 1px solid var(--pcborder-cl);
	padding-left: var(--spacing)
}
.penci-mtp-filters-wrapper.pctp-right {
	flex-direction: row-reverse
}
.penci-mtp-filters-wrapper.pctp-right .penci-mtp-filters-terms {
	padding-right: 0;
	padding-left: var(--spacing)
}
.penci-mtp-filters-wrapper.pctp-right .penci-mtp-filters-posts {
	border-right: 1px solid var(--pcborder-cl);
	padding-right: var(--spacing);
	border-left: 0;
	padding-left: 0
}
.penci-mtp-filters-wrapper.pctp-top {
	flex-direction: column
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-posts,
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms {
	width: 100%;
	border: 0;
	padding: 0
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-posts {
	border-top: 1px solid var(--pcborder-cl);
	padding-top: var(--spacing);
	margin-top: var(--spacing)
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms {
	display: flex;
	flex: 1;
	overflow: auto
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms ul {
	display: flex;
	flex-shrink: 0
}
.penci-mtp-filters-terms ul {
	background: #f5f5f5
}
.penci-mtp-filters-terms ul,
.penci-mtp-filters-terms ul li {
	list-style: none;
	margin: 0;
	padding: 0
}
.penci-mtp-filters-terms ul li:not(:last-child) {
	list-style: none
}
.penci-mtp-filters-terms ul li a:hover {
	text-decoration: none
}
.penci-mtp-filters-posts.layout-list .pcsl-inner .pcsl-item:not(:last-child) {
	padding-bottom: var(--pcsl-bgap);
	border-bottom: 1px solid var(--pcborder-cl)
}
.penci-mtp-filters-terms ul li:not(:last-child) {
	margin-bottom: var(--listspc)
}
.penci-mtp-filters-terms ul li a {
	padding: 0 20px 0 40px;
	position: relative;
	background: 0 0;
	display: flex;
	justify-content: space-between;
	line-height: 45px;
	color: var(--pcheading-cl);
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	font-size: 16px
}
.penci-mtp-filters-terms ul li a.added,
.penci-mtp-filters-wrapper[data-filter-terms=""] ul li a[data-id=all] {
	background: var(--pcaccent-cl);
	color: #fff
}
.penci-mtp-filters-terms ul li a.added:before,
.penci-mtp-filters-wrapper[data-filter-terms=""] ul li a[data-id=all]:before {
	content: "\f111";
	font-family: penciicon;
	font-size: 14px;
	font-display: swap;
	display: inline-block;
	font-style: normal;
	font-weight: 400 !important;
	font-variant: normal;
	text-transform: none;
	line-height: inherit;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	position: absolute;
	left: 14px;
	top: 0;
	bottom: 0
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms ul li:not(:last-child) {
	margin-right: var(--listspc);
	margin-bottom: 0
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms .count {
	margin-left: 10px
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms .count:before {
	content: '('
}
.penci-mtp-filters-wrapper.pctp-top .penci-mtp-filters-terms .count:after {
	content: ')'
}
.penci-mtp-filters-wrapper .penci-pagination {
	margin-top: 30px;
	margin-bottom: 0
}
.penci-mtp-filters-wrapper .pcsl-inner .pcsl-iteminer {
	position: relative
}
.penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt,
.post-entry .penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt {
	position: absolute;
	top: 0;
	right: 0;
	margin: 0;
	padding: 0;
	font-size: 14px;
	line-height: 1.4;
	color: var(--pcheading-cl)
}
.penci-mtp-filters-wrapper .pcsl-inner.pcmtp-ct-middle .grid-post-box-meta.pcmtf-mt-alt,
.post-entry .penci-mtp-filters-wrapper .pcsl-inner.pcmtp-ct-middle .grid-post-box-meta.pcmtf-mt-alt {
	top: 50%;
	bottom: 50%;
	transform: translateY(-50%)
}
.penci-mtp-filters-wrapper .pcsl-inner.pcmtp-ct-bottom .grid-post-box-meta.pcmtf-mt-alt,
.post-entry .penci-mtp-filters-wrapper .pcsl-inner.pcmtp-ct-bottom .grid-post-box-meta.pcmtf-mt-alt {
	top: auto;
	bottom: 0
}
.penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt span,
.post-entry .penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt span {
	color: inherit
}
.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .pcsl-iteminer {
	padding-right: 120px
}
.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner.no-date .pcsl-iteminer {
	padding-right: 0
}
.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .grid-post-box-meta.pcsl-meta:not(.pcmtf-mt-alt) .sl-date {
	display: none;
}
.penci-mtp-filters-close,
.penci-mtp-filters-mobile {
	display: none
}
.pencif-contact-form-wrapper {
	width: 100%;
}
.pencif-contact-form-wrapper .pencif-button-full-width {
	width: 100%;
}
.pencif-contact-form .elementor-field-type-submit .penci-button {
	width: auto;
}
.pencif-contact-form .grecaptcha-badge {
	z-index: 999;
}
.pencif-field-group {
	margin-bottom: 15px;
}
.pencif-contact-form .pencif-field-group.pencif-margin-remove-bottom {
	line-height: 1;
}
.pencif-contact-form .pencif-field-group .pencif-checkbox {
	margin-right: 3px;
}
.pencif-contact-form .elementor-field-type-submit {
	margin-bottom: 0 !important;
}
.pencif-register-additional-message {
	font-size: 12px;
	color: #999;
}
form.pencif-2col {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between;
	column-gap: 30px;
}
form.pencif-2col .pencif-col {
	flex: 1 1 auto;
}
form.pencif-name-inline  {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between;
}
form.pencif-name-inline .pencif-field-group {
	width: 100%;
}
form.pencif-name-inline .pencif-field-normal {
	width: 49%;
}
.pencif-field-group > label {
	display: block;
}
.pencif-text-notice {
	padding-left: 15px;
	margin-bottom: 15px;
	line-height: 40px;
	font-size: 14px;
	text-align: center;
	font-weight: 500;
	width: 100%;
}
.pencif-text-warning {
	background: red;
	color: #fff
}
.pencif-text-warning {
	background: yellow;
	color: #fff
}
.pencif-text-success {
	background: #dcffb4;
	color: #595959
}
.pencif-contact-form.loading .pencif-button:before {
    content: "\f110";
    font-family: "penciicon";
}
.pencif-contact-form.loading .pencif-button {
    position: relative;
}
.pencif-contact-form.loading .pencif-button:before {
    opacity: 1;
    transition: opacity .2s ease;
    content: "";
    display: inline-block;
    border: 1px solid #bbb;
    border-left-color: #fff;
    border-top-color: #fff;
    border-radius: 50%;
    vertical-align: middle;
    position: absolute;
    top: 50%;
    left: 50%;
    margin-top: -12px;
    margin-left: -12px;
    width: 24px;
    height: 24px;
    z-index: 9;
    animation: penci-menu-rotate .35s infinite linear
}
.pencif-contact-form.loading .pencif-button {
    color: transparent !important;
}
.pencif-contact-form.loading input,
.pencif-contact-form.loading textarea {
	pointer-events: none;
	opacity: 0.5;
}
@media screen and (max-width: 1169px) {
	.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .pcsl-iteminer {
		padding-right: 0;
	}
	.penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt,
	.post-entry .penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt {
		display: none;
	}
	.penci-mtp-filters-posts .pcsl-col-1.pcsl-inner .grid-post-box-meta.pcsl-meta:not(.pcmtf-mt-alt) .sl-date {
		display: inline-block;
	}
}  
@media only screen and (max-width:767px) {
	.penci-mtp-filters-posts .theiaStickySidebar,
	.penci-mtp-filters-terms .theiaStickySidebar {
		position: static !important
	}
	.penci-mtp-filters-mobile.active {
		display: none
	}
	.penci-mtp-filters-main.active {
		display: block;
		margin-bottom: 30px
	}
	.penci-mtp-filters-wrapper {
		flex-direction: column
	}
	.penci-mtp-filters-main {
		display: none
	}
	.penci-mtp-filters-wrapper .penci-mtp-filters-posts,
	.penci-mtp-filters-wrapper .penci-mtp-filters-terms {
		width: 100%;
		border: 0;
		padding: 0
	}
	.penci-mtp-filters-close.active,
	.penci-mtp-filters-mobile {
		display: block;
		padding: 10px 40px;
		border: 1px solid var(--pcborder-cl);
		margin-bottom: 30px;
		position: relative
	}
	.penci-mtp-filters-close.active:after,
	.penci-mtp-filters-mobile:after {
		content: "\f11c";
		position: absolute;
		right: 20px;
		top: 50%;
		transform: translateY(-50%);
		font-family: penciicon
	}
	.penci-mtp-filters-close.active {
		border-bottom: 0;
		margin-bottom: 0
	}
	.penci-mtp-filters-close.active:after {
		content: "\f110"
	}
	.penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt span,
	.post-entry .penci-mtp-filters-wrapper .pcsl-inner .grid-post-box-meta.pcmtf-mt-alt span {
		font-size: 12px
	}
	.list-post-3 .content-list-right,
	.penci-grid li.list-post-3 .item > .thumbnail {
		width: 100%;
	}
	.list-post-3 .content-list-right {
		margin: -20px 10px 0;
	}
	.penci-post-share-box-btn {
		bottom: 30px;
	}
	form.pencif-2col .pencif-col {
		max-width: 100%;
	}
	form.pencif-2col .pencif-col .pencif-field-group {
		margin-bottom: 15px;
	}
	.pcrlt-style-5 .penci-related-grid-display .related-content::before {
		left: 0;
		right: 0;
	}
}
.pcstyle-style-1 .container-single .post-entry .post-tags a {
	align-items:center;
	background-color:transparent;
	border:1px solid var(--pcborder-cl);
	border-radius:10px;
	color: var(--pcheading-cl);
	font-size: 13px;
	justify-content:center;
	line-height:25px;
	padding:0 15px;
	position:relative;
	transition:.2s ease-in-out;
	z-index:2;
}
.pcstyle-style-1 .container-single .post-entry .post-tags a:before {
	background-color:var(--pcaccent-cl);
	border-radius:100%;
	display: inline-block;
	height:9px;
	margin-right:5px;
	content: '';
	width:9px;
	vertical-align: middle;
}
.pcstyle-style-2 .container-single .post-entry .post-tags a {
	border: 0;
	padding-left: 0;
	padding-right: 0;
	font-weight: bold;
	font-size: 14px !important;
}
.pcstyle-style-2 .container-single .post-entry .post-tags a:hover {
	background: transparent;
	color: var(--pcaccent-cl);
}
.pcstyle-style-2 .container-single .post-entry .post-tags a:before {
	margin-right:2px;
	content: '#';
	opacity: 0.5;
}
.pcstyle-style-3 .container-single .post-entry .post-tags a {
	text-transform: none;
	border-radius: 4px;
	border: 0;
	background: #f1f1f1;
	font-size: 14px !important;
	color: var(--pcheading-cl);
}
.pcstyle-style-3 .container-single .post-entry .post-tags a:hover {
	background: var(--pcaccent-cl);
	color: #fff;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a {
	text-transform: none;
	border-radius: 3px;
	line-height: 20px;
	padding: 6px 15px 6px 12px;
	border: 0;
	background: #f1f1f1;
	font-size: 14px !important;
	color: var(--pcheading-cl);
	position: relative;
	overflow: hidden;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a:before {
	background: var(--pctext-cl);
	border-radius: 10px;
	content: '';
	height: 6px;
	left: 10px;
	width: 6px;
	display: inline-block;
	margin-right: 5px;
	opacity: 0.5;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a:after {
	background: var(--pcbg-cl);
	border-bottom: 16px solid transparent;
	border-left: 10px solid #f1f1f1;
	border-top: 17px solid transparent;
	content: '';
	position: absolute;
	right: 0;
	top: 0;
	transition: all .3s;
	-webkit-transition: all .3s;
	-moz-transition: all .3s;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a:hover {
	background: var(--pcaccent-cl);
	color: #fff;
}
.pcstyle-style-4 .container-single .post-entry .post-tags a:hover:after {
	border-left-color: var(--pcaccent-cl);
}
.pcstyle-style-5 .container-single .post-entry .post-tags a {
	background-color: var(--pcaccent-cl);
	-webkit-border-radius: 4px 3px 3px 4px;
	-moz-border-radius: 4px 3px 3px 4px;
	border-radius: 4px 3px 3px 4px;
	position: relative;
	color: #fff;
	zoom: 1;
	line-height: 22px;
	padding: 0 8px 0 10px;
	margin: 4px 4px 4px 8px;
	border:0;
}
.pcstyle-style-5 .container-single .post-entry .post-tags a:before {
	content: "";
	position: absolute;
	left: -5px;
	top: 1px;
	width: 0;
	height: 0;
	border-top: 10px solid transparent;
	border-right: 6px solid var(--pcaccent-cl);
	border-bottom: 10px solid transparent;
}
.post-tags.penci-post-sources {
	margin-top: 5px;
}
.penciwp-notice-form {
    position: fixed;
    z-index: 999;
    top: 0;
    bottom: 0;
    right: 0;
    left: 0;
    display: flex;
    align-content: center;
    justify-content: center;
    align-items: center;
    flex-wrap: wrap;
    background: rgba(55,55,55,0.8);
}
.penciwp-notice-form .penciwp-notice-form-inner {
    max-width: 450px;
    position: relative;
    padding: 30px;
    margin: 30px;
    width: 100%;
    text-align: center;
    background: #fff;
    display: flex;
    align-content: center;
    justify-content: center;
    align-items: center;
    flex-wrap: wrap;
    box-shadow: 2px 2px 2px rgba(55,55,555,0.2);
}
.pcwp-close-btn {
    display: block;
    width: 30px;
    height: 30px;
    position: absolute;
    background: var(--pcaccent-cl);
    top: -15px;
    right: -15px;
    color: #fff;
    line-height: 30px;
    font-size: 10px;
    border-radius: 50%;
    transition: 0.3s all ease-in-out;
}
.pcwp-close-btn:hover {
    opacity: 0.8;
}
.pcwp-close-btn:before {
    content: "\f110";
    font-family: "penciicon";
}
.mc4wp-form.loading .msubmit {
    position: relative;
}
.mc4wp-form.loading .msubmit:before {
    opacity: 1;
    transition: opacity .2s ease;
    content: "";
    display: inline-block;
    border: 1px solid #bbb;
    border-left-color: #fff;
    border-top-color: #fff;
    border-radius: 50%;
    vertical-align: middle;
    position: absolute;
    top: 50%;
    left: 50%;
    margin-top: -12px;
    margin-left: -12px;
    width: 24px;
    height: 24px;
    z-index: 9;
    animation: penci-menu-rotate .35s infinite linear
}
.mc4wp-form.loading .msubmit input {
    color: transparent !important;
}
.penci-sg-cth:not(.show-full) {
	position: relative;
}
.penci-sg-cth:not(.show-full):after {
	content: '';
	background: var(--pcbg-cl);
	background: linear-gradient(0deg, var(--pcbg-cl) 0%, transparent 100%);
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	height: 120px;
	z-index: 1;
	display: block;
}
.penci-sg-cth .penci-btn-more-content {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	text-align: center;
}
.container-single .penci-sg-cth .penci-btn-more-content a,
.post-entry .penci-sg-cth .penci-btn-more-content a {
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	position: relative;
	z-index: 3;
	color: var(--pcbg-cl);
	background: var(--pcaccent-cl);
	display: inline-block;
	padding: 0 20px;
	line-height: 35px;
}
.container-single .penci-sg-cth .penci-btn-more-content a:hover,
.post-entry .penci-sg-cth .penci-btn-more-content a:hover {
	opacity: 0.8;
	text-decoration: none;
}
@-webkit-keyframes fadeInZoom {
	from {
		opacity: 0;
		-webkit-transform: scale(1.3);
		transform: scale(1.3)
	}
	to {
		opacity: 1;
		-webkit-transform: none;
		transform: none
	}
}
@keyframes fadeInZoom {
	from {
		opacity: 0;
		-webkit-transform: scale(1.1);
		transform: scale(1.1);
		-webkit-filter: blur(5px);
		filter: blur(5px);
	}
	to {
		opacity: 1;
		-webkit-transform: scale(1);
		transform: scale(1);
		-webkit-filter: blur(0);
		filter: blur(0);
	}
}
.pclz-effs .penci-lazy,
.pclz-effs .thumbnail,
.pclz-effs .standard-post-image {
	overflow: hidden;
}
.pclz-style-1 .penci-lazy.pcloaded,
.pclz-style-1 .thumbnail .pcloaded,
.pclz-style-1 .standard-post-image .pcloaded {
	opacity: 1;
	animation: fadeIn 0.3s ease-in;
}
.pclz-style-2 .penci-lazy.pcloaded,
.pclz-style-2 .thumbnail .pcloaded,
.pclz-style-2 .standard-post-image .pcloaded {
	opacity: 1;
	animation: fadeInZoom 0.3s ease-in;
}
.pclz-style-3 .penci-lazy,
.pclz-style-3 .thumbnail .penci-lazy,
.pclz-style-3 .standard-post-image .penci-lazy {
	-webkit-filter: blur(30px);
	filter: blur(30px);
	transition: filter 400ms, -webkit-filter 400ms;
}
.pclz-style-3 .penci-lazy.pcloaded,
.pclz-style-3 .thumbnail .pcloaded,
.pclz-style-3 .standard-post-image .pcloaded {
	-webkit-filter: blur(0);
	filter: blur(0);
}
.pclz-effs .swiper-slide .penci-lazy {
	overflow: initial;
}
.pclz-style-1 .swiper-slide .penci-lazy:not(.lazyloaded),
.pclz-style-2 .swiper-slide .penci-lazy:not(.lazyloaded),
.pclz-style-3 .swiper-slide .penci-lazy:not(.lazyloaded) {
	animation: pencipreload .6s infinite linear forwards;
}
.pclz-style-3 .swiper-slide .penci-lazy:not(.pcloaded) {
	-webkit-filter: unset;
	filter: unset;
}
.pclz-style-1 .swiper-slide .penci-lazy.pcloaded,
.pclz-style-2 .swiper-slide .penci-lazy.pcloaded,
.pclz-style-3 .swiper-slide .penci-lazy.pcloaded {
	animation: unset;
	-webkit-filter: unset;
	filter: unset;
}
body.loading-posts #main .pcft-elers-wrapper,
body.loading-posts #main .theiaStickySidebar > ul,
body.loading-posts #main .theiaStickySidebar .post,
body.loading-posts #main .theiaStickySidebar section,
body.loading-posts #main .theiaStickySidebar > div:not(.archive-box) {
	opacity: 0.7;
}
body.loading-posts #main .pcft-elers-wrapper,
body.loading-posts #main .archive-box,
body.home.loading-posts #main .penci-wrapper-data {
	position: relative
}
body.loading-posts .pcft-elers-wrapper .penci-loader-effect,
body.loading-posts #main .penci-loader-effect {
	display: block;
	top: 200px;
	opacity: 1 !important;
	transform: translateX(-25px);
}
body.loading-posts .pcft-elers-wrapper .penci-loader-effect,
body.loading-posts #main .pcft-elers-wrapper .penci-loader-effect {
	transform: unset;
}
body.home.loading-posts #main .theiaStickySidebar > .penci-wrapper-posts-content {
	opacity: 1;
}
body.home.loading-posts #main .penci-wrapper-data > * {
	opacity: 0.7;
}
.penci-advanced-map {
	height: 100%;
	--mheight: 360px;
	--search-height: 80px;
}
.penci-advanced-map .penci-grid-wrap {
	display: block
}
.penci-advanced-map .penci-advanced-map-wrapper {
	width: 100%
}
.penci-advanced-map .penci-gmap-lists-wrapper {
	width: 100%
}
.penci-advanced-map .penci-gmap-lists {
	margin: 0;
	padding: 0;
	list-style: none;
	height: 300px;
	overflow: auto
}
.penci-gmap-lists-wrapper {
	background: var(--pcbg-cl)
}
.penci-gmap-lists-wrapper .penci-gmap-search-wrapper {
	margin-bottom: 0;
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-gmap-lists-wrapper .penci-gmap-search-wrapper .penci-search-default {
	padding: 0 20px;
	display: flex;
	align-items: center;
	height: var(--search-height);
	width: 100%
}
.penci-gmap-lists-wrapper .penci-gmap-search-wrapper .penci-search-default .search-box {
	width: 100%
}
.penci-advanced-map .penci-gmap-list-item {
	display: flex;
	align-items: center;
	border-bottom: 1px solid var(--pcborder-cl);
	padding: 16px 20px;
	cursor: pointer;
}
.penci-advanced-map .penci-gmap-list-item:nth-last-child(1) {
	border-bottom: 0
}
.penci-advanced-map .penci-gmap-list-item:nth-last-child(1) {
	margin-bottom: 0
}
.penci-advanced-map .scroll-content {
	display: flex;
	height: 100%;
	flex-direction: column
}
.penci-advanced-map .penci-title {
	font-size: 16px;
	color: var(--pcheading-cl);
	margin-bottom: 10px;
}
.penci-advanced-map .penci-phone,
.penci-advanced-map .penci-web,
.penci-advanced-map .penci-place {
	font-size: 12px;
	line-height: 1.6;
	color: var(--pcmeta-cl);
	display: block;
}
.penci-advanced-map .penci-phone {
	margin-top: 5px;
}
.penci-advanced-map .form-control {
	height: 40px;
	width: 100%;
	text-transform: capitalize;
	padding: 0 13px;
	border: 1px solid var(--pcborder-cl);
	font-size: 12px;
	outline: none;
	border-radius: 5px
}
.penci-advanced-map .form-control:focus {
	border: 1px solid #bdbbbb
}
.penci-advanced-map.penci-direction-left .penci-gmap-lists {
	overflow-y: auto;
	direction: rtl
}
.penci-advanced-map.penci-direction-left .penci-gmap-lists .penci-gmap-list-item {
	direction: ltr
}
.penci-advanced-map .penci-gmap-lists::-webkit-scrollbar {
	width: 5px
}
.penci-advanced-map .penci-gmap-lists::-webkit-scrollbar-track {
	background: #f1f1f1
}
.penci-advanced-map .penci-gmap-lists::-webkit-scrollbar-thumb {
	background: #c8c8c8
}
.penci-advanced-map .penci-gmap-lists::-webkit-scrollbar-thumb:hover {
	background: #afaeae
}
.penci_admap_item {
	display: none;
}
.penci_admap_item.active {
	display: block;
}
.penci_admap_item iframe {
	height: 100%;
	min-height: var(--mheight);
}
@media (min-width:768px) {
	.penci-advanced-map {
		height: var(--mheight);
		margin-bottom: 0
	}
	.penci-advanced-map.penci-direction-left .penci-grid-wrap {
		flex-direction: row-reverse
	}
	.penci-advanced-map .penci-grid-wrap {
		display: flex
	}
	.penci-advanced-map .penci-gmap-lists-wrapper {
		width: 50%;
		max-width: 350px;
		border: 1px solid var(--pcborder-cl);
		height: calc(100% - 2px);
	}
	.penci-advanced-map.penci-has-lists-search-yes .penci-gmap-lists {
		height: calc(var(--mheight) - var(--search-height))
	}
	.penci-advanced-map .penci-gmap-lists {
		height: var(--mheight)
	}
}
.widget ul.side-newsfeed.order-numbers-2.display-order-numbers .order-border-number {
	display: none;
}
.widget ul.side-newsfeed.order-numbers-2.display-order-numbers {
	counter-reset: section;
}
.widget ul.side-newsfeed.order-numbers-2.display-order-numbers li .side-item-text {
	position: relative;
}
.widget ul.side-newsfeed.order-numbers-2.display-order-numbers li .side-item-text:before {
	counter-increment: section;
	content: "#" counter(section);
	font-size: 16px;
	line-height: 1;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	color: var(--pcheading-cl);
	opacity: 0.4;
	margin-bottom: 5px;
	display: block;
}
.widget ul.side-newsfeed {
	--oboxsize: 30px;
}
.widget ul.side-newsfeed.order-numbers-3 li .order-border-number {
	position: absolute;
	background: var(--pcbg-cl);
	box-shadow: none;
	width: var(--oboxsize);
	height: var(--oboxsize);
	line-height: unset;
	border-radius: unset;
	left: 0;
	top: 15px;
}
.widget ul.side-newsfeed.order-numbers-3 li {
	padding-left: 15px;
}
.widget ul.side-newsfeed.order-numbers-3 li .number-post {
	background-color: transparent;
	border-radius: unset;
	width: inherit;
	height: inherit;
	line-height: calc(var(--oboxsize) - 2px);
	text-align: center;
	display: inline-block;
	vertical-align: top;
	color: var(--pcaccent-cl);
	font-size: 17px;
	font-family: var(--pchead-font);
	font-weight: 600;
	z-index: 3;
	border: 2px solid var(--pcaccent-cl);
}
.widget ul.side-newsfeed.order-numbers-4 li .order-border-number {
	display: none;
}
.widget ul.side-newsfeed.order-numbers-4.display-order-numbers {
	counter-reset: section;
}
.widget ul.side-newsfeed.order-numbers-4.display-order-numbers li .side-image {
	position: relative;
}
.widget ul.side-newsfeed.order-numbers-4.display-order-numbers li .side-image:before {
	counter-increment: section;
	content: counter(section);
	position: absolute;
	left: 0;
	right: auto;
	z-index: 2;
	display: flex;
	justify-content: center;
	align-items: center;
	font-size: 22px;
	font-family: var(--pchead-font);
	color: #fff;
	font-weight: var(--pchead-wei);
	width: var(--oboxsize);
	height: var(--oboxsize);
	background: var(--pcaccent-cl);
	opacity: 0.9;
	border: 2px solid var(--pcbg-cl);
	bottom: 0;
}
.penci-slider41-wrapper {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	column-gap: 30px;
}
.penci-slider41-main-wrapper {
	width: calc(70% - 15px);
}
.penci-slider41-thumb-wrapper {
	width: calc(30% - 15px);
}
.penci-slider41-thumb {
	height: 100% !important;
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-slider41-t-item {
	display: flex;
	justify-content: space-between;
	column-gap: 15px;
	height: 100%;
  	align-items: center;
	border-top: 1px solid var(--pcborder-cl);
	cursor: pointer;
}
.penci-slider41-t-item .pcslider-41-img {
	flex: 0 0 120px;
}
.penci-slider41-t-item .pcslider-41-ct {
	flex: 1;
}
.penci-slider41-t-item .pcslider-41-ct h3 {
	font-size: 16px;
	margin-bottom: 0;
}
.penci-slider41-main-wrapper .penci-featured-content {
	left: 0;
	right: auto;
	bottom: 0;
	top: auto;
	transform: none;
	padding: 30px;
}
.penci-slider41-main-wrapper .penci-featured-content .feat-text {
	text-align: left;
	margin: 0;
	max-width: unset;
	padding: 0;
}
.swiper-slide-thumb-active .penci-slider41-t-item h3{
	color: var(--pcaccent-cl);
}
.penci-slider41-main-wrapper .penci-featured-content {
	background: rgb(55,55,55);
	background: linear-gradient(0deg, rgba(55,55,55,1) 0%, rgba(255,255,255,0) 100%);
}
@media only screen and (max-width: 960px) {
	.penci-slider41-wrapper {
		flex-direction: column-reverse;
		row-gap: 10px;
	}
	.penci-slider41-main-wrapper,
	.penci-slider41-thumb-wrapper {
		width: 100%;
	}
	.penci-slider41-thumb-wrapper {
		border-bottom: 0;
	}
	.penci-slider41-t-item {
		flex-direction: column;
		row-gap: 10px;
		border-top: 0;
		opacity: 0.7;
	}
	.penci-slider41-t-item .pcslider-41-img,
	.penci-slider41-t-item .pcslider-41-ct {
		width: 100%;
	}
	.penci-slider41-t-item .pcslider-41-ct {
		display: none;
	}
	.swiper-slide-thumb-active .penci-slider41-t-item {
		opacity: 1;
	}
	.penci-slider41-main-wrapper .penci-featured-content {
		padding: 20px;
	}
}
.penci-slider42-wrapper {
	position: relative;
}
.penci-slider42-wrapper .penci-slider42-thumb-wrapper {
	position: absolute;
    bottom: 0;
    left: 30px;
    right: 30px;
	z-index: 9;
}
.penci-slider42-t-item {
	max-width: 100%;
	height: 100%;
}
.pcslider-42-ct {
	padding: 20px;
	background: rgba(55,55,55,0.8);
	height: 100%;
	display: flex;
  	align-items: center;
	cursor: pointer;
}
.pcslider-42-ct h3 {
	color: #fff;
	font-size: 14px;
	margin-bottom: 0;
}
.swiper-slide-thumb-active .pcslider-42-ct {
	background: #fff;
}
.pcslider-42-ct h3 {
	overflow: hidden;
		display: -webkit-box;
		-webkit-line-clamp: 2;
				line-clamp: 2; 
		-webkit-box-orient: vertical;
}
.swiper-slide-thumb-active .pcslider-42-ct h3 {
	color: var(--pcheading-cl);
}
.penci-slider42-thumb-wrapper .swiper-slide {
	height: auto;
	align-self: stretch;
}
.featured-area.featured-style-42 .penci-featured-content .feat-text {
	text-align: left;
}
.featured-area.featured-style-42 .penci-featured-content {
	bottom: auto;
  	top: 50%;
  	max-width: 50%;
  	transform: translateY( calc( -50% - 34px ) );
}
.featured-area.featured-style-42 .item-inner-content {
	position: relative;
	overflow: hidden;
}
.featured-style-42 .penci-owl-carousel .item-inner-content .penci-image-holder::before {
	padding-top: 45%;
}
.featured-area.featured-style-42 .item-inner-content:after {
	position: absolute;
	background: rgb(24,24,24);
	background: linear-gradient(0deg, rgba(24,24,24,1) 0%, rgba(255,255,255,0) 100%);
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	content: '';
}
.featured-area.featured-style-42 .penci-featured-content .feat-text {
	padding: 0;
	margin: 0;
}
.featured-area.featured-style-42 .penci-featured-content .featured-slider-excerpt:before {
	width: 60px;
	height: 2px;
	content: '';
	background: var(--pcaccent-cl);
	display: block;
	margin-top: 15px;
	margin-bottom: 15px;
}
@media only screen and (min-width: 768px) and (max-width: 960px) {
	.featured-area.featured-style-42 .penci-featured-content {
		max-width: 100%;
	}
	.featured-area.featured-style-42 .penci-featured-content .feat-text .featured-slider-excerpt {
		display: none;
	}
}
@media only screen and (max-width: 767px) {
	.featured-area.featured-style-42 .penci-featured-content {
		max-width: 100%;
	}
	.featured-area.featured-style-42 .penci-featured-content .feat-text {
		text-align: center;
	}
	.penci-slider42-wrapper .penci-slider42-thumb-wrapper {
		left: 10px;
		right: 10px;
	}
	.pcslider-42-ct h3 {
		overflow: hidden;
		display: -webkit-box;
		-webkit-line-clamp: 1;
				line-clamp: 1; 
		-webkit-box-orient: vertical;
	}
	.pcslider-42-ct {
		padding: 10px 15px;
	}
	.featured-area.featured-style-42 .penci-featured-content {
		transform: translateY( calc( -50% - 20px ) );
	}
}
.featured-area.featured-style-43 .penci-image-holder:before {
	padding-top: 430px;
	transition: 0.3s all ease-in-out;
}
.featured-area.featured-style-43 .swiper-slide-fully-visible.active .wrapper-item{
	padding-left: 30px;
	padding-right: 30px;
}
.featured-area.featured-style-43 .penci-mag-featured-content {
	margin: 30px 0 0;
	opacity: 0;
	background: var(--pcbg-cl);
	padding: 30px 0 0;
	position: relative;
	transition: 0.3s all ease-in-out;
	text-align: center;
	position: absolute;
	top: auto;
	bottom: -60px;
	left: 0;
	right: 0;
}
.featured-area.featured-style-43 .penci-mag-featured-content .cat > a.penci-cat-name {
	color: var(--pcaccent-cl);
}
.featured-area.featured-style-43 .swiper-slide-fully-visible.active .penci-image-holder:before {
	padding-top: 400px;
}
.featured-area.featured-style-43 .swiper-slide-fully-visible.active .penci-mag-featured-content {
	opacity: 1;
	bottom: 0;
}
.featured-area.featured-style-43 .penci-mag-featured-content h3 a {
	color: var(--pcheading-cl);
	font-size: 22px;
	line-height: 1.3;
	text-transform: none;
}
.featured-area.featured-style-43 .penci-mag-featured-content .feat-meta a, 
.featured-area.featured-style-43 .penci-mag-featured-content .feat-meta span {
	color: var(--pcmeta-cl);
}
@media only screen and (max-width: 767px) {
	.featured-area.featured-style-43 .penci-mag-featured-content h3 a {
		font-size: 16px;
	}
	.featured-area.featured-style-43 .swiper-slide-fully-visible.active .penci-mag-featured-content {
		position: static;
		margin-top: 0;
	}
}
.penci-slider44-wrapper {
	position: relative;
}
.penci-slider44-main-wrapper .item-inner-content {
	height: 520px;
}
.penci-owl-carousel.penci-slider44-main .penci-image-holder,
.penci-block-el .penci-slider44-main-wrapper .item-inner-content {
	height: 100%;
}
.penci-slider44-main-wrapper .item {
	overflow: hidden;
}
.penci-slider44-thumb-wrapper {
	position: absolute;
	top: 30px;
	right: 30px;
	bottom: 30px;
	width: 340px;
	z-index: 99;
}
.penci-slider44-thumb {
	height: 100% !important;
}
.penci-slider44-t-item {
	display: flex;
	justify-content: space-between;
	column-gap: 15px;
  	align-items: center;
	cursor: pointer;
	padding: 10px;
	position: relative;
}
.penci-slider44-t-item:before {
	content: '';
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	display: block;
	position: absolute;
	z-index: 1;
	background: #000;
	opacity: .6;
}
.swiper-slide-thumb-active .penci-slider44-t-item:before {
	background: var(--pcaccent-cl);
	opacity: .85;
}
.penci-slider44-t-item > div {
	z-index: 2;
}
.penci-slider44-t-item h3 {
	color: #fff;
	font-size: 16px;
	margin-bottom: 0;
}
.penci-slider44-t-item .pcslider-44-img {
	flex: 0 0 120px;
}
.penci-slider44-t-item .pcslider-44-ct {
	flex: 1;
}
.penci-slider44-main-wrapper .penci-featured-content {
	left: 0;
	right: auto;
	bottom: 0;
	top: auto;
	transform: none;
}
.penci-slider44-main-wrapper .penci-featured-content .feat-text {
	text-align: left;
	margin: 0;
	max-width: unset;
}
.penci-slider44-main-wrapper .penci-featured-content {
	background: rgb(55,55,55);
	background: linear-gradient(0deg, rgba(55,55,55,1) 0%, rgba(255,255,255,0) 100%);
	padding: 30px;
}
.penci-slider44-main-wrapper .penci-featured-content .feat-text {
	max-width: calc(100% - 370px);
	padding: 0;
}
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next, 
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-prev {
	border-radius: 0;
	top: 30px;
	left: 30px;
	margin: 0;
}
.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next {
	left: 70px;
}
@media only screen and (max-width: 960px) {
	.penci-slider44-wrapper {
		display: flex;
		flex-direction: column-reverse;
	}
	.penci-slider44-wrapper .penci-featured-slider-button {
		display: none;
	}
	.penci-slider44-thumb-wrapper {
		position: static;
	}
	.penci-slider44-main-wrapper .item-inner-content {
		height: auto;
	}
	.penci-slider44-main-wrapper .penci-featured-content {
		padding: 20px;
	}
	.penci-slider44-main-wrapper .penci-featured-content .feat-text {
		max-width: 100%;
	}
	.penci-slider44-thumb-wrapper {
		width: 100%;
		margin-top: 10px;
	}
	.penci-slider44-t-item .pcslider-44-img {
		flex: 0 0 50px;
	}
	.penci-slider44-t-item h3 {
		font-size: 12px;
		overflow: hidden;
		display: -webkit-box;
		-webkit-line-clamp: 2; /* number of lines to show */
				line-clamp: 2; 
		-webkit-box-orient: vertical;
	}
	.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next, 
	.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-prev {
		opacity: 0.6;
		top: 20px;
		left: 20px;
	}
	.penci-slider44-main.penci-owl-carousel .penci-owl-nav .owl-next {
		left: 60px;
	}
	.penci-slider44-wrapper .penci-owl-carousel-slider[data-direction="vertical"]:not(.penci-owl-loaded) .swiper-slide {
		margin-bottom: 0;
	}
	.penci-slider44-thumb:not(.penci-owl-loaded) .swiper-slide {
		width: 50%;
		max-width: calc( 50% - 7.5px );
	}
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider41-thumb-inner.swiper-wrapper > div .penci-slider41-t-item {
	padding-top: 22px;
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider41-thumb-inner.swiper-wrapper > div {
	margin-bottom: 26px;
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider42-thumb-inner {
	display: flex !important;
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider42-thumb-inner > div > div {
	margin-right: 15px;
}
.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider42-thumb-inner {
	width: calc(100% + 15px);
}
@media only screen and (max-width: 767px) {
	.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider42-thumb-inner > div {
		width: 50%;
	}
	.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider41-thumb-inner.swiper-wrapper > div {
		width: calc(100%/3) !important;;
	}
	.penci-owl-carousel:not(.penci-owl-loaded) .penci-slider41-thumb-inner.swiper-wrapper > div .penci-slider41-t-item {
		padding-top: 0;
	}
}


.penci-ct-accordion {
	display: flex;
	height: 360px;
	overflow: hidden
}
.penci-ct-accordion-item {
	position: relative;
	overflow: hidden;
	flex: 1;
	transition: flex .3s
}
.pcct-ac--default .penci-ct-accordion-item,
.pcct-ac--vertical .penci-ct-accordion-item {
	text-align: center;
	text-decoration: none;
	background-size: cover;
	background-position: center;
	background-repeat: no-repeat
}
.pcct-ac--default .penci-ct-accordion-content:before,
.pcct-ac--vertical .penci-ct-accordion-content:before {
	content: '';
	position: absolute;
	height: 100%;
	width: 100%;
	background: rgba(0, 0, 0, 0.44);
	left: 0;
	top: 0;
	transition: opacity .3s ease-in-out;
	z-index: 0;
	opacity: 0
}
.pcct-ac--default .penci-ct-accordion-item:after,
.pcct-ac--vertical .penci-ct-accordion-item:after {
	content: '';
	position: absolute;
	height: 100%;
	width: 5px;
	background: var(--pcbg-cl);
	right: -2.5px;
	top: 0;
	z-index: 1
}
.pcct-ac--default .penci-ct-accordion-item:nth-last-child(1):after,
.pcct-ac--vertical .penci-ct-accordion-item:nth-last-child(1):after {
	opacity: 0
}
.penci-ct-accordion-item.active {
	flex: 10
}
.penci-ct-accordion-item.active .penci-ct-accordion-content:before {
	opacity: 1
}
.penci-ct-accordion-item.active .penci-ct-accordion-content * {
	opacity: 1;
	visibility: visible;
	transform: translateY(0);
	transition: all .3s ease
}
.penci-ct-accordion-item.active .penci-ct-accordion-sub-title {
	transition-delay: .2s
}
.penci-ct-accordion-item.active .penci-ct-accordion-title {
	transition-delay: .3s
}
.penci-ct-accordion-item.active .penci-ct-accordion-text {
	transition-delay: .4s
}
.penci-ct-accordion-item.active .grid-post-box-meta {
	transition-delay: .4s
}
.penci-ct-accordion-item.active .penci-ct-accordion-button {
	transition-delay: .4s
}
.penci-ct-accordion-item.active .penci-ct-accordion-lightbox {
	opacity: 1;
	transition-delay: .4s;
	visibility: visible
}
.penci-ct-accordion-item.active .penci-ct-accordion-img:before {
	opacity: 1
}
.penci-ct-accordion-content {
	position: absolute;
	padding: 10px;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%);
	width: 100%;
	display: flex;
	flex-direction: column;
	justify-content: center;
	height: 100%
}
.penci-ct-accordion-content * {
	opacity: 0;
	visibility: hidden;
	transform: translateY(8px)
}
.penci-ct-accordion-sub-title {
	color: var(--pcbg-cl);
	margin-bottom: 3px;
	font-weight: 500
}
.penci-ct-accordion-sub-title a,
.post-entry .penci-ct-accordion-sub-title a {
	color: inherit;
	text-decoration: none;
}
.penci-ct-accordion-title,
.post-entry .penci-ct-accordion-title {
	font-size: 20px;
	font-weight: 700;
	color: var(--pcbg-cl);
	margin: 0
}
.penci-ct-accordion-title a,
.post-entry .penci-ct-accordion-title a {
	color: inherit;
	text-decoration: none;
}
.penci-ct-accordion-text,
.post-entry .penci-ct-accordion-text {
	color: var(--pcbg-cl);
	line-height: 1.5em;
	font-size: 15px;
	margin-top: 12px;
	padding: 0;
}
.penci-ct-accordion-item .grid-post-box-meta {
	margin: 10px 0 0;
}
.penci-ct-accordion-text p {
	margin: 0
}
.penci-ct-accordion-button {
	display: block;
	position: relative;
	margin-top: 18px;
}
.post-entry .penci-ct-accordion-button a,
.penci-ct-accordion-button a {
	display: inline-block;
	font-size: 13px;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
	color: var(--pcbg-cl);
	padding: 5px 15px;
	background: var(--pcaccent-cl);
}
.penci-ct-accordion-button a:hover,
.post-entry .penci-ct-accordion-button a:hover {
	background: var(--pcbg-cl);
	color: var(--pcheading-cl);
}
.penci-ct-accordion-lightbox {
	position: absolute;
	z-index: 10;
	display: inline-flex;
	padding: 10px;
	color: var(--pcbg-cl);
	border: 1px solid var(--pcbg-cl);
	border-radius: 100px;
	opacity: 0;
	margin: 10px;
	transition: all .3s ease;
	visibility: hidden
}
.penci-ct-accordion-lightbox i {
	transition: transform .3s ease
}
.penci-ct-accordion-lightbox:hover {
	color: var(--pcbg-cl);
}
.penci-ct-accordion-lightbox:hover i {
	transform: scale(1.25)
}
.penci-ct-meta {
	margin-bottom: 20px;
}
.penci-ct-meta span,
.penci-ct-meta span a{
	color: var(--pcbg-cl);
}
.pcct-img-position--row-reverse .penci-ct-accordion-item.active .penci-ct-accordion-content {
	margin-right: 50%;
	margin-left: auto
}
.elementor-widget-penci-content-accordion .elementor-widget-container {
	overflow: hidden
}
@media only screen and (min-width:768px) {
	.penci-ct-accordion {
		height: 400px
	}
	.penci-ct-accordion-item.active {
		flex: 6
	}
	.penci-ct-accordion-title {
		font-size: 28px
	}
	.penci-ct-accordion-text {
		font-size: 16px
	}
	.penci-ct-accordion-button a {
		font-size: 14px
	}
}
@media only screen and (min-width:961px) {
	.penci-ct-accordion {
		height: 500px
	}
	.pcct-ac--vertical .penci-ct-accordion-item:after {
		width: 100% !important;
		left: 0;
		right: auto !important;
		top: auto;
		height: var(--divider-width, 5px);
		bottom: calc(var(--divider-bottom, -5px) / 2)
	}
}
@media only screen and (min-width:768px) and (max-width:1024px) {
	.pcct-ac--tablet-vertical .penci-ct-accordion-item:after {
		width: 100% !important;
		left: 0;
		right: auto !important;
		top: auto;
		height: var(--divider-width, 5px);
		bottom: calc(var(--divider-bottom, -5px) / 2)
	}
}
@media only screen and (max-width:767px) {
	.pcct-ac--mobile-vertical .penci-ct-accordion-item:after {
		width: 100% !important;
		left: 0;
		right: auto !important;
		top: auto;
		height: var(--divider-width, 5px);
		bottom: calc(var(--divider-bottom, -5px) / 2)
	}
	.pccthide-m {
		display: none !important;
	}
}
.penciimg-compare {
	position: relative;
}
.penciimg-compare .icv__icv--horizontal img {
	height: 100%;
	max-width: inherit
}
.penciimg-compare .penciimg-compare-overlay:before {
	content: '';
	position: absolute;
	height: 100%;
	width: 100%;
	top: 0;
	left: 0;
	background: rgba(55, 55, 5, 0.25);
	z-index: 3
}
.penciimg-compare .icv {
	position: relative;
	overflow: hidden;
	cursor: row-resize
}
.penciimg-compare .icv__icv--vertical {
	cursor: row-resize
}
.penciimg-compare .icv__icv--horizontal {
	cursor: col-resize
}
.penciimg-compare .icv__img {
	pointer-events: none;
	-o-user-select: none;
	-moz-user-select: none;
	-webkit-user-select: none;
	-ms-user-select: none;
	user-select: none;
	max-width: none;
	width: 100%;
	margin: 0 !important;
	padding: 0 !important;
	border: 0 !important;
	border-radius: 0 !important;
	top: 0;
	display: block
}
.penciimg-compare .icv__is--fluid .icv__img {
	display: none
}
.penciimg-compare .icv__img-a {
	height: auto;
	position: static;
	z-index: 1;
	left: 0px
}
.penciimg-compare .icv__img-b {
	height: 100%;
	position: absolute;
	z-index: 2;
	left: auto;
	right: 0px;
	width: auto
}
.penciimg-compare .icv__icv--vertical .icv__img-b {
	width: 100%;
	height: auto
}
.penciimg-compare .icv__imposter {
	z-index: 4;
	position: absolute;
	top: 0px;
	left: 0px;
	width: 100%;
	height: 100%
}
.penciimg-compare .icv__wrapper {
	position: absolute;
	width: 100%;
	height: 100%;
	right: 0px;
	top: 0px;
	overflow: hidden;
	background-size: cover;
	background-position: center center;
	z-index: 3
}
.penciimg-compare .icv__is--fluid .icv__wrapper,
.penciimg-compare .icv__icv--vertical .icv__wrapper {
	width: 100% !important
}
.penciimg-compare .icv__is--fluid .icv__wrapper,
.penciimg-compare .icv__icv--horizontal .icv__wrapper {
	height: 100% !important
}
.penciimg-compare .icv__fluidwrapper {
	background-size: cover;
	background-position: center;
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%
}
.penciimg-compare .icv__control {
	position: absolute;
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-webkit-box-orient: vertical;
	-webkit-box-direction: normal;
	-ms-flex-direction: column;
	flex-direction: column;
	-webkit-box-pack: center;
	-ms-flex-pack: center;
	justify-content: center;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	height: 100%;
	top: 0px;
	z-index: 5
}
.penciimg-compare .icv__icv--vertical .icv__control {
	-webkit-box-orient: horizontal;
	-webkit-box-direction: normal;
	-ms-flex-direction: row;
	flex-direction: row;
	left: 0;
	width: 100%
}
.penciimg-compare .icv__control-line {
	height: 50%;
	width: 2px;
	z-index: 6
}
.penciimg-compare .icv__icv--vertical .icv__control-line {
	width: 50%
}
.penciimg-compare .icv__theme-wrapper {
	width: 100%;
	height: 100%;
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-webkit-box-pack: justify;
	-ms-flex-pack: justify;
	justify-content: space-between;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	position: absolute;
	-webkit-transition: all .1s ease-out 0s;
	transition: all .1s ease-out 0s;
	z-index: 5
}
.penciimg-compare .icv__icv--vertical .icv__theme-wrapper {
	-webkit-box-orient: vertical;
	-webkit-box-direction: normal;
	-ms-flex-direction: column;
	flex-direction: column
}
.penciimg-compare .icv__arrow-wrapper {
	display: -webkit-box;
	display: -ms-flexbox;
	display: flex;
	-webkit-box-pack: center;
	-ms-flex-pack: center;
	justify-content: center;
	-webkit-box-align: center;
	-ms-flex-align: center;
	align-items: center;
	-webkit-transition: all .1s ease-out 0s;
	transition: all .1s ease-out 0s
}
.penciimg-compare .icv__arrow-a {
	-webkit-transform: scale(1.5) rotateZ(180deg);
	transform: scale(1.5) rotateZ(180deg);
	height: 20px;
	width: 20px;
	-webkit-filter: drop-shadow(0 3px 5px rgba(0, 0, 0, 0.33));
	filter: drop-shadow(0 -3px 5px rgba(0, 0, 0, 0.33))
}
.penciimg-compare .icv__arrow-b {
	-webkit-transform: scale(1.5) rotateZ(0deg);
	transform: scale(1.5) rotateZ(0deg);
	height: 20px;
	width: 20px;
	-webkit-filter: drop-shadow(0 3px 5px rgba(0, 0, 0, 0.33));
	filter: drop-shadow(0 3px 5px rgba(0, 0, 0, 0.33))
}
.penciimg-compare .icv__circle {
	width: 50px;
	height: 50px;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	-ms-flex-negative: 0;
	flex-shrink: 0;
	border-radius: 999px
}
.penciimg-compare .icv__label {
	position: absolute;
	z-index: 12;
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
	color: var(--pcbg-cl);
	font-size: 12px;
	background: rgba(255, 255, 255, 0.3);
	padding: 6px 12px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	text-transform: uppercase;
}
.penciimg-compare .icv__label.vertical {
	bottom: auto;
	left: 50%;
	transform: translateX(-50%)
}
.penciimg-compare .icv__icv--horizontal .icv__label {
	top: 50%;
	transform: translateY(-50%)
}
.penciimg-compare .icv__label.on-hover {
	opacity: 0;
	-webkit-transition: .3s cubic-bezier(.62, .24, .60, 1.35);
	transition: .3s cubic-bezier(.62, .24, .60, 1.35)
}
.penciimg-compare .icv:hover .icv__label.on-hover {
	opacity: 1
}
.penciimg-compare .icv__label-before {
	left: 15px;
}
.penciimg-compare .icv__label-after {
	right: 15px;
}
.penciimg-compare .icv__label-before.vertical {
	top: 15px;
}
.penciimg-compare .icv__label-after.vertical {
	bottom: 15px;
	right: auto
}
.penciimg-compare .icv__body {
	-webkit-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none
}
.penci-wrap-gprd-law.style-2 .penci-gprd-law {
	max-width: 470px;
	margin: 30px;
	padding: 20px 30px;
	background: #444;
	box-shadow: 1px 3px 6px rgba(50, 50, 50, 0.25);
}
.penci-wrap-gprd-law.style-2 .penci-gprd-law .penci-gprd-law-content {
	display: block;
	margin-bottom: 20px;
	color: #fff;
	font-size: 16px;
	line-height: 1.6;
}
.penci-wrap-gprd-law.style-2 .penci-gprd-accept,
.penci-wrap-gprd-law.style-2 .penci-gprd-law {
	line-height: 20px;
}
.penci-wrap-gprd-law.style-2 .penci-gprd-accept {
	margin-left: 0;
}
.penci-wrap-gprd-law.style-2 .penci-gprd-law .penci-gprd-more {
	color: #fff;
}
.penci-wrap-gprd-law.style-2.penci-wrap-gprd-law-close .penci-gprd-law {
	bottom: -30px;
}
.penci-wrap-gprd-law.style-3 .penci-gprd-law {
	max-width: 470px;
	margin: 30px;
	padding: 20px 30px;
	background: #eee;
  	box-shadow: 8px 8px 0px #444;
}
.penci-wrap-gprd-law.style-3 .penci-gprd-law .penci-gprd-law-content {
	display: block;
	margin-bottom: 20px;
	font-size: 16px;
	line-height: 1.6;
}
.penci-wrap-gprd-law.style-3 .penci-gprd-accept,
.penci-wrap-gprd-law.style-3 .penci-gprd-more {
	line-height: 20px;
}
.penci-wrap-gprd-law.style-3 .penci-gprd-accept {
	margin-left: 0;
	background: var(--pcaccent-cl);
}
.penci-wrap-gprd-law.style-3 .penci-gprd-law .penci-gprd-more {
	color: #fff;
	background: #000;
	padding: 6px 15px;
}
.penci-wrap-gprd-law.style-3.penci-wrap-gprd-law-close .penci-gprd-law {
	bottom: -30px;
}
.penci-wrap-gprd-law.style-4 .penci-gprd-law {
	max-width: 470px;
	margin: 30px;
	padding: 20px 30px;
	background: #fff;
	border: 1px solid var(--pcborder-cl);
	box-shadow: 1px 3px 6px rgba(50, 50, 50, 0.25);
}
.penci-wrap-gprd-law.style-4 .penci-gprd-law .penci-gprd-law-content {
	display: block;
	margin-bottom: 20px;
	font-size: 16px;
	line-height: 1.6;
}
.penci-wrap-gprd-law.style-4 .penci-gprd-accept,
.penci-wrap-gprd-law.style-4 .penci-gprd-more {
	line-height: 20px;
	display: block;
}
.penci-wrap-gprd-law.style-4 .penci-gprd-accept {
	margin-left: 0;
}
.penci-wrap-gprd-law.style-4 .penci-gprd-more {
	margin-top: 10px;
}
.penci-wrap-gprd-law.style-4.penci-wrap-gprd-law-close .penci-gprd-law {
	bottom: -30px;
}
.penci-wrap-gprd-law:not(.style-1) .penci-gdrd-show {
	right: auto;
	left: 30px;
}
.penci-a-post-subtitle {
  	margin: 0 0 10px;
  	font-weight: var(--pchead-wei);
}
.penci-a-post-subtitle.pcloop {
	pointer-events: none;
	cursor: not-allowed;
	margin: 8px 0 -2px;
	font-size: 105%;
	line-height: 1.25;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
}
.penci-ajax-more-button.disable {
	pointer-events: none;
	cursor: not-allowed;
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul:not(:last-child),
.post-entry
	.penci-toc-wrapper
	.penci-el-toc-table-of-content
	ul:not(:last-child) {
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul li,
.post-entry .penci-toc-wrapper .penci-el-toc-table-of-content ul li {
	padding-top: 10px;
	padding-bottom: 10px;
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul li:not(:last-child),
.post-entry
	.penci-toc-wrapper
	.penci-el-toc-table-of-content
	ul
	li:not(:last-child) {
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul li a,
.post-entry .penci-toc-wrapper .penci-el-toc-table-of-content ul li a {
	text-decoration: none;
	color: var(--pcheading-cl);
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul li a:hover,
.post-entry .penci-toc-wrapper .penci-el-toc-table-of-content ul li a:hover {
	color: var(--pcaccent-cl);
}
.penci-toc-wrapper .penci-el-toc-table-of-content ul ul,
.post-entry .penci-toc-wrapper .penci-el-toc-table-of-content ul ul {
	padding-left: 20px;
}
.penci-el-toc-wrapper,
.post-entry .penci-el-toc-wrapper {
	margin-bottom: 0;
}
.penci-owl-carousel.pcmarquee-slider:not(.penci-owl-loaded) > .swiper-wrapper > div,
.pcmarquee-slider .swiper-wrapper .swiper-slide {
	display: inline-block;
	width: auto;
	height: auto;
	margin-right: 30px;
}
.penci-owl-carousel.pcmarquee-slider:not(.penci-owl-loaded) > .swiper-wrapper > div:last-child,
.pcmarquee-slider .swiper-wrapper .swiper-slide:last-child {
	margin-right: 0;
}
.pcmarquee-slider .swiper-wrapper {
	overflow: hidden;
}
.pencisctn-sticky.pencisctn-active {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	z-index: 9999;
	transition: all 0.3s ease-in-out;
}
.pencisctn-sticky.pencisctn-footer.pencisctn-active {
	top: auto;
	bottom: 0;
}
body.admin-bar .pencisctn-sticky.pencisctn-header.pencisctn-active {
	top: 32px;
}
.penci-mc4wp-widget.penci-mailchimp-s5 .mc4wp-form-fields,
.penci-mailchimp-s5 .widget_mc4wp_form_widget {
	--iconsize: 70px;
	border: 5px solid var(--pcborder-cl);
	padding: 40px 20px 20px;
	position: relative;
	margin-top: var(--iconsize);
}
.penci-mc4wp-widget.penci-mailchimp-s5 .mc4wp-form-fields:before,
.penci-mailchimp-s5 .widget_mc4wp_form_widget:before {
	content: "\f0e0";
	font-family: "FontAwesome";
	display: flex;
	justify-content: center;
	align-items: center;
	font-size: 28px;
	color: #fff;
	width: var(--iconsize);
	height: var(--iconsize);
	background: var(--pcaccent-cl);
	position: absolute;
	border-radius: 50%;
	top: calc(-0.5 * var(--iconsize) - 5px);
	left: 50%;
	right: 50%;
	transform: translateX(-50%);
}
.penci-mailchimp-s5 .mc4wp-form input[type="submit"]:not(:hover) {
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
}
.penci-mc4wp-widget.penci-mailchimp-s6 .mc4wp-form-fields,
.penci-mailchimp-s6 .widget_mc4wp_form_widget {
	--iconsize: 70px;
	border: 1px solid var(--pcborder-cl);
	padding: 40px 20px 20px;
	position: relative;
	margin-top: var(--iconsize);
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
}
.penci-mailchimp-s6 .mc4wp-form {
	max-width: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s6 .mc4wp-form-fields:before,
.penci-mailchimp-s6 .widget_mc4wp_form_widget:before {
	content: "";
	background: url("images/mailchimp/s6.svg");
	background-size: auto 60px;
	background-repeat: no-repeat;
	background-position: center center;
	width: 81px;
	height: 60px;
	position: absolute;
	top: calc(-0.5 * var(--iconsize) - 5px);
	left: 50%;
	right: 50%;
	transform: translateX(-50%) rotate(-22deg);
}
.penci-mailchimp-s6 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #ffbc2c;
	color: var(--pcbg-cl);
}
.penci-mailchimp-s6 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 10px;
}
.penci-mailchimp-s6 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s6 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s6 .mc4wp-form-fields > p:last-child,
.penci-mailchimp-s6 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s7 .mc4wp-form-fields,
.penci-mailchimp-s7 .widget_mc4wp_form_widget {
	--iconsize: 70px;
	border: 1px solid var(--pcborder-cl);
	padding: 0 20px 20px;
	position: relative;
	margin-top: var(--iconsize);
	border-top: 5px solid #000;
}
.penci-mc4wp-widget.penci-mailchimp-s7 .mc4wp-form-fields {
	margin-top: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s7 .mc4wp-form-fields:before,
.penci-mailchimp-s7 .widget_mc4wp_form_widget:before {
	content: "\f0e0";
	font-family: "FontAwesome";
	display: flex;
	justify-content: center;
	align-items: center;
	font-size: 28px;
	color: #fff;
	width: var(--iconsize);
	height: var(--iconsize);
	background: #000;
	top: calc(-0.5 * var(--iconsize) - 5px);
	margin: 0 auto 40px;
}
.penci-mailchimp-s7 .mc4wp-form input[type="submit"]:not(:hover) {
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
}
.penci-mailchimp-s7 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #000;
}
.penci-mailchimp-s7 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 10px;
}
.penci-mailchimp-s7 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s7 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s7 .mc4wp-form-fields > p:last-child,
.penci-mailchimp-s7 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s8 .mc4wp-form-fields,
.penci-mailchimp-s8 .widget_mc4wp_form_widget {
	--iconsize: 70px;
	border: 1px solid var(--pcborder-cl);
	padding: 20px;
	position: relative;
	margin-top: var(--iconsize);
	border-top: 5px solid #ffcb5a;
}
.penci-mc4wp-widget.penci-mailchimp-s8 .mc4wp-form-fields {
	margin-top: 0;
}
.penci-mailchimp-s8 .mc4wp-form input[type="submit"]:not(:hover) {
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
}
.penci-mailchimp-s8 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #ffcb5a;
}
.penci-mc4wp-widget.penci-mailchimp-s9 .mc4wp-form-fields,
.penci-mailchimp-s9 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	padding: 20px;
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
}
.penci-mailchimp-s9 .mc4wp-form input[type="submit"]:not(:hover) {
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
}
.penci-mailchimp-s9 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s9 .mc4wp-form-fields {
	flex-direction: column;
}
.penci-mailchimp-s9 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s9 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s9 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s10 .mc4wp-form-fields,
.penci-mailchimp-s10 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	border-top: 0;
	padding: 20px;
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
}
.penci-mc4wp-widget.penci-mailchimp-s10 .mc4wp-form-fields {
	padding: 20px;
}
.penci-mc4wp-widget.penci-mailchimp-s10 .mc4wp-form-fields:before,
.penci-mailchimp-s10 .widget_mc4wp_form_widget:before {
	position: absolute;
	top: -1px;
	left: -1px;
	right: -1px;
	height: 4px;
	background: #fff;
	background: repeating-linear-gradient(-45deg, #e91c2e, #a01521 19px, transparent 10px, transparent 30px, #7337df 20px, #7337df 46px, transparent 40px, transparent 57px);
	background-clip: border-box;
	background-clip: padding-box;
	content: "";
}
.penci-mailchimp-s10 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #e91c2e;
	color: var(--pcbg-cl);
}
.penci-mc4wp-widget.penci-mailchimp-s11 .mc4wp-form-fields,
.penci-mailchimp-s11 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
}
.penci-mc4wp-widget.penci-mailchimp-s11 .mc4wp-form-fields {
	padding-bottom: 20px;
}
.penci-mc4wp-widget.penci-mailchimp-s11 .mc4wp-form-fields:before,
.penci-mailchimp-s11 .widget_mc4wp_form_widget:before {
	content: "";
	background-image: url("images/mailchimp/s11.svg");
	width: 100%;
	display: block;
	background-repeat: no-repeat;
	background-position: center center;
	background-color: #fffbf1;
	padding: 120px 0;
	margin-bottom: 40px;
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-mc4wp-widget.penci-mailchimp-s11 .mc4wp-form-fields:before {
	background-size: auto 120px;
}
.penci-mc4wp-widget.penci-mailchimp-s11 .mc4wp-form-fields p {
	padding-left: 20px;
	padding-right: 20px;
}
.penci-mailchimp-s11 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #e9ad25;
	color: var(--pcbg-cl);
}
.penci-mc4wp-widget.penci-mailchimp-s12 .mc4wp-form-fields,
.penci-mailchimp-s12 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
	background: #f2ffff;
	padding: 40px 0 0;
}
.penci-mc4wp-widget.penci-mailchimp-s12 .mc4wp-form-fields:before,
.penci-mailchimp-s12 .widget_mc4wp_form_widget:before {
	content: "";
	background-image: url("images/mailchimp/s12.svg");
	width: 100%;
	display: block;
	background-repeat: no-repeat;
	background-position: center center;
	padding: 140px 0;
	margin-bottom: 40px;
}
.penci-mc4wp-widget.penci-mailchimp-s12 .mc4wp-form-fields:before {
	background-size: auto 120px;
	padding: 80px 0;
}
.penci-mailchimp-s12 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #f3688d;
	color: var(--pcbg-cl);
}
.penci-mailchimp-s12 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s12 .mc4wp-form-fields {
	flex-direction: column;
	padding-bottom: 20px;
}
.penci-mc4wp-widget.penci-mailchimp-s12 .mc4wp-form-fields p {
	padding-left: 20px;
	padding-right: 20px;
}
.penci-mailchimp-s12 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s12 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s12 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s13 .mc4wp-form,
.penci-mailchimp-s13 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
	padding-bottom: 40px;
}
.penci-mc4wp-widget.penci-mailchimp-s13 .mc4wp-form {
	padding: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s13 .mc4wp-form-fields {
	padding: 20px;
}
.penci-mc4wp-widget.penci-mailchimp-s13 .mc4wp-form:before,
.penci-mailchimp-s13 .widget_mc4wp_form_widget:before {
	content: "";
	background-image: url("images/mailchimp/s13.svg");
	width: 100%;
	display: block;
	background-repeat: no-repeat;
	background-position: center center;
	padding: 140px 0;
	margin-bottom: 40px;
	background-color: #cbf8ff;
}
.penci-mc4wp-widget.penci-mailchimp-s13 .mc4wp-form:before {
	padding: 120px 0;
	background-size: 150px auto;
	margin-bottom: 0;
}
.penci-mailchimp-s13 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #c52228;
	color: var(--pcbg-cl);
}
.penci-mc4wp-widget.penci-mailchimp-s14 .mc4wp-form-fields,
.penci-mailchimp-s14 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
	padding-bottom: 40px;
}
.penci-mc4wp-widget.penci-mailchimp-s14 .mc4wp-form-fields:before,
.penci-mailchimp-s14 .widget_mc4wp_form_widget:before {
	content: "";
	background-image: url("images/mailchimp/s14.svg");
	width: 100%;
	display: block;
	background-repeat: no-repeat;
	background-position: center center;
	padding: 120px 0;
	margin-bottom: 40px;
}
.penci-mc4wp-widget.penci-mailchimp-s14 .mc4wp-form-fields:before {
	background-size: auto 110px;
	padding: 60px 0;
	margin-bottom: 0;
}
.penci-mailchimp-s14 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #000;
	color: var(--pcbg-cl);
}
.penci-mailchimp-s14 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s14 .mc4wp-form-fields {
	flex-direction: column;
}
.penci-mc4wp-widget.penci-mailchimp-s14 .mc4wp-form-fields p {
	padding-left: 20px;
	padding-right: 20px;
}
.penci-mailchimp-s14 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s14 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s14 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-mc4wp-widget.penci-mailchimp-s15 .mc4wp-form-fields,
.penci-mailchimp-s15 .widget_mc4wp_form_widget {
	border: 1px solid var(--pcborder-cl);
	position: relative;
	box-shadow: 0 0 14px rgba(0, 0, 0, 0.04);
	padding: 20px 20px 30px;
	background: #000;
	color: #fff;
}
.penci-mailchimp-s15 .mc4wp-form input {
	border-color: #333;
	color: #fff;
}
.penci-mailchimp-s15 .mc4wp-form input[type="submit"]:not(:hover) {
	background: #208a4f;
	color: var(--pcbg-cl);
}
.penci-mailchimp-s15 .mc4wp-form-fields {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 0;
}
.penci-mc4wp-widget.penci-mailchimp-s15 .mc4wp-form-fields {
	flex-direction: column;
}
.penci-mailchimp-s15 .mc4wp-form-fields input {
	margin-bottom: 0;
}
.penci-mailchimp-s15 .mc4wp-form input:not([type="submit"]) {
	border-right: 0;
}
.penci-mailchimp-s15 .mc4wp-form-fields > p {
	flex: 1;
}
.penci-mailchimp-s15 .mc4wp-form-fields .mdes {
	flex: 100%;
}
.penci-el-mailchimp.penci-mailchimp-s8 .widget_mc4wp_form_widget {
	margin-top: 0;
}
.penci-el-mailchimp.penci-mailchimp-s9 .mc4wp-form-fields,
.penci-el-mailchimp.penci-mailchimp-s12 .mc4wp-form-fields,
.penci-el-mailchimp.penci-mailchimp-s14 .mc4wp-form-fields {
	column-gap: 20px;
}
.penci-el-mailchimp.penci-mailchimp-s9 .mc4wp-form-fields > p.msubmit,
.penci-el-mailchimp.penci-mailchimp-s12 .mc4wp-form-fields > p.msubmit,
.penci-el-mailchimp.penci-mailchimp-s14 .mc4wp-form-fields > p.msubmit {
	flex: 100%;
}
.penci-el-mailchimp.penci-mailchimp-s15 .mc4wp-form {
	max-width: 550px;
}
.penci-el-mailchimp.penci-mailchimp-s11 .widget_mc4wp_form_widget:before,
.penci-el-mailchimp.penci-mailchimp-s12 .widget_mc4wp_form_widget:before,
.penci-el-mailchimp.penci-mailchimp-s13 .widget_mc4wp_form_widget:before,
.penci-el-mailchimp.penci-mailchimp-s14 .widget_mc4wp_form_widget:before {
	background-size: 120px auto;
}
.penci-el-mailchimp.penci-mailchimp-s12 .widget_mc4wp_form_widget:before,
.penci-el-mailchimp.penci-mailchimp-s14 .widget_mc4wp_form_widget:before {
	padding-top: 80px;
	padding-bottom: 80px;
}
.penci-el-mailchimp.penci-mailchimp-s13 .widget_mc4wp_form_widget,
.penci-el-mailchimp.penci-mailchimp-s14 .widget_mc4wp_form_widget {
	padding-bottom: 0;
}
.penci-el-mailchimp.penci-mailchimp-s11 .mc4wp-form,
.penci-el-mailchimp.penci-mailchimp-s12 .mc4wp-form,
.penci-el-mailchimp.penci-mailchimp-s13 .mc4wp-form,
.penci-el-mailchimp.penci-mailchimp-s14 .mc4wp-form {
	margin-bottom: 30px;
}
.penci_az_taxonomy_listing_head {
	background: var(--pcaccent-cl);
	padding: 15px 10px;
  	margin-bottom: 40px;
}
.penci_az_taxonomy_listing_head.style-2 {
	background: none !important;
	padding: 0;
}
.penci_az_taxonomy_listing_head ul {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: center;
	column-gap: 10px;
}
.post-entry .penci_az_taxonomy_listing_head ul,
.post-entry .penci_az_taxonomy_listing_head ul li {
	list-style: none;
  	line-height: initial;
	margin: 0;
	padding: 0;
}
.penci_az_taxonomy_listing_head a,
.post-entry .penci_az_taxonomy_listing_head ul li a {
	color: #fff;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	font-size: 20px;
	text-transform: uppercase;
}
.penci_az_taxonomy_listing_head.style-2 a {
	padding: 0;
	background: var(--pcaccent-cl);
	width: 36px;
	display: inline-block;
	height: 36px;
	line-height: 36px;
	text-align: center;
}
.penci_az_taxonomy_listing {
  --col:3;
  --gap: 30px;
  display: flex;
  flex-wrap: wrap;
  flex-direction: row;
  column-gap: var(--gap);
  row-gap: var(--gap);
}
.penci_az_taxonomy_item {
  width: calc((100% - (var(--gap) * (var(--col) - 1))) / var(--col));
}
.penci_az_taxonomy_listing h3 {
  padding-bottom: 10px;
  margin-bottom: 30px;
  border-bottom: 5px solid var(--pcheading-cl);
  font-size: 22px;
}
.penci_az_taxonomy_item ul,
.penci_az_taxonomy_item ul li {
  list-style: none;
  padding: 0;
  margin: 0;
}
.penci_az_taxonomy_item ul li:not(:last-child) {
  border-bottom: 1px solid var(--pcborder-cl);
  padding-bottom: 15px;
  margin-bottom: 15px;
}
.penci_az_taxonomy_item a {
  color: var(--pctext-cl);
  display: flex;
  justify-content: space-between;
}
.penci_az_taxonomy_item .pcaz_tcount {
	color: var(--pcmeta-cl);
}
.item-content[data-excerpt-link]:hover {
    cursor: pointer;
}
.penci-cc-cursor {
	--pccrs-cccr: 3.75rem;
	--pccrs-ccsm: 2rem;
	--pccrs-ccesm: 1.25rem;
	--pccrs-ccinner: 0.5rem;
  	--pccrs-cn: #000;
	--pccrs-bw: 1px;
	--pccrs-bs: solid;
}
.penci-cc-cursor .circle-cursor {
	position: fixed;
	left: 0;
	top: 0;
	pointer-events: none;
	transform: translateZ(0);
	visibility: hidden;
	border-radius: 50%;
}
.penci-cc-cursor .penci-ccircle-cinner {
	margin-left: calc(var(--pccrs-ccinner) / 2 * (-1));
	margin-top: calc(var(--pccrs-ccinner) / 2 * (-1));
	width: var(--pccrs-ccinner);
	height: var(--pccrs-ccinner);
	z-index: 10000001;
	background-color: var(--pcaccent-cl);
}
.penci-cc-cursor .penci-ccircle-cinner.penci-clinkh {
	margin-left: calc(var(--pccrs-ccesm) / 2 * (-1));
	margin-top: calc(var(--pccrs-ccesm) / 2 * (-1));
	width: var(--pccrs-ccesm);
	height: var(--pccrs-ccesm);
	background-color: var(--pcaccent-cl);
	opacity: 0.5;
}
.penci-cc-cursor .penci-ccircle-couter {
	margin-left: calc(var(--pccrs-ccsm) / 2 * (-1));
	margin-top: calc(var(--pccrs-ccsm) / 2 * (-1));
	width: var(--pccrs-ccsm);
	height: var(--pccrs-ccsm);
	border: var(--pccrs-bw) var(--pccrs-bs) var(--pcaccent-cl);
	z-index: 10000000;
	opacity: 0.5;
	transition: all 0.125s ease-out;
}
.penci-cc-cursor .cursor-link.penci-ccircle-cinner {
	background: transparent !important;
}
.penci-cc-cursor .cursor-link.penci-ccircle-cinner.penci-clinkh {
	opacity: 1;
}
.penci-cc-cursor .cursor-link.penci-ccircle-cinner svg {
	fill: var(--pcbg-cl);
}
.penci-cc-cursor .cursor-link.penci-ccircle-couter.penci-clinkh {
	margin-left: calc(var(--pccrs-cccr) / 2 * (-1));
	margin-top: calc(var(--pccrs-cccr) / 2 * (-1));
	width: var(--pccrs-cccr);
	height: var(--pccrs-cccr);
	background-color: color-mix(
		in srgb,
		var(--pccrs-cn) 75%,
		transparent
	);
	border: none;
}
.penci-cc-cursor a[data-cursor-class] {
	cursor: none;
}
.pencihd-progress-container {
    position: fixed;
    bottom: 80px;
    right: 20px;
    width: 40px;
    height: 40px;
    z-index: 1000;
}
.pencihd-progress-container svg {
    transform: rotate(-90deg);
    width: 100%;
    height: 100%;
}
.pencihd-progress-container circle {
    fill: none;
    stroke-width: 5;
    stroke-linecap: round;
}
.pencihd-progress-container circle.bg {
    stroke: #ddd;
}
.pencihd-progress-container circle.progress {
    stroke: var(--pcaccent-cl);
    stroke-dasharray: 100;
    stroke-dashoffset: 100;
    transition: stroke-dashoffset 0.2s ease-out;
}
body.pczoomt-effect .standard-post-image,
body.pczoomt-effect .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image,
body.pczoomt-effect .widget ul.side-newsfeed li .side-item .side-image,
body.pczoomt-effect .grid-mixed .thumbnail,
body.pczoomt-effect .penci-grid li .item > .thumbnail,
body.pczoomt-effect .penci-masonry .item-masonry > .thumbnail {
  overflow: hidden;
}
body.pczoomt-effect .standard-post-image > a img,
body.pczoomt-effect .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a,
body.pczoomt-effect .widget ul.side-newsfeed li .side-item .side-image a,
body.pczoomt-effect .grid-mixed .thumbnail .penci-image-holder,
body.pczoomt-effect .penci-grid li .item > .thumbnail .penci-image-holder,
body.pczoomt-effect .penci-masonry .item-masonry > .thumbnail .penci-image-holder {
  transition: 0.5s all ease-in-out;
}
body.pczoomt-effect .standard-post-image > a:hover img,
body.pczoomt-effect .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a:hover,
body.pczoomt-effect .widget ul.side-newsfeed li .side-item .side-image a:hover,
body.pczoomt-effect .grid-mixed .thumbnail:hover .penci-image-holder,
body.pczoomt-effect .penci-grid li .item > .thumbnail:hover .penci-image-holder,
body.pczoomt-effect .penci-masonry .item-masonry > .thumbnail:hover .penci-image-holder {
  transform: scale(1.2);
}
.penci-visitor-count {
	position: fixed;
	max-width: calc( 100% - 60px );
	padding: 10px 20px 10px 35px;
	border-radius: 5px;
	box-shadow: 0px 0px 8px rgba(55,55,55,0.2);
	opacity: 0;
	transition: 0.3 all ease-in-out;
	transform: translateY(-30px);
	text-align: left;
	z-index: 999;
	font-size: 12px;
	font-weight: bold;
	background: url('images/fire.svg') 10px center;
	background-size: 20px auto;
	background-repeat: no-repeat;
	background-color: #fff;
}
.penci-visitor-count.active {
	opacity: 1;
	transform: translateY(0);
}
.penci-visitor-count.bottom-left {
	bottom: 30px;
	left: 30px;
}
.penci-visitor-count.bottom-right {
	bottom: 30px;
	right: 30px;
}
.penci-visitor-count.top-right {
	top: 30px;
	right: 30px;
}
.penci-visitor-count.top-left {
	top: 30px;
	left: 30px;
}
.penci-article-feedback {
	background-color: #f1f1f1;
	margin-top: 30px;
	padding: 15px;
	text-align: center;
	display: flex;
	align-items: center;
	justify-content: center;
	column-gap: 30px;
}
@media only screen and (max-width:767px) {
	.penci-article-feedback {
	  flex-direction: column;
	  row-gap: 10px;
	}
}  
.penci-afb-yn {
	display: flex;
  	flex-wrap: wrap;
}
.penci-afb-yn span {
	padding: 10px 20px;
	background-color: #fff;
	color: var(--pcheading-cl);
	cursor: pointer;
	font-size: 12px;
	transition: 0.3s all ease-in-out;
	display: flex;
  	justify-content: center;
  	align-items: center;
	column-gap: 5px;
}
.penci-afb-yn span svg {
	width: 15px;
  	height: auto;
	transition: 0.3s all ease-in-out;
}
.penci-afb-yn span + span svg {
	transform: rotate(180deg);
}
.penci-afb-yn span:hover {
	background-color: var(--pcaccent-cl);
	color: #fff;
}
.penci-afb-yn span:hover svg {
	fill: #fff;
}
.penci-afb-yn span i {
	font-style: normal;
}
.penci-afb-yn span i:before {
	content: '( ';
}
.penci-afb-yn span i:after {
	content: ' )';
}
.penci-afb-yn span:active {
	background-color: var(--pcaccent-cl);
	color: #fff;
}
.penci-afb-yn span:first-child {
	margin-right: 0.4em;
}
.penci-afb-yn span:last-child {
	margin-left: 0.4em;
}
.penci-article-feedback.penci-afb-disabled {
	pointer-events: none;
}
.penci-advcal-label {
	display: block;
}
.penci-advcal-mouse-disabled {
	pointer-events: none;
}
.penci-advcal-hidden {
	display: none;
}
.penci-advcal-form {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	justify-content: space-between;
}
.penci-advcal-form .penci-advcal-field-wrap {
	width: 100%;
}
.penci-advcal-el-radio-inline-yes {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	column-gap: 15px;
}
.penci-hsubmenu-overlay-wrapper {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 999;
	background: rgba(55,55,55,0.8);
	transition: 0.3s all ease-in-out;
	opacity: 0;
	visibility: hidden;
}
body.menu-hover .penci-hsubmenu-overlay-wrapper {
	opacity: 1;
	visibility: visible;
}
.show-search.pcbds-popup {
	opacity: 0;
	visibility: hidden;
	position: fixed;
	max-width: 999px;
	left: 50%;
	transform: translateX(-50%) translateY(-50%);
	top: calc(50% - 50px);
	padding: 40px;
	height: auto;
	z-index: 999999;
	transition: all 0.3s ease-in-out;
	display: block;
	height: initial !important;
}
.show-search.pcbds-popup.active {
	top: 50%;
	opacity: 1;
	visibility: visible;
}
.show-search.pcbds-popup form.pc-searchform input.search-input {
	position: static;
	border: 1px solid var(--pcborder-cl);
}
.show-search.pcbds-popup form.pc-searchform .pc-searchform-inner {
	display: flex;
	flex-direction: row;
	justify-content: space-between;
	gap: 15px;
	width: 100%;
}
.show-search.pcbds-popup form.pc-searchform .search-input {
	height: auto;
  	padding: 0 15px;
}
.show-search.pcbds-popup .close-search {
	--size: 22px;
	right: 10px;
  	top: 10px;
	width: var(--size);
	height: var(--size) !important;
  	line-height: var(--size) !important;
	color: var(--pcheading-cl);
	font-size: var(--size);
}
.show-search.pcbds-popup form.pc-searchform .searchsubmit {
  	display: block;
}
.show-search.pcbds-popup form.pc-searchform .searchsubmit:after {
	content: '\f105';
	font-family: 'FontAwesome';
	margin-left: 10px;
}
.show-search.pcbds-popup .penci-search-form form.penci-ajax-search button {
	font-size: 12px;
	height: 58px;
}
.pc-search-top-title {
	margin-bottom: 15px;
	font-size: 22px;
}
.pc-search-suggest-term {
	margin-top: 15px;
}
.pc-search-popup-overlay {
	position: fixed;
	top: 0;
	left: 0;
	right: 0;
	left: 0;
	z-index: 9999;
	width: 100vw;
	height: 100vh;
	background: rgba(17, 17, 17, 0.75);
	visibility: hidden;
	opacity: 0;
	margin: 0 !important;
	padding: 0 !important;
	transition: all 0.3s ease-in-out;
	backdrop-filter: blur(5px);
}
body.search-open .pc-search-popup-overlay {
	visibility: visible;
	opacity: 1;
}
.pc-search-recent-posts {
	margin-top: 30px;
}
.pc-search-recent-posts > h3 {
	margin-bottom: 15px;
	font-size: 18px;
}
@media only screen and (max-width: 960px) {
	.pc-search-recent-posts {
		display: none;
	}
	.show-search.pcbds-popup form.pc-searchform .pc-searchform-inner {
		flex-direction: column;
	}
}
body.pah-underline .entry-title a {
	background-image: linear-gradient(var(--pcaccent-cl) 0%, var(--pcaccent-cl) 98%);
	background-size: 0 3px;
	background-repeat: no-repeat;
	background-position: left 100%;
	word-break: break-word;
}
body.pah-underline .entry-title a:hover {
  	background-size: 100% 3px;
}
.penci-post-sticky-nav {
	position: fixed;
	top: 120px;
	left: 0;
	right: 0;
	background: rgba(255,255,255,0.99);
	z-index: 9999;
	opacity: 0;
	visibility: hidden;
	transition: 0.3s all ease-in-out;
	border-top: 1px solid var(--pcborder-cl);
	box-shadow: 0 5px 5px 0 rgba(181, 181, 181, 0.5);
}
.penci-post-sticky-nav .container {
	max-width: calc(100% - 60px);
	width: 100%;
}
.wrapper-boxed.enable-boxed .penci-post-sticky-nav {
	width: calc(var(--pcctain) + 60px);
	left: auto;
	right: auto;
}
.penci-post-sticky-nav.active {
	opacity: 1;
	visibility: visible;
}
.penci-post-sticky-nav-wrap {
	display: grid;
	grid-template-columns: 352px minmax(0, 1fr) 352px;
	align-items: center;
	padding-top: 10px;
	padding-bottom: 10px;
}
.penci-post-sticky-nav-wrap .next-post,
.penci-post-sticky-nav-wrap .prev-post {
	position: relative;
	display: flex;
	flex-wrap: wrap;
	align-items: center;
	grid-column: 1/2;
	word-wrap: break-word;
	word-break: break-word;
}
.penci-post-sticky-nav-wrap .next-post {
	padding-right: 30px;
}
.penci-post-sticky-nav-wrap .prev-post {
	padding-left: 30px;
}
.penci-post-sticky-nav-wrap .next-post-wrap:before,
.penci-post-sticky-nav-wrap .prev-post-wrap:before {
	content: '\f105';
	font-family: 'FontAwesome';
	position: absolute;
	right: 0;
	font-size: 22px;
	height: 100%;
	display: flex;
	align-items: center;
	color: var(--pcaccent-cl);
}
.penci-post-sticky-nav-wrap .prev-post-wrap:before {
	right: auto;
	left: 0;
	content: '\f104';
}
.penci-post-sticky-nav-wrap .next-post {
	flex-direction: row-reverse;
	grid-column: 3/4;
	justify-content: space-between;
}
.penci-post-sticky-nav-wrap .current-post {
	align-self: center;
	display: flex;
	grid-column: 2/3;
	justify-content: center;
	align-items: center;
}
.penci-post-sticky-nav-wrap .penci-post-nav-thumb {
	border-radius: 4px;
}
.snav-pwrap {
	display: flex;
	align-items: center;
}
.snav-pwrap .pagi-text {
	margin: 0;
}
.penci-post-sticky-nav .next-post-wrap {
	flex-direction: row-reverse;
}
.penci-post-sticky-nav .pagi-text h5 {
	color: var(--pcheading-cl);
	margin-top: 0;
}
.penci-post-sticky-nav .pagi-text h5:hover {
	color: var(--pcaccent-cl);
}
.penci-post-sticky-nav-wrap .current-post h4 {
	font-size: 20px;
	text-align: center;
}
.penci-post-sticky-nav-wrap .prev-post-wrap:after,
.penci-post-sticky-nav-wrap .next-post-wrap:after {
	content: "";
	width: 100%;
	max-width: 0;
	height: 2px;
	background: var(--pcaccent-cl);
	left: 0;
	position: absolute;
	transform: translateY(1px);
	transition: 0.3s all ease-in-out;
}
.penci-post-sticky-nav .prev-post .prev-post-wrap:before {
	transition: 0.3s all ease-in-out;
}
.penci-post-sticky-nav .prev-post:hover .prev-post-wrap:before {
	left: -10px;
}
.penci-post-sticky-nav .prev-post:hover .prev-post-wrap:after {
	max-width: 20px;
	left: -8px;
}
.penci-post-sticky-nav-wrap .next-post-wrap:after {
	right: 0;
	left: auto;
}
.penci-post-sticky-nav .next-post .next-post-wrap:before {
	transition: 0.3s all ease-in-out;
}
.penci-post-sticky-nav .next-post:hover .next-post-wrap:before {
	right: -10px;
}
.penci-post-sticky-nav .next-post:hover .next-post-wrap:after {
	max-width: 20px;
	right: -8px;
}
@media only screen and (max-width: 1170px) {
	.penci-post-sticky-nav-wrap {
		grid-template-columns: 50px minmax(0, 1fr) 50px;
    	gap: 10px;
	}
	.penci-post-sticky-nav-wrap .pnavi-inner,
	.penci-post-sticky-nav-wrap .penci-image-holder {
		display: none;
	}
}
@media only screen and (max-width: 767px) {
	.penci-post-sticky-nav {
		display: none;
	}
}
.penci-focus-mode-button {
	position: fixed;
	bottom: 20px;
	left: auto;
	right: 20px;
	background: #000;
	color: #fff;
	padding: 0 18px;
	border-radius: 0;
	font-size: 14px;
	font-weight: bold;
	cursor: pointer;
	z-index: 9999;
	height: 40px;
  	line-height: 40px;
	transition: 0.3s all ease-in-out;
}
.penci-focus-mode-icon::before {
	content: '\f2da';
	font-family: 'FontAwesome';
	margin-right: 6px;
	display: inline-block;
	font-size: 125%;
	vertical-align: middle;
}
.penci-focus-mode-button.left {
	left: 20px;
	right: auto;
}
body.penci-gtt-enable .penci-focus-mode-button.right{
	right: 70px;
}
body.rtl.penci-gtt-enable .penci-focus-mode-button.left{
	left: 70px;
}
body.penci-focus-mode .penci-breadcrumb,
body.penci-focus-mode .post-related,
body.penci-focus-mode .post-author,
body.penci-focus-mode .single-post-share,
body.penci-focus-mode .pcfb-wrapper,
body.penci-focus-mode .penci-sticky-sidebar,
body.penci-focus-mode .penci-post-sticky-nav,
body.penci-focus-mode .penci-ilrelated-posts,
body.penci-focus-mode .penci-header-wrap {
	display: none;
}
body.penci-focus-mode .penci-main-sticky-sidebar {
	min-height: initial !important;
}
body.penci-focus-mode .theiaStickySidebar {
	position: static !important;
}
body.penci-focus-mode {
	--pcbg-cl: #fff;
	background: var(--pcbg-cl);
}
body.penci-focus-mode .penci-single-block {
	margin: 60px 0;
}
body.penci-body-boxed.penci-focus-mode {
	background: var(--pcbg-cl);
}
body.penci-focus-mode.single .post {
	margin-bottom: 0;
	margin-top: 60px;
}
body.penci-focus-mode .container.penci_sidebar #main,
body.penci-focus-mode .penci-single-style-10 .penci-single-s10-content {
	width: 100%;
	margin: 0 auto;
	float: none;
	padding: 0;
	max-width: 770px;
}
body.penci-focus-mode .penci-focus-mode-button {
	background: var(--pcaccent-cl);
	color: #fff;
}
body.penci-focus-mode .wrapper-boxed.enable-boxed {
	box-shadow: unset;
  	webkit-box-shadow: unset;
  	-moz-box-shadow: unset;
}
body.penci-focus-mode #main article.post {
	margin: 0 !important
}
.penci-vscroll {
	overflow: hidden;
}
.penci_push_notification {
	padding: 30px;
	border: 1px solid var(--pcborder-cl);
	text-align: center;
	box-shadow: 0 3px 8px 0 rgba(55,55,55,0.1);
	background: #fcfcfc;
}
.post-entry .penci_push_notification p,
.penci_push_notification p {
	text-align: center;
	font-weight: bolder;
	margin-bottom: 15px;
}
.penci_push_notification .button {
	background: var(--pcaccent-cl);
	color: #fff;
	display: inline-block;
	padding: 5px 15px;
	text-decoration: none;
}
.penci_push_notification .button:hover {
	text-decoration: none;
	opacity: 0.8;
}
.penci-tiline-grid {
	display: flex;
	flex-wrap: wrap;
	margin: 0;
	margin-left: 0px;
	padding: 0;
	list-style: none;
}
.penci-tiline-item {
	width: 100%;
}
.penci-tiline-align-center .penci-tiline-item {
	width: 50%;
}
.penci-tiline .penci-tiline-item-main-container {
	padding-left: 50px;
	padding-bottom: 50px;
}
.penci-tiline .penci-tiline-thumbnail {
	overflow: hidden;
	position: relative;
	z-index: 2;
}
.penci-tiline .penci-tiline-thumbnail img {
	width: 100%;
	object-fit: cover;
}
.penci-tiline .penci-tiline-item-main-wrapper {
	position: relative;
	padding-left: 50px;
}
.penci-tiline
	.penci-tiline-item-main-wrapper
	.penci-tiline-item-main-container {
	padding-left: 50px;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-item-main {
	position: relative;
	background: #f1f1f1;
}
.penci-tiline.penci-tiline-posts .penci-tiline-item-main-wrapper .penci-tiline-item-main {
	background: #fff;
}
.penci-tiline.penci-tiline-posts .penci-biggrid .penci-bgitin {
	border: 1px solid var(--pcborder-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-title a,
.post-entry .penci-tiline.penci-tiline-posts .pcbg-title a {
	color: var(--pcheading-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-title a:hover,
.post-entry .penci-tiline.penci-tiline-posts .pcbg-title a:hover {
	color: var(--pcaccent-cl);
}
.penci-tiline.penci-tiline-posts .pcbg-readmore-sec .pcbg-readmorebtn {
	background: #555;
	color: #fff;
	font-weight: 600;
}
.penci-tiline.penci-tiline-posts .pcbg-readmore-sec .pcbg-readmorebtn:hover {
	background: #000;
}
.penci-tiline.penci-tiline-posts .grid-post-box-meta span:after {
	box-sizing: border-box;
	-webkit-box-sizing: border-box;
	width: 4px;
	height: 4px;
	border: 2px solid;
	border-radius: 2px;
	transform: translateY(-2px);
	-webkit-transform: translateY(-2px);
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line {
	position: absolute;
	top: 0;
	height: 100%;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-line span {
	height: 100%;
	position: absolute;
	transform: translateX(-50%);
	transform-origin: center;
	display: block;
	border-width: 2px;
	border-left-style: dashed;
	border-color: var(--pcborder-cl);
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
	position: absolute;
	top: 20px;
	transform: translate(-50%, -50%);
	left: 51px;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span {
	position: absolute;
	text-align: center;
	border: 4px solid color-mix(in srgb, var(--pcaccent-cl) 40%, #fff);
	transform: translate(-50%, -50%);
	border-radius: 50%;
	height: 48px;
	width: 48px;
	background: var(--pcaccent-cl);
	display: flex;
	align-items: center;
	justify-content: center;
}
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span i,
.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon span svg {
	color: #fff;
}
.penci-tiline .penci-tiline-meta {
	margin-bottom: 0;
}
.penci-tiline .penci-tiline-meta li {
	display: inline-block;
}
.penci-tiline .penci-tiline-title,
.penci-tiline .penci-tiline-excerpt,
.penci-tiline .penci-tiline-excerpt p {
	margin: 0;
	padding: 0;
}
.penci-tiline .penci-tiline-title {
	font-size: 18px;
}
.penci-tiline .penci-tiline-readmore {
	margin: 0;
}
.penci-tiline .penci-tiline-readmore svg {
	width: 1em;
	height: 1em;
	vertical-align: middle;
}
.penci-tiline .penci-tiline-arrow {
	position: absolute;
	width: 15px;
	height: 15px;
	transform: rotate(45deg);
	z-index: 0;
	top: 15px;
	left: -8px;
	background: #f1f1f1;
}
.penci-tiline
	.penci-tiline-item:nth-last-child(-n + 1)
	.penci-tiline-item-main-container {
	padding-bottom: 0;
}
.penci-tiline .penci-tiline-item:nth-last-child(-n + 1) .penci-tiline-line {
	display: none;
}
.penci-tiline-right .penci-tiline-item {
	margin-left: auto;
}
.penci-tiline-right .penci-tiline-item .penci-tiline-item-main-wrapper {
	padding-left: 0;
}
.penci-tiline-right
	.penci-tiline-item.left-part
	.penci-tiline-item-main-container,
.penci-tiline-right
	.penci-tiline-item.right-part
	.penci-tiline-item-main-container {
	padding-right: 50px;
	padding-left: 0;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-arrow,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-arrow {
	right: -8px;
	left: auto;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-line,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-line {
	right: 0;
}
.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-icon,
.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-icon {
	right: 0;
	left: auto;
}
.penci-tiline-right .penci-tiline-date {
	padding: 10px 50px;
}
.penci-tiline-icon svg {
	width: 1em;
	height: 1em;
}
.penci-tiline-desc {
	padding: 30px;
}
@media (max-width: 959px) {
	.penci-tiline-right .penci-tiline-item .penci-tiline-item-main-wrapper {
		padding-right: 55px;
	}
	.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-line,
	.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-line {
		right: 55px;
	}
	.penci-tiline-right .penci-tiline-item.left-part .penci-tiline-icon,
	.penci-tiline-right .penci-tiline-item.right-part .penci-tiline-icon {
		right: 55px;
		left: auto;
	}
}
@media (min-width: 960px) {
	.penci-tiline-center .penci-tiline-item .penci-tiline-item-main-wrapper {
		padding-left: 0;
	}
	.penci-tiline-center
		.penci-tiline-item.left-part
		.penci-tiline-item-main-container {
		padding-right: 50px;
		padding-left: 0;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-arrow {
		right: -8px;
		left: auto;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-line {
		right: 0;
	}
	.penci-tiline-center .penci-tiline-item.left-part .penci-tiline-icon {
		right: 0;
		left: auto;
	}
	.penci-tiline-center
		.penci-tiline-item.right-part
		.penci-tiline-item-main-container {
		padding-left: 50px;
		padding-right: 0;
	}
	.penci-tiline-center .penci-tiline-item.right-part .penci-tiline-icon {
		left: 0;
	}
	.penci-tiline-center .penci-tiline-date {
		padding: 5px 50px;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-child(-n + 2)
		.penci-tiline-item-main-container {
		padding-top: 0;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-child(-n + 2)
		.penci-tiline-icon {
		top: 22px;
	}
	.penci-tiline-center
		.penci-tiline-item:nth-last-child(-n + 2)
		.penci-tiline-item-main-container {
		padding-bottom: 0;
	}
	.penci-tiline-archive.penci-tiline-center .penci-tiline-date {
		margin-top: 5px;
	}
}
.penci-tiline figcaption {
	margin-bottom: 0;
}
@keyframes fadeIn {
	0% {
		opacity: 0;
		top: 70px;
	}
	100% {
		opacity: 1;
		top: 0;
	}
}
@keyframes liftUp {
	0% {
		top: 0;
	}
	100% {
		top: -15px;
	}
}
.post-entry .penci-tiline-meta,
.post-entry .penci-tiline-meta li {
	margin: 0;
	padding: 0;
}
.penci-tiline-meta,
.post-entry .penci-tiline-meta {
	list-style: none;
	font-size: 13px;
	padding: 10px 0;
}
.penci-tiline-meta li:not(:last-child),
.post-entry .penci-tiline-meta li:not(:last-child) {
	margin-right: 20px;
}
.penci-tiline-readmore,
.post-entry .penci-tiline-readmore {
	padding: 5px 15px;
	display: inline-block;
	background: var(--pcaccent-cl);
	color: var(--pcbg-cl);
	transition: 0.3 all ease-in-out;
	margin-top: 20px;
}
.penci-tiline-readmore:hover {
	opacity: 0.8;
}
.penci-tiline-item-date-wrap.right {
	text-align: right;
}
.penci-tiline .penci-tiline-icon span {
	background: #fff;
}
.penci-tiline .penci-tiline-date span {
	background: #1c1b1b;
	color: #fff;
	padding: 10px 15px;
	display: inline;
	box-decoration-break: clone;
  	-webkit-box-decoration-break: clone;
}
.penci-tiline-item--top .penci-tiline-content:after {
	border-top-color: #f1f1f1;
}
.penci-tiline-item--bottom .penci-tiline-content:after {
	border-bottom-color: #f1f1f1;
}
.penci-tiline--mobile .penci-tiline-content:after {
	border-right-color: #f1f1f1;
}
@media only screen and (max-width: 960px) {
	.penci-tiline-align-center .penci-tiline-item {
		width: 100%;
	}
	.penci-tiline-align-center .penci-tiline-item-date-wrap {
		display: none;
	}
	.penci-tiline .penci-tiline-item-main-wrapper {
		padding: 0;
	}
	.penci-tiline .penci-tiline-item-main-wrapper .penci-tiline-icon {
		left: 0;
	}
}
.penci-tiline {
	padding-top: 30px;
}
.penci-tiline-archive {
	padding-top: 60px;
	padding-bottom: 60px;
}
.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line {
	top: -30px;
	height: calc(100% + 30px);
}
.penci-tiline
	.penci-tiline-item:first-child
	.penci-tiline-item-main-wrapper
	.penci-tiline-line:before {
	width: 10px;
	height: 10px;
	content: "";
	background: var(--pcborder-cl);
	top: -20px;
	position: absolute;
	transform: translateX(-50%);
	z-index: 9;
	border-radius: 50%;
}
.penci-tiline-meta a,
.post-entry .penci-tiline-meta a {
	color: var(--pcheading-cl);
	text-decoration: none;
}
.post-entry .penci-tiline-item a {
	text-decoration: none;
}
.penci-tiline .penci-biggrid-wrapper .pcbg-content-inner {
	background: #fff;
}
.penci-tiline .penci-biggrid-wrapper,
.penci-tiline .penci-bgstyle-1 .penci-dflex .penci-bgitem {
	margin-bottom: 0;
}
.penci-tiline-item .pcbg-readmorebtn svg {
	max-height: 15px;
	width: auto;
}
.penci-post-box-timeline {
	padding-bottom: 0;
	border-bottom: 0;
	text-align: center;
}
.penci-post-box-timeline .penci-post-share-box {
	float: none;
	vertical-align: middle;
}
.penci-post-reactions {
	padding-top: 30px;
	margin-top: 30px;
	border-top: 5px solid var(--pcborder-cl);
}
.penci-post-reactions ul,
.penci-post-reactions ul li {
	list-style: none;
	padding: 0;
	margin: 0;
}
.penci-post-reactions ul {
	display: flex;
	justify-content: center;
	gap: 30px;
}
.penci-post-reactions img {
	width: 50px;
	height: auto;
	transform: scale(0.8);
	transition: all 0.15s ease-in-out;
}
.penci-post-reactions li:hover img {
	transform: scale(1);
}
.penci-post-reactions li {
	display: flex;
	flex-direction: column;
	justify-content: center;
	align-items: center;
}
.penci-post-reactions .penci-reaction-count {
	font-weight: bold;
	font-size: 12px;
	color: var(--pcmeta-cl);
}
.penci-post-reactions {
  	text-align: center;
}
.post-entry .penci-post-reactions-title {
	margin: 0;
	padding: 0;
}
.post-entry .penci-post-reactions-desc {
	font-size: 14px;
}
@media only screen and (max-width:767px) {
	.penci-post-reactions ul {
		gap: 10px;
	}
	.penci-post-reactions img {
		width: 30px;
	}
}