/* old-css inherit */
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-author,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-email {
	padding: 0 14px;
}
.woocommerce #review_form #respond p {
	margin: 0 14px 10px 14px;
}
.woocommerce #review_form #respond p.stars {
	margin-left: 0;
	margin-right: 0;
}
/* = Woocommerce
----------------------------------------------------*/
.woocommerce .page-title {
	margin: 0 0 30px 0;
	padding-bottom: 0;
	text-align: left;
	position: relative;
	font-size: 24px;
	color: #313131;
	text-transform: uppercase;
}
.woocommerce .page-description {
	margin: -10px 0 22px;
}
.woocommerce .woocommerce-ordering,
.woocommerce .woocommerce-result-count {
	margin: 0 0 30px;
	color: #888;
}
.woocommerce .woocommerce-ordering select {
	padding: 5px;
	outline: none;
}
.woocommerce span.onsale {
	min-width: 50px;
	min-height: 25px;
	height: 25px;
	line-height: 26px;
	left: 10px;
	top: 10px;
	background: var(--pcaccent-cl);
	text-align: center;
	padding: 0 10px;
	font-weight: var(--pchead-wei);
	font-size: 12px;
	text-transform: uppercase;
	color: #fff;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	font-family: var(--pchead-font);
	white-space: nowrap;
}
.woocommerce ul.products li.product .onsale {
	margin: 0;
	left: auto;
	right: 10px;
	top: 10px;
}
.woocommerce .products .star-rating {
	margin: 0;
	position: absolute;
	top: 16px;
	left: 10px;
	z-index: 5;
}
.woocommerce .star-rating span {
	color: #FFCA00;
}
.woocommerce.penci-image-hotspot .hotspot-product .star-rating {
	float: none;
	margin: 0 auto 8px;
}
.woocommerce #respond input#submit,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button {
	text-transform: uppercase;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	background: #F5F5F5;
	border-radius: 0;
	font-size: 12px;
	color: #313131;
	-o-transition: .3s;
	-moz-transition: .3s;
	-webkit-transition: .3s;
	transition: .3s;
	cursor: pointer;
	text-align: center;
	margin: 0;
	padding: 10px 15px 9px;
	border: none;
	outline: none;
	min-width: 90px;
}
.woocommerce a.added_to_cart {
	display: none !important;
}
.woocommerce #respond input#submit.loading:after,
.woocommerce a.button.loading:after,
.woocommerce button.button.loading:after,
.woocommerce input.button.loading:after {
	top: auto;
	right: auto;
	margin-left: 5px;
}
.woocommerce #respond input#submit:hover,
.woocommerce a.button:hover,
.woocommerce button.button:hover,
.woocommerce input.button:hover {
	background: var(--pcaccent-cl);
	color: #fff;
}
.woocommerce-pagination {
	margin-bottom: 60px;
	overflow: hidden;
	clear: both;
	text-align: center;
}
.woocommerce nav.woocommerce-pagination ul {
	list-style: none;
	display: inline-block;
	vertical-align: top;
	border: none;
	white-space: normal;
	margin: 0;
}
.woocommerce nav.woocommerce-pagination ul li,
.woocommerce .woocommerce-pagination ul.page-numbers li,
.woocommerce-page .woocommerce-pagination ul.page-numbers li {
	display: inline-block;
	float: left;
	margin-right: 10px;
	border: none;
}
.woocommerce nav.woocommerce-pagination ul > li:last-child,
.woocommerce .woocommerce-pagination ul.page-numbers li:last-child,
.woocommerce-page .woocommerce-pagination ul.page-numbers li:last-child {
	margin-right: 0;
}
.woocommerce nav.woocommerce-pagination ul li a,
.woocommerce nav.woocommerce-pagination ul li span {
	padding: 0;
	width: 30px;
	height: 30px;
	text-align: center;
	line-height: 28px;
	font-size: 14px;
	display: inline-block;
	border: 1px solid var(--pcborder-cl);
	color: #888;
	margin: 0;
	text-decoration: none;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
	-moz-transition: all 0.3s;
}
.woocommerce nav.woocommerce-pagination ul li a:focus,
.woocommerce nav.woocommerce-pagination ul li a:hover {
	text-decoration: none;
	color: #313131;
	border-color: #999999;
	background: none;
}
.woocommerce nav.woocommerce-pagination ul li span.current {
	color: #fff;
	background: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	text-decoration: none;
}
.woocommerce #content div.product div.images,
.woocommerce div.product div.images,
.woocommerce-page #content div.product div.images,
.woocommerce-page div.product div.images,
.woocommerce #content div.product div.summary,
.woocommerce div.product div.summary,
.woocommerce-page #content div.product div.summary,
.woocommerce-page div.product div.summary {
	width: 48.7197%;
}
.woocommerce div.product div.images, .woocommerce div.product div.summary {
	margin-bottom: 40px;
}
.woocommerce .penci_sidebar #content div.product div.images,
.woocommerce .penci_sidebar div.product div.images,
.woocommerce-page .penci_sidebar #content div.product div.images,
.woocommerce-page .penci_sidebar div.product div.images,
.woocommerce .penci_sidebar #content div.product div.summary,
.woocommerce .penci_sidebar div.product div.summary,
.woocommerce-page .penci_sidebar #content div.product div.summary,
.woocommerce-page .penci_sidebar div.product div.summary {
	width: 48.078%;
}
.woocommerce div.product div.images div.thumbnails,
.woocommerce div.product div.images .flex-control-thumbs {
	padding-top: 30px;
}
.woocommerce #content div.product div.thumbnails a,
.woocommerce div.product div.thumbnails a,
.woocommerce-page #content div.product div.thumbnails a,
.woocommerce-page div.product div.thumbnails a,
.woocommerce #content div.product div.thumbnails a.last,
.woocommerce div.product div.thumbnails a.last,
.woocommerce-page #content div.product div.thumbnails a.last,
.woocommerce-page div.product div.thumbnails a.last,
.woocommerce div.product div.images .flex-control-thumbs li {
	width: 21.0625%;
	margin-right: 5.25%;
	margin-bottom: 5.25%;
}
.woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image {
	width: 21.0625%;
}
.woocommerce #content div.product div.thumbnails a.first,
.woocommerce div.product div.thumbnails a.first,
.woocommerce-page #content div.product div.thumbnails a.first,
.woocommerce-page div.product div.thumbnails a.first {
	clear: none;
}
.woocommerce #content div.product div.thumbnails a:nth-child(4n+4),
.woocommerce div.product div.thumbnails a:nth-child(4n+4),
.woocommerce-page #content div.product div.thumbnails a:nth-child(4n+4),
.woocommerce-page div.product div.thumbnails a:nth-child(4n+4),
.woocommerce div.product div.images .flex-control-thumbs li:nth-child(4n+4),
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:nth-child(4n+5) {
	margin-right: 0;
}
.woocommerce #content div.product div.thumbnails a:nth-child(4n+1),
.woocommerce div.product div.thumbnails a:nth-child(4n+1),
.woocommerce-page #content div.product div.thumbnails a:nth-child(4n+1),
.woocommerce-page div.product div.thumbnails a:nth-child(4n+1),
.woocommerce div.product div.images .flex-control-thumbs li:nth-child(4n+1) {
	clear: both;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:first-child {
	width: 100%;
	margin-right: 0;
	margin-bottom: 30px;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:before {
	width: 7px;
	height: 7px;
	top: 11px;
	left: 11px;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:after {
	top: 18px;
	left: 22px;
}
.woocommerce div.product .product_title {
	font-size: 30px;
	color: var(--pcheading-cl);
	line-height: 1.2;
	margin-top: -4px;
	margin-bottom: 6px;
}
a.woocommerce-review-link {
	font-size: 14px;
	color: #888;
}
.woocommerce div.product .woocommerce-product-rating {
	margin-bottom: 8px;
}
.woocommerce div.product p.price {
	margin-bottom: 12px;
}
.woocommerce div.product p.price ins,
.woocommerce div.product span.price ins,
.woocommerce div.product p.price,
.woocommerce div.product span.price {
	text-decoration: none;
	color: var(--pcaccent-cl);
}
.woocommerce div.product p.price del,
.woocommerce div.product span.price del {
	display: inline-block;
	margin-right: 10px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] {
	position: relative;
	padding-top: 12px;
	margin-bottom: 24px;
}
.woocommerce div.product .entry-summary div[itemprop="description"]:before {
	content: "";
	width: 45px;
	height: 1px;
	position: absolute;
	top: 0;
	left: 0;
	background: var(--pcaccent-cl);
}
.woocommerce div.product .woocommerce-tabs #tab-description #tab-description {
	display: block !important;
}
.woocommerce div.product div[itemprop="description"] .entry-summary p:last-child,
.woocommerce div.product .woocommerce-tabs #tab-description > p:last-child {
	margin-bottom: 0;
}
.woocommerce div.product div[itemprop="description"] .entry-summary img,
.woocommerce div.product .woocommerce-tabs #tab-description img {
	max-width: 100%;
	height: auto;
}
.woocommerce div.product div[itemprop="description"] a:hover,
.woocommerce div.product .woocommerce-tabs #tab-description a:hover {
	text-decoration: underline;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h1,
.woocommerce div.product .entry-summary div[itemprop="description"] h2,
.woocommerce div.product .entry-summary div[itemprop="description"] h3,
.woocommerce div.product .entry-summary div[itemprop="description"] h4,
.woocommerce div.product .entry-summary div[itemprop="description"] h5,
.woocommerce div.product .entry-summary div[itemprop="description"] h6,
.woocommerce div.product .entry-summary div[itemprop="description"] hr,
.woocommerce div.product .woocommerce-tabs #tab-description h1,
.woocommerce div.product .woocommerce-tabs #tab-description h2,
.woocommerce div.product .woocommerce-tabs #tab-description h3,
.woocommerce div.product .woocommerce-tabs #tab-description h4,
.woocommerce div.product .woocommerce-tabs #tab-description h5,
.woocommerce div.product .woocommerce-tabs #tab-description h6,
.woocommerce div.product .woocommerce-tabs #tab-description hr,
.woocommerce-product-details__short-description h1,
.woocommerce-product-details__short-description h2,
.woocommerce-product-details__short-description h3,
.woocommerce-product-details__short-description h4,
.woocommerce-product-details__short-description h5,
.woocommerce-product-details__short-description h6,
.woocommerce-product-details__short-description hr {
	margin-bottom: 17px;
}
.woocommerce div.product div[itemprop="description"] p,
.woocommerce div.product .woocommerce-tabs #tab-description p,
.woocommerce-product-details__short-description p {
	margin-bottom: 17px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h1,
.woocommerce div.product .entry-summary div[itemprop="description"] h2,
.woocommerce div.product .entry-summary div[itemprop="description"] h3,
.woocommerce div.product .entry-summary div[itemprop="description"] h4,
.woocommerce div.product .entry-summary div[itemprop="description"] h5,
.woocommerce div.product .entry-summary div[itemprop="description"] h6,
.woocommerce div.product .woocommerce-tabs #tab-description h1,
.woocommerce div.product .woocommerce-tabs #tab-description h2,
.woocommerce div.product .woocommerce-tabs #tab-description h3,
.woocommerce div.product .woocommerce-tabs #tab-description h4,
.woocommerce div.product .woocommerce-tabs #tab-description h5,
.woocommerce div.product .woocommerce-tabs #tab-description h6,
.woocommerce-product-details__short-description h1,
.woocommerce-product-details__short-description h2,
.woocommerce-product-details__short-description h3,
.woocommerce-product-details__short-description h4,
.woocommerce-product-details__short-description h5,
.woocommerce-product-details__short-description h6 {
	color: #313131;
	clear: both;
	letter-spacing: 0;
	line-height: 1.3em;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h1,
.woocommerce div.product .woocommerce-tabs #tab-description h1,
.woocommerce-product-details__short-description h1 {
	font-size: 20px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h2,
.woocommerce div.product .woocommerce-tabs #tab-description h2,
.woocommerce-product-details__short-description h2 {
	font-size: 18px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h3,
.woocommerce div.product .woocommerce-tabs #tab-description h3,
.woocommerce-product-details__short-description h3 {
	font-size: 17px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h4,
.woocommerce div.product .woocommerce-tabs #tab-description h4,
.woocommerce-product-details__short-description h4 {
	font-size: 16px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h5,
.woocommerce div.product .woocommerce-tabs #tab-description h5,
.woocommerce-product-details__short-description h5 {
	font-size: 15px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] h6,
.woocommerce div.product .woocommerce-tabs #tab-description h6,
.woocommerce-product-details__short-description h6 {
	font-size: 14px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] hr,
.woocommerce div.product .woocommerce-tabs #tab-description hr,
.woocommerce-product-details__short-description hr {
	border: 0;
	height: 0;
	border-bottom: 1px solid #dedede;
	clear: both;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote,
.woocommerce-product-details__short-description blockquote {
	padding: 0;
	position: relative;
	margin: 0 0 20px 0;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote,
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote p,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote p,
.woocommerce-product-details__short-description blockquote,
.woocommerce-product-details__short-description blockquote p {
	font-size: 16px;
	color: #888;
	font-style: italic;
	line-height: 1.7;
	text-align: left;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote p,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote p,
.woocommerce-product-details__short-description blockquote p {
	margin: 0;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote,
.woocommerce-product-details__short-description blockquote {
	position: relative;
	padding: 0 0 0 40px;
	border: none !important;
	overflow: hidden;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote:before,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote:before,
.woocommerce-product-details__short-description blockquote:before {
	color: var(--pcaccent-cl);
	content: '\f101';
	font-family: 'penciicon';
	font-size: 22px;
	font-weight: normal;
	line-height: 1;
	font-style: normal;
	position: absolute;
	top: 6px;
	left: 0;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote cite,
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote .author,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote cite,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote .author,
.woocommerce-product-details__short-description blockquote cite,
.woocommerce-product-details__short-description blockquote .author {
	display: block;
	font-size: 12px;
	text-transform: uppercase;
	margin-top: 7px;
	color: var(--pcaccent-cl);
	font-style: normal;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	overflow: hidden;
	text-align: left;
	position: relative;
	z-index: 1;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote .author span,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote .author span,
.woocommerce-product-details__short-description blockquote .author span {
	position: relative;
	display: inline-block;
	padding: 0 10px 0 0;
}
.woocommerce div.product .entry-summary div[itemprop="description"] blockquote .author span:after,
.woocommerce div.product .woocommerce-tabs #tab-description blockquote .author span:after,
.woocommerce-product-details__short-description blockquote .author span:after {
	content: "";
	position: absolute;
	top: 50%;
	width: 90px;
	height: 1px;
	background: var(--pcaccent-cl);
	left: 100%;
	opacity: 0.8;
}
.woocommerce div.product .entry-summary div[itemprop="description"] ul,
.woocommerce div.product .entry-summary div[itemprop="description"] ol,
.woocommerce div.product .woocommerce-tabs #tab-description ul,
.woocommerce div.product .woocommerce-tabs #tab-description ol,
.woocommerce-product-details__short-description ul,
.woocommerce-product-details__short-description ol {
	padding-left: 36px;
	margin-bottom: 20px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] ul ul,
.woocommerce div.product .woocommerce-tabs #tab-description ul ul,
.woocommerce-product-details__short-description ul ul {
	margin: 2px 0;
	padding-left: 22px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] ol ol,
.woocommerce div.product .woocommerce-tabs #tab-description ol ol,
.woocommerce-product-details__short-description ol ol {
	margin: 2px 0;
	padding-left: 32px;
}
.woocommerce div.product .entry-summary div[itemprop="description"] ul li,
.woocommerce div.product .woocommerce-tabs #tab-description ul li,
.woocommerce-product-details__short-description ul li {
	margin-bottom: 7px;
	position: relative;
	list-style-type: square;
	line-height: 1.7;
}
.woocommerce div.product .entry-summary div[itemprop="description"] ol li,
.woocommerce div.product .woocommerce-tabs #tab-description ol li,
.woocommerce-product-details__short-description ol li {
	margin-bottom: 2px;
	list-style: decimal;
}
.woocommerce div.product .entry-summary div[itemprop="description"] table,
.woocommerce div.product .woocommerce-tabs #tab-description table,
.woocommerce-product-details__short-description table {
	width: 100%;
	margin-bottom: 22px;
	border-collapse: collapse;
	border-left: 1px solid #f5f5f5;
	border-right: 1px solid #f5f5f5;
}
.woocommerce div.product .entry-summary div[itemprop="description"] td,
.woocommerce div.product .entry-summary div[itemprop="description"] th,
.woocommerce div.product .woocommerce-tabs #tab-description td,
.woocommerce div.product .woocommerce-tabs #tab-description th,
.woocommerce-product-details__short-description td, th {
	padding: 12px;
	border-bottom: 1px #e9e9e9 solid;
}
.woocommerce div.product .entry-summary div[itemprop="description"] th,
.woocommerce div.product .woocommerce-tabs #tab-description th,
.woocommerce-product-details__short-description th {
	font-weight: bold;
	font-size: 14px;
	background: #f5f5f5;
}
.woocommerce div.product .entry-summary div[itemprop="description"] tr:hover,
.woocommerce div.product .woocommerce-tabs #tab-description tr:hover,
.woocommerce-product-details__short-description tr:hover {
	background: var(--pcbg-cl);
}
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
	font-size: 13px;
	min-width: 150px;
	padding: 0 15px;
	-moz-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	color: #fff;
	border: none;
	outline: none;
	background: #313131;
}
.woocommerce #respond input#submit.alt:hover,
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover {
	background: var(--pcaccent-cl);
	color: #fff;
}
.woocommerce div.product form.cart, .woocommerce div.product p.cart {
	margin-bottom: 30px;
}
.woocommerce div.product p.out-of-stock {
	font-size: 18px;
}
.woocommerce div.product form.cart div.quantity {
	margin-right: 20px;
}
.woocommerce .quantity .qty {
	padding: 3px 5px;
	width: 60px;
	line-height: 32px;
	outline: none;
	border: 1px solid var(--pcborder-cl);
	font-size: 18px;
	font-weight: var(--pchead-wei);
	font-family: var(--pchead-font);
}
.woocommerce div.product .product_meta {
	padding-top: 25px;
	border-top: 1px solid #DEDEDE;
}
.woocommerce div.product .product_meta > span {
	font-size: 14px;
	display: block;
	margin-bottom: 10px;
	color: #888;
}
.woocommerce div.product .product_meta > span a {
	color: #888;
}
.woocommerce div.product .product_meta > span a:hover {
	color: var(--pcaccent-cl);
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
	padding: 0 0 12px 0;
	margin: 0 0 24px 0;
	text-align: center;
	border-bottom: 1px solid #DEDEDE;
}
.woocommerce div.product .woocommerce-tabs ul.tabs:before,
.woocommerce div.product .woocommerce-tabs ul.tabs li:after,
.woocommerce div.product .woocommerce-tabs ul.tabs li:before {
	content: none;
	display: none;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li {
	background: none;
	border: none;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
	margin: 0;
	padding: 0 20px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
	padding: 5px 0;
	font-family: var(--pchead-font);
	font-size: 14px;
	color: #313131;
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a:hover {
	color: #888888;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active {
	background: none;
	border: none;
	color: var(--pcaccent-cl);
}
.woocommerce div.product .woocommerce-tabs .panel {
	margin-bottom: 50px;
}
.woocommerce div.product .woocommerce-tabs .panel > h2:first-child,
.woocommerce div.product .woocommerce-tabs .panel #reviews #comments h2,
.woocommerce div.product .woocommerce-tabs .panel #respond h3.comment-reply-title,
.woocommerce div.product .woocommerce-tabs .panel #respond .comment-reply-title {
	font-size: 18px;
	color: #313131;
	clear: both;
	letter-spacing: 0;
	line-height: 1.3em;
	margin-bottom: 17px;
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
	text-align: left;
	display: block;
}
.woocommerce div.product .woocommerce-tabs .panel #respond .comment-reply-title {
	margin-top: 24px;
	font-family: var(--pchead-font);
}
.woocommerce #review_form #respond p,
.woocommerce #review_form #respond .comment-form-rating {
	margin-left: 0;
	margin-right: 0;
}
.woocommerce #review_form #respond p.comment-notes {
	opacity: .5;
	color: var(--pctext-cl);
}
.woocommerce #review_form #respond p.comment-form-author {
	margin-right: 20px;
}
.woocommerce div.product .related > h2,
.woocommerce div.product .upsells > h2 {
	font-family: var(--pchead-font);
	font-size: 18px;
	font-weight: var(--pchead-wei);
	position: relative;
	z-index: 10;
	display: block;
	margin-bottom: 30px;
	padding: 0 0 15px;
	text-transform: uppercase;
	color: #313131;
	border-bottom: 1px solid #dedede;
}
.woocommerce div.product form.cart .variations td.label {
	padding-bottom: 15px;
}
.woocommerce div.product form.cart .variations select {
	margin-bottom: 15px;
}
.woocommerce div.product p.stock {
	font-size: 100%;
	margin-bottom: 20px;
}
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-author,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-email,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-url {
	width: 100%;
	max-width: 374px;
	padding: 0;
	float: none;
}
.woocommerce #review_form #respond textarea,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-author input,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-email input,
.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-url input {
	margin: 0;
}
.woocommerce #review_form #respond p.form-submit {
	margin-bottom: 0;
	margin-top: 20px;
	text-align: left;
}
.woocommerce #review_form #respond p.form-submit input[type="submit"] {
	padding: 15px 15px;
	font-size: 14px;
}
.woocommerce .comment-form p.stars a {
	color: #FFCA00;
}
.woocommerce .comment-form p.stars a:hover {
	color: #FFCA00;
}
.woocommerce #reviews #comments ol.commentlist li img.avatar {
	width: 60px;
	border: none;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	padding: 0;
	background: none;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text {
	margin-left: 80px;
	border: 1px solid var(--pcborder-cl);
	padding: 12px 20px;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text .meta {
	margin-bottom: 9px;
	color: #888888;
	font-size: 14px;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text p.meta {
	font-size: 13px;
}
.woocommerce #reviews #comments ol.commentlist li .comment-text .meta strong {
	font-size: 14px;
	color: #313131;
	text-transform: uppercase;
	font-family: var(--pchead-font);
}
.woocommerce #reviews #comments ol.commentlist li .comment-text div[itemprop="description"] > p:last-child {
	margin: 0;
}
.woocommerce .woocommerce-error,
.woocommerce .woocommerce-info,
.woocommerce .woocommerce-message {
	background: var(--pcbg-cl);
	border: 1px solid var(--pcborder-cl);
	border-top: 3px solid var(--pcaccent-cl);
	margin-bottom: 30px !important;
	padding-left: 56px;
}
.woocommerce .woocommerce-error:before, .woocommerce .woocommerce-info:before, .woocommerce .woocommerce-message:before {
	top: 1em;
	margin-top: 3px;
}
.woocommerce ul.cart_list li, .woocommerce ul.product_list_widget li {
	padding: 0 0 15px 0;
	margin: 0 0 15px;
	border-bottom: 1px solid #DEDEDE;
}
.woocommerce .widget_shopping_cart .cart_list li,
.woocommerce.widget_shopping_cart .cart_list li {
	padding-left: 0;
}
.woocommerce ul.cart_list li:last-child, .woocommerce ul.product_list_widget li:last-child {
	padding-bottom: 0;
	margin-bottom: 0;
	border: none;
}
.woocommerce .widget_shopping_cart .total, .woocommerce.widget_shopping_cart .total {
	margin-top: 20px;
	padding-top: 15px;
	font-size: 16px;
}
.woocommerce .widget_shopping_cart p.buttons,
.woocommerce.widget_shopping_cart p.buttons {
	margin-top: 15px;
}
.woocommerce .widget_shopping_cart p.buttons a,
.woocommerce.widget_shopping_cart p.buttons a,
.woocommerce .widget_price_filter .price_slider_amount .button {
	color: #fff;
	background: #313131;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
	-moz-transition: all 0.3s;
	font-size: 12px;
}
.woocommerce .widget_shopping_cart p.buttons a.checkout,
.woocommerce.widget_shopping_cart p.buttons a.checkout {
	margin-left: 16px;
}
.woocommerce .widget_shopping_cart p.buttons a:hover,
.woocommerce.widget_shopping_cart p.buttons a:hover,
.woocommerce .widget_price_filter .price_slider_amount .button:hover,
.woocommerce div.product form.cart .button:hover {
	opacity: 0.8;
	background: #313131;
	color: #fff;
	text-decoration: none;
}
.woocommerce ul.cart_list li a,
.woocommerce ul.product_list_widget li a {
	font-size: 16px;
	font-weight: var(--pchead-wei);
	margin-bottom: 10px;
	text-decoration: none;
	font-family: var(--pchead-font);
}
.woocommerce ul.cart_list li img,
.woocommerce ul.product_list_widget li img {
	width: 90px;
	margin: 0 20px 0 0;
	float: left;
}
.woocommerce ul.cart_list li .amount,
.woocommerce ul.product_list_widget li .amount {
	font-size: 18px;
	color: var(--pcaccent-cl);
	text-decoration: none;
}
.woocommerce ul.cart_list li del .amount,
.woocommerce ul.product_list_widget li del .amount {
	font-size: 16px;
	color: #ccc;
	margin-right: 5px;
}
.woocommerce ul.product_list_widget li ins,
.woocommerce ul.product_list_widget li ins {
	text-decoration: none;
}
.woocommerce ul.cart_list li .star-rating,
.woocommerce ul.product_list_widget li .star-rating {
	margin-bottom: 10px;
}
.woocommerce .widget_shopping_cart
.cart_list li a.remove,
.woocommerce.widget_shopping_cart
.cart_list li a.remove {
	font-size: 24px;
	line-height: 20px;
	width: 24px;
	height: 24px;
	margin-top: 5px;
	margin-left: 5px;
	text-align: center;
	border: 1px solid #ccc;
}
.woocommerce .widget_price_filter .ui-slider-horizontal {
	height: 6px;
	margin-bottom: 20px;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
	background-color: #DEDEDE;
}
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle {
	background-color: #313131;
	width: 18px;
	height: 18px;
	top: -6px;
}
.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
	background-color: #888;
}
.woocommerce .widget_price_filter .price_label {
	color: #888;
	font-size: 14px;
}
.woocommerce .woocommerce-product-search .screen-reader-text {
	display: none;
}
.woocommerce .woocommerce-product-search input[type="submit"] {
	display: none;
}
.woocommerce .woocommerce-product-search input[type="search"] {
	border: 1px solid var(--pcborder-cl);
	padding: 14px 20px 14px 20px;
}
.woocommerce table.shop_table {
	border: none;
	border-collapse: collapse;
	margin: 0 0 27px 0;
}
.woocommerce table.shop_table th {
	padding: 0 0 15px 0;
	font-weight: var(--pchead-wei);
	text-transform: uppercase;
	color: #313131;
	background: none;
	font-size: 14px;
	font-family: var(--pchead-font);
}
.woocommerce table.shop_table td {
	padding: 30px 0;
	border-color: var(--pcborder-cl);
	border-bottom: none;
}
.woocommerce-cart table.cart img {
	width: 90px;
}
.woocommerce table.shop_table a.remove {
	width: 30px;
	height: 30px;
	border: 1px solid var(--pcborder-cl);
	color: #dedede !important;
	border-radius: 50%;
	-webkit-border-radius: 50%;
	-moz-border-radius: 50%;
	background: none !important;
	line-height: 26px;
	font-size: 26px;
	text-decoration: none;
}
.woocommerce table.shop_table a.remove:hover {
	color: #ff0000 !important;
}
.woocommerce table.shop_table td.product-name a {
	font-size: 16px;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
	color: #313131;
	text-decoration: none;
}
.woocommerce table.shop_table td.product-name a:hover {
	color: var(--pcaccent-cl);
}
.woocommerce table.shop_table td.product-price span,
.woocommerce table.shop_table td.product-subtotal span {
	font-size: 18px;
	color: var(--pcaccent-cl);
}
.woocommerce table.shop_table .quantity .qty {
	line-height: 28px;
}
.woocommerce-cart table.cart td.actions .coupon .input-text {
	border: 1px solid #e9e9e9;
	padding: 12px 20px 11px;
	font-family: var(--pcbody-font);
	font-size: 12px;
	color: #313131;
	min-width: 150px;
	margin-right: 20px;
}
.woocommerce-cart table.cart input[type="submit"] {
	padding: 13px 20px 13px;
	font-size: 13px;
	background: #313131;
	color: #fff;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
	-moz-transition: all 0.3s;
}
.woocommerce-cart .woocommerce input.button[name="update_cart"] {
	color: #ffffff;
	background: #313131;
	opacity: 1;
	padding: 13px 20px 13px;
}
.woocommerce-cart .woocommerce input.button[name="update_cart"]:hover,
.woocommerce-cart table.cart input[type="submit"]:hover {
	background: #313131;
	color: #fff;
	opacity: 0.8;
}
.woocommerce .woocommerce-cart-form .cart .button[name="apply_coupon"],
.woocommerce .woocommerce-cart-form .cart button.button:disabled,
.woocommerce .woocommerce-cart-form .cart button.button:disabled[disabled] {
	padding: 13px 20px;
	line-height: 14px;
}
.woocommerce .cart-collaterals .cart_totals,
.woocommerce-page .cart-collaterals .cart_totals {
	width: 100%;
}
.woocommerce .cart-collaterals .cart_totals h2,
.woocommerce-page .cart-collaterals .cart_totals h2 {
	font-size: 16px;
	text-transform: uppercase;
}
.woocommerce-cart .cart-collaterals .cart_totals table {
	border-collapse: collapse;
	border: 1px solid var(--pcborder-cl);
	padding: 0 30px;
}
.woocommerce-cart .cart-collaterals .cart_totals table td,
.woocommerce-cart .cart-collaterals .cart_totals table th {
	background: none;
	padding: 15px 0;
}
.woocommerce-cart .cart-collaterals .cart_totals table td .amount {
	font-size: 18px;
	color: var(--pcaccent-cl);
}
.woocommerce-cart .cart-collaterals .cart_totals .form-row {
	padding: 0;
	margin-bottom: 15px;
}
.woocommerce-shipping-calculator p {
	margin-bottom: 10px;
}
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form select {
	padding: 5px;
	max-width: 400px;
	width: 100%;
}
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form input[type="text"],
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form input[type="date"],
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form input[type="number"],
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form input[type="search"] {
	max-width: 400px;
	padding: 8px;
}
.woocommerce .woocommerce-info:before {
	color: var(--pcaccent-cl);
	top: 1em;
}
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form button[type="submit"] {
	padding: 14px 20px;
	color: #fff;
	background: #313131;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
	-moz-transition: all 0.3s;
}
.woocommerce-cart .cart-collaterals .cart_totals table .shipping-calculator-form button[type="submit"]:hover {
	background: #313131;
	color: #fff;
	opacity: 0.8;
}
.woocommerce-cart .wc-proceed-to-checkout a {
	display: inline-block !important;
	padding-left: 20px !important;
	padding-right: 20px !important;
	background: #313131 !important;
	color: #fff !important;
	transition: all 0.3s;
	-webkit-transition: all 0.3s;
	-moz-transition: all 0.3s;
}
.woocommerce-cart .wc-proceed-to-checkout a:hover {
	opacity: 0.8;
}
.woocommerce form.checkout_coupon,
.woocommerce form.login,
.woocommerce form.register {
	border-radius: 0;
	border: 1px solid var(--pcborder-cl);
}
.woocommerce form .form-row .input-text,
.woocommerce-page form .form-row .input-text {
	line-height: 38px;
	padding: 0 20px;
	color: #313131;
	border: 1px solid var(--pcborder-cl);
}
p.lost_password {
	margin-bottom: 0 !important;
}
.woocommerce form.login .form-row {
	margin-bottom: 20px;
}
.woocommerce form .form-row input[type="submit"],
.woocommerce .return-to-shop .button {
	background: #313131;
	color: #fff;
	padding: 15px 20px;
}
.woocommerce form .form-row input[type="submit"]:hover,
.woocommerce .return-to-shop .button:hover {
	opacity: 0.8;
	background: #313131;
	color: #fff;
}
.woocommerce form.login .form-row input[type="submit"] {
	margin-right: 20px;
}
.woocommerce form.checkout .form-row {
	margin-bottom: 20px;
	padding: 0;
}
.woocommerce form .form-row {
	padding-left: 0;
	padding-right: 0;
}
.woocommerce form.checkout h3 {
	font-size: 16px;
	text-transform: uppercase;
}
.woocommerce form.checkout h3#order_review_heading {
	margin-top: 28px;
}
.woocommerce form.checkout table.shop_table {
	border: 1px solid var(--pcborder-cl);
}
.woocommerce form.checkout table.shop_table th,
.woocommerce form.checkout table.shop_table td {
	padding: 15px 30px;
}
.woocommerce form.checkout table.shop_table .amount {
	font-size: 16px;
}
.woocommerce form.checkout table.shop_table .order-total .amount {
	color: var(--pcaccent-cl);
}
.woocommerce-checkout #payment {
	background: none;
	border-radius: 0;
	-webkit-border-radius: 0;
	-moz-border-radius: 0;
}
.woocommerce-checkout #payment ul.payment_methods {
	padding: 30px;
	border: 1px solid var(--pcborder-cl);
}
.woocommerce-checkout #payment ul.payment_methods li {
	list-style: none !important;
}
.woocommerce-checkout #payment div.form-row.place-order {
	padding: 0;
	margin-top: 30px;
	margin-bottom: 0;
}
.woocommerce-checkout #payment div.payment_box {
	background: none;
	color: #888;
	padding: 0;
}
.woocommerce-checkout #payment div.payment_box:before {
	content: none;
	display: none;
}
.woocommerce #payment #place_order,
.woocommerce-page #payment #place_order {
	float: left;
}
.woocommerce form.lost_reset_password .form-row input[type="submit"],
.woocommerce form.register .form-row input[type="submit"] {
	margin-top: 20px;
}
section.related.products {
	clear: both;
}
@media only screen and (min-width: 961px) and (max-width: 1169px) {
	.woocommerce ul.products li.product h3,
	.woocommerce ul.products li.product .price ins,
	.woocommerce ul.products li.product .price,
	.woocommerce ul.cart_list li .amount,
	.woocommerce ul.product_list_widget li .amount {
		font-size: 16px;
	}
	.woocommerce div.product .product_title {
		font-size: 24px;
	}
}
@media only screen and (max-width: 960px) {
	.woocommerce div.product .product_title {
		font-size: 24px;
	}
}
@media only screen and (min-width: 768px) and (max-width: 960px) {
	.woocommerce ul.products.columns-5 li.product,
	.woocommerce-page ul.products.columns-5 li.product,
	.woocommerce ul.products.columns-4 li.product,
	.woocommerce-page ul.products.columns-4 li.product {
		width: 30.769%;
		margin-right: 3.8465%;
	}
	.woocommerce ul.products li.first, .woocommerce-page ul.products li.first,
	.woocommerce ul.products.columns-4 > li.product:nth-child( 4n+1 ),
	.woocommerce-page ul.products.columns-4 > li.product:nth-child( 4n+1 ) {
		clear: none;
	}
	.woocommerce ul.products.columns-5 > li.product:nth-child( 3n+1 ),
	.woocommerce-page ul.products.columns-5 > li.product:nth-child( 3n+1 ),
	.woocommerce ul.products.columns-4 > li.product:nth-child( 3n+1 ),
	.woocommerce-page ul.products.columns-4 > li.product:nth-child( 3n+1 ) {
		clear: both;
	}
	.woocommerce ul.products.columns-5 > li.product:nth-child( 4n+4 ),
	.woocommerce-page ul.products.columns-5 > li.product:nth-child( 4n+4 ),
	.woocommerce ul.products.columns-4 > li.product:nth-child( 4n+4 ),
	.woocommerce-page ul.products.columns-4 > li.product:nth-child( 4n+4 ) {
		margin-right: 3.8465%;
	}
	.woocommerce ul.products.columns-5 > li.product:nth-child( 3n+3 ),
	.woocommerce-page ul.products.columns-5 > li.product:nth-child( 3n+3 ),
	.woocommerce ul.products.columns-4 > li.product:nth-child( 3n+3 ),
	.woocommerce-page ul.products.columns-4 > li.product:nth-child( 3n+3 ) {
		margin-right: 0;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce .penci_sidebar #content div.product div.images,
	.woocommerce .penci_sidebar div.product div.images,
	.woocommerce-page .penci_sidebar #content div.product div.images,
	.woocommerce-page .penci_sidebar div.product div.images,
	.woocommerce .penci_sidebar #content div.product div.summary,
	.woocommerce .penci_sidebar div.product div.summary,
	.woocommerce-page .penci_sidebar #content div.product div.summary,
	.woocommerce-page .penci_sidebar div.product div.summary,
	.woocommerce #content div.product div.images,
	.woocommerce div.product div.images,
	.woocommerce-page #content div.product div.images,
	.woocommerce-page div.product div.images,
	.woocommerce #content div.product div.summary,
	.woocommerce div.product div.summary,
	.woocommerce-page #content div.product div.summary,
	.woocommerce-page div.product div.summary {
		width: 100% !important;
		float: none;
	}
	.woocommerce div.product .woocommerce-tabs ul.tabs li {
		display: block;
		margin-bottom: 10px;
	}
	.woocommerce ul.products li.product,
	.woocommerce-page ul.products li.product,
	.woocommerce ul.products.columns-4 li.product,
	.woocommerce-page ul.products.columns-4 li.product,
	.woocommerce .penci_sidebar ul.products.columns-4 li.product,
	.woocommerce-page .penci_sidebar ul.products.columns-4 li.product {
		width: 48%;
		margin-right: 4%;
	}
	.woocommerce .penci_sidebar ul.products.columns-4 > li.product:nth-child( 3n+1 ),
	.woocommerce-page .penci_sidebar ul.products.columns-4 > li.product:nth-child( 3n+1 ) {
		clear: none;
	}
	.woocommerce .penci_sidebar ul.products.columns-4 > li.product:nth-child( 3n+3 ),
	.woocommerce-page .penci_sidebar ul.products.columns-4 > li.product:nth-child( 3n+3 ) {
		margin-right: 4%;
	}
	.woocommerce ul.products li.product:nth-child(2n+2),
	.woocommerce-page ul.products li.product:nth-child(2n+2),
	.woocommerce ul.products.columns-4 li.product:nth-child(2n+2),
	.woocommerce-page ul.products.columns-4 li.product:nth-child(2n+2),
	.woocommerce .penci_sidebar ul.products.columns-4 > li.product:nth-child( 2n+2 ),
	.woocommerce-page .penci_sidebar ul.products.columns-4 > li.product:nth-child( 2n+2 ) {
		margin-right: 0;
	}
	.woocommerce ul.products li.product:nth-child(2n+1),
	.woocommerce-page ul.products li.product:nth-child(2n+1),
	.woocommerce ul.products.columns-4 li.product:nth-child(2n+1),
	.woocommerce-page ul.products.columns-4 li.product:nth-child(2n+1),
	.woocommerce .penci_sidebar ul.products.columns-4 > li.product:nth-child( 2n+1 ),
	.woocommerce-page .penci_sidebar ul.products.columns-4 > li.product:nth-child( 2n+1 ) {
		clear: both;
	}
	.woocommerce ul.products li.product h3,
	.woocommerce ul.products li.product .price ins,
	.woocommerce ul.products li.product .price,
	.woocommerce ul.cart_list li .amount,
	.woocommerce ul.product_list_widget li .amount,
	.woocommerce table.shop_table td.product-price span,
	.woocommerce table.shop_table td.product-subtotal span,
	.woocommerce-cart .cart-collaterals .cart_totals table td .amount {
		font-size: 16px;
	}
	.woocommerce table.cart td.actions .button,
	.woocommerce table.cart td.actions input,
	.woocommerce-page table.cart td.actions .button,
	.woocommerce-page table.cart td.actions input {
		width: auto;
	}
	.woocommerce #reviews #comments ol.commentlist li img.avatar {
		display: none;
	}
	.woocommerce #reviews #comments ol.commentlist li .comment-text {
		margin-left: 0;
	}
}
@media only screen and (max-width: 479px) {
	.woocommerce ul.products li.product,
	.woocommerce-page ul.products li.product,
	.woocommerce .penci_sidebar ul.products li.product,
	.woocommerce-page .penci_sidebar ul.products li.product {
		width: 100% !important;
		margin-right: 0 !important;
	}
	.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-author,
	.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-email,
	.woocommerce div.product .woocommerce-tabs .panel #respond p.comment-form-url {
		max-width: 300px;
	}
	.woocommerce table.shop_table th {
		font-size: 12px;
	}
	.woocommerce table.shop_table .quantity .qty {
		width: 46px;
		font-size: 14px;
	}
	.woocommerce-cart table.cart td.actions .coupon .input-text {
		width: 48%;
		margin-right: 0;
		margin-bottom: 20px;
	}
	.woocommerce table.shop_table a.remove {
		width: 20px;
		height: 20px;
		line-height: 18px;
		font-size: 20px;
	}
	.woocommerce table.shop_table td.product-name a {
		font-size: 14px;
		padding-left: 5px;
	}
}
/*************************************
 * Reset
 ************************************/
body {
	--pc-woo-quick-view-width: 960px;
	--pccat_tt_cl: var(--pctext-cl);
	--pccat_price_cl: var(--pcaccent-cl);
	--pccat_cat_cl: var(--pcmeta-cl);
	--pccat_cat_hv_cl: var(--pctext-cl);
	--pccat_btn_groups_bgcl: #fff;
	--pccat_btn_cl: var(--pctext-cl);
	--pccat_progress_bg_cl: #dedede;
	--pccat_progress_active_bg_cl: var(--pcaccent-cl);
	--pccat_progress_height: 7px;
	--pcpage_gtext_cl: var(--pctext-cl);
	--pcpage_glink_cl: var(--pcaccent-cl);
	--pcpage_glink_hv_cl: var(--pcaccent-cl);
	--pcpage_gbdr_cl: var(--pcborder-cl);
	--pcpage_btns_bdr_cl: var(--pcborder-cl);
	--pcpage_btns_bdr_hv_cl: var(--pcaccent-cl);
	--pcpage_btns_bg_cl: var(--pcaccent-cl);
	--pcpage_btns_bg_hv_cl: var(--pcaccent-cl);
	--pcpage_btn_atc_bg_cl: #000;
	--pcpage_btn_atc_bg_hv_cl: var(--pctext-cl);
	--pcpage_meta_cl: var(--pcmeta-cl);
	--pcpage_meta_link_cl: var(--pcmeta-cl);
	--pcpage_meta_link_hv_cl: var(--pctext-cl);
	--pcpage_tab_tt_cl: var(--pcmeta-cl);
	--pcpage_tab_tt_active_cl: var(--pctext-cl);
	--pcwp_tt_cl: var(--pctext-cl);
	--pcwp_btn_bg_cl: var(--pcaccent-cl);
	--pcwp_btn_bg_hv_cl: var(--pcaccent-cl);
	--pcwp_btn_alt_bg_cl: var(--pcmeta-cl);
	--pcwp_btn_alt_bg_hv_cl: var(--pcaccent-cl);
	--pcwc_ckout_inner_bg: #f1f1f1;
	--pcsl_tt_fs: 15px;
	--pcsl_tt_m_fs: 15px;
	--pcsl_tt_l_fs: var(--pcsl_tt_fs);
	--pcsl_tt_l_m_fs: var(--pcsl_tt_m_fs);
	--pcsl_meta_fs: 14px;
	--pcsl_meta_m_fs: 14px;
	--pcsl_price_fs: 14px;
	--pcsl_price_m_fs: 14px;
	--pcsl_btn_icon_size: 18px;
	--pcs_fsp_single_tt: 30px;
	--pcs_fsp_single_m_tt: 22px;
	--pcs_fsp_price: 18px;
	--pcs_fsp_m_price: 18px;
	--pcs_fsp_breadcrumb: 13px;
	--pcs_fsp_m_breadcrumb: 13px;
	--pcs_fsp_general: 14px;
	--pcs_fsp_tab_tt: 14px;
	--pcs_fsp_tab_m_tt: 14px;
	--pcs_fsp_meta: 14px;
	--pcs_fsp_m_meta: 14px;
	--pchd_mn_font: var(--pchead-font);
	--pchd_mn_font_w: var(--pchead-wei);
	--pclabel_hot: #fb1919;
	--pclabel_new: #8dd620;
	--pclabel_sale: var(--pcaccent-cl);
	--pclabel_outstock: maroon;
	--transition-delay: 0.04s;
	--pcsl_tt_lb_size: 12px;
	--pcsl_tt_lb_m_size: 12px;
	--pcl_o_bg: black;
	--pcl_o_opacity: 0.5;
	--pcl_o_tt_cl: #fff;
	--pcl_o_l_cl: #bfbfbf;
	--pcl_o_lhv_cl: #fff;
	--pcl_o_btn_cl: #fff;
	--pcsl_tt_btn4_size: 15px;
	--pcsl_tt_btn4_m_size: 12px;
	--pcsl_tt_btn3_size: 12px;
	--pcsl_tt_btn3_m_size: 12px;
	--pcsl_tt_btn5_size: 12px;
	--pcsl_tt_btn5_m_size: 12px;
	--pcl_3_atc_bg_cl: var(--pcaccent-cl);
	--pcl_3_atc_bg_hv_cl: var(--pcaccent-cl);
	--pcl_3_atc_txt_cl: #fff;
	--pcl_3_atc_txt_hv_cl: #fff;
	--pcl_btn_group_bg_color: #fff;
	--pcl_btn_group_bg_hv_color: #fff;
	--pcl_btn_group_txt_color: var(--pcheading-cl);
	--pcl_btn_group_txt_hv_color: var(--pcheading-cl);
	--pcl_5_btn_txt_cl: #fff;
	--pcl_5_btn_txt_hv_cl: var(--pcheading-cl);
	--pcl_5_btn_bd_cl: #fff;
	--pcl_5_btn_bd_hv_cl: #fff;
	--pcl_5_btn_bg_cl: transparent;
	--pcl_5_btn_bg_hv_cl: #fff;
	--pc-sidebar-w: 29.1%;
	--pcl_6_bg_cl: #fff;
	--pcl_6_tt_cl: var(--pcheading-cl);
	--pcl_6_txt_cl: var(--pctext-cl);
	--pcl_6_l_cl: var(--pcmeta-cl);
	--pcl_6_lhv_cl: var(--pcmeta-cl);
	--pcl_6_price_cl: var(--pccat_price_cl);
	--pcl_4_btn_txt_cl: white;
	--pcl_4_btn_txt_hv_cl: white;
	--pcl_4_btn_bg_cl: var(--pcaccent-cl);
	--pcl_4_btn_bg_hv_cl: var(--pcaccent-cl);
	--pcl_l_cat_fs: 14px;
	--pcl_l_cat_fs_m: 12px;
	--pcl_l_cat_tt_fs: 15px;
	--pcl_l_cat_tt_fs_m: 13px;
	--pc-w-mh: 275px;
	--pc-w-mhm: 275px;
	--pcl_l_cat_tt_cl: var(--pcheading-cl);
	--pcl_l_cat_cl: var(--pcmeta-cl);
	--pcl_l_cat_o_cl: rgba(255, 255, 255, 1);
	--pcl_l_cat_o_cl_rgba: linear-gradient(0deg, rgba(255, 255, 255, 1) 0%, rgba(255, 255, 255, 0.5) 50%, rgba(255, 255, 255, 0) 100%);
	--penci-scrollbar-track-bg: rgba(0, 0, 0, 0.05);
	--penci-scrollbar-thumb-bg: rgba(0, 0, 0, 0.12);
	--pc-sf-sum-w: 780px;
}
button, html input[type="button"], input[type="reset"], input[type="submit"] {
	cursor: pointer;
}
.text-center {
	text-align: center;
}

/*************************************
 * Slick Slider
 ************************************/
.slick-slider {
	position: relative;
}
.slick-slider .slick-arrow {
	position: absolute;
	top: 50%;
	bottom: 50%;
	z-index: 9;
	border: 0;
	font-size: 0;
	transition: 0.3s all ease-in-out;
	opacity: 0;
	background: transparent;
}
.slick-slider:hover .slick-arrow {
	opacity: 1;
}
.slick-slider .slick-arrow:before {
	content: "\f11a";
	font-family: 'penciicon';
	font-size: 20px;
}
.slick-slider .slick-arrow.slick-next {
	left: 0;
}
.slick-slider:hover .slick-arrow.slick-next {
	left: 15px;
}
.slick-slider .slick-arrow.slick-prev:before {
	content: "\f11b";
}
.slick-slider .slick-arrow.slick-prev {
	right: 0;
}
.slick-slider:hover .slick-arrow.slick-prev {
	right: 15px;
}
.slick-vertical .slick-slide {
	border: 0;
}
.slick-vertical .slick-slide > div {
	line-height: 0;
}
.slick-vertical .slick-slide figure {
	padding-top: 5px;
	padding-bottom: 5px;
}
/*************************************
 * Product Labels
 ************************************/
.woocommerce .product-labels {
	position: absolute;
	z-index: 2;
	top: 10px;
	right: 10px;
	left: auto;
	display: flex;
	flex-direction: column;
	flex-wrap: wrap;
	transition: all 0.3s cubic-bezier(.645, .045, .355, 1);
}
.woocommerce .product-labels .onsale {
	position: static;
	background-color: var(--pclabel_sale);
}
.woocommerce .product-labels .product-label,
.woocommerce .product-labels .new,
.woocommerce .product-labels .featured {
	line-height: 26px;
	min-width: 50px;
	height: 25px;
	min-height: 25px;
	padding: 0 10px;
}
.woocommerce .product-labels .featured {
	background-color: var(--pclabel_hot);
}
.woocommerce .product-labels .new {
	background-color: var(--pclabel_new);
}
.woocommerce .product-labels .out-of-stock {
	background-color: var(--pclabel_outstock);
}
.woocommerce .product-labels .product-label {
	font-family: var(--pchead-font);
	font-size: var(--pcsl_tt_lb_size);
	font-weight: var(--pchead-wei);
	position: static;
	text-align: center;
	text-transform: uppercase;
	color: #fff;
}
@media only screen and (max-width: 767px) {
	.woocommerce .product-labels .product-label {
		font-size: var(--pcsl_tt_lb_m_size);
	}
}
.woocommerce .product-labels .product-label + .product-label {
	margin-top: 5px;
}
.woocommerce .product-labels .product-label:last-child {
	margin-bottom: 0;
}
.woocommerce .product-labels.labels-round .product-label {
	display: inline-flex;
	align-items: center;
	justify-content: center;
	width: 50px;
	height: 50px;
	border-radius: 50%;
	line-height: 1.1;
}
.woocommerce .penci_sidebar ul.products.columns-4 .product-labels.labels-round .product-label {
	font-size: 11px;
	width: 35px;
	min-width: 35px;
	height: 35px;
}
.woocommerce .penci-single-product-top-container .product-labels {
	right: auto;
	left: 120px;
}
.woocommerce .penci-single-product-top-container .product-labels {
	right: auto;
	left: 10px;
}
.woocommerce .penci-content-quickview .product-labels {
	right: auto;
	left: 25px;
}
.woocommerce .thumbnail-left .penci-single-product-top-container .product-labels {
	left: 120px;
}
@media only screen and (max-width: 767px) {
	.woocommerce .penci-single-product-top-container .product-labels {
		top: 60px;
		right: 20px;
		left: auto;
	}
	.woocommerce .thumbnail-left .penci-single-product-top-container .product-labels {
		left: auto;
	}
}
/*************************************
 * WooCommerce Cart Form
 ************************************/
.woocommerce .price del,
.woocommerce ul.products li.product .price del {
	font-weight: normal;
	margin-right: 0;
	text-decoration: line-through;
}
.woocommerce-grouped-product-list.group_table {
	width: 100%;
	margin-bottom: 30px;
}
.woocommerce div.product form.cart table {
	border-top: 1px solid #ECECEC;
}
.woocommerce div.product form.cart .group_table tr {
	border-bottom: 1px solid #ECECEC;
}
.woocommerce div.product form.cart .group_table td {
	padding: 15px 0;
	vertical-align: middle;
}
.woocommerce div.product form.cart .group_table a {
	font-weight: bold;
	color: inherit;
}
.woocommerce div.product form.cart .group_table .woocommerce-grouped-product-list-item__label a {
	font-size: 16px;
}
.woocommerce div.product form.cart .woocommerce-grouped-product-list-item__price {
	font-size: 16px;
	text-align: right;
}
.woocommerce div.product form.cart bdi {
	font-weight: bold;
}
.woocommerce div.product form.cart ins {
	text-decoration: none;
}
.woocommerce div.product form.cart del bdi {
	font-weight: normal;
	opacity: .5;
}
.woocommerce #content div.product.penci-product-medium div.images,
.woocommerce div.product.penci-product-medium div.images,
.woocommerce-page #content div.product.penci-product-medium div.images,
.woocommerce-page div.product.penci-product-medium div.images {
	width: 55%;
}
.woocommerce #content div.product.penci-product-medium div.summary,
.woocommerce div.product.penci-product-medium div.summary,
.woocommerce-page #content div.product.penci-product-medium div.summary,
.woocommerce-page div.product.penci-product-medium div.summary {
	width: 40%;
}
.woocommerce #content div.product.penci-product-large div.images,
.woocommerce div.product.penci-product-large div.images,
.woocommerce-page #content div.product.penci-product-large div.images,
.woocommerce-page div.product.penci-product-large div.images {
	width: 62%;
}
.woocommerce #content div.product.penci-product-large div.summary,
.woocommerce div.product.penci-product-large div.summary,
.woocommerce-page #content div.product.penci-product-large div.summary,
.woocommerce-page div.product.penci-product-large div.summary {
	width: 35%;
}
.woocommerce #content div.product.penci-product-fullwidth-container div.images,
.woocommerce div.product.penci-product-fullwidth-container div.images,
.woocommerce-page #content div.product.penci-product-fullwidth-container div.images,
.woocommerce-page div.product.penci-product-fullwidth-container div.images {
	float: none;
	width: 100%;
}
.woocommerce #content div.product.penci-product-fullwidth-container div.summary,
.woocommerce div.product.penci-product-fullwidth-container div.summary,
.woocommerce-page #content div.product.penci-product-fullwidth-container div.summary,
.woocommerce-page div.product.penci-product-fullwidth-container div.summary {
	float: none;
	width: 100%;
}
.woocommerce #content div.product.penci-product-fullwidth .penci-single-product-top-container > .container,
.woocommerce div.product.penci-product-fullwidth .penci-single-product-top-container > .container,
.woocommerce-page #content div.product.penci-product-fullwidth .penci-single-product-top-container > .container,
.woocommerce-page div.product.penci-product-fullwidth .penci-single-product-top-container > .container {
	width: 100%;
	margin-right: 60px;
	margin-left: 60px;
}
@media only screen and (max-width: 767px) {
	.woocommerce #content div.product.penci-product-medium div.images,
	.woocommerce div.product.penci-product-medium div.images,
	.woocommerce-page #content div.product.penci-product-medium div.images,
	.woocommerce-page div.product.penci-product-medium div.images,
	.woocommerce #content div.product.penci-product-medium div.summary,
	.woocommerce div.product.penci-product-medium div.summary,
	.woocommerce-page #content div.product.penci-product-medium div.summary,
	.woocommerce-page div.product.penci-product-medium div.summary,
	.woocommerce #content div.product.penci-product-large div.images,
	.woocommerce div.product.penci-product-large div.images,
	.woocommerce-page #content div.product.penci-product-large div.images,
	.woocommerce-page div.product.penci-product-large div.images,
	.woocommerce #content div.product.penci-product-large div.summary,
	.woocommerce div.product.penci-product-large div.summary,
	.woocommerce-page #content div.product.penci-product-large div.summary,
	.woocommerce-page div.product.penci-product-large div.summary {
		width: 100%;
	}
}
.woocommerce .cart-collaterals + .cross-sells {
	width: 100%;
}
/*************************************
 * Product Catalog Style
 ************************************/
.products .penci-soledad-product .penci-product-loop-inner-content {
	position: relative;
}
.products .penci-soledad-product .star-rating {
	transition: all 0.3s ease-in-out;
}
.products .penci-soledad-product .penci-product-loop-top {
	position: relative;
}
.product-style-1 .penci-soledad-product .penci-product-loop-buttons {
	position: absolute;
	z-index: 2;
	right: 0;
	bottom: 10px;
	left: 0;
	visibility: hidden;
	/*padding: 10px;*/
	transition: opacity 0.3s ease, visibility 0.3s ease, transform 0.3s ease;
	-webkit-transform: translateY(-15px) translateZ(0);
	transform: translateY(-15px) translateZ(0);
	text-align: center;
	opacity: 0;
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden;
}
.product-style-1 .penci-soledad-product.penci-hover .penci-product-loop-buttons,
.product-style-1 .penci-soledad-product:hover .penci-product-loop-buttons {
	visibility: visible;
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 1;
}
.product-style-1 .penci-soledad-product .penci-product-loop-title {
	margin-top: 14px;
	text-align: center;
}
.product-style-1 .penci-soledad-product .penci-swatches-list {
	justify-content: center;
}
.products .penci-soledad-product .penci-product-loop-button {
	display: inline-flex;
	align-items: stretch;
	flex-direction: row;
	flex-wrap: nowrap;
	max-width: calc(100% - 20px);
	background-color: var(--pccat_btn_groups_bgcl);
	box-shadow: 1px 1px 1px rgba(0, 0, 0, 0.1);
}
.products.product-style-7 .penci-soledad-product .penci-product-loop-button {
	background-color: transparent;
}
.products .penci-soledad-product .penci-product-loop-button .button {
	color: var(--pccat_btn_cl);
}
.products .penci-soledad-product .penci-product-loop-button .button:hover {
	background-color: white;
}
.products .penci-soledad-product .penci-product-loop-button .loading:before {
	display: none;
}
.products .penci-soledad-product .penci-product-loop-button .button {
	position: relative;
}
.products .penci-product-loop-button .penci-tooltip:after,
.products .penci-product-loop-button .penci-tooltip {
	position: absolute;
	transition: all 0.3s ease;
	pointer-events: none;
	opacity: 0;
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden;
}
.products .penci-product-loop-button > p {
	display: none; /* display button only */
}
.products .penci-product-loop-button .penci-tooltip {
	font-size: 12px;
	font-weight: normal;
	line-height: 1;
	z-index: 10;
	right: auto;
	bottom: calc(100% + 10px);
	left: auto;
	min-width: 110px;
	padding: 8px 5px;
	white-space: nowrap;
	letter-spacing: normal;
	text-transform: none;
	color: #ffffff;
	border-radius: 4px;
	background: rgba(17, 17, 17, .9);
}
.products .penci-product-loop-button .penci-tooltip:after {
	right: 50%;
	bottom: -5px;
	left: 50%;
	width: 0;
	height: 0;
	margin-left: -5px;
	content: '';
	border-width: 5px 5px 0 5px;
	border-style: solid;
	border-color: rgba(17, 17, 17, .9) transparent transparent transparent;
}
.penci-product-loop-button .button:hover .penci-tooltip,
.penci-product-loop-button .button:hover .penci-tooltip:after {
	pointer-events: auto;
	opacity: 1;
}
.penci-product-loop-button .yith-wcwl-add-to-wishlist {
	display: inline-flex;
	flex: 1 1 auto;
	width: 100vw;
	max-width: 45px;
	margin: 0;
}
.penci-product-loop-button .yith-wcwl-add-to-wishlist span {
	display: none;
}
.penci-product-loop-button .yith-wcwl-add-to-wishlist a {
	font-size: 0;
	line-height: 0;
	position: relative;
	display: inline-flex;
	align-items: center;
	flex-direction: column;
	justify-content: center;
	width: 45px;
	height: 45px;
	margin: 0;
}
.penci-product-loop-button .button {
	display: inline-flex;
	flex: 1 1 auto;
	width: 100vw;
	min-width: 0;
	max-width: 45px;
	height: 45px;
	padding: 0;
	letter-spacing: 0;
	background: transparent;
}
.products.icon-style-round.icon-align-vertical.penci-small-width .penci-product-loop-buttons .button,
.products.icon-style-round.icon-align-vertical.penci-small-width .penci-product-loop-button .yith-wcwl-add-to-wishlist,
.products.penci-small-width.icon-align-vertical .penci-product-loop-button .button {
	width: 30px;
	height: 30px;
	max-width: 30px;
	flex: 0 0 30px;
}
.products.icon-style-round.icon-align-vertical.penci-small-width .yith-wcwl-add-to-wishlist a {
	width: 30px;
	height: 30px;
}
.products.icon-style-round.icon-align-vertical.penci-small-width .penci-product-loop-buttons .button:before,
.products.penci-small-width.icon-align-vertical .penci-product-loop-button .button:before {
	font-size: 13px;
}
.products.icon-style-round.icon-align-vertical.penci-small-width .penci-product-loop-button > a.button.loading:after {
	margin-top: -6px;
}
.woocommerce .penci-product-loop-button a.button,
.penci-product-loop-button > a {
	font-size: 0;
	line-height: 0;
	position: relative;
	display: inline-flex;
	align-items: center;
	flex-direction: column;
	justify-content: center;
	width: 42px;
	min-width: unset; /* old-css rule*/
	height: 42px;
	margin: 0;
	padding: 0;
	color: var(--pccat_btn_cl);
	background-color: var(--pccat_btn_groups_bgcl);
}
.woocommerce .penci-product-loop-button a.button:hover,
.penci-product-loop-button > a:hover {
	opacity: 0.8;
	color: black;
}
.penci-product-loop-button > a:before {
	font-family: "penciicon", serif;
	font-size: 16px;
	font-weight: 400;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
	animation: none;
}
.penci-product-loop-button .product_type_simple:before,
.penci-product-loop-button .product_type_variable:before,
.penci-product-loop-button .product_type_external:before,
.penci-product-loop-button .product_type_grouped:before,
.penci-product-loop-button .add_to_cart_button:before {
	content: "\f119";
}
.penci-product-loop-button .penci-quickview-button:before,
.penci-product-loop-button .yith-wcqv-button:before {
	content: "\f108";
}
.penci-product-loop-button .compare.button:before {
	content: "\f16b";
}
.penci-product-loop-button .penci-addtowishlist:before {
	content: "\f109";
}
.penci-product-loop-button .compare.button.added:before,
.penci-product-loop-button .penci-addtowishlist.added:before {
	content: "\f111";
}
.penci-product-loop-button .yith-wcwl-add-to-wishlist a:before {
	font-family: "penciicon", serif;
	font-size: 16px;
	font-weight: 400;
	content: "\f10b";
	color: black;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.penci-product-loop-button .yith-wcwl-add-to-wishlist.exists a:before {
	content: "\f111";
}
.products.icon-style-round.icon-align-vertical.penci-small-width .penci-product-loop-button .yith-wcwl-add-to-wishlist a:before {
	font-size: 13px;
}
.penci-product-loop-button .blockUI {
	display: none !important;
}
.woocommerce-loop-product__title.penci-loop-title a,
.penci-product-loop-title h3 a {
	color: var(--pccat_tt_cl);
}
.penci-product-loop-image {
	position: relative;
	overflow: hidden;
}
.penci-product-loop-image > img {
	display: none;
}
.penci-product-loop-image .penci-image-loader {
	position: absolute;
	z-index: 1;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	display: flex;
	justify-content: center;
	align-items: center;
	visibility: hidden;
	background: rgba(255, 255, 255, 0.6);
}
.penci-soledad-product.loading-image .penci-image-loader {
	visibility: visible;
}
.penci-soledad-product.loading-image .penci-product-loop-image .penci-image-loader:before {
	z-index: 2;
	top: 14px;
	right: 50%;
	left: 50%;
	display: block;
	width: 30px;
	height: 30px;
	margin: 0;
	content: " ";
	animation: lds-dual-ring 0.35s linear infinite;
	vertical-align: middle;
	opacity: 1;
	border: 1px solid #888;
	border-left-color: #000;
	border-top-color: #000;
	border-radius: 50%;
}
.penci-product-loop-image a img {
	width: 100%;
	margin: 0;
}
.penci-product-loop-image .hover-img,
.penci-product-loop-image .variations-img {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	display: flex;
	align-items: center;
	justify-content: center;
	transition: opacity 0.45s ease, transform 2s cubic-bezier(0, 0, 0.4, 1.46);
	opacity: 0;
	background-color: var(--pcbg-cl);
}
.penci-product-loop-image .variations-img {
	transition: none;
	opacity: 1;
}
.penci-product-loop-image .hover-img a {
	display: block;
	flex: 1 1 100%;
	width: 100%;
	max-width: 100%;
}
.woocommerce ul.products li.product .penci-product-loop-title .star-rating {
	position: relative;
	top: 0;
	left: 0;
	right: 0;
	margin-bottom: 10px;
}
.woocommerce ul.products.product-style-7 li.product .penci-product-loop-title .star-rating {
	margin-top: 10px;
	margin-bottom: 0;
}
.woocommerce ul.products.product-style-1 li.product .penci-product-loop-title .star-rating,
.woocommerce ul.products.product-style-3 li.product .penci-product-loop-title .star-rating,
.woocommerce ul.products.product-style-5 li.product .penci-product-loop-title .star-rating,
.woocommerce ul.products.product-style-7 li.product .penci-product-loop-title .star-rating {
	margin-left: auto;
	margin-right: auto;
}
ul.product-style-7 .penci-soledad-product:hover .penci-product-loop-image .hover-img,
ul.product-style-7 .penci-soledad-product.penci-hover .penci-product-loop-image .hover-img,
.penci-product-loop-top:hover .penci-product-loop-image .hover-img {
	-webkit-transform: scale(1.095);
	transform: scale(1.095);
	opacity: 1;
}
.products.product-style-2 .penci-product-loop-title {
	position: static;
}
.products.product-style-2 .product-title-top {
	position: absolute;
	top: 15px;
	left: 15px;
	right: 15px;
	z-index: 9;
}
.products.product-style-2 .penci-soledad-product .product-title-bottom {
	position: absolute;
	bottom: 15px;
	left: 15px;
	right: 15px;
	z-index: 9;
	overflow: hidden;
	max-height: 25px;
	transition: all 0.3s ease-in-out;
}
.products.product-style-2 .quick-shop-shown .penci-soledad-product .product-title-bottom {
	visibility: hidden;
}
.products.product-style-2 li.product.sale .penci-soledad-product .product-title-bottom {
	max-height: 40px;
}
.products.product-style-2 li.product.sale .penci-soledad-product .product-title-bottom,
.products.product-style-2 .penci-soledad-product.penci-hover .product-title-bottom,
.products.product-style-2 .penci-soledad-product:hover .product-title-bottom {
	max-height: 100px;
}
.products.product-style-2 .woocommerce-loop-product__title {
	text-align: left;
}
.products.product-style-2 .penci-product-loop-title .star-rating {
	position: relative;
	top: 0;
	left: 0;
}
.products.product-style-2 .penci-stock-progress-bar {
	width: calc(100% - 20px);
	padding: 10px;
	transition: all 0.3s ease-in-out;
	background-color: var(--pcbg-cl);
}
.products.product-style-2 .penci-soledad-product.penci-hover .penci-stock-progress-bar,
.products.product-style-2 .penci-soledad-product:hover .penci-stock-progress-bar {
	opacity: 0;
}
.products.product-style-2 .price del,
.products.product-style-2 .price ins {
	display: block;
}
.products.product-list .penci-product-loop-buttons,
.products.product-style-2 .penci-product-loop-buttons {
	position: absolute;
	z-index: 999;
	right: 10px;
	bottom: 10px;
	transition: all 0.3s ease;
	-webkit-transform: translateX(-20px) translateZ(0);
	transform: translateX(-20px) translateZ(0);
	opacity: 0;
}
.products.product-list .penci-product-loop-buttons .penci-product-loop-button,
.products.product-style-2 .penci-product-loop-buttons .penci-product-loop-button {
	flex-direction: column;
	max-width: none;
	padding-right: 0;
	padding-left: 0;
}
.products.product-list .penci-soledad-product .penci-product-loop-top:hover .penci-product-loop-buttons,
.products.product-style-2 .penci-soledad-product .penci-product-loop-top:hover .penci-product-loop-buttons {
	-webkit-transform: translateX(0) translateZ(0);
	transform: translateX(0) translateZ(0);
	opacity: 1;
}
.products.product-style-3 .onsale,
.products.product-style-6 .onsale {
	right: auto;
	left: 10px;
}
.products.product-style-3 .penci-product-loop-title,
.products.product-style-6 .penci-product-loop-title {
	margin-top: 15px;
}
.products.product-style-6 .woocommerce-loop-product__title,
.products.product-style-6 .price {
	text-align: left;
}
.products.product-style-3 .penci-product-loop-buttons,
.products.product-style-6 .penci-product-loop-buttons {
	position: absolute;
	top: 10px;
	right: 10px;
	transition: all 0.3s ease;
	-webkit-transform: translateX(-20px) translateZ(0);
	transform: translateX(-20px) translateZ(0);
	opacity: 0;
	z-index: 9;
}
.products.product-style-3 .penci-product-loop-buttons .penci-product-loop-button,
.products.product-style-6 .penci-product-loop-buttons .penci-product-loop-button {
	display: flex;
	flex-direction: column;
	max-width: none;
	padding-right: 0;
	padding-left: 0;
}
.products.product-style-3 .penci-soledad-product:hover .penci-product-loop-buttons,
.products.product-style-3 .penci-soledad-product.penci-hover .penci-product-loop-buttons,
.products.product-style-6 .penci-soledad-product:hover .penci-product-loop-buttons,
.products.product-style-6 .penci-soledad-product.penci-hover .penci-product-loop-buttons {
	-webkit-transform: translateX(0) translateZ(0);
	transform: translateX(0) translateZ(0);
	opacity: 1;
}
.products.product-style-3 .penci-product-loop-title {
	text-align: center;
}
.products.product-style-3 .penci-soledad-product .penci-swatches-list {
	margin-bottom: 10px;
	justify-content: center;
}
.products.product-style-3 .penci-soledad-product .penci-product-loop-image {
	overflow: hidden;
}
.products.product-style-3 .penci-soledad-product .penci-product-loop-image a.button,
.products.product-style-3 .penci-soledad-product a.add_to_cart_button {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	z-index: 9;
	opacity: 0.8;
	font-size: var(--pcsl_tt_btn3_size);
	background-color: var(--pcl_3_atc_bg_cl);
	color: var(--pcl_3_atc_txt_cl);
	transform: translate(0, 100%);
	-webkit-transform: translate(0, 100%);
	-moz-transform: translate(0, 100%);
	transition: 0.3s all ease-in-out;
}
.products.product-style-3 .penci-soledad-product .penci-product-loop-image a.button:hover,
.products.product-style-3 .penci-soledad-product a.add_to_cart_button:hover {
	color: var(--pcl_3_atc_txt_hv_cl);
	background-color: var(--pcl_3_atc_bg_hv_cl);
}
@media only screen and (max-width: 767px) {
	.products.product-style-3 .penci-soledad-product .penci-product-loop-image a.button,
	.products.product-style-3 .penci-soledad-product a.add_to_cart_button {
		font-size: var(--pcsl_tt_btn3_m_size);
	}
}
.products.product-style-3 .penci-soledad-product.quick-shop-loaded .penci-product-loop-image a.add_to_cart_button {
	visibility: hidden;
}
.products.product-style-3 .penci-soledad-product.penci-hover a.add_to_cart_button,
.products.product-style-3 .penci-soledad-product:hover a.add_to_cart_button {
	transform: translate(0, 0);
	-webkit-transform: translate(0, 0);
	-moz-transform: translate(0, 0);
}
.products.product-style-3 .penci-soledad-product.penci-hover a.add_to_cart_button:hover,
.products.product-style-3 .penci-soledad-product:hover a.add_to_cart_button:hover {
	opacity: 1;
}
.products.product-style-4 .onsale {
	right: auto;
	left: 10px;
}
.products.product-style-4 .penci-product-loop-title .button.loading:before {
	position: static;
	display: inline-block;
	margin: -2px 10px 0 0;
}
.products.product-style-4 .penci-product-loop-title .button {
	font-size: inherit;
	justify-content: left;
}
.products.product-style-4 .penci-product-loop-title .button.loading:after {
	display: none;
}
.products.product-style-4 .penci-product-loop-title {
	margin-top: 15px;
}
.products.product-style-4 .penci-product-loop-title .button {
	position: absolute;
	top: calc(100% - 35px);
	left: 0;
	min-width: unset;
	height: auto;
	margin: 0;
	padding: 6px 12px;
	background: var(--pcl_4_btn_bg_cl);
	transition: all 0.3s ease;
	-webkit-transform: translateY(15px) translateZ(0);
	transform: translateY(15px) translateZ(0);
	text-align: left;
	text-transform: none;
	opacity: 0;
	line-height: 1.3;
	color: var(--pcl_4_btn_txt_cl);
	font-size: var(--pcsl_tt_btn4_size);
	display: inline-block;
}
.products.product-style-4 .penci-product-loop-title .button:hover {
	color: var(--pcl_4_btn_txt_hv_cl);
	background: var(--pcl_4_btn_bg_hv_cl);
}
.products.product-style-4 .penci-product-loop-title .button.loading:before {
	background-color: transparent;
}
@media only screen and (max-width: 767px) {
	.products.product-style-4 .penci-product-loop-title .button {
		font-size: var(--pcsl_tt_btn4_m_size);
	}
}
.products.product-style-4 .penci-product-loop-title .price {
	transition: all 0.2s ease-in-out;
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 1;
	display: block;
	margin-top: 0;
}
.products.product-style-4 .penci-soledad-product.penci-hover .penci-product-loop-title .price,
.products.product-style-4 .penci-soledad-product:hover .penci-product-loop-title .price {
	-webkit-transform: translateY(-15px) translateZ(0);
	transform: translateY(-15px) translateZ(0);
	opacity: 0;
}
.products.product-style-4 .penci-soledad-product.penci-hover .penci-product-loop-title .button,
.products.product-style-4 .penci-soledad-product:hover .penci-product-loop-title .button {
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 1;
}
.products.product-style-4 .woocommerce-loop-product__title,
.products.product-style-4 .price {
	text-align: left;
}
.products.product-style-4 .penci-product-loop-buttons {
	position: absolute;
	top: 10px;
	right: 10px;
	transition: all 0.3s ease;
	-webkit-transform: translateX(-20px) translateZ(0);
	transform: translateX(-20px) translateZ(0);
	opacity: 0;
	z-index: 99;
}
.products.product-style-4 .penci-product-loop-buttons .penci-product-loop-button {
	display: flex;
	flex-direction: column;
	max-width: none;
	padding-right: 0;
	padding-left: 0;
}
.products.product-style-4 .penci-swatches-list {
	margin-bottom: 10px;
}
.products.product-style-4 .penci-soledad-product.penci-hover .penci-product-loop-buttons,
.products.product-style-4 .penci-soledad-product:hover .penci-product-loop-buttons {
	-webkit-transform: translateX(0) translateZ(0);
	transform: translateX(0) translateZ(0);
	opacity: 1;
}
.products.product-style-5 .penci-product-loop-top {
	position: relative;
}
.products.product-style-5 .penci-product-loop-top:before {
	position: absolute;
	z-index: 1;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	content: "";
	transition: all 0.3s ease;
	background-color: transparent;
}
.products.product-style-5 .penci-product-loop-top .penci-product-loop-extra-buttons {
	position: absolute;
	z-index: 2;
	top: 50%;
	right: auto;
	left: auto;
	width: 100%;
	text-align: center;
}
.products.product-style-5 .penci-product-loop-top .penci-product-loop-extra-buttons .button {
	display: inline-block;
	padding-right: 15px;
	padding-left: 15px;
	transition: all 0.3s ease;
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 0;
	color: var(--pcl_5_btn_txt_cl);
	border: 2px solid var(--pcl_5_btn_bd_cl);
	background-color: var(--pcl_5_btn_bg_cl);
	line-height: 38px;
	margin-top: 0;
	font-size: var(--pcsl_tt_btn5_size);
}
@media only screen and (max-width: 767px) {
	.products.product-style-5 .penci-product-loop-top .penci-product-loop-extra-buttons .button {
		font-size: var(--pcsl_tt_btn5_m_size);
	}
}
.products.product-style-5 .penci-product-loop-top .penci-product-loop-extra-buttons .button.loading {
	color: transparent;
}
.products.product-style-5 .penci-product-loop-top .penci-product-loop-extra-buttons .button.loading:hover .penci-loading-icon .bubble:after {
	background-color: var(--pctext-cl);
}
.products.product-style-5 .onsale {
	right: auto;
	left: 10px;
}
.products.product-style-5 .penci-product-loop-title {
	margin-top: 15px;
	text-align: center;
}
.products.product-style-5 .penci-product-loop-title .penci-swatches-list {
	justify-content: center;
	margin-bottom: 10px;
}
.products.product-style-5 .penci-product-loop-buttons {
	position: absolute;
	z-index: 3;
	top: 0;
	right: 0;
	transition: all 0.3s ease;
	-webkit-transform: translateX(-20px) translateZ(0);
	transform: translateX(-20px) translateZ(0);
}
.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button {
	display: flex;
	flex-direction: column;
	max-width: none;
	padding-right: 0;
	padding-left: 0;
	background-color: transparent;
	box-shadow: none;
}
.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button .button,
.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button .button:hover {
	background-color: transparent;
}
.woocommerce ul.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button a.loading:after {
	border-left-color: var(--pcl_o_btn_cl);
	border-top-color: var(--pcl_o_btn_cl);
}
.woocommerce ul.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button a:before,
.woocommerce ul.products.product-style-5 .penci-product-loop-buttons .penci-product-loop-button a:hover:before {
	color: var(--pcl_o_btn_cl);
}
.products.product-style-5 .penci-soledad-product .penci-product-loop-top:hover:before {
	background-color: var(--pcl_o_bg);
	opacity: var(--pcl_o_opacity);
}
.productsproduct-style-5 .penci-soledad-product .penci-product-loop-top:hover .penci-product-loop-buttons {
	-webkit-transform: translateX(0) translateZ(0);
	transform: translateX(0) translateZ(0);
	opacity: 1;
}
.products.product-style-5 .penci-soledad-product .penci-product-loop-top:hover .penci-product-loop-extra-buttons .button {
	-webkit-transform: translateY(-20px) translateZ(0);
	transform: translateY(-20px) translateZ(0);
	opacity: 1;
}
.products.product-style-5 .penci-product-loop-extra-buttons .button:hover {
	color: var(--pcl_5_btn_txt_hv_cl);
	background-color: var(--pcl_5_btn_bg_hv_cl);
	border-color: var(--pcl_5_btn_bd_hv_cl);
}
.products.product-style-6 .penci-product-loop-inner-content {
	background-color: var(--pcl_6_bg_cl);
	box-shadow: 0 0 4px rgba(0, 0, 0, 0.12);
	margin: 2px;
}
.products.product-style-6 .penci-product-loop-inner-content .penci-loop-title a {
	color: var(--pcl_6_tt_cl);
}
.products.product-style-6 .penci-product-loop-inner-content .penci-product-cats a {
	color: var(--pcl_6_l_cl);
}
.products.product-style-6 .penci-product-loop-inner-content .penci-product-cats a:hover {
	color: var(--pcl_6_lhv_cl);
}
.products.product-style-6 .penci-soledad-product .penci-product-loop-inner-content .price {
	color: var(--pcl_6_price_cl);
}
.products.product-style-6 .penci-product-loop-inner-content .penci-product-loop-title {
	padding: 0 15px 15px;
}
.products.product-style-6 .penci-soledad-product .penci-swatches-list {
	margin-bottom: 10px;
}
.products .penci-soledad-product .penci-swatches-list {
	align-items: center;
}
.products .penci-soledad-product .penci-stock-progress-bar {
	margin-top: 15px;
}
.products .penci-soledad-product h3,
.products .penci-soledad-product .woocommerce-loop-product__title {
	margin-bottom: 5px;
}
.products.product-standard .penci-soledad-product h3,
.products.product-standard .penci-soledad-product .woocommerce-loop-product__title {
	margin-top: 10px;
	text-align: center;
}
.products .penci-soledad-product .price {
	margin-top: 10px;
}
.products.product-standard .penci-soledad-product .price {
	display: block;
	text-align: center;
}
.products.product-standard .penci-soledad-product .button {
	display: block;
	margin: 0 auto;
}
.products.product-style-5 .penci-soledad-product .price {
	margin-top: 5px;
}
.products .penci-soledad-product .price ins,
.products .penci-soledad-product .price {
	font-weight: bold;
	text-decoration: none;
	color: var(--pccat_price_cl);
}
.products .penci-soledad-product .price del {
	opacity: 0.5;
	color: inherit;
}
.products .penci-soledad-product .penci-product-cats {
	margin-bottom: 7px;
}
.products.product-style-1 .penci-soledad-product .penci-product-cats,
.products.product-style-1 .penci-soledad-product .star-rating,
.products.product-standard .penci-soledad-product .penci-product-cats {
	text-align: center;
}
.products .penci-product-cats a {
	color: var(--pccat_cat_cl);
}
.products .penci-product-cats a:hover {
	color: var(--pccat_cat_hv_cl);
}
.penci-soledad-product .penci-swatches-list {
	display: flex;
	margin: 10px -4px 0;
}
.products.product-list .penci-soledad-product .penci-swatches-list {
	margin-bottom: 10px;
}
.products.product-style-1 .penci-soledad-product .penci-swatches-list {
	margin: 0 -3px 10px;
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item {
	font-size: 0;
	display: inline-flex;
	width: 15px;
	height: 18px;
	margin: 0 4px;
	cursor: pointer;
	text-indent: -999999px;
	border-radius: 50%;
	background-color: #f1f1f1;
	box-shadow: 0 1px 1px 0 rgba(55, 55, 55, 0.1);
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item.no-user-swatch,
.penci-soledad-product .penci-swatches-list .penci-swatch-item.label {
	text-indent: 0;
	font-size: 13px;
	line-height: 16px;
	text-align: center;
	justify-content: center;
	border-radius: 0;
	padding: 0 6px;
	width: auto;
	background-color: var(--pcbg-cl);
	border: 1px solid var(--pcpage_gbdr_cl);
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item.swatch-with-bg {
	font-size: 0;
	line-height: 0;
	width: 16px;
	height: 16px;
	margin: 0 4px;
	cursor: pointer;
	text-indent: -999999px;
	border-radius: 50%;
	border: 0;
	padding: 0;
	background-color: transparent;
	box-shadow: 0 0 0 0 transparent;
	transition: all 0.3s ease-in-out;
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item.swatch-with-bg.bg-image {
	width: 20px;
	height: 20px;
	border-radius: 0;
	background-size: cover;
}
.penci-soledad-product.loading-image .penci-swatches-list .penci-swatch-item {
	pointer-events: none;
}
.penci-soledad-product.active-custom-swatches .penci-swatches-list .penci-swatch-item:not(.swatch-with-bg) {
	opacity: .5;
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item:hover {
	opacity: .75;
}
.penci-soledad-product.active-custom-swatches .penci-swatches-list .penci-swatch-item.active-swatches {
	opacity: 1;
}
.penci-soledad-product .penci-swatches-list .penci-swatch-item.swatch-with-bg:hover,
.penci-soledad-product .penci-swatches-list .penci-swatch-item.swatch-with-bg.active-swatches {
	box-shadow: 0 0 0 1px var(--pcpage_gbdr_cl), inset 0 0 0 2px var(--pcbg-cl);
}
.penci-soledad-product .penci-swatches-divider {
	cursor: pointer;
	line-height: 15px;
	margin: 0 4px;
	transition: all 0.3s;
}
.penci-soledad-product .penci-swatches-divider:hover {
	opacity: 0.6;
}
.products.product-style-7 .penci-product-loop-title {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 9;
	color: #fff;
	padding: 15px 48px;
	display: flex;
	flex-wrap: wrap;
	flex-direction: column;
	justify-content: center;
	text-align: center;
	transition: 0.3s all ease-in-out;
	opacity: 0;
	visibility: hidden;
}
.products.product-style-7 .penci-product-loop-title:before {
	content: '';
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	background-color: var(--pcl_o_bg);
	opacity: var(--pcl_o_opacity);
	position: absolute;
	z-index: -1;
}
.products.product-style-7 .penci-soledad-product.penci-hover .penci-product-loop-title,
.products.product-style-7 .penci-soledad-product:hover .penci-product-loop-title {
	opacity: 1;
	visibility: visible;
}
.products.product-style-7.icon-style-round.icon-align-vertical .penci-product-loop-buttons {
	position: absolute;
}
.products.product-style-7.icon-style-round.icon-align-vertical .penci-product-loop-button,
.products.product-style-7.icon-style-round.icon-align-vertical .penci-product-loop-button a {
	background-color: transparent;
}
.products.product-style-7 .price,
.products.product-style-7 .penci-product-loop-title a {
	color: var(--pcl_o_tt_cl);
}
.products.product-style-7 .penci-product-loop-title .penci-product-cats a {
	color: var(--pcl_o_l_cl);
}
.products.product-style-7 .penci-product-loop-title .penci-product-cats a:hover {
	color: var(--pcl_o_lhv_cl);
}
.products.product-style-7.icon-align-horizontal .penci-product-loop-buttons {
	margin-top: 15px;
}
.products.product-style-7 .penci-swatches-list {
	justify-content: center;
}
.products.product-style-7.icon-align-horizontal .penci-product-loop-buttons .penci-product-loop-button,
.products.product-style-7.icon-align-horizontal .penci-product-loop-buttons .penci-product-loop-button a.button {
	background-color: transparent;
	box-shadow: none;
}
.products.product-style-7 .penci-product-loop-buttons .penci-product-loop-button a.button:before {
	color: var(--pcheading-cl);
}
.products.product-style-7.icon-style-round .penci-product-loop-buttons .penci-product-loop-button a.button:before {
	color: var(--pcl_o_btn_cl);
}
.products.product-style-7 .penci-product-loop-buttons .penci-product-loop-button a.button.loading:after {
	border-left-color: var(--pcl_o_btn_cl);
}
.products.product-style-7.icon-style-group.icon-align-vertical .penci-product-loop-buttons {
	position: absolute;
}
.penci-soledad-product.style-7 .penci-swatches-list .penci-swatch-item.no-user-swatch,
.penci-soledad-product.style-7 .penci-swatches-list .penci-swatch-item.label {
	color: #111;
}
.products.icon-align-horizontal .penci-product-loop-buttons {
	left: 10px;
	right: 10px;
}
.products.icon-align-horizontal .penci-product-loop-buttons .penci-product-loop-button {
	flex-direction: row;
	justify-content: center;
	padding: 0 8px;
}
.products.icon-align-horizontal .penci-product-loop-buttons .penci-product-loop-button .button {
	flex: 0 0 40px;
}
.products.icon-style-group.icon-align-vertical .penci-product-loop-buttons .penci-product-loop-button {
	flex-direction: column;
}
.products.icon-style-group.icon-align-vertical.icon-position-top-left .penci-product-loop-buttons {
	top: 10px;
	right: auto;
	left: 10px;
}
.products.icon-style-group.icon-align-vertical.icon-position-top-right .penci-product-loop-buttons {
	top: 10px;
	right: 10px;
	left: auto;
}
.products.icon-style-group.icon-align-vertical.icon-position-bottom-left .penci-product-loop-buttons {
	top: auto;
	right: auto;
	left: 10px;
	bottom: 10px;
}
.products.icon-style-group.icon-align-vertical.icon-position-bottom-right .penci-product-loop-buttons {
	top: auto;
	left: auto;
	right: 10px;
	bottom: 10px;
}
.products.icon-style-group .penci-product-loop-buttons {
	transition: 0.3s all ease-in-out;
	opacity: 0;
	visibility: hidden;
}
.products.icon-position-center-top .penci-product-loop-buttons,
.products.icon-position-center-center .penci-product-loop-buttons,
.products.icon-position-center-bottom .penci-product-loop-buttons {
	text-align: center;
}
.products.icon-style-group.icon-animation-move-right .penci-soledad-product .penci-product-loop-buttons {
	transform: translate(-15px, 0);
	-webkit-transform: translate(-15px, 0);
	-moz-transform: translate(-15px, 0);
}
.products.icon-style-group.icon-animation-move-left .penci-soledad-product .penci-product-loop-buttons {
	transform: translate(15px, 0);
	-webkit-transform: translate(15px, 0);
	-moz-transform: translate(15px, 0);
}
.products.icon-style-group.icon-animation-move-top .penci-soledad-product .penci-product-loop-buttons {
	transform: translate(0, 15px);
	-webkit-transform: translate(0, 15px);
	-moz-transform: translate(0, 15px);
}
.products.icon-style-group.icon-animation-move-bottom .penci-soledad-product .penci-product-loop-buttons {
	transform: translate(0, -15px);
	-webkit-transform: translate(0, -15px);
	-moz-transform: translate(0, -15px);
}
.products.icon-style-group.icon-animation-fade .penci-soledad-product .penci-product-loop-buttons {
	transform: translate(0, 0);
	-webkit-transform: translate(0, 0);
	-moz-transform: translate(0, 0);
}
.products.icon-style-group.icon-animation-zoom .penci-soledad-product .penci-product-loop-buttons {
	transform: scale(0.85);
	-webkit-transform: scale(0.85);
	-moz-transform: scale(0.85);
}
.products.icon-style-group .penci-soledad-product.penci-hover .penci-product-loop-buttons,
.products.icon-style-group .penci-soledad-product:hover .penci-product-loop-buttons {
	transform: translate(0, 0) scale(1);
	-webkit-transform: translate(0, 0) scale(1);
	-moz-transform: translate(0, 0) scale(1);
	opacity: 1;
	visibility: visible;
}
/*************************************
 * Product Icon Style
 ************************************/
.products.icon-style-round.icon-align-vertical .penci-product-loop-buttons {
	top: 0;
	right: 0;
	bottom: 5px;
	left: 0;
	display: flex;
	align-content: start;
	flex-wrap: wrap;
	justify-content: start;
	width: 60px;
	padding: 10px;
}
.products.icon-align-vertical .penci-soledad-product .penci-product-loop-button {
	max-width: unset;
}
.products.icon-align-horizontal.icon-position-center-top .penci-product-loop-buttons {
	top: 10px;
	bottom: auto;
	position: absolute;
}
.products.icon-align-horizontal.icon-position-center-center .penci-product-loop-buttons {
	top: 50%;
	bottom: 50%;
	margin-top: -20px;
	position: absolute;
}
.products.icon-align-horizontal.icon-position-center-bottom .penci-product-loop-buttons {
	top: auto;
	bottom: 10px;
	position: absolute;
}
.products.icon-style-round.icon-align-vertical.icon-position-top-right .penci-product-loop-buttons {
	left: auto;
	justify-content: flex-end;
}
.products.icon-style-round.icon-align-vertical.icon-position-bottom-left .penci-product-loop-buttons {
	align-content: flex-end;
}
.products.icon-style-round.icon-align-vertical.icon-position-bottom-right .penci-product-loop-buttons {
	left: auto;
	align-content: flex-end;
	justify-content: flex-end;
}
.products.icon-style-round.icon-align-vertical .penci-product-loop-buttons .button {
	flex: 0 0 40px;
}
.products.icon-style-round.icon-align-vertical .penci-product-loop-button {
	flex-direction: column;
	padding: 0;
}
.products.icon-style-round.icon-align-vertical .penci-product-loop-button .button {
	margin: 0 0 8px;
}
.products.icon-style-round.icon-align-vertical .penci-product-loop-button .button:last-child {
	margin-bottom: 0;
}
.products.icon-style-round .penci-product-loop-buttons {
	transition: all 0.3s cubic-bezier(.645, .045, .355, 1);
	-moz-transform: none;
	-webkit-transform: none;
	transform: none;
}
.products.icon-style-round .penci-product-loop-button {
	transition: all 0.3s cubic-bezier(.645, .045, .355, 1);
	background-color: transparent;
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}
.products.icon-style-round .penci-product-loop-button .button {
	visibility: hidden;
	width: 40px;
	height: 40px;
	margin: 0 2px;
	transition: all 0.3s cubic-bezier(0.645, 0.045, 0.355, 1);
	transform: translate3d(0, 0, 0);
	pointer-events: auto;
	opacity: 0;
	border-radius: 50%;
	background-color: var(--pcl_btn_group_bg_color);
}
.products.icon-style-round.icon-align-horizontal .penci-product-loop-button .button {
	margin: 2px;
}
.penci_sidebar .products.columns-4.icon-style-round .penci-product-loop-button .button {
	flex: 0 0 30px;
	width: 30px;
	height: 30px;
}
.penci_sidebar .products.columns-4.products.icon-style-round .penci-product-loop-button .button:before {
	font-size: 12px;
}
.products.icon-style-round.icon-animation-move-left .penci-product-loop-button .button {
	transform: translate3d(15px, 0, 0);
}
.products.icon-style-round.icon-animation-move-right .penci-product-loop-button .button {
	transform: translate3d(-15px, 0, 0);
}
.products.icon-style-round.icon-animation-move-bottom .penci-product-loop-button .button {
	transform: translate3d(0, -15px, 0);
}
.products.icon-style-round.icon-animation-move-top .penci-product-loop-button .button {
	transform: translate3d(0, 15px, 0);
}
.products.icon-style-round.icon-animation-zoom .penci-product-loop-button .button {
	transform: scale(0.5);
}
.products.icon-style-round .penci-soledad-product.penci-hover .penci-product-loop-button .button,
.products.icon-style-round .penci-soledad-product:hover .penci-product-loop-button .button {
	visibility: visible;
	transform: translate3d(0, 0, 0) scale(1);
	opacity: 1;
}
.products.icon-style-round:not(.product-standard) .penci-soledad-product .penci-product-loop-top:hover .star-rating,
.products.icon-style-round:not(.product-standard) .penci-soledad-product .penci-product-loop-top:hover .product-labels {
	opacity: 0;
}
.products.icon-style-round .penci-product-loop-button > a.button.loading:after {
	margin: -2px 0 0 -8px;
}
.penci_sidebar .products.columns-4.icon-style-round .penci-product-loop-button > a.button.loading:after {
	margin: -7px 0 0 -8px;
}
.products.icon-style-round .penci-soledad-product .penci-product-loop-button .button:nth-child(1) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.05s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.05s, color 0.3s, background 0.3s;
}
.products.icon-style-round .penci-soledad-product .penci-product-loop-button .button:nth-child(2) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.09s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.09s, color 0.3s, background 0.3s;
}
.products.icon-style-round .penci-soledad-product .penci-product-loop-button .button:nth-child(3) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.13s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.13s, color 0.3s, background 0.3s;
}
.products.icon-style-round .penci-soledad-product .penci-product-loop-button .button:nth-child(4) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.17s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.17s, color 0.3s, background 0.3s;
}
.products.icon-style-round.icon-animation-zoom .penci-soledad-product .penci-product-loop-button .button:nth-child(1) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.05s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.05s, color 0.3s, background 0.3s;
}
.products.icon-style-round.icon-animation-zoom .penci-soledad-product .penci-product-loop-button .button:nth-child(2) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.11s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.11s, color 0.3s, background 0.3s;
}
.products.icon-style-round.icon-animation-zoom .penci-soledad-product .penci-product-loop-button .button:nth-child(3) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.17s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.17s, color 0.3s, background 0.3s;
}
.products.icon-style-round.icon-animation-zoom .penci-soledad-product .penci-product-loop-button .button:nth-child(4) {
	transition: transform 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.23s, opacity 0.3s cubic-bezier(0.645, 0.045, 0.355, 1) 0.23s, color 0.3s, background 0.3s;
}
#yith-quick-view-modal .yith-wcqv-main {
	padding: 40px;
	box-shadow: none;
}
#yith-quick-view-close {
	font-size: 0;
	line-height: 0;
	width: 35px;
	height: 35px;
	opacity: 1;
	color: #f7f7f7;
	border: 0;
	background-color: #333;
}
#yith-quick-view-close:before {
	font-family: "penciicon", serif;
	font-size: 16px;
	font-weight: normal;
	line-height: 35px;
	content: "";
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
#yith-quick-view-close:hover {
	color: white;
	background-color: black;
}
.yith-wcwl-wishlistexistsbrowse .feedback {
	display: none;
}
/*************************************
 * Single Product
 ************************************/
.product.penci-woo-single-center {
	position: relative;
}
.product.penci-woo-single-center .summary.entry-summary {
	text-align: center;
}
.product.penci-woo-single-center form.cart div.quantity,
.product.penci-woo-single-center form.cart .button {
	float: none;
}
.penci-review-style-default {
	display: flex;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}
.woocommerce #reviews #comments ol.commentlist {
	padding: 0;
}
.woocommerce #reviews #comments ol.commentlist li {
	list-style: none;
}
.penci-review-style-default #comments,
.penci-review-style-default #review_form_wrapper {
	flex: 0 0 50%;
	max-width: 50%;
	padding-right: 15px;
	padding-left: 15px;
}
.woocommerce div.product .woocommerce-tabs .panel #respond .comment-reply-title {
	margin-top: 0;
}
.woocommerce-accordion-item .penci-review-style-default #comments .woocommerce-Reviews-title,
.product .woocommerce-accordion-item #respond .comment-reply-title {
	margin-top: 15px;
	font-size: var(--pcsl_tt_fs);
	font-family: var(--pchead-font);
	color: #313131;
	clear: both;
	letter-spacing: 0;
	line-height: 1.3em;
	margin-bottom: 15px;
	text-transform: uppercase;
	font-weight: var(--pchead-wei);
	text-align: left;
	display: block;
}
#respond .comment-form-cookies-consent label {
	vertical-align: middle;
}
.penci-extra-buttons .penci-addtowishlist.button,
.summary.entry-summary .compare.button {
	font-size: inherit;
	padding: 0;
	text-transform: none;
	color: inherit;
	background: transparent;
}
.penci-extra-buttons .penci-addtowishlist.button:hover,
.summary.entry-summary .compare.button:hover {
	color: inherit;
	background-color: transparent;
}
.penci-extra-buttons {
	padding-bottom: 15px;
}
.penci-extra-buttons .yith-wcwl-add-to-wishlist,
.penci-extra-buttons .penci-addtowishlist.button,
.penci-extra-buttons .woocommerce.product.compare-button {
	display: inline-block;
}
.woocommerce .penci-extra-buttons > .button {
	margin-right: 20px;
}
.woocommerce .penci-extra-buttons > .button:last-child {
	margin-right: 0;
}
.penci-extra-buttons a,
.penci-extra-buttons .compare.button {
	font-weight: var(--pchead-wei);
	vertical-align: middle;
	color: black;
}
.penci-extra-buttons .penci-addtowishlist.button:before,
.penci-extra-buttons .compare.button:before {
	font-family: "penciicon", serif;
	font-weight: normal;
	/*line-height: 1;*/
	display: inline-block;
	margin-right: 5px;
	content: "\f16a";
	vertical-align: top;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.penci-extra-buttons .penci-addtowishlist.button:before {
	content: '\f109';
}
.penci-extra-buttons .penci-addtowishlist.button.loading:before,
.penci-extra-buttons .compare.button.loading:before {
	position: static;
	display: inline-block;
	margin: -2px 5px 0 0;
}
.penci-extra-buttons .penci-addtowishlist.button.added:before,
.penci-extra-buttons .compare.button.added:before {
	content: '\f111';
}
.penci-extra-buttons .penci-addtowishlist.button.added:after,
.penci-extra-buttons .compare.button.added:after {
	display: none;
}
.penci-extra-buttons .penci-addtowishlist.button.loading:after,
.penci-extra-buttons .compare.button.loading:after {
	display: none;
}
.products.columns-4 .product {
	margin-bottom: 30px;
}
/*************************************
 * Penci Quickview
 ************************************/
.penci-content-quickview {
	position: relative;
	width: auto;
	max-width: var(--pc-woo-quick-view-width);
	margin: 20px auto;
	padding: 20px;
	-moz-transition: all 0.3s ease;
	-webkit-transition: all 0.3s ease;
	transition: all 0.3s ease;
	-webkit-transform: translateY(100px);
	transform: translateY(100px);
	opacity: 0;
	background: var(--pcbg-cl);
}
.penci-content-quickview .woocommerce-product-gallery__image > a,
.penci-content-quickview .penci-product-gallery-slider .woocommerce-product-gallery__image > a {
	pointer-events: none;
}
.penci-content-quickview button.mfp-close,
.penci-content-quickview button.mfp-arrow {
	line-height: 40px;
	top: 0;
	right: 0;
	width: 40px;
	height: 40px;
	transition: all 0.3s;
	opacity: 1;
	color: var(--pctext-cl);
	background: none;
	font-size: 32px;
	opacity: 0.7;
}
.penci-content-quickview button.mfp-close:hover,
.penci-content-quickview button.mfp-arrow:hover {
	opacity: 0.6;
}
.penci-content-quickview .product {
	overflow: hidden;
}
.penci-content-quickview .product.hide-variable .woocommerce-variation-description {
	display: none;
}
.woocommerce .penci-content-quickview div.product {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}
.woocommerce .penci-content-quickview div.product div.images,
.woocommerce .penci-content-quickview div.product div.summary {
	float: none;
	flex: 0 0 auto;
	width: 50%;
	padding-right: 15px;
	padding-left: 15px;
}
.woocommerce .penci-content-quickview div.product div.images,
.woocommerce .penci-content-quickview div.product div.summary,
.woocommerce .penci-content-quickview div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:first-child {
	margin-bottom: 0;
}
.woocommerce .penci-content-quickview div.product div.summary {
	overflow: hidden;
	overflow-y: auto;
	max-height: 600px;
}
.woocommerce .penci-content-quickview div.product.no-product-gallery div.summary {
	max-height: 445px;
}
.quick-view-wrapper.mfp-ready .penci-content-quickview {
	-webkit-transform: translateY(0);
	transform: translateY(0);
	opacity: 1;
}
.quick-view-wrapper.mfp-removing .penci-content-quickview {
	-webkit-transform: translateY(-100px);
	transform: translateY(-100px);
	opacity: 0;
}
.quick-view-wrapper .penci-content-quickview .product {
	display: flex;
	flex-wrap: wrap;
	flex-direction: column;
}
.quick-view-wrapper .penci-content-quickview .product .entry-summary-wrapper {
	width: 50%;
	flex: 0 0 auto;
	padding: 0 15px;
	position: relative;
}
.quick-view-wrapper .penci-content-quickview .product .entry-summary-wrapper .summary.entry-summary {
	width: 100%;
	max-height: unset;
	padding: 0 15px;
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	overflow: hidden;
	overflow-y: auto;
}
.hidden {
	display: none !important;
	visibility: hidden !important;
}
@media only screen and (max-width: 767px) {
	.mfp-container {
		padding-left: 0;
		padding-right: 0;
	}
	.penci-content-quickview {
		margin: 10px;
	}
	.penci-content-quickview .woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider {
		display: none;
	}
	.splide__arrows button {
		opacity: 1;
	}
	.splide__arrows button svg {
		max-width: 20px;
	}
	.woocommerce .penci-content-quickview div.product {
		flex-direction: column;
	}
	.woocommerce .penci-content-quickview div.product div.images,
	.woocommerce .penci-content-quickview div.product div.summary,
	.quick-view-wrapper .penci-content-quickview .product .entry-summary-wrapper {
		width: 100%;
	}
	.quick-view-wrapper .penci-content-quickview .product .entry-summary-wrapper .summary.entry-summary {
		position: relative;
		margin-top: 15px;
	}
}
/* Swatches */
.penci-swatches .swatch {
	line-height: 26px;
	position: relative;
	display: inline-block;
	width: 26px;
	height: 26px;
	margin-right: 8px;
	cursor: pointer;
	-moz-transition: all 0.3s;
	-o-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	text-align: center;
	white-space: nowrap;
	-moz-border-radius: 50%;
	-webkit-border-radius: 50%;
	border-radius: 50%;
	vertical-align: top;
}
.penci-swatches .swatch:last-child {
	margin-right: 0;
}
.penci-swatches .swatch.disabled {
	cursor: default;
	opacity: 0.1 !important;
}
.penci-swatches .swatch.disabled .swatch__tooltip {
	display: none;
}
.penci-swatches .swatch-color {
	text-indent: -9999em;
	transition: 0.3s all ease-in-out;
	box-shadow: 0 0 0 0 transparent;
}
.penci-swatches .swatch-color.selected {
	opacity: 1;
	box-shadow: 0 0 0 1px var(--pcpage_gbdr_cl), inset 0 0 0 5px var(--pcbg-cl);
}
.penci-swatches .swatch-label {
	font-size: 14px;
	width: auto;
	height: auto;
	padding: 1px 10px;
	color: var(--pctext-cl);
	border: 1px solid var(--pcpage_btns_bdr_cl);
	background-color: var(--pcbg-cl);
	border-radius: 2px;
	transition: all 0.3s ease-in-out;
}
.penci-swatches .swatch-label:hover,
.penci-swatches .swatch-label.selected {
	color: #fff;
	background-color: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
}
.penci-swatches .swatch-image {
	font-size: 0;
	border-radius: 0;
	box-shadow: 0 0 0 0 transparent;
}
.penci-swatches .swatch-image.selected {
	box-shadow: 0 0 0 1px var(--pcpage_gbdr_cl), inset 0 0 0 5px var(--pcbg-cl);
}
.penci-swatches .swatch-image .swatch__tooltip {
	font-size: 14px;
}
.penci-swatches .swatch__tooltip {
	font-size: 14px;
	line-height: 1.3;
	font-weight: 500;
	position: absolute;
	z-index: 2;
	top: 0;
	left: 50%;
	visibility: hidden;
	margin: -10px 0 0 0;
	padding: 6px 10px;
	user-select: none;
	-moz-transition: all 0.3s;
	-o-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	-moz-transform: translate(-50%, -100%);
	-webkit-transform: translate(-50%, -100%);
	transform: translate(-50%, -100%);
	text-indent: initial;
	opacity: 0;
	color: #fff;
	background: #333;
}
.penci-swatches .swatch__tooltip:after {
	position: absolute;
	bottom: -3px;
	left: 50%;
	width: 6px;
	height: 6px;
	margin-left: -3px;
	content: "";
	-moz-transform: rotate(45deg);
	-webkit-transform: rotate(45deg);
	transform: rotate(45deg);
	background: #333;
}
.penci-swatches .swatch:hover .swatch__tooltip {
	visibility: visible;
	user-select: auto;
	opacity: 1;
}
.woocommerce div.product form.cart .variations td.label {
	margin: 0;
	padding: 0 15px 15px 0;
}
.woocommerce div.product form.cart .variations td.value {
	position: relative;
	width: 100%;
}
.woocommerce div.product .product_meta span.product_meta_title,
.woocommerce div.product .product_meta > span {
	font-weight: bold;
	color: var(--pcheading-cl);
	margin-bottom: 15px;
}
.woocommerce div.product .product_meta span.product_meta_title {
	display: inline-block;
	margin-bottom: 0;
}
.woocommerce div.product .product_meta > span > * {
	font-weight: normal;
	color: var(--pcmeta-cl);
}
.woocommerce div.product p.stock.out-of-stock {
	color: var(--pclabel_outstock);
}
/* Product Quantity */
div.quantity {
	font-size: 0;
	display: inline-flex;
	vertical-align: top;
	white-space: nowrap;
}
div.quantity input[type=number]::-webkit-inner-spin-button,
div.quantity input[type=number]::-webkit-outer-spin-button,
div.quantity input[type="number"] {
	margin: 0;
	-webkit-appearance: none;
	-moz-appearance: none;
	appearance: none;
}
div.quantity input[type="number"],
div.quantity input[type="button"] {
	display: inline-block;
	color: var(--pctext-cl);
	background-color: var(--pcbg-cl);
}
.woocommerce .quantity .qty,
div.quantity input[type="number"] {
	display: flex;
	align-self: center;
	width: 30px;
	height: 40px;
	color: var(--pctext-cl);
	border-right: none;
	border-left: none;
	border-radius: 0;
}
@-moz-document url-prefix() {
	div.quantity input[type="number"] {
		-webkit-appearance: textfield;
		-moz-appearance: textfield;
		/*appearance: textfield;*/
	}
}
div.quantity input[type="button"] {
	min-width: 25px;
	height: 40px;
	padding: 0 5px;
	border: 1px solid var(--pcborder-cl);
	background: var(--pcbg-cl);
	box-shadow: none;
}
div.quantity input[type="button"]:hover {
	color: var(--pctext-cl);
	border-color: var(--pcaccent-cl);
	background-color: var(--pcaccent-cl);
}
div.quantity .minus {
	border-top-left-radius: 0;
	border-bottom-left-radius: 0;
}
div.quantity .plus {
	border-top-right-radius: 0;
	border-bottom-right-radius: 0;
}
div.quantity.hidden {
	display: none !important;
}
.variations select,
.woocommerce-ordering select,
.penci-widget-layered-nav-dropdown-form select {
	font-size: 14px;
	font-weight: bold;
	line-height: 18px;
	max-width: 140px;
	height: auto;
	padding-right: 20px;
	padding-bottom: 5px;
	padding-left: 2px;
	cursor: pointer;
	color: #2d2a2a;
	border: 0;
	border-bottom: 2px solid var(--pcborder-cl);
	border-radius: 0;
	background-position: right 0 top 50%;
}
.woocommerce .widget .woocommerce-ordering,
.woocommerce-page .widget .woocommerce-ordering,
.penci-widget-layered-nav-dropdown-form select,
.widget .woocommerce-ordering select {
	float: none;
	width: 100%;
	max-width: unset;
}
.woocommerce-ordering select:focus {
	border-color: var(--pcaccent-cl)
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image {
	overflow: hidden;
}
.woocommerce div.product div.images .woocommerce-product-gallery__wrapper .woocommerce-product-gallery__image:first-child {
	margin-bottom: 0;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
	top: 10px;
	right: 10px;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:before,
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:after {
	top: 12px;
	right: 0;
	bottom: 0;
	left: 0;
	width: unset;
	height: unset;
	text-align: center;
	border: 0;
	background-color: transparent;
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:before {
	font-family: penciicon, serif;
	font-size: 12px;
	content: '\f112';
	text-indent: 0;
	color: var(--pcheading-cl);
}
.woocommerce .penci-product-gallery-slider {
	margin-bottom: 10px;
}
.woocommerce .penci-product-gallery-slider.splide {
	margin-bottom: 0;
}
.woocommerce-product-gallery.thumbnail-right,
.woocommerce-product-gallery.thumbnail-left {
	position: relative;
	overflow: hidden;
}
.woocommerce-product-gallery.thumbnail-left .penci-product-gallery-slider {
	margin-left: 110px;
}
.woocommerce-product-gallery.thumbnail-right .penci-product-gallery-slider {
	margin-right: 110px;
}
.woocommerce-product-gallery.thumbnail-right .penci-product-gallery-slider figure,
.woocommerce-product-gallery.thumbnail-left .penci-product-gallery-slider figure {
	max-width: 100%;
}
.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider,
.woocommerce-product-gallery.thumbnail-left .penci-thumbnail-slider {
	position: absolute;
	top: 0;
	left: 0;
	width: 100px;
	height: 100%;
}
@media only screen and (min-width: 767px) {
	.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider .splide__track,
	.woocommerce-product-gallery.thumbnail-left .penci-thumbnail-slider .splide__track {
		max-height: calc(100% - 35px);
		overflow: hidden;
	}
	.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider,
	.woocommerce-product-gallery.thumbnail-left .penci-thumbnail-slider {
		height: 100%
	}
	.woocommerce-product-gallery.thumbnail-right.no-js .penci-thumbnail-slider,
	.woocommerce-product-gallery.thumbnail-left.no-js .penci-thumbnail-slider {
		margin-top: 0;
	}
}
.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider .splide__arrows,
.woocommerce-product-gallery.thumbnail-left .penci-thumbnail-slider .splide__arrows {
	display: none;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider {
	margin: 10px 0 0 0;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider {
	position: relative;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .splide__track figure img {
	width: auto;
	display: block;
	margin: 0 auto;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .splide__arrows button {
	width: 30px;
	height: 30px;
	margin-top: -15px;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .splide__arrows button svg {
	width: 15px;
	height: 15px;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav {
	position: static;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button {
	position: absolute;
	z-index: 9;
	top: 50%;
	bottom: 50%;
	width: 40px;
	height: 40px;
	margin-top: -20px;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button.penci-product-slider-next {
	right: 0;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button,
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button:hover {
	background-color: transparent;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button:hover {
	color: var(--pcaccent-cl);
}
.woocommerce-product-gallery.thumbnail-bottom .penci-product-slider-next i,
.woocommerce-product-gallery.thumbnail-bottom .penci-product-slider-prev i {
	transform: rotate(270deg);
}
.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav {
	position: absolute;
	z-index: 9;
	right: 0;
	bottom: 0;
	left: 0;
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
}
@media only screen and (max-width: 767px) {
	.penci-thumbnail-slider.splide--ttb > .splide__track > .splide__list {
		display: flex;
	}
}
.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button {
	flex: 0 0 auto;
	width: 48%;
	margin: 0;
	padding: 7px 5px;
	border: 0;
	background-color: var(--pcborder-cl);
}
.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button:hover {
	background-color: #f1f1f1;
}
.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider {
	right: 0;
	left: auto;
}
.woocommerce-product-gallery .penci-thumbnail-slider figure {
	overflow: hidden;
	cursor: pointer;
	-moz-transition: all 0.3s;
	-o-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	opacity: 0.5;
}
.woocommerce-product-gallery .penci-thumbnail-slider figure.swiper-slide-visible,
.woocommerce-product-gallery .penci-thumbnail-slider figure.swiper-slide-thumb-active {
	opacity: 1;
}
.woocommerce div.product div.images.thumbnail-right .woocommerce-product-gallery__trigger {
	top: auto;
	right: auto;
	bottom: 1em;
	left: 1em;
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product div.images .woocommerce-product-gallery__trigger,
	.woocommerce div.product div.images.thumbnail-left .woocommerce-product-gallery__trigger,
	.woocommerce div.product div.images.thumbnail-right .woocommerce-product-gallery__trigger {
		top: 3px;
		right: auto;
		bottom: auto;
		left: 5px;
		width: 46px;
		height: 46px;
	}
	.woocommerce div.product div.images .woocommerce-product-gallery__trigger::before {
		font-size: 16px;
		top: 14px;
	}
}
.variations_form .woocommerce-variation-add-to-cart {
	overflow: hidden;
	margin-top: 30px;
}
.theiaStickySidebar {
	position: relative;
}
.penci-top-relate-post {
	position: absolute;
	z-index: 99;
	top: 0;
	right: 0;
}
.penci-top-relate-post ul {
	position: relative;
	display: flex;
}
.penci-top-relate-post ul li {
	align-self: center;
	margin-right: 5px;
	cursor: pointer;
}
.penci-top-relate-post ul li:last-child {
	margin-right: 0;
}
.penci-top-relate-post ul li.top-ralate-item,
.penci-top-relate-post ul li.item-shop-link {
}
.penci-top-relate-post ul li.top-ralate-item > a,
.penci-top-relate-post ul li.item-shop-link > a {
	width: 25px;
	height: 25px;
	text-align: center;
	border: 1px solid var(--pcpage_gbdr_cl);
	display: block;
}
.penci-top-relate-post ul li.top-ralate-item > a i,
.penci-top-relate-post ul li.item-shop-link > a i {
	line-height: inherit;
}
.penci-top-relate-post ul li.top-ralate-item > a:hover,
.penci-top-relate-post ul li.item-shop-link > a:hover {
	border-color: var(--pcheading-cl);
}
.penci-top-relate-post ul li.top-ralate-item > a {
	font-size: 12px;
	line-height: 22px;
	color: var(--pcheading-cl);
}
.penci-top-relate-post ul li.item-shop-link svg {
	display: inline-block;
	margin: 5px 0 0;
}
.penci-top-relate-post .inner-content {
	position: absolute;
	top: 30px;
	right: 0;
	display: flex;
	visibility: hidden;
	overflow: hidden;
	align-items: center;
	flex-direction: row;
	min-width: 250px;
	transition: all 0.3s;
	opacity: 0;
	border: 1px solid var(--pcpage_gbdr_cl);
	background-color: var(--pcbg-cl);
	-moz-box-shadow: 0 -1px 2px rgba(190, 190, 190, 0.15);
	-webkit-box-shadow: 0 -1px 2px rgba(190, 190, 190, 0.15);
	box-shadow: 0 -1px 2px rgba(190, 190, 190, 0.15);
}
.penci-top-relate-post .top-ralate-item .inner-content {
	-webkit-transform: translateY(15px);
	transform: translateY(15px);
}
.penci-top-relate-post .top-ralate-item:hover > .inner-content {
	visibility: visible;
	-webkit-transform: translateY(0);
	transform: translateY(0);
	opacity: 1;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__image {
	width: 90px;
	flex-grow: 0;
	flex-shrink: 0;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__image img {
	width: 100%;
	height: auto;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary {
	align-self: center;
	margin: 0 !important;
	text-align: left;
	padding: 10px 15px;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary a {
	color: inherit;
	transition: all 0.3s;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary a:hover {
	opacity: 0.7;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary .price {
	font-size: 14px;
	display: inline-block;
	margin-top: 5px;
}
.penci-top-relate-post .top-ralate-item .top-ralate-item__summary .price ins{
	font-size: inherit;
}
.widget.soledad-product-filter .penci-scroll {
	max-height: var(--pc-w-mh);
	position: relative;
	overflow-x: hidden;
}
.widget.soledad-product-filter.penci-scroll-active .penci-scroll {
	height: var(--pc-w-mh);
}
@media only screen and (max-width: 767px) {
	.widget.soledad-product-filter .penci-scroll {
		max-height: var(--pc-w-mhm);
	}
	.widget.soledad-product-filter.penci-scroll-active .penci-scroll {
		height: var(--pc-w-mhm);
	}
}
.widget.soledad-product-filter .penci-scroll .penci-scroll-content {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	height: 100%;
}
.widget.soledad-product-filter.penci-scroll-inactive .penci-scroll .penci-scroll-content {
	position: static;
	height: auto;
}
.soledad-product-filter li {
	position: relative;
}
.soledad-product-filter .swatches-display-double {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
}
.soledad-product-filter .swatches-display-double li {
	flex: 0 0 auto;
	width: 45%;
}
.soledad-product-filter .swatches-display-inline {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
}
.soledad-product-filter .swatches-display-inline li {
	margin-right: 10px;
	border: 0;
}
.soledad-product-filter .swatches-display-inline li a {
	display: inline-block;
}
.soledad-product-filter .swatches-display-inline li:last-child {
	margin-bottom: 11px;
	padding-bottom: 12px;
}
.soledad-product-filter .swatches-display-inline .with-swatch-text .layer-term-name {
	min-width: 0;
	padding-right: 4px;
	padding-left: 4px;
}
.soledad-product-filter .swatches-display-inline .count {
	position: static;
}
.soledad-product-filter .swatches-display-inline.swatches-brands li {
	margin-right: 20px;
}
.soledad-product-filter .swatches-display-inline.show-labels-off .with-swatch-text .layer-term-name {
	min-width: 25px;
}
.soledad-product-filter .layered-nav-link {
	display: block;
}
.soledad-product-filter .with-swatch-image {
	position: relative;
	display: flex;
	align-items: center;
	justify-content: space-between;
	margin: 0;
	padding: 0;
	border: 0;
}
.soledad-product-filter .swatches-display-double .with-swatch-image:last-child,
.soledad-product-filter .with-swatch-image:not(:last-child) {
	border-bottom: 1px solid var(--pcborder-cl);
	padding-bottom: 10px;
	margin-bottom: 10px;
}
.soledad-product-filter .swatches-display-double.swatches-large .with-swatch-image,
.soledad-product-filter .swatches-display-double.swatches-large .with-swatch-image:last-child {
	border-bottom: none;
	padding-bottom: 0;
}
.soledad-product-filter .with-swatch-image .layered-nav-link {
	display: inline-block;
	max-width: 220px;
}
.soledad-product-filter .with-swatch-image .filter-swatch,
.soledad-product-filter .with-swatch-image .swatch-inner {
	display: flex;
	align-items: center;
}
.soledad-product-filter .swatches-display-double .filter-swatch,
.soledad-product-filter .with-swatch-image .swatch-inner {
	flex-direction: row;
}
.soledad-product-filter .with-swatch-image .layered-nav-link:hover,
.soledad-product-filter .with-swatch-image .layered-nav-link {
	background-color: transparent;
}
.soledad-product-filter .with-swatch-image .filter-swatch > span {
	font-size: 0;
	display: block;
	width: 100%;
	height: 60px;
	padding: 0;
}
.soledad-product-filter .swatches-display-inline .with-swatch-image,
.soledad-product-filter .swatches-display-inline li.with-swatch-image:last-child {
	border: 1px solid var(--pcborder-cl);
	padding: 5px;
	margin-bottom: 10px;
}
.soledad-product-filter .show-labels-off .with-swatch-image .layer-term-name,
.soledad-product-filter .show-labels-off .with-swatch-image .count {
	display: flex;
}
.soledad-product-filter .show-count-off .with-swatch-image .count,
.soledad-product-filter .show-labels-off .with-swatch-image .layer-term-name .term_name {
	display: none;
}
.soledad-product-filter .swatches-display-inline .with-swatch-image .layer-term-name img {
	max-height: 25px;
}
.soledad-product-filter .swatches-display-inline .with-swatch-image .count {
	margin-left: 5px;
}
.soledad-product-filter .with-swatch-image .filter-swatch,
.soledad-product-filter .with-swatch-image .layer-term-name {
	display: flex;
	min-width: 110px;
	align-items: center;
}
.soledad-product-filter .with-swatch-image.chosen .layer-term-name {
	font-weight: var(--pchead-wei);
}
.soledad-product-filter .with-swatch-image .layer-term-name img {
	width: auto;
	max-height: 50px;
	display: inline-block;
	margin-right: 5px;
}
.soledad-product-filter .swatches-large .with-swatch-image .layer-term-name img {
	max-height: 90px;
	max-width: 100%;
}
.soledad-product-filter .swatches-small .with-swatch-image .layer-term-name img {
	max-height: 25px;
}
.soledad-product-filter .swatches-display-inline.swatches-small .with-swatch-image .layer-term-name img {
	max-height: 18px;
}
.soledad-product-filter .swatches-display-inline.swatches-large .with-swatch-image .layer-term-name img {
	max-height: 40px;
}
.soledad-product-filter .swatches-large.swatches-display-double .with-swatch-image,
.soledad-product-filter .swatches-large.swatches-display-double .with-swatch-image .layer-term-name {
	flex-direction: column;
}
.soledad-product-filter .show-count-off .count,
.soledad-product-filter .show-labels-off .layer-term-name {
	display: none;
}
.soledad-product-filter a:hover {
	text-decoration: none;
}
.soledad-product-filter .swatches-display-double li,
.soledad-product-filter .swatches-display-list li {
	overflow: hidden;
}
.soledad-product-filter .swatches-display-list li .count,
.soledad-product-filter .swatches-display-double li .count {
	float: right;
}
.soledad-product-filter .swatches-display-list li .layered-nav-link,
.soledad-product-filter .swatches-display-double li .layered-nav-link {
	float: left;
}
.penci-woo-before-main-content {
	display: flex;
	flex-wrap: wrap;
	flex-direction: column;
	/*justify-content: space-between;*/
	margin-bottom: 30px;
}
.penci-woo-before-main-content .penci-woo-before-main-inner-content {
	display: flex;
	overflow: hidden;
	overflow-x: visible;
	flex: 0 0 auto;
	flex-wrap: wrap;
}
.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right {
	display: flex;
	justify-content: space-between;
}
.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .penci-wofilter-inner {
	display: flex;
}
@media only screen and (min-width: 768px) and (max-width: 1170px) {
	.penci-woo-before-main-content .penci-woo-before-main-inner-content,
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right {
		width: 100%;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right {
		justify-content: space-between;
		margin-top: 15px;
		padding-top: 15px;
		border-top: 1px solid var(--pcborder-cl);
	}
	.header-header-ecommerce .main-nav-social .inner-header-social {
		overflow: hidden;
		overflow-x: visible;
		white-space: nowrap;
	}
	.header-header-ecommerce .main-nav-social a {
		float: none;
	}
}
@media only screen and (min-width: 960px) and (max-width: 1170px) {
	.header-header-ecommerce .main-nav-social .inner-header-social {
		overflow: hidden;
		overflow-x: visible;
		white-space: nowrap;
	}
	.header-header-ecommerce .main-nav-social a {
		float: none;
	}
}
.penci-woo-before-main-content .penci-breadcrumb.penci-woo-breadcrumb {
	display: flex;
	align-items: center;
	width: auto;
	margin: 0;
}
.container.penci-breadcrumb.penci-woo-breadcrumb.top {
	position: relative;
	z-index: 9;
	margin-top: 30px;
	margin-bottom: -30px;
}
.sidebar-placement-both .container.penci-breadcrumb.penci-woo-breadcrumb.top {
	margin-bottom: 30px;
}
.content-left .container.penci-breadcrumb.penci-woo-breadcrumb.top {
	margin-top: 0;
	margin-bottom: 15px;
}
@media only screen and (max-width: 767px) {
	.container.penci-breadcrumb.penci-woo-breadcrumb.top {
		margin-bottom: 0;
		padding: 0 20px;
	}
	.content-left .container.penci-breadcrumb.penci-woo-breadcrumb.top {
		margin-bottom: 0;
	}
}
.summary .penci-breadcrumb.penci-woo-breadcrumb {
	position: relative;
	overflow: hidden;
	padding-right: 40px;
	white-space: pre-line;
}
@media only screen and (min-width: 768px) {
	.top-related-posts-show .summary .penci-breadcrumb.penci-woo-breadcrumb {
		padding-right: 110px;
	}
}
.summary .penci-breadcrumb.penci-woo-breadcrumb:after {
	position: absolute;
	z-index: 2;
	top: 0;
	right: 0;
	bottom: 0;
	display: none;
	width: 100%;
	height: 100%;
	content: '';
	background: rgb(255, 255, 255);
	background: linear-gradient(270deg, rgba(255, 255, 255, 1) 0%, rgba(255, 255, 255, 0.5) 50%, rgba(255, 255, 255, 0) 100%);
}
@media only screen and (max-width: 767px) {
	.summary .penci-breadcrumb.penci-woo-breadcrumb:after {
		display: none;
		overflow-x: scroll;
	}
}
.penci-woo-before-main-content .penci-products-per-page {
	display: flex;
	align-items: center;
	margin-right: 15px;
}
.penci-woo-before-main-content .penci-products-per-page span {
	font-weight: normal;
}
.penci-woo-before-main-content .penci-products-per-page a {
	margin-left: 10px;
	color: rgba(0, 0, 0, 0.5);
}
.penci-woo-before-main-content .penci-products-per-page a.current-variation {
	color: black;
}
.penci-woo-before-main-content .woocommerce-ordering {
	display: flex;
	float: none;
	margin: 0;
}
.penci-woo-before-main-content .penci-products-shop-view {
	display: flex;
	align-items: center;
	margin-right: 5px;
}
.penci-woo-before-main-content .penci-products-shop-view.products-view-grid-list {
	flex-direction: row-reverse;
}
.penci-woo-before-main-content .penci-products-shop-view svg.icon {
	width: 20px;
	height: 20px;
	opacity: 0.5;
	fill: var(--pctext-cl);
}
.penci-woo-before-main-content .penci-products-shop-view .per-row-5 svg.icon,
.penci-woo-before-main-content .penci-products-shop-view .per-row-6 svg.icon {
	width: 25px;
}
.penci-woo-before-main-content .penci-products-shop-view .current-variation svg.icon {
	opacity: 1;
}
.penci-woo-before-main-content .penci-products-shop-view .shop-view {
	display: inline-flex;
	margin: 0 5px;
}
body.post-type-archive-product .woocommerce-products-header {
	overflow: hidden;
	margin-bottom: 15px;
	padding-bottom: 15px;
}
@media only screen and (max-width: 767px) {
	body.post-type-archive-product .woocommerce-products-header {
		border-bottom: 1px solid #ececec;
	}
	.penci-woo-before-main-content .penci-products-shop-view .shop-view.per-row-3,
	.penci-woo-before-main-content .penci-products-shop-view .shop-view.per-row-4,
	.penci-woo-before-main-content .penci-products-shop-view .shop-view.per-row-5,
	.penci-woo-before-main-content .penci-products-shop-view .shop-view.per-row-6 {
		display: none;
	}
}
body.post-type-archive-product .woocommerce-products-header .penci-woo-before-main-content {
	margin-bottom: 0;
}
.widget.soledad-price-filter .penci-price-filter li .current-state {
	font-weight: bold;
	color: var(--pcaccent-cl);
}
.thumbnail-bottom-2-col .penci-thumbnail-grid .woocommerce-product-thumbnail,
.thumbnail-bottom-1-col .penci-thumbnail-grid .woocommerce-product-thumbnail {
	margin-top: 15px;
}
.thumbnail-grid .penci-thumbnail-grid {
	display: flex;
	flex-wrap: wrap;
	margin-right: -7.5px;
	margin-left: -7.5px;
}
.thumbnail-grid .penci-thumbnail-grid .woocommerce-product-thumbnail {
	display: inline-flex;
	flex: 1 1 33.3333333333%;
	max-width: 33.3333333333%;
	margin-top: 15px;
	padding: 0 7.5px;
}
.thumbnail-grid .penci-thumbnail-grid .woocommerce-product-thumbnail:nth-child(4n) {
	flex: 1 1 100%;
	max-width: 100%;
}
.thumbnail-bottom-2-col .penci-thumbnail-grid {
	display: flex;
	flex-wrap: wrap;
	margin-right: -7.5px;
	margin-left: -7.5px;
}
.thumbnail-bottom-2-col .penci-thumbnail-grid .woocommerce-product-thumbnail {
	display: inline-flex;
	flex: 1 1 50%;
}
.thumbnail-bottom-2-col .penci-thumbnail-grid .woocommerce-product-thumbnail:nth-child(3n) {
	flex: 100%
}
.thumbnail-bottom-2-col .penci-thumbnail-grid .woocommerce-product-thumbnail .woocommerce-product-gallery__image {
	padding: 0 7.5px;
}
.penci-product-img-thumbnail-grid .penci-thumbnail-grid {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
}
.penci-product-img-thumbnail-grid .penci-thumbnail-grid figure {
	display: inline-flex;
	flex: 1 1 50%;
}
.woocommerce div.product div.summary .penci-woo-breadcrumb {
	width: auto;
	margin: 0 0 30px;
}
.penci-products-preloader {
	display: none;
}
.pre-load-content .penci-products-preloader {
	display: block;
}
body #main ul.products {
	-moz-transition: all 0.3s;
	-o-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	opacity: 1;
}
.pre-load-content #main ul.products {
	visibility: hidden;
	opacity: 0;
}
.penci-products-compare-table .penci-compare-row {
	position: relative;
	display: flex;
}
.penci-products-compare-table .penci-compare-row:nth-child(2n) .penci-compare-col {
	background-color: rgba(0, 0, 0, 0.025);
}
.penci-products-compare-table .penci-compare-col {
	display: inline-flex;
	flex-direction: column;
	justify-content: flex-start;
	padding: 15px;
	text-align: center;
	border-right: 1px solid var(--pcpage_gbdr_cl);
}
.penci-products-compare-table .compare-basic .penci-compare-col {
	padding-top: 0;
}
.penci-products-compare-table .penci-compare-col:last-child {
	border-right: 0;
}
.penci-products-compare-table .penci-compare-col p:last-child {
	margin-bottom: 0;
}
.penci-products-compare-table .compare-field {
	font-weight: bold;
	text-transform: uppercase;
	flex: 0 0 20%;
	text-align: left;
	font-family: var(--pchead-font);
	justify-content: center;
}
.penci-products-compare-table .compare-value {
	flex: 0 1 26%;
	flex-direction: column;
}
.penci-products-compare-table.penci-multicompare {
	overflow: hidden;
	overflow-x: auto;
}
.penci-products-compare-table.penci-multicompare .compare-value {
	flex: 0 0 290px;
}
.penci-products-compare-table .compare-value .stock {
	font-weight: bold;
	font-size: 14px;
}
.penci-products-compare-table .compare-value .stock.out-of-stock {
	color: var(--pclabel_outstock);
}
.penci-products-compare-table .compare-value .stock.in-stock:before {
	font-family: 'penciicon';
	content: '\f111';
	color: var(--pcaccent-cl);
	display: inline-block;
	margin-right: 5px;
	vertical-align: middle;
}
.penci-products-compare-table .penci-product-title {
	font-size: var(--pcsl_tt_fs);
	display: block;
	margin: 10px 0;
}
.woocommerce.penci-products-compare-table .star-rating {
	float: none;
	margin: 0 auto 8px;
}
.penci-products-compare-table .compare-basic-content {
	padding-bottom: 15px;
}
.penci-products-compare-table .compare-basic-content a.button {
	margin-top: 10px;
	height: 40px;
	line-height: 1.2;
}
@media only screen and (max-width: 767px) {
	.penci-products-compare-table .penci-product-title {
		font-size: var(--pcsl_tt_m_fs);
	}
}
@media only screen and (max-width: 767px) {
	.penci-products-compare-table .penci-product-title {
		font-size: var(--pcsl_tt_m_fs);
	}
}
.penci-products-compare-table .penci-product-title a {
	text-decoration: none;
	color: var(--pcheading-cl);
}
.penci-products-compare-table .penci-top-button {
	text-align: center;
	line-height: 1;
}
.penci-products-compare-table .price del {
	opacity: .7;
	color: var(--pcpage_meta_cl);
}
.penci-products-compare-table .price .amount,
.penci-products-compare-table .price ins {
	font-weight: bold;
	text-decoration: none;
	color: var(--pcaccent-cl);
}
.penci-products-compare-table .price del .amount {
	color: inherit;
}
.woocommerce.penci-products-compare-table .penci-top-button a.button {
	background-color: transparent;
	color: var(--pcheading-cl);
	margin: 0 0 12px;
	padding: 0;
	line-height: 1;
	height: auto;
}
.penci-products-compare-table .penci-top-button a:before {
	font-family: "penciicon", serif;
	font-size: 8px;
	line-height: inherit;
	display: inline-block;
	margin-right: 5px;
	content: '\f110';
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.penci-products-compare-table .penci-top-button a.penci-compare.loading:before {
	display: none;
}
.penci-products-compare-table .penci-top-button a.penci-compare.loading:after {
	position: static;
	display: inline-block;
	margin-left: 5px;
}
@media only screen and (max-width: 767px) {
	.penci-products-compare-table {
		overflow-x: auto;
	}
	.penci-products-compare-table .penci-compare-row .compare-field {
		flex: 0 0 180px;
	}
	.penci-products-compare-table .compare-value {
		flex: 0 0 290px;
	}
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
	border: 2px solid rgba(55, 55, 55, 0.1);
}
.woocommerce div.product div.images .woocommerce-product-gallery__trigger:hover {
	color: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
}
.penci-header-cart-detail {
	position: absolute;
	z-index: 9999;
	top: 100%;
	right: 0;
	visibility: hidden;
	width: 300px;
	-webkit-transition: opacity 0.3s ease, visibility 0.3s ease, -webkit-transform 0.3s ease;
	transition: opacity 0.3s ease, visibility 0.3s ease, transform 0.3s ease, -webkit-transform 0.3s ease;
	-webkit-transform: translateY(15px) translateZ(0);
	transform: translateY(15px) translateZ(0);
	text-align: left;
	opacity: 0;
	border: 1px solid var(--pcpage_gbdr_cl);
	background-color: var(--pcbg-cl);
	-webkit-backface-visibility: hidden;
	backface-visibility: hidden;
}
.penci-header-cart-detail .widget_shopping_cart_content {
	padding-top: 10px;
}
.penci-header-cart-detail .woocommerce-mini-cart__empty-message {
	padding: 0 20px 10px;
	text-align: center;
}
.penci-header-cart-detail .penci-woo-cart-buttons-group > p{
	text-align: center;
}
li:hover .penci-header-cart-detail {
	visibility: visible;
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 1;
}
.penci-header-cart-detail ul.product_list_widget li {
	position: relative;
	margin-bottom: 0;
	padding: 10px 0;
}
.penci-header-cart-detail ul.product_list_widget li img {
	width: 50px;
}
.penci-header-cart-detail ul.product_list_widget li .amount {
	font-size: inherit;
}
.penci-header-cart-detail ul.product_list_widget li a {
	font-size: inherit;
	color: var(--pctext-cl);
	font-family: var(--pchead-font);
	font-weight: bold;
	margin-bottom: 5px;
}
.penci-header-cart-detail ul.woocommerce-mini-cart {
	overflow-y: auto;
	max-height: 320px;
	padding: 0 20px;
}
.penci-header-cart-detail ul.product_list_widget li a.remove {
	position: absolute;
	top: 15px;
	bottom: 50%;
	right: 10px;
	margin-top: 0;
	font-size: 0;
	opacity: 0.8;
}
.penci-header-cart-detail ul.product_list_widget li a.remove:before {
	font-family: 'penciicon';
	content: '\f110';
	font-size: 8px;
	color: var(--pcheading-cl);
	background-color: transparent;
}
.penci-header-cart-detail ul.product_list_widget li div.quantity {
	display: none;
}
.penci-header-cart-detail ul.product_list_widget li a.remove:hover {
	background-color: transparent;
	opacity: 1;
}
.woocommerce .penci-header-cart-detail ul.product_list_widget li a.remove:hover:before {
	color: var(--pcheading-cl);
}
.penci-header-cart-detail .woocommerce-mini-cart__total.total {
	position: relative;
	margin: 20px 0 0;
	padding: 10px 20px 0;
	text-align: center;
	background-color: var(--pcbg-cl);
	font-weight: bold;
	font-size: 1rem;
	border-top: 1px solid var(--pcpage_gbdr_cl);
}
.penci-header-cart-detail .woocommerce-mini-cart__buttons.buttons {
	margin: 0 -1px -10px;
	padding: 0 20px 20px;
	background-color: var(--pcbg-cl);
	border: 1px solid var(--pcpage_gbdr_cl);
	border-top: 0;
}
.penci-header-cart-detail .woocommerce-mini-cart__buttons.buttons .button {
	display: block;
	margin-top: 10px;
	padding: 0 15px;
	line-height: 36px;
	color: white;
	background-color: var(--pctext-cl);
}
.penci-header-cart-detail .woocommerce-mini-cart__buttons.buttons .button.checkout.wc-forward {
	background-color: var(--pcaccent-cl);
}
body.woocommerce-cart .entry-content .woocommerce {
	display: flex;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}
body.woocommerce-cart .entry-content .woocommerce .woocommerce-cart-form,
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals {
	padding-right: 15px;
	padding-left: 15px;
}
body.woocommerce-cart .entry-content .woocommerce .woocommerce-cart-form {
	display: flex;
	flex: 0 0 auto;
	width: 66.5%;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals {
	display: flex;
	flex: 0 0 auto;
	width: 33.5%;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals {
	float: none;
	width: 100%;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals .button {
	/*line-height: 1.1;*/
	display: block;
	width: 100%;
	text-align: center;
	background-color: var(--pcpage_btns_bg_cl) !important;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals .penci-woo-cart-total-wrap {
	padding: 30px 30px 0;
	border: 2px solid var(--pcpage_gbdr_cl);
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table {
	border: 0;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table th {
	padding-right: 10px;
	text-transform: none;
}
body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table td {
	border-bottom: 1px solid var(--pcpage_gbdr_cl);
}
.woocommerce-cart table.cart img {
	width: 60px;
}
@media only screen and (max-width: 767px) {
	body.woocommerce-cart .entry-content .woocommerce {
		margin-left: 0;
		margin-right: 0;
	}
	body.woocommerce-cart .woocommerce table.shop_table a.remove {
		margin: 0 auto;
	}
	body.woocommerce-cart .entry-content .woocommerce .woocommerce-cart-form,
	body.woocommerce-cart .entry-content .woocommerce .cart-collaterals {
		flex: 0 0 100%;
		width: 100%;
	}
	.woocommerce .penci_woo_pages_breadcrumbs {
		text-align: center;
		margin-bottom: 30px;
	}
}
.woocommerce .cart-collaterals .cart_totals h2, .woocommerce-page .cart-collaterals .cart_totals h2 {
	line-height: 1.2;
}
.products .penci-soledad-product .penci-removewishlist.button,
.post-entry .products .penci-soledad-product a.penci-removewishlist.button {
	z-index: 2;
	display: block;
	text-align: center;
	color: var(--pcpage_gtext_cl);
	background-color: transparent;
	padding-left: 0;
	padding-right: 0;
}
.products .penci-soledad-product.penci-hover .penci-removewishlist.button,
.products .penci-soledad-product:hover .penci-removewishlist.button {
	opacity: .85;
}
.products .penci-soledad-product .penci-removewishlist.button:before {
	font-family: "penciicon", serif;
	font-size: 8px;
	line-height: 27px;
	display: inline-block;
	margin: 0 5px 0 0;
	content: '\f110';
	color: inherit;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.products .penci-soledad-product .penci-removewishlist.button.loading:before {
	display: none;
}
.products .penci-soledad-product .penci-removewishlist.button.loading:after {
	position: static;
	display: inline-block;
	margin-left: 5px;
}
.woocommerce a.button.alt.disabled, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled[disabled], .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt:disabled[disabled]:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled[disabled], .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt:disabled[disabled]:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled[disabled], .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt:disabled[disabled]:hover, .woocommerce #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled[disabled], .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt:disabled[disabled]:hover {
	background-color: black;
}
@media only screen and (max-width: 767px) {
	.woocommerce-cart table.cart td.actions {
		padding-right: 30px;
		padding-left: 30px;
	}
	.woocommerce-cart table.cart td.actions .coupon .input-text {
		margin-bottom: 10px;
	}
	.woocommerce-cart table.cart td.actions button,
	.woocommerce-page table.cart td.actions .coupon .input-text + .button,
	.woocommerce-cart table.cart td.actions .coupon .input-text,
	.woocommerce .woocommerce-cart-form .cart button.button,
	.woocommerce-page table.cart td.actions .button,
	.woocommerce-cart table.cart td.actions input {
		float: none;
		width: 100%;
	}
}
.woocommerce-cart table.cart td.actions .coupon .input-text {
	font-family: var(--pchead-font);
	font-size: 13px;
	font-weight: var(--pchead-wei);
	min-width: 270px;
	min-height: 40px;
	padding: 10px 20px;
	text-transform: uppercase;
}
@media only screen and (min-width: 768px) {
	.woocommerce table.shop_table td.product-name {
		max-width: 220px;
	}
	.woocommerce-result-count {
		display: none;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce table.shop_table_responsive tr td,
	.woocommerce-page table.shop_table_responsive tr td {
		padding-right: 10px;
		padding-left: 10px;
	}
}
.woocommerce table.shop_table td.product-name a {
	font-size: 14px;
}
.woocommerce table.shop_table td.product-price .woocommerce-Price-currencySymbol,
.woocommerce table.shop_table td.product-price span * {
	color: var(--pcheading-cl);
}
.woocommerce table.shop_table td.product-subtotal span {
	font-size: 16px;
	font-weight: bold;
}
.woocommerce .woocommerce-cart-form .cart .button[name="apply_coupon"],
.woocommerce .woocommerce-cart-form .cart button.button,
.woocommerce .woocommerce-cart-form .cart button.button:disabled,
.woocommerce .woocommerce-cart-form .cart button.button:disabled[disabled] {
	font-size: 13px;
	line-height: 14px;
	padding: 13px 20px 13px;
	color: #fff;
	background-color: var(--pcpage_btns_bg_cl);
}
.woocommerce .woocommerce-cart-form .cart button.button:disabled,
.woocommerce .woocommerce-cart-form .cart button.button:disabled[disabled] {
	background-color: grey;
}
.woocommerce .cart-collaterals .cart_totals h2, .woocommerce-page .cart-collaterals .cart_totals h2 {
	font-family: var(--pchead-font);
}
.woocommerce-NoticeGroup.woocommerce-NoticeGroup-checkout {
	display: flex;
	flex: 0 0 auto;
	width: 100%;
	padding: 0 15px;
}
.woocommerce-NoticeGroup.woocommerce-NoticeGroup-checkout ul {
	width: 100%;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout {
	display: flex;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review,
body.woocommerce-checkout form.checkout.woocommerce-checkout #step-wrapper-address,
body.woocommerce-checkout form.checkout.woocommerce-checkout #customer_details {
	flex: 0 0 auto;
	width: 60%;
	padding-right: 15px;
	padding-left: 15px;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout #step-wrapper-address #customer_details {
	width: 100%;
	padding-left: 0;
	padding-right: 0;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout .col2-set .col-1,
body.woocommerce-checkout form.checkout.woocommerce-checkout .col2-set .col-2 {
	float: none;
	width: 100%;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout label {
	font-weight: bold;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review {
	flex: 0 0 auto;
	width: 40%;
}
@media only screen and (max-width: 960px) {
	body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review,
	body.woocommerce-checkout form.checkout.woocommerce-checkout #step-wrapper-address,
	body.woocommerce-checkout form.checkout.woocommerce-checkout #customer_details {
		width: 50%;
	}
	body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review {
		width: 50%;
	}
	body.woocommerce-checkout form.checkout.woocommerce-checkout #step-wrapper-address #customer_details {
		width: 100%;
	}
}
@media only screen and (max-width: 767px) {
	body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review,
	body.woocommerce-checkout form.checkout.woocommerce-checkout #customer_details,
	body.woocommerce-checkout form.checkout.woocommerce-checkout #step-wrapper-address,
	body.woocommerce-checkout form.checkout.woocommerce-checkout #order_review {
		flex: 0 0 auto;
		width: 100%;
	}
}
.woocommerce form.checkout h3#order_review_heading {
	margin-top: 0;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner {
	position: relative;
	margin-top: 10px;
	padding: 30px;
	background-color: var(--pcwc_ckout_inner_bg);
}
body.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner table,
body.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner .woocommerce-checkout-payment {
	border: 0;
	border-radius: 0;
	background-color: var(--pcbg-cl);
}
body.woocommerce-checkout form.checkout.woocommerce-checkout button {
	width: 100%;
	text-align: center;
	color: #fff;
}
body.woocommerce-checkout form.checkout.woocommerce-checkout button:hover {
	color: #fff;
}
.woocommerce-checkout #payment ul.payment_methods {
	background-color: var(--pcbg-cl);
}
.select2-container--default .select2-selection--single {
	height: 44px;
	border-color: var(--pcborder-cl);
	border-radius: 0;
}
.select2-container--default .select2-selection--single .select2-selection__rendered {
	line-height: 44px;
}
.select2-container--default .select2-selection--single .select2-selection__arrow {
	height: 44px;
}
.select2-dropdown {
	border-color: var(--pcborder-cl);
	border-radius: 0;
}
body.woocommerce-order-received .woocommerce-order {
	text-align: center;
}
body.woocommerce-order-received .woocommerce-order .woocommerce-notice {
	font-size: 18px;
}
body.woocommerce-order-received .woocommerce-order .woocommerce-notice:before {
	font-family: penciicon, serif;
	font-size: 30px;
	line-height: 70px;
	display: block;
	width: 70px;
	height: 70px;
	margin: 0 auto 30px;
	content: "\f111";
	color: #fff;
	border-radius: 50%;
	background-color: var(--pcaccent-cl);
}
body.woocommerce-order-received .woocommerce-order tr:last-child th {
	border: 0;
}
.woocommerce ul.order_details li {
	display: inline-block;
	float: none;
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.order_details li {
		display: block;
		padding: 5px 0;
		border-right: 0;
		border-bottom: 1px dashed #d3ced2;
	}
	.woocommerce ul.order_details li:last-child {
		border: 0;
	}
}
body.woocommerce-order-received .woocommerce-order section {
	max-width: 700px;
	margin: 0 auto;
	padding: 30px;
	border: 1px solid var(--pcborder-cl);
}
body.woocommerce-order-received .woocommerce-order section + section {
	margin-top: 30px;
}
.woocommerce .woocommerce-customer-details address {
	border: 0;
	border-radius: 0;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color {
	display: flex;
	align-items: center;
	justify-content: space-between;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color .count {
	padding: 2px 5px;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color .swatch-inner {
	display: flex;
	align-items: center;
}
.widget .swatches-display-list .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch {
	display: inline-flex;
	margin-right: 10px;
}
.widget .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span {
	font-size: 0;
	display: block;
	width: 24px;
	height: 24px;
	text-align: center;
	border-radius: 50%;
}
.widget .swatches-small .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span {
	width: 18px;
	height: 18px;
}
.widget .swatches-small .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span:before {
	font-size: 8px;
	line-height: 18px;
}
.widget .swatches-large .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span {
	width: 32px;
	height: 32px;
}
.widget .swatches-large .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span:before {
	font-size: 14px;
	line-height: 32px;
}
.widget .swatches-display-inline .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span {
	display: inline-block;
}
.widget .swatches-display-inline .wc-layered-nav-term.with-swatch-color a {
	display: flex;
}
.widget .swatches-display-inline .wc-layered-nav-term.with-swatch-color,
.widget .swatches-display-double .wc-layered-nav-term.with-swatch-color,
.widget .swatches-display-double .wc-layered-nav-term.with-swatch-color .layered-nav-link,
.widget .swatches-display-double .wc-layered-nav-term.with-swatch-color span,
.widget .swatches-display-inline .wc-layered-nav-term.with-swatch-color span {
	display: inline-flex;
	align-items: center;
	justify-content: space-between;
}
.widget .swatches-display-double .wc-layered-nav-term.with-swatch-color .layer-term-name,
.widget .swatches-display-inline .wc-layered-nav-term.with-swatch-color .layer-term-name {
	margin: 0 5px;
}
.widget .wc-layered-nav-term.with-swatch-color .swatch-inner .filter-swatch span:before {
	font-family: penciicon, serif;
	font-size: 12px;
	line-height: 24px;
	content: "\f111";
	opacity: 0;
	color: white;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.widget .wc-layered-nav-term.chosen a {
	font-weight: bold;
}
.widget .wc-layered-nav-term.with-swatch-color.chosen .swatch-inner .filter-swatch span:before {
	opacity: 1;
}
.quick-shop-wrapper {
	position: absolute;
	top: 0;
	left: 0;
	bottom: 0;
	right: 0;
	visibility: hidden;
	padding: 0 0 40px;
	text-align: center;
	opacity: 0;
	display: flex;
	justify-content: center;
	align-items: center;
}
.quick-shop-shown .quick-shop-wrapper {
	z-index: 99;
	visibility: visible;
	opacity: 1;
	background-color: rgba(255, 255, 255, .95);
}
.quick-shop-shown .quick-shop-wrapper .quick-shop-form {
	height: calc(100% - 32px);
	overflow-y: auto;
	padding-top: 16px;
	overflow-x: hidden;
	width: 100%;
	display: flex;
	justify-content: center;
	align-items: center;
}
@media only screen and (max-width: 767px) {
	.quick-shop-shown .quick-shop-wrapper .quick-shop-form {
		display: block;
		padding-top: 22px;
	}
}
.quick-shop-shown .quick-shop-wrapper table,
.quick-shop-shown .quick-shop-wrapper table th,
.quick-shop-shown .quick-shop-wrapper table td {
	border: 0;
	position: relative;
	text-align: center;
}
.quick-shop-shown .quick-shop-wrapper .variations select {
	box-shadow: 0 1px 3px rgba(55, 55, 55, .1);
}
.woocommerce div.product form.cart .variations tr th {
	padding-top: 0;
	padding-bottom: 0;
	padding-left: 0;
}
.woocommerce div.product form.cart .variations tr:not(:last-child) td {
	padding-bottom: 10px;
}
.woocommerce div.product .quick-shop-wrapper form.cart .variations td.label {
	padding: 0;
}
.woocommerce div.product .quick-shop-wrapper form.cart,
.woocommerce div.product .quick-shop-wrapper p.cart {
	margin-bottom: 0;
}
.products li.product.quick-shop-shown .penci-product-loop-buttons,
.products li.product.quick-shop-shown .hover-img {
	visibility: hidden;
	opacity: 0;
	display: none;
}
.quick-shop-shown .quick-shop-wrapper label {
	font-weight: bold;
}
.quick-shop-shown .quick-shop-wrapper .reset_variations {
	display: block;
	margin-top: 10px;
}
.quick-shop-wrapper .quantity .qty,
.quick-shop-wrapper div.quantity input[type="number"] {
	border: 0;
}
.quick-shop-wrapper div.quantity input[type="button"].minus,
.quick-shop-wrapper div.quantity input[type="button"].plus {
	width: 39px;
	height: 39px;
	color: #fff;
	border-radius: 50%;
	background-color: rgba(0, 0, 0, 0.5);
}
.quick-shop-wrapper div.quantity input[type="button"].minus:hover,
.quick-shop-wrapper div.quantity input[type="button"].plus:hover {
	background-color: rgba(0, 0, 0, 0.9);
}
.quick-shop-wrapper .quantity,
.quick-shop-wrapper .woocommerce-variation.single_variation {
	display: none !important;
}
.quick-shop-wrapper .variations {
	text-align: center;
}
.quick-shop-wrapper table {
	width: 100%;
}
.quick-shop-wrapper table tr {
	display: flex;
	flex-direction: column;
	flex-wrap: wrap;
}
.quick-shop-wrapper table tr td {
	padding: 5px 0;
}
.quick-shop-wrapper .reset_variations {
	display: block;
}
.quick-shop-wrapper .variations_form .woocommerce-variation-add-to-cart {
	margin-top: 0;
	position: absolute;
	overflow: visible;
	bottom: 0;
	left: 0;
	right: 0;
}
.woocommerce div.penci-summary-align-center .quick-shop-wrapper form.cart .button,
.quick-shop-wrapper .single_add_to_cart_button.button {
	position: absolute;
	bottom: 0;
	left: 0;
	display: block;
	width: 100%;
	color: #fff;
}
.woocommerce .quick-shop-wrapper .single_add_to_cart_button.button:hover {
	color: #fff;
}
.quick-shop-wrapper div.quantity input[type="button"] {
	border: 0;
}
.quick-shop-wrapper .quick-shop-close {
	font-size: 0;
	position: absolute;
	top: 10px;
	left: 10px;
	width: 20px;
	height: 20px;
	cursor: pointer;
	text-align: center;
	border: 1px solid #888;
	border-radius: 50%;
	background-color: white;
	z-index: 5;
}
.quick-shop-wrapper .quantity {
	display: none;
}
.woocommerce div.product.penci-summary-align-center .quick-shop-wrapper form.cart .variations td.label,
.woocommerce div.product.penci-summary-align-center .quick-shop-wrapper form.cart .variations td.value {
	margin-left: 0;
	margin-right: 0;
	padding-right: 0;
	padding-left: 0;
	width: initial;
	text-align: center;
}
.woocommerce div.product.penci-summary-align-center .quick-shop-wrapper form.cart .variations td.label {
	padding-bottom: 5px;
}
.woocommerce div.product .quick-shop-wrapper form.cart .variations .reset_variations {
	display: block;
}
.quick-shop-wrapper .quick-shop-close:before {
	font-family: penciicon, serif;
	font-size: 8px;
	line-height: 18px;
	content: "\f110";
	color: gray;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.woocommerce ul.cart_list li,
.woocommerce ul.product_list_widget li {
	font-size: inherit;
	padding-right: 20px;
	color: inherit;
}
.woocommerce.widget_products ul.product_list_widget li,
.woocommerce.widget_top_rated_products ul.product_list_widget li {
	padding-left: 0;
	padding-right: 0;
}
.woocommerce ul.cart_list li div.quantity .qty,
.woocommerce ul.cart_list li div.quantity input[type="number"],
.woocommerce ul.cart_list li div.quantity input[type="button"],
.woocommerce ul.product_list_widget div.quantity input[type="button"] {
	font-size: 14px;
	height: 30px;
	line-height: 1;
	transition: all 0.3s ease-in-out;
}
.woocommerce ul.cart_list li div.quantity,
.woocommerce ul.product_list_widget div.quantity {
	margin-bottom: 10px;
}
.woocommerce ul.cart_list .product-cart-info,
.woocommerce ul.product_list_widget .product-cart-info {
	float: right;
	margin-bottom: 10px;
	width: calc(100% - 110px);
}
.woocommerce ul.cart_list li div.quantity + span.quantity,
.woocommerce ul.product_list_widget div.quantity + li span.quantity {
	display: block;
}
.woocommerce .widget ul.cart_list li .star-rating,
.woocommerce .widget ul.product_list_widget li .star-rating {
	margin: 0 0 10px;
}
.woocommerce ul.cart_list li a,
.woocommerce ul.product_list_widget li a {
	font-size: inherit;
	color: inherit;
}
.woocommerce ul.cart_list li a .product-title,
.woocommerce ul.product_list_widget li a .product-title {
	transition: all 0.3s;
}
.woocommerce ul.cart_list li a:hover .product-title,
.woocommerce ul.product_list_widget li a:hover .product-title {
	opacity: 0.7;
}
.woocommerce ul.cart_list li .amount,
.woocommerce ul.product_list_widget li .amount {
	font-size: inherit;
	float: none;
	font-weight: bold;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove,
.woocommerce .widget_shopping_cart .cart_list li a.remove,
.woocommerce.widget_shopping_cart .cart_list li a.remove {
	font-size: 0;
	line-height: 0;
	top: 0;
	right: 0;
	bottom: 0;
	left: auto;
	color: black !important;
	border: 0;
	background-color: var(--pcbg-cl);
}
body .penci-sidebar-cart .sidecart-content ul li a.remove:before,
.woocommerce .widget_shopping_cart .cart_list li a.remove:before,
.woocommerce.widget_shopping_cart .cart_list li a.remove:before {
	font-family: "penciicon", serif;
	font-size: 10px;
	line-height: 24px;
	content: "\f110";
	opacity: .5;
	color: black !important;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove:hover:before,
.woocommerce .widget_shopping_cart .cart_list li a.remove:hover:before,
.woocommerce.widget_shopping_cart .cart_list li a.remove:hover:before {
	opacity: 1;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove:hover,
.woocommerce .widget_shopping_cart .cart_list li a.remove:hover,
.woocommerce.widget_shopping_cart .cart_list li a.remove:hover {
	color: black;
	background-color: transparent;
}
.woocommerce .widget_shopping_cart .total,
.woocommerce.widget_shopping_cart .total {
	font-size: inherit;
	text-transform: uppercase;
}
.woocommerce .widget_shopping_cart .amount,
.woocommerce.widget_shopping_cart .amount {
	float: right;
}
.woocommerce .widget_shopping_cart .woocommerce-mini-cart__buttons.buttons {
	overflow: hidden;
}
.woocommerce .widget_shopping_cart .woocommerce-mini-cart__buttons.buttons .button {
	float: left;
	width: 48%;
	margin: 0;
	/*padding-top: 14px;
    padding-bottom: 14px;*/
}
.woocommerce ul.cart_list li del,
.woocommerce ul.product_list_widget li del {
	color: #999;
}
.woocommerce ul.cart_list li del .amount,
.woocommerce ul.product_list_widget li del .amount {
	font-size: inherit;
	color: inherit;
}
.woocommerce .widget_shopping_cart .woocommerce-mini-cart__buttons.buttons .button.checkout.wc-forward {
	float: right;
	background-color: var(--pcaccent-cl);
}
.woocommerce-accordion.wc-accordion-wrapper {
	clear: both;
}
.woocommerce-accordion.wc-accordion-wrapper + .related.products {
	margin-top: 60px;
}
.summary.entry-summary .woocommerce-accordion.wc-accordion-wrapper {
	margin-bottom: -1px;
	border-top: 1px solid #dedede;
}
.summary.entry-summary .penci-review-style-default #comments,
.summary.entry-summary .penci-review-style-default #review_form_wrapper {
	flex: 100%;
	width: 100%;
	max-width: unset;
}
.summary.entry-summary .penci-review-style-default #review_form_wrapper {
	margin-top: 30px;
}
.woocommerce #review_form #respond p.form-submit input[type="submit"] {
	padding: 0 15px;
}
.woocommerce table.shop_attributes {
	max-width: 600px;
	margin: 0 auto;
	border-top: 0;
}
.woocommerce table.shop_attributes p,
.woocommerce table.shop_attributes a {
	color: var(--pcmeta-cl);
}
.woocommerce table.shop_attributes a:hover {
	color: var(--pcaccent-cl);
}
.woocommerce table.shop_attributes tr td {
	text-align: right;
}
.woocommerce table.shop_attributes tr:last-child td,
.woocommerce table.shop_attributes tr:last-child th {
	border: 0;
}
.woocommerce table.shop_attributes tr:nth-child(2n) td,
.woocommerce table.shop_attributes tr:nth-child(2n) th {
	background-color: transparent;
}
.woocommerce-accordion.wc-accordion-wrapper:after {
	display: table;
	clear: both;
	content: "";
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-panel {
	display: none;
	padding: 25px 0;
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-item.parent-active {
	border-bottom: 1px solid var(--pcborder-cl);
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title {
	position: relative;
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title:after {
	font-family: penciicon !important;
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	display: inline-flex;
	align-items: center;
	height: 100%;
	content: '\f11a';
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title.active:after {
	-moz-transform: rotate(90deg);
	-ms-transform: rotate(90deg);
	-o-transform: rotate(90deg);
	-webkit-transform: rotate(90deg);
	transform: rotate(90deg);
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title > a {
	display: block;
	padding-top: 20px;
	padding-bottom: 20px;
	color: var(--pcheading-cl);
	border-bottom: 1px solid var(--pcborder-cl);
	text-transform: uppercase;
	opacity: 0.7;
}
.woocommerce-accordion.wc-accordion-wrapper .woocommerce-accordion-title.active > a {
	opacity: 1;
}
.products.product-list .penci-soledad-product,
.woocommerce ul.products.product-list li.product,
.woocommerce-page ul.products.product-list li.product {
	margin-bottom: 0;
}
.products.product-list .penci-soledad-product .penci-product-loop-inner-content {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	margin-bottom: 30px;
	padding-bottom: 30px;
	border-bottom: 1px solid #dedede;
}
.products.product-list .penci-soledad-product .penci-product-loop-top {
	position: relative;
	align-self: flex-start;
	flex: 0 0 auto;
	width: 35%;
}
.products.product-list .penci-soledad-product .penci-product-loop-title {
	display: flex;
	flex: 0 0 auto;
	flex-direction: column;
	justify-content: center;
	width: 65%;
	padding-left: 30px;
	text-align: left;
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products.product-list[class*="columns-"] .penci-soledad-product,
	.woocommerce-page ul.products.product-list[class*="columns-"] .penci-soledad-product {
		float: none;
		width: 100%;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce .products.product-list .penci-soledad-product .penci-product-loop-top {
		width: 40%;
	}
	.woocommerce .products.product-list .penci-soledad-product .penci-product-loop-title {
		width: 60%;
	}
	.woocommerce .products.product-list .penci-soledad-product .penci-list-summary.entry-summary {
		display: none;
	}
	.woocommerce ul.products.mobile-columns-2.product-list .penci-soledad-product,
	.woocommerce-page ul.products.mobile-columns-2.product-list .penci-soledad-product,
	.woocommerce .penci_sidebar ul.products.mobile-columns-2.product-list .penci-soledad-product,
	.woocommerce-page .penci_sidebar ul.products.mobile-columns-2.product-list .penci-soledad-product,
	.woocommerce ul.products[class*="columns-"].product-list .penci-soledad-product,
	.woocommerce-page ul.products[class*="columns-"].product-list .penci-soledad-product {
		float: none !important;
		width: 100% !important;
	}
}
.woocommerce .products.product-list .penci-soledad-product h3,
.woocommerce .products.product-list .penci-soledad-product .woocommerce-loop-product__title {
	text-align: inherit;
}
.woocommerce .products.product-list .penci-soledad-product .price {
	text-align: inherit;
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button {
	line-height: 40px;
	display: inline-block;
	padding: 0 30px;
	color: white;
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button.added {
	min-width: 160px;
}
@media only screen and (max-width: 767px) {
	.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button {
		width: 100%;
		padding: 0 5px;
	}
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button {
	font-size: 12px;
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button.loading {
	color: transparent;
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-action .button:hover {
	opacity: 0.8;
}
.woocommerce .products.product-list .penci-soledad-product .penci-list-summary {
	margin-top: 15px;
}
.woocommerce a.button.loading:before,
.woocommerce button.button.loading:before,
.woocommerce input.button.loading:before,
.woocommerce #respond input#submit.loading:before {
	position: absolute;
	z-index: 1;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	content: '';
	background-color: rgba(255, 255, 255, .75);
}
.woocommerce a.button.loading:before,
.woocommerce button.button.loading:before,
.woocommerce input.button.loading:before,
.woocommerce #respond input#submit.loading:before,
.woocommerce a.button.loading:after,
.woocommerce button.button.loading:after,
.woocommerce input.button.loading:after,
.woocommerce #respond input#submit.loading:after {
	font-family: inherit !important;
	line-height: 0;
	position: absolute;
	z-index: 2;
	top: 14px;
	right: 50%;
	left: 50%;
	display: block;
	width: 14px;
	height: 14px;
	margin: 0 0 0 -9px;
	content: " " !important;
	animation: lds-dual-ring 0.4s linear infinite;
	vertical-align: middle;
	opacity: 1;
	border: 1px solid #999;
	border-left-color: #000;
	border-top-color: #000;
	border-radius: 50%;
}
.woocommerce .penci-products-preloader {
	text-align: center;
}
.woocommerce .penci-products-preloader .penci-layout-loader:before {
	z-index: 2;
	right: 50%;
	left: 50%;
	display: inline-block;
	width: 30px;
	height: 30px;
	margin: 0 0 0 -15px;
	content: " " !important;
	animation: lds-dual-ring 0.5s linear infinite;
	vertical-align: middle;
	opacity: 1;
	border: 1px solid #999;
	border-left-color: #000;
	border-radius: 50%;
}
.woocommerce a.button.loading,
.woocommerce button.button.loading,
.woocommerce input.button.loading,
.woocommerce #respond input#submit.loading {
	opacity: 1;
}
.penci-sticky-cart {
	position: fixed;
	z-index: 99;
	top: auto !important;
	bottom: 0 !important;
	left: 0;
	visibility: hidden;
	width: 100%;
	-moz-transition: all 0.3s;
	-o-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	-webkit-transform: translateY(5px) translateZ(0);
	transform: translateY(5px) translateZ(0);
	opacity: 0;
	background-color: var(--pcbg-cl);
	-moz-box-shadow: 1px -8px 17px 0 rgba(0, 0, 0, 0.15);
	-webkit-box-shadow: 1px -8px 17px 0 rgba(0, 0, 0, 0.15);
	box-shadow: 1px -8px 17px 0 rgba(0, 0, 0, 0.15);
}
.penci-sticky-cart.cart-sticky {
	visibility: visible;
	-webkit-transform: translateY(0) translateZ(0);
	transform: translateY(0) translateZ(0);
	opacity: 1;
}
.penci-sticky-cart-wrapper {
	display: flex;
	flex-wrap: wrap;
	padding: 5px 0;
}
.penci-sticky-cart-wrapper .penci-sticky-cart-title,
.penci-sticky-cart-wrapper .penci-sticky-cart-buttons {
	display: flex;
	align-items: center;
	align-self: center;
	flex: 0 0 50%;
	flex-direction: row;
	max-width: 50%;
}
.penci-sticky-cart-wrapper .penci-sticky-cart-buttons {
	justify-content: flex-end;
}
.penci-sticky-cart-wrapper .penci-sticky-cart-buttons button:hover,
.penci-sticky-cart-wrapper .penci-sticky-cart-buttons button.button.alt:hover {
	color: #fff;
}
.penci-sticky-cart-wrapper .product-image {
	width: 70px;
	margin-right: 15px;
}
.penci-sticky-cart-wrapper .product-price {
	font-size: 18px;
	font-weight: bold;
}
.penci-sticky-cart-wrapper .product-price del {
	font-size: 80%;
	opacity: .75;
}
.penci-sticky-cart-wrapper .product-price ins {
	text-decoration: none;
	color: var(--pcaccent-cl);
}
.penci-sticky-cart-wrapper .product-action {
	margin-left: 15px;
}
.penci-sticky-cart-wrapper .product-action a.button {
	padding: 0 25px;
	color: white;
	background-color: var(--pcpage_btn_atc_bg_cl);
}
.penci-sticky-cart-wrapper .product-action a.button:hover {
	color: white;
}
@media only screen and (max-width: 767px) {
	.penci-sticky-cart-wrapper {
		padding-right: 5px;
		padding-left: 5px;
	}
	.penci-sticky-cart-wrapper .penci-sticky-cart-title {
		display: none;
	}
	.penci-sticky-cart-wrapper .penci-sticky-cart-buttons {
		flex: 0 0 100%;
		justify-content: space-between;
		width: 100%;
		max-width: 100%;
	}
}
body.single-product #header {
	margin-bottom: 0;
}
.penci-single-product-top-container {
	overflow: hidden;
	margin-bottom: 20px;
	padding-top: 60px;
	border-bottom: 1px solid var(--pcpage_gbdr_cl);
}
.sidebar-placement-both .penci-single-product-top-container {
	position: relative;
	padding-top: 0;
}
@media only screen and (max-width: 767px) {
	.product.no-background .penci-single-product-top-container {
		padding-top: 15px;
	}
}
.penci-single-product-top-container .container {
	position: relative;
}
.woocommerce .product.penci-product-img-medium div.images {
	width: 57.5%;
}
.woocommerce .product.penci-product-img-medium div.summary {
	width: 40%;
}
.woocommerce .product.penci-product-img-large div.images {
	width: 67.5%;
}
.woocommerce .product.penci-product-img-large div.summary {
	width: 30%;
}
.woocommerce .product.penci-product-img-large .penci-top-relate-post {
	top: -50px;
}
.woocommerce .product.penci-product-img-fullwidth-container .penci-top-relate-post {
	top: -50px;
	left: auto;
	right: calc((100% - var(--pcctain)) / 2);
}
.woocommerce .penci_sidebar div.product.penci-product-img-fullwidth-container div.images,
.woocommerce-page .penci_sidebar div.product.penci-product-img-fullwidth-container div.images,
.woocommerce div.penci-product-img-fullwidth-container div.images {
	width: 100%;
}
.woocommerce div.penci-product-img-fullwidth-container div.images .woocommerce-product-gallery__trigger {
	right: calc((100% - var(--pcctain)) / 2);
}
@media only screen and (min-width: 961px) and (max-width: 1169px) {
	.woocommerce .product.penci-product-img-fullwidth-container .penci-top-relate-post {
		right: calc((100% - 940px) / 2);
	}
	.woocommerce div.penci-product-img-fullwidth-container div.images .woocommerce-product-gallery__trigger {
		right: calc((100% - 940px) / 2);
	}
}
@media only screen and (min-width: 768px) and (max-width: 960px) {
	.woocommerce .product.penci-product-img-fullwidth-container .penci-top-relate-post {
		right: calc((100% - 726px) / 2);
	}
	.woocommerce div.penci-product-img-fullwidth-container div.images .woocommerce-product-gallery__trigger {
		right: calc((100% - 726px) / 2);
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce .product.penci-product-img-fullwidth-container .penci-top-relate-post {
		position: relative;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
	}
}
@media only screen and (min-width: 768px) {
	.woocommerce .product.penci-product-img-fullwidth-container .penci-single-product-top-container .product-labels {
		left: 10px;
		right: auto;
	}
}
.woocommerce .product.penci-product-img-fullwidth-container div.images,
.woocommerce .product.penci-product-img-fullwidth-container div.summary {
	float: none;
	width: 100%;
}
.woocommerce .product.penci-product-img-fullwidth .penci-single-product-top-container > .container {
	width: 100%;
}
.penci-summary-align-center .summary.entry-summary {
	text-align: center;
}
.woocommerce div.penci-summary-align-center form.cart {
	/*display: flex;
	flex-wrap: wrap;
	justify-content: center;*/
}
.woocommerce div.penci-summary-align-center form.cart .variations {
	width: auto;
	margin: 0 auto;
}
.woocommerce div.penci-summary-align-center.penci-product-img-fullwidth-container .single_variation_wrap {
	max-width: 570px;
	margin: 0 auto;
}
.woocommerce div.penci-product-img-fullwidth-container figure.splide__slide {
	opacity: 0.2;
	pointer-events: none;
	cursor: none;
}
.woocommerce div.product.penci-product-img-fullwidth-container div.images .woocommerce-product-gallery__wrapper {
	transition: none;
}
.woocommerce div.penci-product-img-fullwidth-container figure.is-active,
.woocommerce div.penci-product-img-fullwidth-container .owl-item.active.center figure,
.woocommerce div.penci-product-img-fullwidth-container .slick-center figure {
	opacity: 1;
	pointer-events: visible;
}
.woocommerce div.penci-summary-align-center form.cart .variations td.value {
	text-align: left;
	width: 70%;
}
.woocommerce div.penci-summary-align-center form.cart .variations td.label {
	text-align: right;
	width: 30%;
}
.woocommerce div.penci-summary-align-center form.cart .button,
.woocommerce div.penci-summary-align-center form.cart div.quantity {
	display: inline-flex;
	float: none;
	width: auto;
}
@media only screen and (max-width: 767px) {
	.woocommerce form.cart .single_add_to_cart_button {
		width: calc(100% - 100px);
	}
	.woocommerce .quick-shop-wrapper form.cart .single_add_to_cart_button {
		width: 100%;
	}
}
.penci-woo-page-container.penci_sidebar .sidebar-both,
.penci-woo-page-container.penci_sidebar .sidebar-bottom .penci-single-product-bottom-container .container {
	display: flex;
	flex-wrap: wrap;
	justify-content: space-between;
}
.penci-woo-page-container.penci_sidebar .sidebar-both .penci-single-product-sidebar-wrap,
.penci-woo-page-container.penci_sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
	flex: 0 0 auto;
	width: calc(100% - var(--pc-sidebar-w));
}
.penci-woo-page-container.penci_sidebar.right-sidebar .sidebar-both .penci-single-product-sidebar-wrap,
.penci-woo-page-container.penci_sidebar.right-sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
	padding-right: 50px;
}
.penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-both .penci-single-product-sidebar-wrap,
.penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
	padding-left: 60px;
}
@media only screen and (max-width: 767px) {
	.penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-both .penci-single-product-sidebar-wrap,
	.penci-woo-page-container.penci_sidebar.left-sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
		padding-left: 0;
	}
	.penci-woo-page-container.penci_sidebar.right-sidebar .sidebar-both .penci-single-product-sidebar-wrap,
	.penci-woo-page-container.penci_sidebar.right-sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
		padding-right: 0;
	}
	.penci-woo-page-container.penci_sidebar .sidebar-both .penci-single-product-sidebar-wrap,
	.penci-woo-page-container.penci_sidebar .sidebar-bottom .penci-single-product-bottom-container .bottom-content {
		width: 100%;
	}
}
.penci-woo-page-container.penci_sidebar .sidebar-both #sidebar,
.penci-woo-page-container.penci_sidebar .sidebar-bottom .penci-single-product-bottom-container #sidebar {
	flex: 0 0 auto;
}
.penci-woo-page-container.left-sidebar .sidebar-both,
.penci-woo-page-container.left-sidebar .sidebar-bottom .penci-single-product-bottom-container .container {
	flex-direction: row-reverse;
}
@media only screen and (max-width: 767px) {
	.penci-woo-page-container.penci_sidebar .sidebar-both #sidebar,
	.penci-woo-page-container.penci_sidebar .sidebar-both .penci-single-product-sidebar-wrap,
	.penci-woo-page-container.penci_sidebar .penci-single-product-bottom-container .bottom-content,
	.penci-woo-page-container.penci_sidebar .penci-single-product-bottom-container #sidebar {
		width: 100%;
	}
	.penci-woo-page-container.penci_sidebar .sidebar-both {
		padding-right: 15px;
		padding-left: 15px;
	}
	.penci-woo-page-container.left-sidebar .sidebar-both .penci-sidebar-content > .theiaStickySidebar,
	.penci-woo-page-container.left-sidebar .penci-single-product-bottom-container .theiaStickySidebar {
		padding-right: 0;
		border-right: 0;
	}
	.penci-woo-page-container.right-sidebar .sidebar-both .penci-sidebar-content > .theiaStickySidebar,
	.penci-woo-page-container.right-sidebar .penci-single-product-bottom-container .theiaStickySidebar {
		padding-left: 0;
		border-left: 0;
	}
}
.woocommerce ul.products.product-standard .penci-soledad-product a.button {
	background-color: #f5f5f5;
	color: var(--pctext-cl);
}
.woocommerce ul.products.product-standard .penci-soledad-product a.button:hover {
	background-color: var(--pcaccent-cl);
	color: #fff;
}
/* Rating Position*/
.woocommerce .product.product-style-1 .star-rating,
.woocommerce .product.product-style-3 .star-rating,
.woocommerce .product.product-style-4 .star-rating,
.woocommerce .product.product-style-5 .star-rating,
.woocommerce .product.product-style-6 .star-rating {
	position: relative;
	top: 0;
	right: 0;
	left: 0;
	margin-top: 5px;
	margin-bottom: 5px;
}
.woocommerce .product.product-style-2 .star-rating {
	top: 50px;
	left: 15px;
}
.woocommerce .products.product-style-2 .penci-product-cats,
.woocommerce .products.product-style-2 .woocommerce-loop-product__title {
	padding-right: 80px;
}
.woocommerce ul.products .product.product-style-1 .star-rating,
.woocommerce ul.products .product.product-style-5 .star-rating {
	margin-right: auto;
	margin-left: auto;
}
.penci-woo-page-container.loadmore .woocommerce-pagination,
.penci-woo-page-container.infinit .woocommerce-pagination {
	display: none;
}
.penci-woo-page-container.loadmore .woocommerce-pagination,
.penci-woo-page-container.infinit .page-load-status {
	padding: 15px 0;
	text-align: center;
}
.penci-woo-page-container .page-load-status {
	display: none;
}
.woocommerce nav.woocommerce-pagination {
	text-align: center;
}
.woocommerce nav.woocommerce-pagination ul li {
	float: none;
	margin-bottom: 10px;
}
.penci-woo-page-container .page-load-button {
	text-align: center;
}
.penci-woo-page-container .page-load-button a {
	color: rgb(153, 153, 153);
}
.penci-woo-page-container .page-load-button .button.loading,
.penci-woo-page-container .page-load-button .button {
	min-width: 183px;
	/*padding: 16px 20px 14px;*/
	transform: none;
	color: rgb(153, 153, 153);
}
.penci-woo-page-container .page-load-button .button.loading:hover,
.penci-woo-page-container .page-load-button .button:hover {
	color: var(--pcaccent-cl);
	border-color: var(--pcaccent-cl);
	background-color: transparent;
}
.penci-woo-page-container .page-load-button .button.loading {
	cursor: not-allowed;
	pointer-events: none;
	color: transparent;
}
.product.penci-product-thumbnail-left .product-labels .product-label {
	left: 120px;
}
/* Product Categories */
.products .penci-product-cat-loop {
	position: relative;
	overflow: hidden;
	height: 100%;
	border: 1px solid var(--pcborder-cl);
}
.woocommerce ul.products li.product-category .woocommerce-loop-category__title {
	margin-bottom: 0;
}
.woocommerce ul.products li.product-category .product-category-img:before {
	position: absolute;
	z-index: 1;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	content: '';
	background: var(--pcl_l_cat_o_cl);
	background: var(--pcl_l_cat_o_cl_rgba);
}
.woocommerce ul.products li.product-category a img {
	margin: 0;
	transition: -webkit-transform 2s cubic-bezier(0, 0, 0.44, 1.18);
	transition: transform 2s cubic-bezier(0, 0, 0.44, 1.18);
	transition: transform 2s cubic-bezier(0, 0, 0.44, 1.18), -webkit-transform 2s cubic-bezier(0, 0, 0.44, 1.18);
}
.woocommerce ul.products li.product-category:hover a img {
	-webkit-transform: scale(1.23);
	transform: scale(1.23);
}
.woocommerce ul.products li.product-category .woocommerce-loop-category__wrapper {
	position: absolute;
	z-index: 9;
	bottom: 0;
	left: 0;
	width: 100%;
	padding: 15px;
	transition: transform .3s ease;
	transform: translateY(calc(15px)) translateZ(0);
}
.woocommerce ul.products li.product-category:hover .woocommerce-loop-category__wrapper {
	transform: translateY(0) translateZ(0);
}
.woocommerce ul.products li.product .woocommerce-loop-category__title {
	font-size: var(--pcl_l_cat_tt_fs);
	padding: 0;
	color: var(--pcl_l_cat_tt_cl);
}
.woocommerce ul.products li.product-category .count {
	display: block;
	transition: transform .3s ease, opacity .3s ease;
	transform: translateY(15px) translateZ(0);
	opacity: 0;
	color: var(--pcl_l_cat_cl);
	font-size: var(--pcl_l_cat_fs);
}
.woocommerce ul.products li.product-category:hover .count {
	transform: translateY(0) translateZ(0);
	opacity: 1;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-2 {
	border: 0;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-2 .woocommerce-loop-category__wrapper {
	top: 50%;
	bottom: 50%;
	transform: translateY(-25px) translateZ(0);
	text-align: center;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-2:hover .woocommerce-loop-category__wrapper {
	transform: translateY(0) translateZ(0);
}
.woocommerce ul.products li.product-category.penci-product-cat-style-2 .count {
	transform: translateY(80px) translateZ(0);
}
.woocommerce ul.products li.product-category.penci-product-cat-style-2:hover .count {
	transform: translateY(0px) translateZ(0);
}
.woocommerce ul.products li.product-category.penci-product-cat-style-3 .woocommerce-loop-category__wrapper {
	text-align: center;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .woocommerce-loop-category__wrapper,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .woocommerce-loop-category__wrapper {
	position: relative;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .product-category-img,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .product-category-img {
	overflow: hidden;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .product-category-img {
	border-radius: 50%;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .count,
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .woocommerce-loop-category__title,
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .woocommerce-loop-category__wrapper,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .count,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .woocommerce-loop-category__title,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .woocommerce-loop-category__wrapper {
	transform: translateY(0px) translateZ(0);
	opacity: 1;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-4 .penci-product-cat-loop,
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .penci-product-cat-loop {
	border: 0;
}
.woocommerce ul.products li.product-category.penci-product-cat-style-5 .woocommerce-loop-category__wrapper {
	text-align: center;
}
/* Progress Bar */
.penci-stock-progress-bar .stock-info {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
	margin-bottom: 5px;
	color: var(--pcmeta-cl);
}
.penci-stock-progress-bar .stock-info span {
	font-weight: 600;
	margin-left: 3px;
	color: var(--pcheading-cl);
}
.penci-stock-progress-bar .progress-area,
.penci-stock-progress-bar .progress-bar {
	height: var(--pccat_progress_height);
}
.penci-stock-progress-bar .progress-area {
	width: 100%;
	background-color: var(--pccat_progress_bg_cl);
}
.penci-stock-progress-bar .progress-bar {
	background-color: var(--pccat_progress_active_bg_cl);
}
.summary.entry-summary .penci-stock-progress-bar {
	margin: 15px 0;
}
.woocommerce div.product form.cart .reset_variations,
.variations_form a.reset_variations {
	font-size: inherit;
	position: static;
	display: inline-block;
	margin: 5px 0 0;
	vertical-align: middle;
	color: var(--pcheading-cl);
}
.woocommerce div.product form.cart .penci-swatches + .reset_variations,
.woocommerce div.product form.cart .jquery-grid-picker-widget + .reset_variations {
	margin: 0 0 5px 10px;
}
.variations_form a.reset_variations:before {
	font-family: penciicon;
	font-size: 10px;
	display: inline-block;
	margin-right: 5px;
	content: '\f110';
}
@media only screen and (max-width: 767px) {
	.variations_form a.reset_variations {
		position: absolute;
		top: 0;
		right: 0;
	}
}
.variations_form ul.jquery-grid-picker-widget {
	display: inline-block;
	margin: 0 -2.5px;
	padding: 0;
	list-style: none;
}
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item {
	display: inline-block;
	padding: 0 2.5px;
}
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item[data-jquery-grid-picker-value=""] {
	display: none;
}
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item a {
	padding: 3px 10px;
	color: var(--pctext-cl);
	border: 1px solid var(--pcpage_btns_bdr_cl);
	border-radius: 2px;
	transition: all 0.3s ease-in-out;
}
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item a:hover {
	color: #fff;
	border-color: var(--pcpage_btns_bdr_hv_cl);
	background-color: var(--pcpage_btns_bg_hv_cl);
}
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item-selected a,
.variations_form ul.jquery-grid-picker-widget li.jquery-grid-picker-item-selected a:hover {
	color: #fff;
	border-color: var(--pcaccent-cl);
	background-color: var(--pcaccent-cl);
}
.woocommerce div.product form.cart .variations select.jquery-grid-picker,
.variations_form select.jquery-grid-picker {
	display: none;
}
.woocommerce .cart-empty.woocommerce-info,
.woocommerce .return-to-shop {
	flex: 0 0 100%;
}
.woocommerce .return-to-shop {
	text-align: center;
	margin-top: 25px;
}
.woocommerce .woocommerce-error:before,
.woocommerce .woocommerce-info:before,
.woocommerce .woocommerce-message:before {
	margin-top: 0;
}
.products-view-grid_list .shop-view.per-row-list {
	order: 1
}
.penci-sidebar-filter,
.penci-sidebar-cart {
	position: fixed;
	z-index: 99999999;
	top: 0;
	visibility: hidden;
	width: 320px;
	height: 100vh;
	-webkit-transition: all 0.5s;
	transition: all 0.5s;
	opacity: 0;
	background-color: var(--pcbg-cl);
}
.penci-sidebar-filter .penci-sidebar-content {
	float: none;
	width: 100%;
	padding: 40px 20px;
	height: calc(100% - 80px);
	overflow-y: auto;
}
.penci-sidebar-filter .penci-sidebar-content .widget:last-child {
	margin-bottom: 0;
}
.penci-sidebar-filter.overlay,
.penci-sidebar-filter.side-right,
.penci-sidebar-cart.side-right {
	right: 0;
	-moz-transform: translateX(320px);
	-webkit-transform: translateX(320px);
	transform: translateX(320px);
}
.penci-sidebar-filter.side-left,
.penci-sidebar-cart.side-left {
	left: 0;
	-moz-transform: translateX(-320px);
	-webkit-transform: translateX(-320px);
	transform: translateX(-320px);
}
.woocommerce-no-js .penci-sidebar-filter.side-right,
.woocommerce-no-js .penci-sidebar-cart.side-right,
.woocommerce-no-js .penci-sidebar-filter.side-left,
.woocommerce-no-js .penci-sidebar-cart.side-left {
	-webkit-transition: unset;
	transition: unset;
	-moz-transform: translateX(0);
	-webkit-transform: translateX(0);
	transform: translateX(0);
}
.penci-sidebar-filter .notice {
	padding: 10px;
}
body.penci-side-right-filter-active .penci-sidebar-filter,
body.penci-side-left-filter-active .penci-sidebar-filter,
body.open-filter-side .penci-sidebar-filter,
body.open-sidecart .penci-sidebar-cart {
	visibility: visible;
	-moz-transform: translateX(0);
	-webkit-transform: translateX(0);
	transform: translateX(0);
	opacity: 1;
}
.penci-sidebar-filter .sidefilter-heading,
.penci-sidebar-cart .sidecart-heading {
	display: flex;
	align-items: center;
	justify-content: space-between;
	padding: 0 20px;
	border-bottom: 1px solid var(--pcborder-cl);
	background-color: var(--pcbg-cl);
	height: 80px;
}
.penci-sidebar-filter .sidefilter-heading h3,
.penci-sidebar-cart .sidecart-heading h3 {
	font-size: 22px;
	display: inline-block;
	text-transform: uppercase;
}
.penci-sidebar-filter .sidefilter-heading .close,
.penci-sidebar-cart .sidecart-heading .close {
	font-size: 0;
	display: inline-block;
	float: right;
	height: 27px;
	cursor: pointer;
	text-align: center;
}
.penci-sidebar-filter .sidefilter-heading .close i,
.penci-sidebar-cart .sidecart-heading .close i {
	font-size: 14px;
	line-height: 27px;
	display: inline-block;
	margin-right: 5px;
	color: var(--pcheading-cl);
	transition: all 0.3s;
}
.penci-sidebar-filter .sidefilter-heading .close:hover i,
.penci-sidebar-cart .sidecart-heading .close:hover i {
	transform: rotate(90deg);
}
.penci-sidebar-cart .sidecart-content ul {
	overflow: hidden;
	overflow-y: auto;
	width: 100%;
	height: calc(100vh - 290px);
	padding: 0;
	border-bottom: 0;
}
.penci-sidebar-cart .sidecart-content ul li {
	position: relative;
	margin: 0;
	padding: 15px 40px 15px 15px;
	transition: all 0.3s ease-in-out;
}
.penci-sidebar-cart .sidecart-content ul li .penci-loading-icon {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	display: flex;
	visibility: hidden;
	align-items: center;
	justify-content: center;
	width: 100%;
	transition: all 0.3s ease-in-out;
	text-align: center;
	opacity: 0;
	background-color: rgba(255, 255, 255, .75);
}
.penci-sidebar-cart .sidecart-content ul li.loading .penci-loading-icon {
	visibility: visible;
	opacity: 1;
}
.penci-sidebar-cart .sidecart-content ul li .penci-loading-icon .bubble:after {
	background-color: black;
}
.penci-sidebar-cart .sidecart-content ul li a {
	transition: all 0.3s ease-in-out;
}
.penci-sidebar-cart .sidecart-content ul li:hover a {
	opacity: 0.8;
}
.penci-sidebar-cart .sidecart-content ul li img {
	width: 60px;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove {
	position: absolute;
	top: 10px;
	right: 30px;
	transition: opacity 0.3s ease-in-out;
	opacity: .8;
	color: var(--pcheading-cl) !important;
	background-color: transparent;
}
body .penci-sidebar-cart .sidecart-content ul li a.remove:hover {
	opacity: 1;
}
.sidebar-filter-close,
.penci-sidebar-cart-close {
	position: fixed;
	z-index: 9999;
	top: 0;
	left: 0;
	visibility: hidden;
	width: 100%;
	height: 100%;
	cursor: pointer;
	text-indent: -999999px;
	opacity: 0;
	background-color: rgba(55, 55, 55, .75);
}
body.open-filter-side,
body.open-sidecart {
	overflow: hidden;
}
body.open-filter-side .sidebar-filter-close,
body.penci-side-right-filter-active .sidebar-filter-close,
body.penci-left-right-filter-active .sidebar-filter-close,
body.open-sidecart .penci-sidebar-cart-close {
	visibility: visible;
	opacity: 1;
}
@media only screen and (max-width: 767px) {
	body.penci-side-left-filter-active .sidebar-filter-close,
	body.penci-side-right-filter-active .sidebar-filter-close {
		visibility: visible;
		opacity: 1;
	}
}
.penci-sidebar-cart .penci-woo-cart-buttons-group,
.penci-sidebar-cart .penci-woo-cart-total-group {
	position: absolute;
	bottom: 0;
	left: 0;
	width: 100%;
	padding: 15px 20px;
	background-color: var(--pcbg-cl);
}
.penci-sidebar-cart .penci-woo-cart-buttons-group {
	min-height: 120px;
	padding: 0 20px 20px;
}
.penci-sidebar-cart .penci-woo-cart-buttons-group p {
	margin-bottom: 5px;
	font-size: 12px;
	font-weight: var(--pchead-wei);
}
.penci-sidebar-cart .penci-woo-cart-buttons-group p .amount {
	float: right;
}
.penci-sidebar-cart .woocommerce-mini-cart__buttons.buttons .button {
	display: block;
	text-align: center;
	color: var(--pcbg-cl);
	background-color: black;
}
.penci-sidebar-cart .woocommerce-mini-cart__buttons.buttons .button + .button {
	margin-top: 15px;
	background-color: var(--pcaccent-cl);
}
.penci-sidebar-cart .penci-woo-cart-total-group {
	font-size: 16px;
	bottom: 130px;
	text-transform: uppercase;
	border-top: 3px solid #dedede;
}
.penci-sidebar-cart .woocommerce-mini-cart__total.total .amount {
	font-weight: bold;
	float: right;
	color: var(--pcaccent-cl);
}
.penci-sidebar-cart .woocommerce-mini-cart__empty-message {
	font-weight: bold;
	font-size: 16px;
	padding: 15px;
	text-align: center;
}
.penci-sidebar-cart .woocommerce-mini-cart__empty-message:before {
	font-family: 'penciicon', serif;
	font-size: 48px;
	line-height: 48px;
	font-weight: 300;
	display: block;
	content: '\f16c';
	color: var(--pctext-cl);
	opacity: 0.15;
	padding: 15px 0;
}
.woocommerce .penci-sidebar-cart ul.cart_list li img,
.woocommerce .penci-sidebar-cart ul.product_list_widget li img {
	width: 60px;
}
.woocommerce-content-wrapper {
	width: 100%;
}
.penci-empty-compare,
.penci-empty-page-text,
.penci-compare-products-empty-text,
.penci-wishlist-products-empty-text {
	text-align: center;
}
.penci-empty-compare h3 {
	font-size: 18px;
	font-weight: bold;
}
.penci-empty-page.penci-empty-cart:before,
.penci-compare-products-empty-text:before,
.penci-empty-compare.penci-empty-page:before,
.penci-wishlist-products-empty-text:before {
	font-family: 'FontAwesome', serif;
	font-size: 128px;
	font-weight: 300;
	line-height: 1;
	display: block;
	margin-bottom: 17px;
	content: '\f08a';
	color: var(--pctext-cl);
	opacity: 0.15;
}
.penci-compare-products-empty-text:before,
.penci-empty-compare.penci-empty-page:before {
	content: '\f16b';
	font-family: 'penciicon', serif;
}
.penci-empty-page.penci-empty-cart:before {
	content: '\f16c';
	font-family: 'penciicon', serif;
}
.post-entry .woocommerce .penci-wishlist-products-empty-text,
.woocommerce .penci-wishlist-products-empty-text {
	margin-bottom: 30px;
	font-size: 110%;
}
.post-entry .woocommerce .penci-compare-empty-title,
.woocommerce .penci-compare-empty-title,
.post-entry .woocommerce .penci-wishlist-empty-title,
.woocommerce .penci-wishlist-empty-title {
	font-size: 48px;
	line-height: 1.2;
}
@media only screen and (max-width: 767px) {
	.post-entry .woocommerce .penci-compare-empty-title,
	.woocommerce .penci-compare-empty-title,
	.post-entry .woocommerce .penci-wishlist-empty-title,
	.woocommerce .penci-wishlist-empty-title {
		font-size: 28px;
	}
}
.sidebar-filter-container {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	width: 100%;
	max-height: 100%;
	box-shadow: 0 0 1px var(--pctext-cl);
}
.sidebar-filter-container .sidebar-filter-footer-buttons {
	position: absolute;
	right: 0;
	bottom: 10px;
	left: 0;
	padding: 0 10px;
}
.woocommerce .sidebar-filter-container button.close-sidebar {
	display: block;
	width: 100%;
	padding: 0 10px;
	color: var(--pcbg-cl);
	background-color: var(--pcheading-cl);
}
/* Top Product Filter */
.penci-top-product-filter {
	display: flex;
	overflow: hidden;
	flex-wrap: wrap;
	max-height: 0;
	margin-right: -15px;
	margin-left: -15px;
	transition: max-height 1s ease-in-out;
}
.penci-top-filter-active .penci-top-product-filter {
	max-height: 990px;
}
.penci-top-product-filter > * {
	flex-shrink: 0;
	box-sizing: border-box;
	width: 100%;
	max-width: 100%;
	padding-right: 15px;
	padding-left: 15px;
}
.penci-top-product-filter .widget {
	flex: 0 0 auto;
	width: 20%;
}
.penci-container-inside.penci-breadcrumb.penci-woo-breadcrumb i,
.container.penci-breadcrumb.penci-woo-breadcrumb i {
	margin: 0 10px;
}
@media only screen and (max-width: 767px) {
	.penci-top-product-filter .widget {
		width: 100%;
	}
	.penci-top-product-filter .widget + .widget {
		margin-top: 30px;
	}
}
.penci-top-product-filter .widget .widget-title {
	margin-bottom: 30px;
}
.penci-product-top-filter-button {
	display: flex;
	align-items: center;
	margin-left: 10px;
}
.penci-product-top-filter-button a {
	display: flex;
	height: 20px;
	color: var(--pctext-cl);
	opacity: 0.9;
}
.penci-product-top-filter-button svg {
	fill: var(--pctext-cl);
}
.penci-product-top-filter-button a.close {
	opacity: 0.6;
}
.penci-product-top-filter-button a i {
	width: 20px;
	height: 20px;
}
.penci-product-top-filter-button a span {
	margin-left: 5px;
}
/* Product Tabs */
.penci-products-tabs .products-tabs-title {
	font-weight: bold;
	margin-right: -15px;
	margin-bottom: 0;
	margin-left: -15px;
	list-style: none;
	padding: 0;
	color: #000;
	--li-pl: 0;
	--list-mb: 0;
	--li-mb: 0;
}
.penci-products-tabs .products-tabs-title li {
	margin-bottom: 0;
}
.penci-products-tabs.tabs-design-default .products-tabs-title .tab-label,
.penci-products-tabs.tabs-design-alt .products-tabs-title .tab-label {
	line-height: 1.2;
	position: relative;
	display: inline-block;
	padding-top: 1px;
	padding-bottom: 1px
}
.penci-products-tabs.tabs-design-default .products-tabs-title .tab-label:after,
.penci-products-tabs.tabs-design-alt .products-tabs-title .tab-label:after {
	position: absolute;
	top: 100%;
	left: 50%;
	width: 0;
	height: 2px;
	content: '';
	transition: all 0.4s cubic-bezier(0.18, 0.89, 0.45, 1.32);
	background-color: var(--pcaccent-cl);
}
.penci-products-tabs.tabs-design-default .products-tabs-title li:hover .tab-label:after,
.penci-products-tabs.tabs-design-default .products-tabs-title li.active-tab-title .tab-label:after,
.penci-products-tabs.tabs-design-alt .products-tabs-title li:hover .tab-label:after,
.penci-products-tabs.tabs-design-alt .products-tabs-title li.active-tab-title .tab-label:after {
	left: 0;
	width: 100%;
}
.penci-products-tabs .tabs-navigation-wrapper {
	position: relative
}
.penci-products-tabs .penci-tabs-header {
	position: relative
}
.penci-products-tabs .penci-tabs-header.text-right {
	text-align: right;
}
.penci-products-tabs .open-title-menu {
	display: none
}
.penci-products-tabs .tabs-name {
	font-size: 22px;
	text-transform: uppercase;
}
.penci-products-tabs .tabs-name > span {
	vertical-align: middle
}
.penci-products-tabs .tabs-name .img-wrapper {
	margin-right: 10px
}
.penci-products-tabs .img-wrapper {
	display: inline-block
}
.penci-products-tabs .products-tabs-title li {
	font-size: 16px;
	font-weight: inherit;
	line-height: 1.4;
	display: inline-flex;
	align-items: center;
	flex-direction: column;
	padding: 10px 15px;
	cursor: pointer;
	transition: opacity .25s ease,
	color .25s ease;
	vertical-align: bottom;
	text-transform: uppercase;
	opacity: .7;
	color: inherit;
}
.penci-products-tabs .products-tabs-title li:hover,
.penci-products-tabs .products-tabs-title li.active-tab-title {
	opacity: 1
}
.penci-products-tabs .products-tabs-title .tab-label {
	position: relative;
	font-family: var(--pchead-font);
	font-weight: var(--pchead-wei);
}
.penci-products-tabs .penci-tab-content {
	visibility: visible;
	transition: transform .25s ease,
	opacity .25s ease,
	visibility 0s ease;
	transform: none;
	opacity: 1;
}
.penci-products-tabs .penci-tab-content.loading {
	visibility: hidden;
	transition: transform .25s ease,
	opacity .25s ease,
	visibility 0s ease .3s;
	transform: translateY(30px);
	pointer-events: none;
	opacity: 0;
}
.penci-products-tabs.tabs-design-default .penci-tab-content.loading .wrap-loading-arrow,
.penci-products-tabs.tabs-design-alt .penci-tab-content.loading .wrap-loading-arrow {
	display: none
}
.penci-products-tabs.tabs-design-default .penci-tabs-header {
	margin-bottom: 15px
}
.penci-products-tabs.tabs-design-default .tabs-name {
	margin-bottom: 10px
}
.penci-products-tabs.tabs-design-default .products-tabs-title .img-wrapper {
	margin-bottom: 10px;
	display: inline-block;
}
.penci-products-tabs .products-tabs-title .img-wrapper img {
	max-height: 30px;
	width: auto;
}
.penci-products-tabs.tabs-design-alt .penci-tabs-header {
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: space-between;
	margin-bottom: 10px
}
.penci-products-tabs.tabs-design-alt .tabs-name,
.penci-products-tabs.tabs-design-alt .tabs-navigation-wrapper {
	margin-bottom: 10px
}
.penci-products-tabs.tabs-design-alt .products-tabs-title li {
	align-items: center;
	flex-direction: row;
	vertical-align: middle
}
.penci-products-tabs.tabs-design-alt .products-tabs-title .img-wrapper {
	margin-right: 10px
}
.penci-products-tabs.tabs-design-simple .penci-tabs-header {
	display: flex;
	align-items: flex-end;
	flex-direction: row;
	margin-bottom: 20px;
	border-bottom: 2px solid #EAEAEA
}
.penci-products-tabs.tabs-design-simple .tabs-name {
	position: relative;
	z-index: 1;
	margin-right: 25px;
	margin-bottom: -2px;
	padding-top: 5px;
	padding-bottom: 5px;
	vertical-align: middle;
	border-bottom: 2px solid var(--pcaccent-cl);
}
.penci-products-tabs.tabs-design-simple .tabs-name > span {
	vertical-align: bottom
}
.penci-products-tabs.tabs-design-simple .tabs-name .img-wrapper {
	margin-left: 4px
}
.penci-products-tabs.tabs-design-simple .products-tabs-title li {
	font-size: 14px;
	align-items: flex-end;
	flex-direction: row;
}
.penci-products-tabs.tabs-design-simple .products-tabs-title li.active-tab-title {
	color: var(--pcaccent-cl)
}
.penci-products-tabs.tabs-design-simple .products-tabs-title .img-wrapper {
	margin-right: 10px
}
.penci-products-tabs.tabs-design-simple .penci-owl-nav,
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow {
	position: absolute;
	top: -62px;
	animation: ease-in-out .5s ease both .3s
}
.penci-products-tabs.tabs-design-simple .penci-owl-nav > div,
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow > div {
	position: static;
	visibility: visible;
	width: 30px;
	height: 40px;
	margin-top: 0;
	transform: none;
	pointer-events: visible;
	opacity: 1;
}
.penci-products-tabs.tabs-design-simple .penci-owl-nav > div:after,
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow > div:after {
	font-size: 14px;
	font-weight: 700;
}
.penci-products-tabs.tabs-design-simple .penci-owl-nav > div[class*="prev"],
.penci-products-tabs.tabs-design-simple .penci-owl-nav > div[class*="next"],
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow > div[class*="prev"],
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow > div[class*="next"] {
	margin: 0;
	padding: 0
}
.penci-products-tabs.tabs-design-simple .wrap-loading-arrow {
	right: -10px
}
.penci-products-tabs.tabs-design-simple .penci-owl-nav {
	right: 0
}
.penci-products-tabs.tabs-design-simple .penci-carousel-spacing-30 .penci-owl-nav {
	right: 5px
}
.penci-products-tabs.tabs-design-simple .penci-owl-loaded:after,
.penci-products-tabs.tabs-design-simple .penci-owl-loaded:before {
	content: none
}
.penci-products-tabs.tabs-design-simple .penci-products-loader .penci-loader {
	position: absolute;
	top: 30px
}
.penci-products-tabs.tabs-design-simple .penci-tab-content.loading .penci-owl-nav,
.penci-products-tabs.tabs-design-simple .penci-tab-content.loading .wrap-loading-arrow {
	display: none
}
.penci-products-tabs .penci-tab-content-container {
	position: relative;
}
.penci-products-tabs .penci-tab-content-container .penci-custom-products,
.penci-products-tabs .penci-tab-content-container .penci-custom-products .penci-products-preloader {
	display: none;
}
.penci-products-tabs .penci-tab-content-container .penci-custom-products.active {
	display: block;
}
.penci-products-tabs .penci-tab-content-container .penci-products-preloader {
	padding: 30px 0;
}
.elementor-widget-penci_products_tabs .penci-products-preloader,
.penci-products-tabs .penci-tab-content-container .penci-products-preloader {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 999;
	display: flex;
	justify-content: center;
	visibility: hidden;
}
.elementor-widget-penci_products_tabs .elementor-widget-container.pre-load-content .penci-products-preloader,
.penci-products-tabs .penci-tab-content-container.pre-load-content .penci-products-preloader {
	visibility: visible;
}
body #main .elementor-widget-penci_products_tabs .elementor-widget-container.pre-load-content ul.products,
body #main .penci-products-tabs .penci-tab-content-container.pre-load-content ul.products {
	opacity: 0.5;
	pointer-events: none;
}
.elementor-element.loading .penci-tab-content .penci-products-loader {
	display: none !important;
	padding: 30px 0;
}
.penci-tabs-loader {
	position: absolute;
	top: 100%;
	right: 0;
	left: 0;
	visibility: hidden;
	margin-top: 50px;
	text-align: center;
	pointer-events: none;
	opacity: 0;
}
.browser-Safari .penci-tabs-loader {
	visibility: visible
}
.loading .penci-tabs-loader {
	visibility: visible;
	transition: opacity .3s ease,
	visibility .3s ease;
	opacity: 1;
}
.loading .penci-tabs-loader .penci-loader:after {
	animation: pencirotate 450ms infinite linear
}
@media only screen and (max-width: 1169px) {
	.penci-products-tabs.tabs-design-simple .penci-owl-nav > div,
	.penci-products-tabs.tabs-design-simple .wrap-loading-arrow > div {
		justify-content: center
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce.penci-products-tabs {
		overflow: hidden;
	}
	.penci-products-tabs .tabs-name .svg-icon {
		width: 25px !important;
		height: 25px !important
	}
	.penci-products-tabs .tabs-name .img-wrapper img {
		width: auto;
		max-height: 25px;
	}
	.penci-products-tabs .tabs-navigation-wrapper .svg-icon {
		width: 25px !important;
		height: 25px !important
	}
	.penci-products-tabs .tabs-navigation-wrapper .img-wrapper img {
		width: auto;
		max-height: 25px;
	}
	.penci-products-tabs .products-tabs-title {
		margin: 0 0 20px;
	}
	.penci-products-tabs .products-tabs-title::-webkit-scrollbar {
		display: none
	}
	.penci-products-tabs .products-tabs-title li {
		font-size: 14px;
		padding: 7px 10px;
	}
	.penci-products-tabs.tabs-design-alt .tabs-name,
	.penci-products-tabs.tabs-design-alt .tabs-navigation-wrapper {
		flex: 1 1 100%;
		width: 100%;
		max-width: 100%;
	}
	.penci-products-tabs.tabs-design-simple .penci-tabs-header {
		align-items: flex-start;
		flex-direction: column;
		margin-bottom: 10px;
		border-bottom: none
	}
	.penci-products-tabs.tabs-design-simple .tabs-name {
		margin-right: 0
	}
	.penci-products-tabs.tabs-design-simple .tabs-navigation-wrapper {
		flex: 1 1 auto;
		width: 100%;
		max-width: 100%;
		padding-top: 10px;
		border-top: 2px solid #EAEAEA
	}
	.penci-products-tabs.tabs-design-simple .penci-owl-nav,
	.penci-products-tabs.tabs-design-simple .wrap-loading-arrow {
		top: -103px
	}
	.penci-products-tabs.tabs-design-simple .owl-carousel .penci-owl-nav {
		right: -5px
	}
}
/* Hotspot */
.penci-image-hotspot-hotspots {
	position: relative
}
.penci-image-hotspot-img {
	width: 100%
}
.hotspot-content {
	position: absolute;
	z-index: 10;
	visibility: hidden;
	width: 250px;
	padding: 15px;
	transition: opacity .25s ease,
	visibility .25s ease,
	transform .25s ease;
	transform: translateY(20px) translateZ(0);
	text-align: center;
	opacity: 0;
	background: white;
	box-shadow: 0 0 3px rgba(0, 0, 0, 0.15)
}
.hotspot-content > div,
.hotspot-content > h4 {
	margin-bottom: 10px;
	text-decoration: none;
}
.hotspot-content .price {
	font-weight: var(--pchead-wei);
}
.hotspot-content ins {
	text-decoration: none;
}
.hotspot-content del {
	opacity: 0.5;
	font-weight: normal;
}
.hotspot-content .hotspot-content-image {
	margin: -15px -15px 10px;
}
.hotspot-content > div:last-child,
.hotspot-content > h4:last-child {
	margin-bottom: 0
}
.hotspot-content .hotspot-content-text {
	margin-bottom: 15px
}
.hotspot-content .penci-product-title a,
.hotspot-content .hotspot-content-image a {
	display: block;
	text-decoration: none;
	color: var(--pcheading-cl);
}
.post-entry .hotspot-content a:hover,
.wpb_text_column .hotspot-content a:hover,
.hotspot-content .penci-product-title a:hover,
.hotspot-content .hotspot-content-image a:hover {
	text-decoration: none;
}
.hotspot-content .penci-product-title {
	font-size: var(--pcsl_tt_fs);
}
.hotspot-content:before {
	position: absolute;
	content: "";
}
.hotspot-opened .hotspot-content {
	visibility: visible;
	transform: none;
	opacity: 1;
}
.hotspot-content:hover .penci-more-desc-btn {
	transform: translateY(0) translateZ(0)
}
.hotspot-content .price {
	font-size: var(--pcsl_price_fs);
	color: var(--pccat_price_cl);
}
.hotspot-content .add_to_cart_button,
.hotspot-content .product_type_variable {
	font-size: 12px;
	line-height: 16px;
	padding: 10px 14px;
}
.hotspot-content .add_to_cart_button:hover,
.hotspot-content .product_type_variable:hover {
}
.hotspot-content .add_to_cart_button:active,
.hotspot-content .product_type_variable:active {
}
.hotspot-content .added_to_cart {
	display: none
}
.hotspot-dropdown-top,
.hotspot-dropdown-bottom {
	left: -115px
}
.hotspot-dropdown-top:before,
.hotspot-dropdown-bottom:before {
	left: 0;
	width: 100%;
	height: 30px
}
.hotspot-dropdown-top.hotspot-overflow-left,
.hotspot-dropdown-bottom.hotspot-overflow-left {
	right: 0;
	left: auto
}
.hotspot-dropdown-top.hotspot-overflow-right,
.hotspot-dropdown-bottom.hotspot-overflow-right {
	left: 0
}
.hotspot-dropdown-top {
	bottom: 40px
}
.hotspot-dropdown-top:before {
	top: 100%
}
.hotspot-dropdown-bottom {
	top: 40px
}
.hotspot-dropdown-bottom:before {
	bottom: 100%
}
.hotspot-dropdown-left,
.hotspot-dropdown-right {
	top: -55px
}
.hotspot-dropdown-left:before,
.hotspot-dropdown-right:before {
	top: 0;
	width: 30px;
	height: 100%
}
.hotspot-dropdown-left {
	right: 40px
}
.hotspot-dropdown-left:before {
	left: 100%
}
.hotspot-dropdown-left.hotspot-overflow-right {
	right: auto;
	left: 40px
}
.hotspot-dropdown-left.hotspot-overflow-right:before {
	right: 100%;
	left: auto
}
.hotspot-dropdown-right {
	left: 40px
}
.hotspot-dropdown-right:before {
	right: 100%
}
.hotspot-dropdown-right.hotspot-overflow-left {
	right: 40px;
	left: auto
}
.hotspot-dropdown-right.hotspot-overflow-left:before {
	right: auto;
	left: 100%
}
.penci-image-hotspot {
	position: absolute;
	width: 20px;
	height: 20px;
	margin-top: -10px;
	margin-left: -10px;
	transition: opacity .8s ease;
	border-radius: 50%;
	box-shadow: 0 0 3px rgba(0, 0, 0, 0.15);
}
.hotspot-btn,
.hotspot-sonar {
	border-radius: 50%;
	backface-visibility: hidden;
	perspective: 800px
}
.hotspot-btn {
	z-index: 1;
	transition: all .3s ease;
	letter-spacing: normal;
}
.hotspot-action-click .hotspot-btn {
	cursor: pointer
}
.hotspot-btn:after {
	position: absolute;
	content: "";
	transition: all .3s ease
}
@keyframes pencisonar {
	0% {
		opacity: 0;
		transform: scale(0.2);
	}
	50% {
		opacity: .8;
	}
	100% {
		opacity: 0;
		transform: scale(1);
	}
}
@keyframes pencipulse {
	0%,
	100% {
		transform: scale(1);
	}
	50% {
		transform: scale(1.5);
	}
}
.hotspot-sonar {
	position: absolute;
	top: -8px;
	right: -8px;
	bottom: -8px;
	left: -8px;
	display: block;
	animation: pencisonar 2s ease infinite
}
.hotspot-icon-default .hotspot-btn {
	/*animation: pencipulse 2s ease-in-out infinite;*/
	background-color: var(--pcaccent-cl);
	box-shadow: inset 100px 100px transparent;
}
.hotspot-icon-default .hotspot-btn:after {
	top: 7px;
	left: 7px;
	width: 6px;
	height: 6px;
	border-radius: 50%;
	background-color: var(--pcbg-cl);
	animation: pencipulse 2s ease-in-out infinite;
}
.hotspot-icon-default .penci-image-hotspot.hotspot-opened .hotspot-btn {
	box-shadow: inset 100px 100px rgba(0, 0, 0, 0.1)
}
.hotspot-icon-default .hotspot-sonar {
	background-color: rgba(255, 255, 255, 0.5)
}
.hotspot-icon-alt .hotspot-btn {
	background-color: var(--pcbg-cl);
}
.hotspot-icon-alt .hotspot-btn:after {
	font-family: serif;
	font-size: 22px;
	font-weight: 700;
	line-height: 20px;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	content: "+";
	text-align: center;
	color: var(--pcaccent-cl)
}
.hotspot-icon-alt .penci-image-hotspot.hotspot-opened .hotspot-btn:after {
	color: var(--pcbg-cl);
}
.hotspot-icon-alt .penci-image-hotspot.hotspot-opened .hotspot-btn,
.hotspot-icon-alt .penci-image-hotspot:hover .hotspot-btn {
	background-color: var(--pcaccent-cl)
}
.hotspot-icon-alt .hotspot-sonar {
	background-color: var(--pcbg-cl);
}
@keyframes pencisonar {
	0% {
		opacity: 0;
		transform: scale(0.2)
	}
	50% {
		opacity: .8
	}
	100% {
		opacity: 0;
		transform: scale(1)
	}
}
.hotspot-content .add_to_cart_button:after,
.hotspot-content .product_type_variable:after {
	position: absolute;
	top: 50%;
	left: 50%;
	display: inline-block;
	width: 18px;
	height: 18px;
	margin-top: -9px;
	margin-left: -9px;
	content: "";
	transition: opacity 0s ease;
	vertical-align: middle;
	opacity: 0;
	border: 1px solid rgba(255, 255, 255, 0.3);
	border-left-color: var(--pcbg-cl);
	border-radius: 50%;
}
.hotspot-content .loading.add_to_cart_button,
.hotspot-content .loading.product_type_variable {
	color: transparent !important
}
.hotspot-content .loading.add_to_cart_button:after,
.hotspot-content .loading.product_type_variable:after {
	transition: opacity .25s ease;
	animation: pencirotate 450ms infinite linear;
	opacity: 1;
}
.hotspot-action-hover .hotspot-content {
	pointer-events: none
}
.hotspot-action-hover .penci-image-hotspot:hover .hotspot-content {
	visibility: visible;
	transform: none;
	pointer-events: visible;
	opacity: 1;
}
.hotspot-icon-default .penci-image-hotspot:hover .hotspot-btn {
	box-shadow: inset 100px 100px rgba(255, 255, 255, 0.1)
}
.hotspot-icon-alt .penci-image-hotspot:hover .hotspot-btn:after {
	color: var(--pcbg-cl);
}
@media only screen and (max-width: 767px) {
	.hotspot-type-product .hotspot-content-text {
		display: none
	}
	.hotspot-type-product .penci-entities-title,
	.hotspot-type-product .price {
		font-size: 14px
	}
	.hotspot-content {
		top: 40px;
		right: auto;
		bottom: auto
	}
	.hotspot-dropdown-left,
	.hotspot-dropdown-right {
		left: -115px
	}
	.hotspot-icon-alt .penci-image-hotspot:hover:not(.hotspot-opened) .hotspot-btn {
		background-color: var(--pcbg-cl);
	}
}
@media only screen and (max-width: 767px) {
	body.mobile-bottom-nav-active {
		padding-bottom: 60px;
	}
}
.penci-mobile-bottom-nav {
	position: fixed;
	z-index: 99999;
	right: 0;
	bottom: 0;
	left: 0;
	display: none;
	border-top: 1px solid var(--pcpage_gbdr_cl);
	background-color: var(--pcbg-cl);
	-moz-box-shadow: 0 -1px 5px rgba(190, 190, 190, 0.46);
	-webkit-box-shadow: 0 -1px 5px rgba(190, 190, 190, 0.46);
	box-shadow: 0 -1px 5px rgba(190, 190, 190, 0.46);
}
.penci-mobile-bottom-nav nav {
	display: flex;
	flex-shrink: 0;
}
@media only screen and (max-width: 767px) {
	.penci-mobile-bottom-nav {
		display: block;
	}
}
.penci-mobile-bottom-nav nav ul {
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-shrink: 0;
	flex-wrap: wrap;
	justify-content: space-between;
	width: 100%;
}
.penci-mobile-bottom-nav nav ul li .penci-footer-icon {
	display: block;
	width: 20px;
	max-height: 20px;
	margin: 0 auto 5px;
}
.penci-mobile-bottom-nav nav ul li {
	display: inline-flex;
	position: relative;
}
.penci-mobile-bottom-nav nav ul li .current-item {
	font-size: 8px;
	line-height: 14px;
	position: absolute;
	z-index: 1;
	top: calc(50% - 30px);
	right: calc(50% - 20px);
	display: inline-block;
	width: 14px;
	height: 14px;
	-moz-transition: all 0.3s;
	-webkit-transition: all 0.3s;
	transition: all 0.3s;
	text-align: center;
	white-space: nowrap;
	color: var(--pcbg-cl);
	-moz-border-radius: 50%;
	-webkit-border-radius: 50%;
	border-radius: 50%;
	background: var(--pcaccent-cl);
}
.penci-mobile-bottom-nav nav ul li:last-child {
	border-right: 0;
}
.penci-mobile-bottom-nav nav ul li a {
	font-size: 12px;
	font-weight: bold;
	display: block;
	min-width: 50px;
	padding: 15px 10px;
	transition: all 0.3s ease-in-out;
	text-align: center;
	opacity: .75;
	text-transform: capitalize;
	color: var(--pctext-cl);
}
@media only screen and (max-width: 376px) {
	.penci-mobile-bottom-nav nav ul li a {
		padding: 15px 5px;
		min-width: auto;
	}
}
.penci-mobile-bottom-nav nav ul li a:hover {
	opacity: 1;
}
.penci-mobile-bottom-nav nav ul li i {
	font-size: 14px;
	display: block;
	font-family: 'penciicon';
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.penci-mobile-bottom-nav nav ul li i:before {
	font-family: inherit;
	display: inline-block;
}
.penci-mobile-bottom-nav nav ul li i.home:before {
	content: "\f16e";
}
.penci-mobile-bottom-nav nav ul li i.shop:before {
	content: "\f16d";
}
.penci-mobile-bottom-nav nav ul li i.wishlist:before {
	content: "\f109";
}
.penci-mobile-bottom-nav nav ul li i.compare:before {
	content: "\f16b";
}
.penci-mobile-bottom-nav nav ul li i.cart:before {
	content: "\f10c";
}
.penci-mobile-bottom-nav nav ul li i.account:before {
	content: "\f16f";
}
.penci-mobile-bottom-nav nav ul li i.filter:before {
	content: "\f169";
	transform: rotate(90deg);
}
@media only screen and (max-width: 767px) {
	.penci-header-signup-form {
		margin-bottom: 30px;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products.penci-owl-carousel .owl-item li {
		width: 100% !important;
		margin-right: 0 !important;
	}
}
/* Restyle */
.woocommerce div.product .product_title {
	font-size: var(--pcs_fsp_single_tt);
	margin: 0;
}
.woocommerce div.product.penci-summary-align-center .single-product-share {
	justify-content: center;
}
.single-product-share .list-posts-share {
	display: flex;
}
@media only screen and (min-width: 768px) {
	.woocommerce div.product .product_title {
		padding-right: 110px;
	}
	.woocommerce div.product.penci-summary-align-center .product_title {
		padding-left: 110px;
	}
	.woocommerce div.product.top-related-posts-hidden .product_title,
	.woocommerce div.product.penci-product-img-fullwidth .product_title,
	.woocommerce div.product.penci-product-img-fullwidth-container .product_title,
	.woocommerce div.product.penci-product-img-large .product_title {
		padding-left: 0;
		padding-right: 0;
	}
	.woocommerce div.product.penci-summary-align-center .woocommerce-product-rating .star-rating {
		display: inline-block;
		float: none;
	}
	.woocommerce div.product.penci-product-fullwidth-container .product_title {
		padding-right: 0;
	}
	.woocommerce div.product.penci-product-fullwidth-container .penci-single-product-top-container {
		overflow: visible;
	}
	.woocommerce div.product.penci-product-fullwidth-container .penci-top-relate-post {
		top: -50px;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product .product_title {
		font-size: var(--pcs_fsp_single_m_tt);
	}
	.woocommerce div.product .woocommerce-product-rating .star-rating {
		float: none;
	}
}
.woocommerce div.product p.price ins, .woocommerce div.product span.price ins,
.woocommerce div.product p.price, .woocommerce div.product span.price {
	font-size: var(--pcs_fsp_price);
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product p.price ins, .woocommerce div.product span.price ins,
	.woocommerce div.product p.price, .woocommerce div.product span.price {
		font-size: var(--pcs_fsp_m_price);
	}
}
body.single .container.penci-breadcrumb span,
body.single .container.penci-breadcrumb span a,
body.single .container.penci-breadcrumb i,
body.single.woocommerce .container.penci-breadcrumb.penci-woo-breadcrumb.top,
.woocommerce div.product div.summary .penci-woo-breadcrumb {
	font-size: var(--pcs_fsp_breadcrumb);
}
@media only screen and (max-width: 767px) {
	body.single .container.penci-breadcrumb span,
	body.single .container.penci-breadcrumb span a,
	body.single .container.penci-breadcrumb i,
	body.single.woocommerce .container.penci-breadcrumb.penci-woo-breadcrumb.top,
	.woocommerce div.product div.summary .penci-woo-breadcrumb {
		font-size: var(--pcs_fsp_m_breadcrumb);
	}
}
.woocommerce div.product div[itemprop="description"] p,
.woocommerce div.product .woocommerce-tabs #tab-description p,
.woocommerce-product-details__short-description p {
	font-size: var(--pcs_fsp_general);
	color: var(--pcpage_gtext_cl);
}
.woocommerce div.product div[itemprop="description"] a,
.woocommerce div.product .woocommerce-tabs #tab-description a,
.woocommerce-product-details__short-description a {
	color: var(--pcpage_glink_cl);
}
.woocommerce div.product div[itemprop="description"] a:hover,
.woocommerce div.product .woocommerce-tabs #tab-description a:hover,
.woocommerce-product-details__short-description a:hover {
	color: var(--pcpage_glink_hv_cl);
}
.woocommerce div.product .woocommerce-tabs ul.tabs {
	padding-bottom: 20px;
	margin-bottom: 30px;
}
.woocommerce div.product .woocommerce-tabs ul.tabs li a {
	font-size: var(--pcs_fsp_tab_tt);
	color: var(--pcpage_tab_tt_cl);
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product .woocommerce-tabs ul.tabs li a {
		font-size: var(--pcs_fsp_tab_m_tt);
	}
}
.woocommerce div.product .woocommerce-tabs ul.tabs li.active a {
	color: var(--pcpage_tab_tt_active_cl);
}
.woocommerce .widget.woocommerce.widget_product_categories li span.count {
	float: right;
}
.woocommerce .widget_shopping_cart p.buttons a,
.woocommerce.widget_shopping_cart p.buttons a,
.woocommerce .widget_price_filter .price_slider_amount .button,
.woocommerce div.product form.cart .button {
	background-color: var(--pcpage_btn_atc_bg_cl);
}
.woocommerce .widget_shopping_cart p.buttons a:hover,
.woocommerce.widget_shopping_cart p.buttons a:hover,
.woocommerce .widget_price_filter .price_slider_amount .button:hover,
.woocommerce div.product form.cart .button:hover {
	background-color: var(--pcpage_btn_atc_bg_hv_cl);
}
.woocommerce div.product .product_meta > span > * {
	font-size: var(--pcs_fsp_meta);
	color: var(--pcpage_meta_cl);
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product .product_meta > span > * {
		font-size: var(--pcs_fsp_m_meta);
	}
}
.woocommerce div.product .product_meta > span a,
.woocommerce div.product .product_meta > span a + * {
	color: var(--pcpage_meta_link_cl);
}
.woocommerce div.product .product_meta > span a:hover {
	color: var(--pcpage_meta_link_hv_cl);
}
.woocommerce ul.products li.product h3, .woocommerce ul.products li.product .woocommerce-loop-product__title {
	font-size: var(--pcsl_tt_fs);
}
.woocommerce ul.products.product-list li.product h3,
.woocommerce ul.products.product-list li.product .woocommerce-loop-product__title {
	font-size: var(--pcsl_tt_l_fs);
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products li.product h3, .woocommerce ul.products li.product .woocommerce-loop-product__title {
		font-size: var(--pcsl_tt_m_fs);
	}
	.woocommerce ul.products.product-list li.product h3,
	.woocommerce ul.products.product-list li.product .woocommerce-loop-product__title {
		font-size: var(--pcsl_tt_l_m_fs);
	}
}
li.product .penci-product-cats {
	font-size: var(--pcsl_meta_fs);
	color: var(--pccat_cat_cl);
}
@media only screen and (max-width: 767px) {
	li.product .penci-product-cats {
		font-size: var(--pcsl_meta_m_fs);
	}
}
.woocommerce ul.products li.product .price ins,
.woocommerce ul.products li.product .price {
	font-size: var(--pcsl_price_fs);
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products li.product .price ins,
	.woocommerce ul.products li.product .price {
		font-size: var(--pcsl_price_m_fs);
	}
}
.woocommerce ul.products .penci-soledad-product .penci-product-loop-button > a:before {
	font-size: var(--pcsl_btn_icon_size);
	color: var(--pcl_btn_group_txt_color);
}
.woocommerce ul.products:not(.product-style-7):not(.product-style-5) .penci-soledad-product .penci-product-loop-button > a:hover {
	background-color: var(--pcl_btn_group_bg_hv_color);
}
.woocommerce ul.products .penci-soledad-product .penci-product-loop-button > a:hover:before {
	color: var(--pcl_btn_group_txt_hv_color);
}
.woocommerce .penci-page-header h1 {
	color: var(--pcwp_tt_cl);
}
.woocommerce #respond input#submit.alt,
.woocommerce a.button.alt,
.woocommerce button.button.alt,
.woocommerce input.button.alt {
	color: var(--pcbg-cl);
}
.woocommerce #respond input#submit.alt:hover,
.woocommerce a.button.alt:hover,
.woocommerce button.button.alt:hover,
.woocommerce input.button.alt:hover {
	color: var(--pcwp_btn_alt_bg_hv_cl);
}
.woocommerce #respond input#submit,
.woocommerce a.button,
.woocommerce button.button,
.woocommerce input.button {
	line-height: 40px;
	display: inline-flex;
	align-items: center;
	justify-content: center;
	padding: 0 30px;
	color: white;
	background-color: var(--pcwp_btn_bg_cl);
}
.woocommerce #respond input#submit {
	color: white;
}
.woocommerce #respond input#submit:hover,
.woocommerce a.button:hover,
.woocommerce button.button:hover,
.woocommerce input.button:hover {
	opacity: 0.8;
	background-color: var(--pcwp_btn_bg_hv_cl);
}
.woocommerce div.product .product_meta,
.woocommerce div.product .woocommerce-tabs ul.tabs {
	border-color: var(--pcpage_gbdr_cl);
}
/* Brand */
.brands-widget .brand-item {
	text-align: center;
}
.brands-widget .brand-item a {
	display: block;
	padding: 20px;
}
.brands-widget .brand-item img {
	width: auto;
	height: auto;
	max-height: 60px;
	display: inline-block;
}
.brands-carousel .owl-carousel:not(.penci-owl-loaded),
.brands-carousel .owl-stage {
	display: flex;
	align-items: center;
}
.brands-list .brand-item {
	margin-bottom: 15px;
	text-align: left;
}
.brands-list .brand-item a {
	padding: 0;
	color: var(--pcheading-cl);
	text-decoration: none;
}
.brands-list .brand-item a:hover {
	color: var(--pcaccent-cl);
}
.brands-style-bordered {
	border: 1px solid var(--pcpage_gbdr_cl);
	border-right: 0;
	border-bottom: 0;
}
.brands-style-bordered.brands-list {
	border: 0;
}
.brands-style-bordered .brand-item {
	border-width: 1px;
	border-color: var(--pcpage_gbdr_cl);
}
.brands-style-bordered.brands-grid {
	overflow: hidden;
}
.brands-style-bordered.brands-grid .row {
	margin-right: -2px;
	margin-bottom: -2px;
}
.brands-style-bordered.brands-grid .brand-item {
	border-right-style: solid;
	border-bottom-style: solid;
}
.brands-style-bordered.brands-carousel .brand-item {
	border-right-style: solid;
}
.brands-style-bordered.brands-carousel {
	border: 0;
}
.brands-style-bordered.brands-carousel .owl-stage-outer,
.brands-style-bordered.brands-carousel .owl-carousel:not(.penci-owl-loaded) {
	border: 1px solid var(--pcpage_gbdr_cl);
}
.brands-style-bordered.brands-carousel .owl-stage-outer {
	margin-right: 1px;
	margin-left: 1px;
}
.brands-style-bordered.brands-carousel .owl-item:last-child .brand-item {
	border-right-style: none;
}
.brands-style-bordered.brands-list .row {
	margin-right: -10px;
	margin-left: -10px;
}
.brands-style-bordered.brands-list .brand-item {
	margin-bottom: 10px;
	padding-right: 10px;
	padding-left: 10px;
}
.brands-style-bordered.brands-list .brand-item > a {
	padding-bottom: 10px;
	border-bottom: 1px solid var(--pcpage_gbdr_cl);
}
.brands-style-bordered[data-hide_pagination_control="no"] .owl-carousel:not(.penci-owl-loaded) {
	padding-bottom: 0 !important;
}
.brands-hover-simple .brand-item img {
	transition: filter .3s ease;
	filter: grayscale(100%);
}
.brands-hover-simple .brand-item:hover img {
	filter: grayscale(0);
}
.brands-hover-alt .brand-item img {
	transition: filter .3s ease,
	opacity .3s ease;
	opacity: .5;
	filter: grayscale(100%);
}
.brands-hover-alt .brand-item:hover img {
	opacity: 1;
	filter: grayscale(0);
}
.penci-custom-row {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
}
.penci-custom-row .column-item {
	align-self: center;
}
.penci-custom-row.row-2 .column-item {
	flex: 0 0 auto;
	width: 50%;
}
.penci-custom-row.row-3 .column-item {
	flex: 0 0 auto;
	width: 33.3333333333%;
}
.penci-custom-row.row-4 .column-item {
	flex: 0 0 auto;
	width: 25%;
}
.penci-custom-row.row-5 .column-item {
	flex: 0 0 auto;
	width: 20%;
}
.penci-custom-row.row-5 .column-item {
	flex: 0 0 auto;
	width: 16.6666666667%;
}
/* Filter */
.penci-product-filters {
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-wrap: wrap;
	margin-right: -5px;
	margin-left: -5px
}
.penci-product-filters .penci-pf-checkboxes {
	flex: 1 1 200px;
	width: 0
}
.penci-product-filters > div {
	margin-bottom: 10px;
	padding-right: 5px;
	padding-left: 5px
}
.penci-pf-btn button {
	font-weight: bold;
	padding: 13px 15px;
	color: var(--pcwp_tt_cl);
	border: 0;
	background-color: var(--pcwp_btn_bg_cl);
	transition: all 0.3s ease-in-out;
}
.penci-pf-btn button:hover {
	color: white;
	background-color: var(--pcwp_btn_bg_hv_cl);
}
.penci-pf-btn button:active {
	bottom: var(--pcwp_btn_bg_hv_cl);
	box-shadow: var(--pcwp_tt_cl);
}
.penci-pf-checkboxes {
	position: relative
}
.penci-pf-title {
	line-height: 1;
	position: relative;
	display: flex;
	align-items: center;
	flex-direction: row;
	height: 40px;
	padding-right: 40px;
	padding-left: 15px;
	cursor: pointer;
	user-select: none;
	transition: border-color .5s ease;
	color: #333;
	border: 1px solid var(--pcpage_gbdr_cl);
}
.penci-pf-title .title-text {
	font-size: 12px;
	font-weight: 600;
	flex: 1 0 auto;
	text-transform: uppercase;
}
.penci-pf-title:after {
	font-family: "penciicon";
	font-size: 12px;
	position: absolute;
	top: 50%;
	right: 15px;
	content: "\f11e";
	transition: transform .2s ease;
	color: #B7B7B7;
	backface-visibility: hidden;
	-webkit-backface-visibility: hidden;
	font-size: 12px;
	transform: translatey(-47%);
}
.penci-pf-title:hover {
	border-color: rgba(129, 129, 129, 0.3)
}
.opened .penci-pf-title:after {
	transform: rotate(-180deg)
}
.penci-product-filters.color-scheme-light .penci-pf-title {
	color: var(--pcbg-cl);
	border-color: rgba(255, 255, 255, 0.15);
}
.penci-product-filters.color-scheme-light .penci-pf-title:after {
	color: rgba(255, 255, 255, 0.8)
}
.penci-product-filters.color-scheme-light .penci-pf-title:hover {
	border-color: rgba(255, 255, 255, 0.4)
}
.penci-pf-results {
	line-height: 1;
	overflow: hidden;
	white-space: nowrap;
}
.woocommerce ul.penci-pf-results li {
	font-size: 12px;
	font-weight: 600;
	position: relative;
	display: inline-block;
	margin-left: 5px;
	margin-bottom: 0;
	padding: 4px 8px;
	transition: all .25s ease;
	color: #333;
	background-color: #F1F1F1;
}
.woocommerce ul.penci-pf-results li:after {
	font-family: "penciicon", serif;
	font-size: 8px;
	position: absolute;
	top: 50%;
	left: 7px;
	margin-top: -6px;
	content: "\f110";
	transition: all 0.3s ease-in-out;
	opacity: 0;
}
.woocommerce ul.penci-pf-results li:hover {
	padding-left: 20px
}
.woocommerce ul.penci-pf-results li:hover:after {
	opacity: 1
}
.penci-pf-dropdown {
	position: absolute;
	z-index: 300;
	top: 100%;
	right: 0;
	left: 0;
	display: none;
	overflow: hidden;
	width: auto;
	height: auto;
	margin: 0 5px;
	background-color: #FFF;
	box-shadow: 0 0 3px rgba(0, 0, 0, 0.15)
}
.penci-pf-dropdown .pf-value {
	font-size: 14px;
	line-height: 20px;
	display: flex;
	align-items: center;
	flex-direction: row;
	padding: 8px 18px;
	cursor: pointer;
	transition: all .25s ease;
	color: #777;
}
.penci-product-filters ul.penci-pf-results,
.penci-product-filters .penci-pf-dropdown ul {
	margin: 0;
	padding: 0;
	list-style: none;
}
.penci-pf-dropdown ul a:hover {
	text-decoration: none;
}
.penci-pf-dropdown .pf-value:hover {
	color: #777;
	background-color: #F9F9F9;
}
.penci-pf-dropdown .pf-active > .pf-value {
	font-weight: 600;
	color: #333;
}
.penci-pf-dropdown .swatches-brands .filter-swatch span {
	border: none !important;
	border-radius: 0;
}
.penci-pf-dropdown .swatches-brands:not(.show-labels-off) .filter-swatch span:after {
	content: none
}
.penci-pf-dropdown .swatches-brands.show-labels-off .filter-swatch span:after {
	color: #2d2a2a;
	border-radius: 0;
	background-color: rgba(255, 255, 255, 0.6);
}
.penci-pf-dropdown .show-labels-off {
	padding: 10px
}
.penci-pf-dropdown .show-labels-off .filter-swatch {
	margin-right: 0
}
.penci-pf-dropdown .show-labels-off li {
	display: inline-block
}
.penci-pf-dropdown .show-labels-off .pf-value:hover {
	background-color: transparent !important
}
.penci-pf-dropdown .show-labels-off .swatch-inner {
	margin: 6px;
	padding: 0
}
.penci-pf-dropdown .show-labels-off li:not(.with-swatch-text) .layer-term-name {
	display: none
}
.penci-product-filters.color-scheme-light .penci-pf-dropdown {
	background-color: #101010
}
.penci-product-filters.color-scheme-light .penci-pf-dropdown .pf-value {
	color: rgba(255, 255, 255, 0.8)
}
.penci-product-filters.color-scheme-light .penci-pf-dropdown .pf-value:hover {
	color: rgba(255, 255, 255, 0.8);
	background-color: rgba(255, 255, 255, 0.08);
}
.penci-product-filters.color-scheme-light .penci-pf-dropdown .pf-active > .pf-value {
	color: var(--pcbg-cl)
}
.penci-product-filters.color-scheme-light .penci-pf-dropdown .swatches-brands.show-labels-off .filter-swatch span:after {
	color: var(--pcbg-cl);
	background-color: rgba(0, 0, 0, 0.6);
}
.penci-pf-price-range .penci-pf-dropdown {
	padding: 20px
}
.penci-pf-price-range .ui-slider-horizontal {
	margin-bottom: 20px
}
.penci-pf-price-range .filter_price_slider_amount {
	margin-right: -20px;
	margin-bottom: -20px;
	margin-left: -20px;
	padding: 6px 20px;
	text-align: center;
	border-top: 1px solid rgba(119, 119, 119, 0.2);
	background-color: #F9F9F9;
}
.penci-pf-price-range .price_label {
	font-size: 14px;
	font-weight: 600;
	color: #2d2a2a;
}
.penci-pf-price-range .price_label .from:after {
	margin-right: 10px;
	margin-left: 10px;
	content: "-";
}
.penci-product-filters.color-scheme-light .penci-pf-price-range .filter_price_slider_amount {
	background-color: rgba(0, 0, 0, 0.3)
}
.penci-product-filters.color-scheme-light .penci-pf-price-range .price_label {
	color: var(--pcbg-cl);
}
.penci-pf-categories .children .pf-value {
	padding-left: 35px
}
.penci-pf-categories .children .children .pf-value {
	padding-left: 55px
}
.woocommerce table.shop_table thead tr th {
	border-width: 2px;
}
.woocommerce table.shop_table a.remove {
	font-size: 0;
	border: 0;
}
.woocommerce table.shop_table a.remove:before {
	font-family: penciicon;
	font-size: 8px;
	content: '\f110';
	transition: opacity .3s ease-in-out;
	opacity: .8;
	color: black;
}
.woocommerce table.shop_table a.remove:hover:before {
	opacity: 1;
}
.single-product-share {
	position: relative;
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-wrap: wrap;
	margin-top: 15px;
}
.single-product-share .share-title {
	font-weight: bold;
	margin-right: 5px;
}
.single-product-share a {
	display: inline-flex;
	align-items: center;
	justify-content: center;
	width: 36px;
	height: 36px;
	margin-right: 12px;
	transition: all 0.3s ease-in-out;
	color: var(--pctext-cl);
	border: 1px solid var(--pcpage_gbdr_cl);
	border-radius: 50%;
}
.penci-share-icon-style-square .single-product-share a {
	border-radius: 0;
}
.penci-share-style-3 .single-product-share a {
	border-color: #eee;
	background-color: #eee;
}
.penci-share-style-3 .single-product-share a:hover {
	color: var(--pcbg-cl);
}
.penci-share-style-4 .single-product-share a {
	width: auto;
	height: auto;
	border: 0;
	margin-right: 10px;
}
.penci-share-style-4 .single-product-share a:last-child {
	margin-right: 0;
}
.single-product-share a:hover {
	color: var(--pcbg-cl);
}
.penci-share-style-4 .single-product-share a:hover {
	color: var(--pcaccent-cl);
}
.penci-share-style-2 .single-product-share a,
.penci-share-style-3 .single-product-share a:hover {
	color: var(--pcbg-cl);
	border: 0;
}
.penci-share-style-2 .single-product-share a:hover {
	opacity: 0.85;
}
.single-product-share a:last-child {
	margin-right: 0;
}
.single-product-share .dt-share {
	display: none;
}
.penci-product-brands .penci-product-brand a {
	display: inline-block;
	max-width: 100px;
	margin: 0 0 15px;
	padding: 5px;
	border: 1px solid var(--pcpage_gbdr_cl);
}
.penci-product-brands .penci-product-brand .brand-title {
	display: none;
}
.penci-product-brands .penci-product-brand a {
	display: block;
}
.product_meta .penci-product-brands .penci-product-brand {
	display: flex;
	align-items: center;
}
.penci-summary-align-center .product_meta .penci-product-brands .penci-product-brand {
	justify-content: center;
}
.product_meta .penci-product-brands .penci-product-brand a,
.product_meta .penci-product-brands .penci-product-brand .brand-title {
	display: inline-flex;
}
.product_meta .penci-product-brands .penci-product-brand a {
	margin-left: 10px;
	margin-bottom: 0;
}
.product_meta .penci-product-brands .penci-product-brand .brand-title {
	font-weight: bold;
	color: var(--pcheading-cl);
}
#add_payment_method #payment ul.payment_methods li,
.woocommerce-cart #payment ul.payment_methods li,
.woocommerce-checkout #payment ul.payment_methods li {
	margin-bottom: 15px;
	padding-bottom: 15px;
	cursor: pointer;
	border-bottom: 1px solid var(--pcpage_gbdr_cl);
}
#add_payment_method #payment ul.payment_methods li:last-child,
.woocommerce-cart #payment ul.payment_methods li:last-child,
.woocommerce-checkout #payment ul.payment_methods li:last-child {
	margin-bottom: 0 !important;
}
.woocommerce .penci_woo_pages_breadcrumbs {
	display: flex;
	flex: 1 1 100%;
	justify-content: center;
	margin-bottom: 60px;
}
@media only screen and (max-width: 767px) {
	.woocommerce .penci_woo_pages_breadcrumbs {
		text-align: center;
		margin-bottom: 30px;
	}
}
.woocommerce .penci_woo_pages_breadcrumbs ul {
	margin: 0;
	padding: 0;
	list-style: none;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li {
	display: inline-block;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li:after {
	font-family: penciicon !important;
	display: inline-block;
	margin: 0 15px;
	content: "\f11a";
	font-size: 80%;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li:last-child:after {
	display: none;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li span,
.woocommerce .penci_woo_pages_breadcrumbs ul li a {
	font-size: 18px;
	font-weight: bold;
	text-decoration: none;
	color: var(--pctext-cl);
}
@media only screen and (max-width: 767px) {
	.woocommerce .penci_woo_pages_breadcrumbs ul li span,
	.woocommerce .penci_woo_pages_breadcrumbs ul li a {
		font-size: 14px;
	}
	.woocommerce .penci_woo_pages_breadcrumbs ul li:after {
		margin: 0 5px;
	}
}
.woocommerce .penci_woo_pages_breadcrumbs ul li.inactive {
	opacity: .5;
}
.woocommerce .penci_woo_pages_breadcrumbs ul li a:hover {
	color: var(--pcaccent-cl);
}
.header-header-ecommerce .main-nav-social {
	margin-right: 0;
	padding-right: 0;
	border-right: 0;
}
.header-header-ecommerce .header-middle-content {
	padding: 20px 0;
}
.header-header-ecommerce #logo {
	text-align: left;
}
.header-header-ecommerce #logo img {
	width: auto;
	max-width: 100%;
	height: auto;
	max-height: 35px;
}
.header-header-ecommerce .is-sticky #navigation.header-layout-bottom {
	border: 0;
}
@media only screen and (min-width: 768px) and (max-width: 960px) {
	.header-header-ecommerce #logo img {
		max-width: 100%;
	}
}
.header-header-ecommerce #navigation .container {
	display: block;
}
.header-header-ecommerce .main-nav-wrapper,
.header-header-ecommerce .sub-nav-wrapper,
.header-header-ecommerce .header-middle-content .penci-wrap {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	margin-right: -15px;
	margin-left: -15px;
}
.header-header-ecommerce .main-nav-wrapper > div,
.header-header-ecommerce .sub-nav-wrapper > div,
.header-header-ecommerce .header-middle-content .penci-wrap > div {
	align-self: center;
	padding-right: 15px;
	padding-left: 15px;
}
.header-header-ecommerce #navigation .sub-nav-wrapper > ul.menu {
	overflow: hidden;
	overflow-x: auto;
	align-self: center;
	padding-right: 15px;
	padding-left: 15px;
	white-space: nowrap;
}
.header-header-ecommerce #navigation .sub-nav-wrapper > ul.menu > li {
	float: none;
}
.header-header-ecommerce .header-middle-content .penci-wrap .penci-header-shop-logo {
	flex: 0 0 auto;
	width: 25%;
}
.header-header-ecommerce .header-middle-content .penci-wrap .penci-header-shop-search {
	flex: 0 0 auto;
	width: 55%;
}
.header-header-ecommerce .header-middle-content .penci-wrap .penci-header-shop-tools {
	flex: 0 0 auto;
	width: 20%;
}
.penci-header-shop-tools {
	font-size: 13px;
	display: flex;
	align-items: center;
	flex-direction: row;
	flex-wrap: wrap;
	justify-content: flex-end;
}
.penci-header-shop-tools .top-search-classes.shoping-cart-icon {
	float: none;
	margin-right: 0;
}
.penci-header-shop-tools .pcshop-login-btn {
	font-family: var(--pchd_mn_font);
}
.penci-header-shop-tools .pcshop-login-btn img.avatar {
	margin-right: 5px;
	border-radius: 50%;
}
.penci-header-shop-tools .pcshop-login-btn li {
	position: relative;
}
.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a {
	display: flex;
	align-items: center;
}
.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a span > span {
	margin: 0;
}
.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a span > span:first-child:after {
	display: inline-block;
	margin: 0 2px;
	content: '/';
}
@media only screen and (max-width: 767px) {
	.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a > i {
		font-size: 28px;
		opacity: .5;
	}
	.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a span > span {
		display: block;
	}
	.penci-header-shop-tools .pcshop-login-btn li.pclogin-item > a span > span:first-child:after {
		display: none;
	}
}
.penci-header-shop-tools .pcshop-login-btn li a {
	color: var(--pcheading-cl);
}
.penci-header-shop-tools .pcshop-login-btn li ul {
	position: absolute;
	z-index: 9;
	top: 100%;
	left: 0;
	visibility: hidden;
	width: 170px;
	margin-top: 10px;
	padding: 10px;
	transition: 0.3s all ease-in-out;
	opacity: 0;
	border: 1px solid var(--pcborder-cl);
	background-color: var(--pcbg-cl);
}
.penci-header-shop-tools .pclogin-item.login.login-popup {
	font-weight: bold;
}
.penci-header-shop-tools .pcshop-login-btn li:hover ul {
	visibility: visible;
	opacity: 1;
}
.penci-header-shop-tools .pcshop-login-btn li ul li {
	margin-bottom: 10px;
	padding-bottom: 10px;
	border-bottom: 1px solid var(--pcborder-cl);
}
.penci-header-shop-tools .pcshop-login-btn li ul li i {
	display: inline-block;
	margin-right: 5px;
}
.penci-header-shop-tools .pcshop-login-btn li ul li:last-child {
	margin-bottom: 0;
	padding-bottom: 0;
	border-bottom: 0;
}
.header-header-ecommerce .penci-menu-wrap {
	flex: 0 0 auto;
	width: 82%;
}
.header-header-ecommerce .penci-header-extra {
	flex: 0 0 auto;
	width: 18%;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu {
	flex: 0 0 auto;
	width: 30%;
}
.header-header-ecommerce .sub-nav-wrapper > .menu {
	flex: 0 0 auto;
	width: 70%;
}
.header-header-ecommerce .vertical-shop-menu-title-wrapper {
	font-family: var(--pchd_mn_font);
	padding: 0 20px;
	text-align: left;
	color: #fff;
	background-color: #000;
}
.header-header-ecommerce .vertical-shop-menu-title-wrapper i {
	display: inline-block;
	margin-right: 10px;
}
.header-header-ecommerce .vertical-shop-menu-title {
	font-size: 15px;
	font-weight: bold;
	line-height: 58px;
}
.header-header-ecommerce .penci-vertical-shop-menu {
	position: absolute;
	top: calc(100%);
	right: 0;
	left: 0;
}
.header-header-ecommerce .vertical-shop-menu.close .penci-vertical-shop-menu,
.header-header-ecommerce .is-sticky .penci-vertical-shop-menu {
	display: none;
}
.header-header-ecommerce .vertical-shop-menu.close li:hover .penci-vertical-shop-menu,
.header-header-ecommerce .is-sticky li:hover .penci-vertical-shop-menu {
	display: block;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul.menu-shop {
	width: 23%;
	text-align: left;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul > li {
	display: block;
	float: none;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul > li.penci-mega-menu > a:after {
	font-family: FontAwesome, serif;
	float: right;
	content: '\f107';
	transform: rotate(-90deg);
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul > li > a {
	font-family: var(--pchd_mn_font);
	font-size: 12px;
	font-weight: var(--pchd_mn_font_w);
	position: relative;
	z-index: 99;
	display: block;
	padding: 15px;
	text-transform: uppercase;
	color: var(--pcheading-cl);
	border: 1px solid #ececec;
	border-top: 0;
	background-color: var(--pcbg-cl);
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul > li > a:hover {
	background-color: #f9f9f9;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul ul > li a:hover {
	color: #000;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul.sub-menu,
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul.sub-menu > li {
	margin: 0;
	padding: 0;
	border: 0;
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu ul.sub-menu {
	position: absolute;
	z-index: 9999;
	top: 0;
	right: 0;
	bottom: 0;
	display: block;
	visibility: hidden;
	width: calc(77%);
	transition: all 0.3s ease-in-out;
	-moz-transform: translate(0, 15px);
	-ms-transform: translate(0, 15px);
	-o-transform: translate(0, 15px);
	-webkit-transform: translate(0, 15px);
	transform: translate(0, 15px);
	opacity: 0;
	background-color: var(--pcbg-cl);
}
.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu li.penci-mega-menu:hover > ul.sub-menu {
	visibility: visible;
	-moz-transform: translate(0, 0);
	-ms-transform: translate(0, 0);
	-o-transform: translate(0, 0);
	-webkit-transform: translate(0, 0);
	transform: translate(0, 0);
	opacity: 1;
}
.woocommerce-notices-wrapper {
	flex: 100%;
	margin-top: 30px;
}
.woocommerce-notices-wrapper:empty {
	display: none;
}
.penci-search-cat {
	font-family: var(--pchd_mn_font);
	font-size: 13px;
	position: relative;
	display: flex;
	align-items: center;
	width: 35%;
	height: 45px;
	padding: 0 20px;
	border-left: 1px solid var(--pcborder-cl);
}
.penci-search-cat:after {
	font-family: "penciicon";
	font-size: 12px;
	position: absolute;
	top: 0;
	right: 10px;
	bottom: 0;
	display: flex;
	align-items: center;
	content: "\f11c";
}
.penci-search-cat > a {
	color: var(--pchead-font);
}
.penci-search-cat .penci-dropdown {
	position: absolute;
	z-index: 99;
	top: 100%;
	left: -1px;
	visibility: hidden;
	overflow: hidden;
	overflow-y: auto;
	width: 240px;
	max-height: 390px;
	opacity: 0;
}
.penci-search-cat:hover .penci-dropdown {
	visibility: visible;
	opacity: 1;
}
.penci-search-cat .penci-dropdown ul {
	border: 1px solid var(--pcborder-cl);
}
.penci-search-cat .penci-dropdown ul ul {
	border: 0;
}
.penci-search-cat .penci-dropdown ul li a {
	display: block;
	padding: 10px 20px;
	color: var(--pcheading-cl);
	background-color: var(--pcbg-cl);
}
.header-header-ecommerce #navigation.menu-item-padding .menu > li.current-menu-item > a,
.header-header-ecommerce #navigation.menu-item-padding .menu > li.current_page_item > a {
	color: var(--pcaccent-cl);
	background-color: transparent;
}
.header-header-ecommerce #navigation.menu-item-padding .menu > li > a:hover,
.header-header-ecommerce #navigation.menu-item-padding .menu > li:hover > a {
	color: var(--pcaccent-cl);
	background-color: transparent;
}
@media only screen and (max-width: 960px) {
	.header-header-ecommerce .penci-menu-wrap,
	.header-header-ecommerce .penci-header-shop-search {
		display: none;
	}
	.header-header-ecommerce .penci-header-extra {
		width: 80%;
	}
	.header-header-ecommerce .header-middle-content .penci-wrap .penci-header-shop-logo,
	.header-header-ecommerce .header-middle-content .penci-wrap .penci-header-shop-tools {
		width: 50%;
	}
	.header-header-ecommerce .header-middle-content .penci-wrap,
	.header-header-ecommerce .main-nav-wrapper {
		justify-content: space-between;
		padding-right: 15px;
		padding-left: 15px;
	}
	.woocommerce-cart table.cart td.actions .coupon .input-text {
		width: 170px;
		min-width: unset;
	}
}
@media only screen and (min-width: 768px) and (max-width: 1170px) {
	.header-header-ecommerce .sub-nav-wrapper .vertical-shop-menu {
		width: 35%;
	}
	.header-header-ecommerce .sub-nav-wrapper > .menu {
		width: 65%;
	}
}
@media only screen and (max-width: 767px ) {
	.woocommerce-cart table.cart td.actions .coupon .input-text {
		width: 100%;
	}
	body.woocommerce-cart .entry-content .woocommerce .cart-collaterals .cart_totals table td {
		padding-right: 15px;
	}
}
.header-countdown {
	position: relative;
	margin-bottom: 30px;
}
.header-countdown .ends-text {
	display: inline-block;
	letter-spacing: 0.05rem;
	text-transform: uppercase;
}
.header-countdown .penci-product-countdown {
	display: flex;
	flex-direction: row;
	flex-wrap: wrap;
	margin: 0 -5px;
}
.header-countdown .penci-product-countdown > span {
	font-size: 20px;
	font-weight: bold;
	line-height: 1;
	display: block;
	margin: 0 5px;
	padding: 10px;
	text-align: center;
	border: 1px solid #ececec;
}
.countdown-style-round .header-countdown .penci-product-countdown > span {
	display: flex;
	align-items: center;
	flex-direction: column;
	flex-wrap: wrap;
	justify-content: center;
	min-width: 75px;
	min-height: 75px;
	border-radius: 50%;
}
.header-countdown .penci-product-countdown > span > span {
	font-size: 12px;
	font-weight: normal;
	display: block;
	text-transform: uppercase;
}
.penci-deal-footer-link {
	margin-top: 60px;
	text-align: center;
}
nav.woocommerce-MyAccount-navigation ul {
	margin: 0;
	padding: 0;
	list-style: none;
}
@media only screen and (min-width: 960px) {
	nav.woocommerce-MyAccount-navigation ul {
		margin-right: 30px;
		padding-right: 60px;
		border-right: 1px solid var(--pcborder-cl);
	}
}
nav.woocommerce-MyAccount-navigation ul li {
	list-style: none;
}
nav.woocommerce-MyAccount-navigation ul li a {
	font-weight: bold;
	display: block;
	margin-bottom: 15px;
	padding-bottom: 15px;
	color: var(--pcheading-cl);
	border-bottom: 1px solid var(--pcborder-cl);
}
nav.woocommerce-MyAccount-navigation ul li.is-active a,
nav.woocommerce-MyAccount-navigation ul li a:hover {
	text-decoration: none;
	color: var(--pcaccent-cl);
}
.woocommerce .woocommerce-MyAccount-content .button,
.woocommerce .woocommerce-MyAccount-content button {
	margin-top: 0;
	padding-right: 30px;
	padding-left: 30px;
}
.woocommerce .woocommerce-MyAccount-content button:hover {
	color: #fff;
}
/* hover color default*/
.penci-share-style-1 .single-product-share a.post-share-facebook:hover {
	border-color: #0d47a1;
}
.penci-share-style-1 .single-product-share a.post-share-twitter:hover {
	border-color: #40c4ff;
}
.penci-share-style-1 .single-product-share a.post-share-pinterest:hover {
	border-color: #bd081c;
}
.penci-share-style-1 .single-product-share a.post-share-linkedin:hover {
	border-color: #0077b5;
}
.penci-share-style-1 .single-product-share a.post-share-tumblr:hover {
	border-color: #34465d;
}
.penci-share-style-1 .single-product-share a.post-share-email:hover {
	border-color: #0084ff;
}
.penci-share-style-1 .single-product-share a.post-share-vk:hover {
	border-color: #5181b8;
}
.penci-share-style-1 .single-product-share a.post-share-pocket:hover {
	border-color: #ef4056;
}
.penci-share-style-1 .single-product-share a.post-share-skype:hover {
	border-color: #00aff0;
}
.penci-share-style-1 .single-product-share a.post-share-whatsapp:hover {
	border-color: #00E676;
}
.penci-social-colored a i.fa-heart-o {
	border-color: #000;
}
.penci-share-style-1 .single-product-share a.post-share-telegram:hover {
	border-color: #289FD9;
}
.penci-share-style-1 .single-product-share a.post-share-reddit:hover {
	border-color: #F74300;
}
.penci-share-style-1 .single-product-share a.post-share-ok:hover {
	border-color: #F18F00;
}
.penci-share-style-1 .single-product-share a.post-share-stumbleupon:hover {
	border-color: #EB4823;
}
.penci-share-style-1 .single-product-share a.post-share-viber:hover {
	border-color: #7d51a0;
}
/* end*/
.penci-share-style-2 .single-product-share a.post-share-facebook,
.penci-share-style-3 .single-product-share a.post-share-facebook:hover,
.penci-share-style-1 .single-product-share a.post-share-facebook:hover {
	background: #0d47a1;
}
.penci-share-style-2 .single-product-share a.post-share-twitter,
.penci-share-style-3 .single-product-share a.post-share-twitter:hover,
.penci-share-style-1 .single-product-share a.post-share-twitter:hover {
	background: #40c4ff;
}
.penci-share-style-2 .single-product-share a.post-share-pinterest,
.penci-share-style-3 .single-product-share a.post-share-pinterest:hover,
.penci-share-style-1 .single-product-share a.post-share-pinterest:hover {
	background: #bd081c;
}
.penci-share-style-2 .single-product-share a.post-share-linkedin,
.penci-share-style-3 .single-product-share a.post-share-linkedin:hover,
.penci-share-style-1 .single-product-share a.post-share-linkedin:hover {
	background: #0077b5;
}
.penci-share-style-2 .single-product-share a.post-share-tumblr,
.penci-share-style-3 .single-product-share a.post-share-tumblr:hover,
.penci-share-style-1 .single-product-share a.post-share-tumblr:hover {
	background: #34465d;
}
.penci-share-style-2 .single-product-share a.post-share-email,
.penci-share-style-3 .single-product-share a.post-share-email:hover,
.penci-share-style-1 .single-product-share a.post-share-email:hover {
	background: #0084ff;
}
.penci-share-style-2 .single-product-share a.post-share-vk,
.penci-share-style-3 .single-product-share a.post-share-vk:hover,
.penci-share-style-1 .single-product-share a.post-share-vk:hover {
	background: #5181b8;
}
.penci-share-style-2 .single-product-share a.post-share-pocket,
.penci-share-style-3 .single-product-share a.post-share-pocket:hover,
.penci-share-style-1 .single-product-share a.post-share-pocket:hover {
	background: #ef4056;
}
.penci-share-style-2 .single-product-share a.post-share-skype,
.penci-share-style-3 .single-product-share a.post-share-skype:hover,
.penci-share-style-1 .single-product-share a.post-share-skype:hover {
	background: #00aff0;
}
.penci-share-style-2 .single-product-share a.post-share-whatsapp,
.penci-share-style-3 .single-product-share a.post-share-whatsapp:hover,
.penci-share-style-1 .single-product-share a.post-share-whatsapp:hover {
	background: #00E676;
}
.penci-social-colored a i.fa-heart-o {
	background: #000;
}
.penci-share-style-2 .single-product-share a.post-share-telegram,
.penci-share-style-3 .single-product-share a.post-share-telegram:hover,
.penci-share-style-1 .single-product-share a.post-share-telegram:hover {
	background: #289FD9;
}
.penci-share-style-2 .single-product-share a.post-share-reddit,
.penci-share-style-3 .single-product-share a.post-share-reddit:hover,
.penci-share-style-1 .single-product-share a.post-share-reddit:hover {
	background: #F74300;
}
.penci-share-style-2 .single-product-share a.post-share-ok,
.penci-share-style-3 .single-product-share a.post-share-ok:hover,
.penci-share-style-1 .single-product-share a.post-share-ok:hover {
	background: #F18F00;
}
.penci-share-style-2 .single-product-share a.post-share-stumbleupon,
.penci-share-style-3 .single-product-share a.post-share-stumbleupon:hover,
.penci-share-style-1 .single-product-share a.post-share-stumbleupon:hover {
	background: #EB4823;
}
.penci-share-style-2 .single-product-share a.post-share-viber,
.penci-share-style-3 .single-product-share a.post-share-viber:hover,
.penci-share-style-1 .single-product-share a.post-share-viber:hover {
	background: #7d51a0;
}
.woocommerce #review_form_wrapper form .required {
	color: red;
}
.woocommerce #review_form_wrapper form .comment-form-rating {
	display: flex;
	margin-bottom: 0;
}
.woocommerce #review_form #respond p.stars,
.woocommerce #review_form_wrapper form .comment-form-rating label,
.woocommerce #review_form_wrapper form .comment-form-rating p.stars {
	display: inline-block;
	margin-bottom: 0;
	vertical-align: middle;
}
.woocommerce #review_form #respond p.stars > span {
	display: inline-block;
	padding: 5px 0 0 15px;
	vertical-align: middle;
}
@media only screen and (min-width: 960px) {
	.woocommerce div.product .woocommerce-tabs .panel #review_form #respond p.comment-form-email,
	.woocommerce div.product .woocommerce-accordion-item #respond p.comment-form-email,
	.woocommerce div.product .woocommerce-tabs .panel #review_form #respond p.comment-form-author,
	.woocommerce div.product .woocommerce-accordion-item #respond p.comment-form-author {
		float: left;
		width: 48%;
		margin-right: 0;
		margin-left: 0;
	}
	.woocommerce div.product .woocommerce-tabs .panel #review_form #respond p.comment-form-author,
	.woocommerce div.product .woocommerce-accordion-item #review_form #respond p.comment-form-author {
		float: right;
		margin-right: 0;
	}
	.woocommerce-form-coupon-toggle,
	form.checkout_coupon.woocommerce-form-coupon {
		max-width: calc(60% - 12px);
		margin-right: auto;
		margin-left: auto;
	}
	form.checkout_coupon.woocommerce-form-coupon .form-row {
		width: 49%;
	}
	form.checkout_coupon.woocommerce-form-coupon p {
		text-align: center;
	}
	form.checkout_coupon.woocommerce-form-coupon .form-row.form-row-first {
		width: 65%;
	}
	form.checkout_coupon.woocommerce-form-coupon .form-row.form-row-last {
		width: 32%;
	}
	form.checkout_coupon.woocommerce-form-coupon .button {
		display: block;
		width: 100%;
	}
}
@media only screen and (max-width: 960px) {
	.woocommerce-form-coupon-toggle,
	form.checkout_coupon.woocommerce-form-coupon {
		max-width: calc(50% - 12px);
	}
	form.checkout_coupon.woocommerce-form-coupon .form-row.form-row-first,
	form.checkout_coupon.woocommerce-form-coupon .form-row.form-row-last {
		width: 100%;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce-form-coupon-toggle,
	form.checkout_coupon.woocommerce-form-coupon {
		width: 100%;
		max-width: 100%;
	}
	body.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner {
		padding: 20px;
	}
	h3#order_review_heading {
		padding: 15px 0;
		text-align: center;
	}
}
.penci-active-filters ul {
	margin-bottom: 30px;
}
.woocommerce .penci-active-filters .widget_layered_nav_filters ul li {
	padding-right: 10px;
	margin-right: 10px;
	border-right: 1px solid var(--pcborder-cl);
}
.woocommerce .penci-active-filters .widget_layered_nav_filters ul li:last-child {
	padding-right: 0;
	margin-right: 0;
	border-right: 0;
}
.woocommerce .penci-active-filters .widget_layered_nav_filters ul li a:hover {
	color: var(--pctext-cl);
}
.woocommerce .penci-active-filters .widget_layered_nav_filters ul li a:hover:before {
	color: var(--pcaccent-cl);
}
@keyframes bubble {
	0%, 100% {
		transform: scale(0)
	}
	50% {
		transform: scale(1)
	}
}
@-webkit-keyframes bubble {
	0%, 100% {
		transform: scale(0)
	}
	50% {
		transform: scale(1)
	}
}
.penci-loading-icon {
	display: flex;
	justify-content: center;
	align-items: center;
	text-align: center;
	vertical-align: middle;
}
.penci-loading-icon * {
	-webkit-animation-play-state: paused;
	animation-play-state: paused
}
.penci-loading-icon .bubble:after {
	display: block;
	width: 100%;
	height: 100%;
	content: '';
	transform-origin: 50% 50%;
	-webkit-animation: bubble 1.2s -.6s infinite ease-out;
	animation: bubble 1.2s -.6s infinite ease-out;
	border-radius: 50%;
	background-color: var(--pcbg-cl);
}
.penci-products-preloader > .penci-loading-icon .bubble:after {
	background-color: var(--pctext-cl);
}
.penci-loading-icon .bubble {
	display: inline-block;
	width: 10px;
	height: 10px;
	margin: 0 5px
}
.penci-loading-icon .bubble:nth-child(2n):after {
	-webkit-animation-delay: -.3s;
	animation-delay: -.3s
}
.penci-loading-icon .bubble:nth-child(3n):after {
	-webkit-animation-delay: 0s;
	animation-delay: 0s
}
.button {
	position: relative;
}
.button .penci-loading-icon {
	position: absolute;
	z-index: 2;
	top: 0;
	right: 0;
	bottom: 0;
	left: 0;
	transition: opacity 0.3s ease-in-out;
	opacity: 0;
}
.woocommerce .button.has-new-preload.loading:before,
.woocommerce .button.has-new-preload.loading:after {
	display: none;
}
.woocommerce .button.has-new-preload.loading,
.woocommerce div.product form.cart .button.has-new-preload.loading,
.woocommerce div.product form.cart .button.has-new-preload.loading:hover {
	color: transparent !important;
}
.woocommerce .button.has-new-preload.loading .penci-loading-icon {
	opacity: 1;
}
.woocommerce div.product form.cart .variations {
	margin-bottom: 0;
}
.woocommerce div.product form.cart .variations .penci-swatches {
	display: inline-block;
	vertical-align: top;
}
.pswp {
	z-index: 99999;
}
.woocommerce .return-to-shop .button {
	padding-top: 0;
	padding-bottom: 0;
}
.woocommerce .woocommerce-checkout-review-order-table th {
	border-bottom: 0;
}
.penci-woo-page-container.next_previous {
	position: relative;
}
.penci-woo-page-container.next_previous .woocommerce-pagination {
	margin: 0;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li {
	margin: 0;
	line-height: 28px;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a,
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li span {
	display: none;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers,
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.next.page-numbers {
	display: block;
	margin: 0 5px;
	border: 0;
}
.penci-woo-page-container.next_previous ul.products {
	position: relative;
	z-index: 99;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li {
	display: initial;
	margin: 0;
	padding: 0;
	overflow: visible;
	position: static;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers,
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.next.page-numbers {
	font-size: 0;
	position: absolute;
	width: 50px;
	height: 50px;
	top: 50%;
	z-index: 999;
	right: -40px;
	text-align: center;
	transform: translate(30px, 0);
	transition: 0.3s all ease-in-out;
	margin: -55px 0 0 0;
	opacity: 0;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers {
	right: auto;
	left: -40px;
	transform: translate(-30px, 0);
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers:before,
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.next.page-numbers:before {
	content: '\f11a';
	font-family: "penciicon", serif;
	font-size: 24px;
	line-height: 50px;
}
.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers:before {
	content: '\f11b';
}
.penci-woo-page-container.next_previous:hover .woocommerce-pagination .page-numbers li a.prev.page-numbers,
.penci-woo-page-container.next_previous:hover .woocommerce-pagination .page-numbers li a.next.page-numbers {
	transform: translate(0, 0);
	opacity: 1;
}
@media only screen and (max-width: 767px) {
	.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers,
	.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.next.page-numbers {
		transform: translate(0, 0);
		opacity: 1;
	}
	.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.next.page-numbers {
		right: 0;
	}
	.penci-woo-page-container.next_previous .woocommerce-pagination .page-numbers li a.prev.page-numbers {
		right: auto;
		left: 0;
	}
}
.woocommerce ul.products.penci-owl-carousel {
	flex-wrap: nowrap;
	overflow: hidden;
}
.woocommerce ul.products.penci-owl-carousel.penci-owl-loaded {
	flex-wrap: wrap;
}
.woocommerce ul.products.penci-owl-carousel.penci-owl-loaded li.product {
	width: 100%;
}
.select2-container .select2-selection--single .select2-selection__rendered {
	padding-left: 20px;
}
.select2-results__option {
	padding: 6px 20px;
}
.select2-search--dropdown {
	padding: 4px 20px;
}
.select2-container--default .select2-search--dropdown .select2-search__field {
	border-color: var(--pcpage_gbdr_cl);
}
.select2-search--dropdown .select2-search__field {
	padding: 10px;
}
.select2-container--default .select2-selection--single .select2-selection__arrow {
	right: 15px;
}
.select2-container--default .select2-results__option--highlighted[aria-selected], .select2-container--default .select2-results__option--highlighted[data-selected] {
	background-color: var(--pcaccent-cl);
}
.penci-scroll ::-webkit-scrollbar,
.penci-scroll::-webkit-scrollbar,
.penci-products-compare-table.penci-multicompare ::-webkit-scrollbar,
.quick-shop-form::-webkit-scrollbar,
.sidebar-filter-container ::-webkit-scrollbar,
.sidebar-cart-container .widget_shopping_cart_content ::-webkit-scrollbar,
.penci-header-cart-detail .widget_shopping_cart_content ::-webkit-scrollbar {
	width: 5px;
}
.penci-scroll ::-webkit-scrollbar-track,
.penci-scroll::-webkit-scrollbar-track,
.sidebar-filter-container ::-webkit-scrollbar-track,
.quick-shop-form::-webkit-scrollbar-track,
.penci-products-compare-table.penci-multicompare ::-webkit-scrollbar-track,
.sidebar-cart-container .widget_shopping_cart_content ::-webkit-scrollbar-track,
.penci-header-cart-detail .widget_shopping_cart_content ::-webkit-scrollbar-track {
	background-color: var(--penci-scrollbar-track-bg);
}
.penci-scroll ::-webkit-scrollbar-thumb,
.penci-scroll::-webkit-scrollbar-thumb,
.sidebar-filter-container ::-webkit-scrollbar-thumb,
.quick-shop-form::-webkit-scrollbar-thumb,
.penci-products-compare-table.penci-multicompare ::-webkit-scrollbar-thumb,
.sidebar-cart-container .widget_shopping_cart_content ::-webkit-scrollbar-thumb,
.penci-header-cart-detail .widget_shopping_cart_content ::-webkit-scrollbar-thumb {
	background-color: var(--penci-scrollbar-thumb-bg);
}
.tippy-box[data-placement^="top"] {
	top: 4px;
}
.tippy-box[data-placement^="left"] {
	left: 4px;
}
.tippy-box[data-placement^="right"] {
	right: 4px;
}
.tippy-box[data-placement^="bottom"] {
	bottom: 4px;
}
.woocommerce div.product .related > h2, .woocommerce div.product .upsells > h2 {
	border-bottom-color: var(--pcpage_gbdr_cl);
}
.dark-layout-enabled .penci-woo-before-main-content .penci-products-per-page a {
	color: var(--pcmeta-cl);
}
.dark-layout-enabled .penci-woo-before-main-content .penci-products-shop-view .current-variation svg.icon {
	fill: rgba(255, 255, 255, .9);
}
.dark-layout-enabled .variations select,
.dark-layout-enabled .woocommerce-ordering select,
.dark-layout-enabled .penci-widget-layered-nav-dropdown-form select {
	background-color: transparent;
	color: var(--pctext-cl);
}
.dark-layout-enabled .penci-top-relate-post ul li.item-shop-link svg {
	fill: var(--pcmeta-cl);
}
.woocommerce form .form-row textarea.input-text,
.woocommerce-page form .form-row textarea.input-text
.woocommerce form .form-row textarea {
	padding-top: 10px;
	padding-bottom: 10px;
}
.woocommerce-MyAccount-content fieldset {
	padding: 30px;
	margin-bottom: 30px;
	border: 1px solid var(--pcborder-cl);
}
.woocommerce-MyAccount-content label {
	font-weight: bold;
}
.woocommerce-MyAccount-content fieldset legend {
	background-color: var(--pcbg-cl);
	display: inline-block;
	padding: 0 10px;
	font-weight: bold;
}
.woocommerce .woocommerce-MyAccount-content .woocommerce-error,
.woocommerce .woocommerce-MyAccount-content .woocommerce-info,
.woocommerce .woocommerce-MyAccount-content .woocommerce-message {
	display: flex;
	justify-content: space-between;
	align-items: center;
	flex-wrap: wrap;
	flex-direction: row-reverse;
}
.woocommerce .woocommerce-MyAccount-content .woocommerce-error:before,
.woocommerce .woocommerce-MyAccount-content .woocommerce-info:before,
.woocommerce .woocommerce-MyAccount-content .woocommerce-message:before {
	top: 0;
	bottom: 0;
	display: flex;
	align-items: center;
}
.woocommerce .woocommerce-MyAccount-content .woocommerce-error:after,
.woocommerce .woocommerce-MyAccount-content .woocommerce-info:after,
.woocommerce .woocommerce-MyAccount-content .woocommerce-message:after {
	display: none;
}
@media only screen and (max-width: 767px) {
	.woocommerce-MyAccount-content .woocommerce-account .woocommerce-MyAccount-content,
	.woocommerce-account .woocommerce-MyAccount-navigation {
		float: none;
		width: 100%;
	}
	.woocommerce .woocommerce-MyAccount-content .woocommerce-error,
	.woocommerce .woocommerce-MyAccount-content .woocommerce-info,
	.woocommerce .woocommerce-MyAccount-content .woocommerce-message {
		flex-direction: column-reverse;
	}
	ul.products .penci-soledad-product .penci-product-loop-button a.button.penci-quickview-button,
	ul.products .penci-soledad-product .penci-product-loop-button a.button.penci-compare {
		display: none;
	}
}
@media only screen and (min-width: 961px) {
	.woocommerce .penci_sidebar div.product.penci-product-img-fullwidth-container div.summary,
	.woocommerce-page .penci_sidebar div.product.penci-product-img-fullwidth-container div.summary,
	.woocommerce .product.penci-product-img-fullwidth-container div.summary {
		max-width: var(--pc-sf-sum-w);
		width: auto;
		margin-left: auto;
		margin-right: auto;
	}
}
@media only screen and (min-width: 728px) and (max-width: 960px) {
	.woocommerce .product.penci-product-img-fullwidth-container div.summary {
		width: 726px;
		margin-left: auto;
		margin-right: auto;
	}
}
@media only screen and (min-width: 480px) and (max-width: 767px) {
	.woocommerce .product.penci-product-img-fullwidth-container div.summary {
		width: 440px;
		margin-left: auto;
		margin-right: auto;
	}
}
@media only screen and (max-width: 479px) {
	.woocommerce .product.penci-product-img-fullwidth-container div.summary {
		width: 100%;
	}
	.woocommerce .penci-woo-page-container {
		padding-left: 20px;
		padding-right: 20px;
	}
	.woocommerce.penci-products-tabs .penci-woo-page-container {
		padding-left: 0;
		padding-right: 0;
	}
}
.woocommerce .products ul.penci-woo-product-loop-categories {
	display: flex;
	flex-wrap: wrap;
	flex-direction: row;
	margin-bottom: 60px;
	padding-bottom: 30px;
	position: relative;
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.columns-4 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.columns-4 li.product {
	width: 25%;
}
.woocommerce .products ul.penci-woo-product-loop-categories.display-style-carousel {
	flex-wrap: nowrap;
	overflow: hidden;
	margin-left: 0;
	margin-right: 0;
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-6 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-6 li.product {
	width: calc(16.6666666667% - 25px);
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-5 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-5 li.product {
	width: calc(20% - 24px);
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-4 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-4 li.product {
	width: calc(25% - 22px);
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-3 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-3 li.product {
	width: calc(33.3333333333% - 20px);
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-2 li.product,
.woocommerce-page ul.products ul.penci-woo-product-loop-categories.display-style-carousel.columns-2 li.product {
	width: calc(50% - 15px);
}
.woocommerce .products ul.penci-woo-product-loop-categories.display-style-carousel.penci-owl-loaded {
	flex-wrap: wrap;
	overflow: visible;
}
.woocommerce .products ul.penci-woo-product-loop-categories.display-style-carousel li {
	margin-bottom: 0;
	padding: 1px;
	margin-right: 30px;
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products li.product-category .woocommerce-loop-category__wrapper {
		padding: 10px;
	}
	.woocommerce ul.products li.product .woocommerce-loop-category__title {
		font-size: var(--pcl_l_cat_tt_fs_m);
	}
	.woocommerce ul.products li.product span.count {
		font-size: var(--pcl_l_cat_fs_m);
	}
}
@media only screen and (min-width: 767px) {
	.woocommerce .products ul.penci-woo-product-loop-categories {
		padding-left: 15px;
		padding-right: 15px;
	}
}
.woocommerce .products ul.penci-woo-product-loop-categories:after {
	content: '';
	position: absolute;
	bottom: 0;
	left: 30px;
	right: 30px;
	border-bottom: 1px solid var(--pcpage_gbdr_cl);
	display: block;
}
.woocommerce ul.products ul.penci-woo-product-loop-categories.penci-woo-product-loop-categories.penci-owl-carousel:after {
	left: 15px;
	right: 15px;
}
@media only screen and (min-width: 1170px) and (max-width: 1399px) {
	.woocommerce ul.products.columns-6:not(.display-style-carousel) li.product,
	.woocommerce-page ul.products.columns-6:not(.display-style-carousel) li.product {
		margin-right: 0;
		width: 20%;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce ul.products ul.penci-woo-product-loop-categories.penci-woo-product-loop-categories:after {
		left: 0;
		right: 0;
	}
	.woocommerce ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) ul.products.penci-woo-product-loop-categories.penci-owl-carousel li.product-category,
	.woocommerce-page ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) ul.products.penci-woo-product-loop-categories.penci-owl-carousel li.product-category {
		width: calc(50% - 10px) !important;
		margin-right: 20px !important;
	}
	.woocommerce ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list):not(.swiper) ul.products.penci-woo-product-loop-categories.penci-owl-carousel.penci-owl-loaded li.product-category,
	.woocommerce-page ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list):not(.swiper) ul.products.penci-woo-product-loop-categories.penci-owl-carousel.penci-owl-loaded li.product-category,
	.woocommerce .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list):not(.swiper) ul.products.penci-woo-product-loop-categories.penci-owl-carousel.penci-owl-loaded li.product-category,
	.woocommerce-page .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list):not(.swiper) ul.products.penci-woo-product-loop-categories.penci-owl-carousel.penci-owl-loaded li.product-category {
		width: 100% !important;
		margin-right: 0 !important;
	}
	.pswp {
		z-index: 99999999;
	}
}
@media only screen and (min-width: 768px) and (max-width: 1169px) {
	.woocommerce ul.products.columns-6:not(.display-style-carousel) li.product,
	.woocommerce-page ul.products.columns-6:not(.display-style-carousel) li.product,
	.woocommerce ul.products.columns-5:not(.display-style-carousel) li.product,
	.woocommerce-page ul.products.columns-5:not(.display-style-carousel) li.product{
		margin-right: 0;
		width: 33.3333333333%;
	}
}
@media only screen and (min-width: 768px) and (max-width: 960px) {
	.woocommerce ul.products.columns-5:not(.display-style-carousel) li.product,
	.woocommerce-page ul.products.columns-5:not(.display-style-carousel) li.product,
	.woocommerce ul.products.columns-4:not(.display-style-carousel) li.product,
	.woocommerce-page ul.products.columns-4:not(.display-style-carousel) li.product {
		margin-right: 0;
		width: 33.3333333333%;
	}
	.woocommerce ul.products.columns-5:not(.display-style-carousel) > li.product:nth-child( 4n+4 ),
	.woocommerce-page ul.products.columns-5:not(.display-style-carousel) > li.product:nth-child( 4n+4 ),
	.woocommerce ul.products.columns-4:not(.display-style-carousel) > li.product:nth-child( 4n+4 ),
	.woocommerce-page ul.products.columns-4:not(.display-style-carousel) > li.product:nth-child( 4n+4 ) {
		margin-right: 0;
	}
	.woocommerce .products ul.penci-woo-product-loop-categories.display-style-carousel:not(.penci-owl-loaded) li {
		margin-right: 30px !important;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce .product.penci-product-img-medium div.images,
	.woocommerce .product.penci-product-img-medium div.summary {
		float: none;
		width: 100%;
	}
	.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
		top: 10px;
		right: auto;
		bottom: auto;
		left: 10px;
	}
	.penci-review-style-default #comments,
	.penci-review-style-default #review_form_wrapper {
		flex: 100%;
		max-width: 100%;
	}
	.penci-review-style-default #review_form_wrapper {
		margin-top: 30px;
	}
	.penci-products-shop-view.products-view-grid_list {
		display: none;
	}
	.penci-woo-before-main-content .woocommerce-ordering {
		width: 5%;
		flex: 0 0 auto;
	}
	.penci-woo-before-main-inner-content.content-right {
		padding-top: 15px;
		border-top: 1px solid #ECECEC;
	}
	.penci-woo-before-main-inner-content.content-right .penci-products-per-page {
		font-weight: bold;
		text-transform: uppercase;
	}
	.penci-woo-before-main-inner-content .penci-product-top-filter-button {
		margin-right: 0;
	}
	.woocommerce .widget .woocommerce-ordering,
	.woocommerce-page .widget .woocommerce-ordering {
		float: none;
		width: 100%;
	}
	.woocommerce .widget .woocommerce-ordering select,
	.woocommerce-page .widget .woocommerce-ordering select {
		width: 100%;
		max-width: unset;
	}
	.woocommerce nav.woocommerce-pagination ul li,
	.woocommerce .woocommerce-pagination ul.page-numbers li,
	.woocommerce-page .woocommerce-pagination ul.page-numbers li {
		float: none;
	}
	.woocommerce .products ul.penci-woo-product-loop-categories.display-style-carousel:not(.penci-owl-loaded) li {
		margin-right: 30px !important;
	}
	body.woocommerce-cart .entry-content .woocommerce .woocommerce-cart-form, body.woocommerce-cart .entry-content .woocommerce .cart-collaterals {
		padding-left: 0;
		padding-right: 0;
	}
}
@media only screen and (min-width: 479px) and (max-width: 767px) {
	.penci-woo-before-main-inner-content.content-left {
		padding-top: 15px;
	}
}
@media only screen and (max-width: 767px) {
	.container.penci-breadcrumb.penci-woo-breadcrumb.top {
		padding: 0;
	}
	.woocommerce ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list),
	.woocommerce-page ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list),
	.woocommerce .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list),
	.woocommerce-page .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) {
		margin-left: -5px;
		margin-right: -5px;
	}
	.woocommerce ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) li.product,
	.woocommerce-page ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) li.product,
	.woocommerce .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) li.product,
	.woocommerce-page .penci_sidebar ul.products.mobile-columns-2:not(.penci-owl-carousel):not(.product-list) li.product {
		width: 50% !important;
		margin-right: 0 !important;
		margin-bottom: 15px;
		padding-left: 5px;
		padding-right: 5px;
	}
	.woocommerce ul.products.mobile-columns-2 li.product:nth-child(2n+2),
	.woocommerce-page ul.products.mobile-columns-2 li.product:nth-child(2n+2),
	.woocommerce ul.products.mobile-columns-2 li.product:nth-child(2n+2),
	.woocommerce-page ul.products.mobile-columns-2 li.product:nth-child(2n+2),
	.woocommerce .penci_sidebar ul.mobile-columns-2 > li.product:nth-child(2n+2),
	.woocommerce-page .penci_sidebar ul.mobile-columns-2 > li.product:nth-child(2n+2) {
		margin-right: 0 !important;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content {
		flex: 100%;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-left {
		justify-content: space-between;
		padding-top: 10px;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-left .penci-container-inside.penci-woo-breadcrumb, .container.penci-woo-breadcrumb {
		width: 50% !important;
	}
	body.single-product .penci-woo-before-main-content .penci-woo-before-main-inner-content.content-left .penci-container-inside.penci-woo-breadcrumb,
	body.single-product .container.penci-woo-breadcrumb {
		width: 100% !important;
	}
	body.woocommerce-page .woocommerce-products-header {
		margin-left: -20px;
		margin-right: -20px;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content {
		padding-left: 20px;
		padding-right: 20px;
	}
	.penci-product-top-filter-button {
		margin-left: 0;
	}
	.woocommerce .content-left .container.penci-breadcrumb.penci-woo-breadcrumb.top {
		width: auto !important;
	}
	.woocommerce .penci-woo-before-main-inner-content.content-left .woocommerce-result-count {
		margin: 0;
		font-size: 13px;
		text-align: right;
		align-self: center;
		display: flex;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right {
		justify-content: space-between;
		margin-top: 15px;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .penci-products-per-page {
		display: none;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .penci-products-per-page,
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .woocommerce-ordering {
		flex: 0 0 48%;
		max-width: 48%;
		margin: 0;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .woocommerce-ordering {
		width: 30px;
		flex: 0 0 auto;
		position: relative;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .woocommerce-ordering select {
		opacity: 0;
	}
	.penci-woo-before-main-content .penci-woo-before-main-inner-content.content-right .woocommerce-ordering:before {
		opacity: 1;
		content: '\f16b';
		transform: rotate(90deg);
		font-family: 'penciicon', serif;
		position: absolute;
		text-align: center;
		line-height: 30px;
		font-size: 18px;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
	}
	.variations select,
	.woocommerce-ordering select {
		width: 100%;
		max-width: 160px;
	}
	body.single.single-product #header,
	body.post-type-archive-product #header {
		margin-bottom: 15px;
	}
	body.single.single-product #header {
		margin-bottom: 0;
	}
	.woocommerce div.product div.images,
	.woocommerce div.product div.summary {
		margin-bottom: 15px;
	}
	.woocommerce div.product div.summary .penci-woo-breadcrumb {
		overflow-x: scroll;
		margin-bottom: 15px;
		white-space: nowrap;
	}
	.penci-top-relate-post {
		position: relative;
	}
	.penci-top-relate-post ul {
		justify-content: space-between;
		margin-bottom: 15px;
		padding-bottom: 15px;
		border-bottom: 1px solid var(--pcborder-cl);
	}
	body.tax-product_cat #header {
		margin-bottom: 10px;
	}
}
@media only screen and (max-width: 767px) {
	.woocommerce-product-gallery.thumbnail-left .penci-product-gallery-slider {
		margin-left: 0;
	}
	.woocommerce-product-gallery.thumbnail-right .penci-product-gallery-slider {
		margin-right: 0;
	}
	.woocommerce-product-gallery.thumbnail-right .penci-thumbnail-slider,
	.woocommerce-product-gallery.thumbnail-left .penci-thumbnail-slider {
		position: relative;
		top: 0;
		right: 0;
		bottom: 0;
		left: 0;
		width: 100%;
		height: auto;
		margin-top: 10px;
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav {
		position: static;
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button {
		width: 50px;
		height: 50px;
		background-color: transparent;
		position: absolute;
		top: 50%;
		bottom: 50%;
		margin-top: -25px;
		left: 0;
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button:hover {
		background-color: transparent;
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button.penci-product-slider-next {
		left: auto;
		right: 0;
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button.penci-product-slider-prev i,
	.woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button.penci-product-slider-next i {
		transform: rotate(270deg);
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .splide__track {
		/*display: flex;
		justify-content: center;*/
	}
	.woocommerce-product-gallery .penci-thumbnail-slider .splide__track figure.splide__slide {
		padding-left: 5px;
		padding-right: 5px;
	}
	.woocommerce div.penci-product-img-fullwidth-container figure.splide__slide {
		opacity: 1;
	}
}
.woocommerce.product-layout-carousel ul.products li.product {
	margin-bottom: 0;
}
.woocommerce-single-tab-content.post-entry {
	margin-bottom: 0;
}
.elementor-widget-penci_products .penci-custom-products .penci-products-preloader {
	position: absolute;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
	z-index: 999999;
	display: flex;
	justify-content: center;
	align-items: center;
	visibility: hidden;
}
.elementor-widget-penci_products .pre-load-content .penci-custom-products ul.products {
	opacity: 0;
}
.elementor-widget-penci_products .pre-load-content .penci-custom-products .penci-products-preloader {
	visibility: visible;
}
body #main .elementor-widget-penci_products .pre-load-content .penci-custom-products ul.products,
.elementor-widget-penci_products .pre-load-content .penci-custom-products ul.products {
	opacity: 0.5;
	pointer-events: none;
}
.woocommerce ul.cart_list li dl,
.woocommerce ul.product_list_widget li dl {
	padding-left: 0;
	border-left: 0;
	display: none;
}
.woocommerce ul.cart_list li dl dt, .woocommerce ul.cart_list li dl dd, .woocommerce ul.product_list_widget li dl dt, .woocommerce ul.product_list_widget li dl dd {
	float: none;
}
.woocommerce ul.cart_list li dl dt, .woocommerce ul.product_list_widget li dl dt {
	margin: 0;
	padding: 0;
}
.woocommerce div.product .quick-shop-wrapper .variations_form,
.quick-shop-wrapper .variations_form {
	transition: margin-bottom .3s ease;
	width: 100%;
}
.woocommerce div.product .quick-shop-wrapper form.cart .reset_variations,
.quick-shop-wrapper .variations_form a.reset_variations {
	margin-left: 0;
	margin-right: 0;
	position: absolute;
	left: 50%;
	bottom: -30px;
	transform: translateX(-50%);
	width: 100%;
}
@media only screen and (max-width: 767px) {
	.woocommerce div.product .quick-shop-wrapper form.cart .reset_variations,
	.quick-shop-wrapper .variations_form a.reset_variations {
		bottom: 30px;
		top: 30px;
	}
}
.quick-shop-wrapper .variations_form .penci-swatches .swatch {
	margin-bottom: 5px;
}
.woocommerce div.product .quick-shop-wrapper form.cart .variations select {
	margin-bottom: 0;
	margin-right: 0;
}
.woocommerce div.product .quick-shop-wrapper form.cart.has-selected-swatch,
.quick-shop-wrapper .variations_form.has-selected-swatch {
	margin-bottom: 40px;
}
.penci-thumbnail-image-wrapper:not(.swiper-initialized) figure {
	display: inline-block;
	max-width: 100px;
	max-height: 100px;
	height: auto;
	padding-bottom: 6px;
	opacity: 1;
}
.thumbnail-right .penci-thumbnail-image-wrapper figure,
.thumbnail-left .penci-thumbnail-image-wrapper figure {
	height: 100% !important;
	max-height: 107.8px;
}
.woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-image-wrapper figure {
	max-width: 106px;
	margin-right: 10px;
}
.penci-content-quickview .woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-image-wrapper figure {
	max-width: 82.6px;
}
.woocommerce div.product div.images.no-js .woocommerce-product-gallery__wrapper:not(:first-child) {
	display: none;
}
.woocommerce div.product.penci-product-img-fullwidth-container div.images.no-js .woocommerce-product-gallery__wrapper {
	flex: 0 0 auto;
	width: calc(33.3333333333% - 20px);
	margin-right: 30px;
}
.woocommerce div.product.penci-product-img-fullwidth-container div.images.no-js .woocommerce-product-gallery__wrapper:not(:first-child) {
	display: block;
}
.woocommerce div.product.penci-product-img-fullwidth-container div.images.no-js .penci-gallery-image-list {
	display: flex;
	overflow: hidden;
}
.woocommerce .woocommerce-ordering select,
.woocommerce ul.cart_list li div.quantity .qty, .woocommerce ul.cart_list li div.quantity input[type="number"], .woocommerce ul.cart_list li div.quantity input[type="button"], .woocommerce ul.product_list_widget div.quantity input[type="button"] {
	background-color: transparent;
}
.woocommerce .slider > ul.products,
.products.slider ul.products,
.products.slider ul.products.penci-owl-carousel-slider {
	flex-wrap: nowrap;
	overflow: hidden;
	margin-right: 0;
	margin-left: 0;
}
.woocommerce .slider > ul.products li,
.slider > ul.products.penci-owl-carousel-slider li,
.products.slider ul.products.penci-owl-carousel-slider li {
	padding: 0;
	margin-right: 30px;
	float: none;
	flex-shrink: 0;
}
.products.penci-owl-carousel:not(.penci-owl-loaded) > .swiper-wrapper {
	display: flex;
	flex-wrap: nowrap;
	overflow: hidden;
}
.woocommerce .slider > ul.products.columns-2 li,
.slider > ul.products.penci-owl-carousel-slider.columns-2 li,
.products.slider ul.products.penci-owl-carousel-slider.columns-2 li {
	width: calc(50% - 15px);
}
.woocommerce .slider > ul.products.columns-3 li,
.slider > ul.products.penci-owl-carousel-slider.columns-3 li,
.products.slider ul.products.penci-owl-carousel-slider.columns-3 li {
	width: calc(33.3333333333% - 20px);
}
.woocommerce .slider > ul.products.columns-4 li,
.slider > ul.products.penci-owl-carousel-slider.columns-4 li,
.products.slider ul.products.penci-owl-carousel-slider.columns-4 li {
	width: calc(25% - 22.5px);
}
.woocommerce .slider > ul.products.columns-5 li,
.slider > ul.products.penci-owl-carousel-slider.columns-5 li,
.products.slider ul.products.penci-owl-carousel-slider.columns-5 li {
	width: calc(20% - 24px);
}
.woocommerce .slider > ul.products.columns-6 li,
.slider > ul.products.penci-owl-carousel-slider.columns-6 li,
.products.slider ul.products.penci-owl-carousel-slider.columns-6 li {
	width: calc(16.6666666667% - 25px);
}
.woocommerce .slider > ul.products.penci-owl-carousel-slider.penci-owl-loaded,
.products.slider ul.products.penci-owl-carousel-slider.penci-owl-loaded {
	flex-wrap: wrap;
}
.woocommerce .slider > ul.products.penci-owl-carousel-slider.penci-owl-loaded li.product,
.products.slider ul.products.penci-owl-carousel-slider.penci-owl-loaded li.product {
	width: 100%;
	margin-right: 0;
	padding: 0;
}
@media only screen and (max-width: 767px) {
	html .woocommerce .products.slider > ul.products.mobile-columns-2 > li.product,
	html .woocommerce-page .products.slider > ul.products.mobile-columns-2 > li.product,
	html .woocommerce .penci_sidebar .products.slider > ul.products.mobile-columns-2 > li.product,
	html .woocommerce-page .penci_sidebar .products.slider > ul.products.mobile-columns-2 > li.product,
	.products.slider ul.products.penci-owl-carousel.mobile-columns-2 > li.product {
		width: calc(50% - 12px) !important;
		margin-right: 20px !important;
		padding: 0 !important;
	}
}
.up-sells.upsells.products {
	margin-top: 60px;
}
.pcw-breadcrumb-summary .penci-single-product-top-container {
	padding-top: 0;
}
.woocommerce-notice.woocommerce-thankyou-order-received {
	text-align: center;
}
.pc-proterm-description.post-entry {
	margin-bottom: 10px;
}
.pc-proterm-description.post-entry.pc-proterm-description-bottom {
  margin: -30px 0 30px;
}
.pc-proterm-description:empty {
	display: none;
}
.woocommerce-no-js .woocommerce-tabs .woocommerce-Tabs-panel {
	display: none;
}
.woocommerce-no-js .woocommerce-tabs .tabs + .woocommerce-Tabs-panel {
	display: block;
}