body.pcdm-enable {
    --pcwc_ckout_inner_bg: var(--pcbg-l-cl);
    --pcl_btn_group_bg_color: var(--pcbg-l-cl);
    --pcl_btn_group_bg_hv_color: var(--pcaccent-cl);
    --pcl_6_bg_cl: var(--pcbg-l-cl);
    --pchb-main-menu-cl: var(--pcbg-l-cl);
    --pchb-second-menu-cl: var(--pctext-cl);
}
body.pcdm-loading,
body.pcdm-loading * {
    transition: none !important;
    transition-delay: unset !important;
}
/* Customizer Overwritten Color*/
body.pcdm-enable.pcdark-mode .pccatds-filled .cat > a.penci-cat-name {
    color: var(--pcaccent-cl);
    background-color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .pccatds-filled .cat > a.penci-cat-name:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #header .inner-header,
body.pcdm-enable.pcdark-mode .pccatds-filled .cat > a.penci-cat-name:hover {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode.penci-body-boxed {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-page-header h1 {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.hide-tags.page-share .share-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.hide-tags.page-share .post-share a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.hide-tags.page-share .post-share a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .error-image:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .error-404 .sub-heading-text-404 {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .error-404 form.pc-searchform input.search-input {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .error-404 form.pc-searchform input.search-input::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .error-404 form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .error-404 form.pc-searchform input.search-input::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .error-404 .go-back-home a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-quote,
body.pcdm-enable.pcdark-mode .wpb_text_column .wp-block-quote,
body.pcdm-enable.pcdark-mode .woocommerce .page-description .wp-block-quote {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-single-style-7:not(.penci-single-pheader-noimg).penci_sidebar #main article.post,
body.pcdm-enable.pcdark-mode .penci-single-style-3:not(.penci-single-pheader-noimg).penci_sidebar #main article.post {
    background-color: var(--pcbg-cl);
}
@media only screen and (max-width: 767px) {
    body.pcdm-enable.pcdark-mode .standard-post-special_wrapper {
        background: var(--pcbg-cl);
    }
}
body.pcdm-enable.pcdark-mode .wrapper-boxed,
body.pcdm-enable.pcdark-mode .wrapper-boxed.enable-boxed,
body.pcdm-enable.pcdark-mode .home-pupular-posts-title span,
body.pcdm-enable.pcdark-mode .penci-post-box-meta.penci-post-box-grid .penci-post-share-box,
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button,
body.pcdm-enable.pcdark-mode .woocommerce .woocommerce-product-search input[type="search"],
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li.featured-news2 .side-item .side-item-text,
body.pcdm-enable.pcdark-mode .widget select,
body.pcdm-enable.pcdark-mode .widget select option,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-error,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-info,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-message,
body.pcdm-enable.pcdark-mode #penci-demobar,
body.pcdm-enable.pcdark-mode #penci-demobar .style-toggle {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .list-post.list-boxed-post .item > .thumbnail:before {
    border-right-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .list-post.list-boxed-post:nth-of-type(2n+2) .item > .thumbnail:before {
    border-left-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #main #bbpress-forums .bbp-login-form fieldset.bbp-form select,
body.pcdm-enable.pcdark-mode #main #bbpress-forums .bbp-login-form .bbp-form input[type="password"],
body.pcdm-enable.pcdark-mode #main #bbpress-forums .bbp-login-form .bbp-form input[type="text"],
body.pcdm-enable.pcdark-mode .widget ul li,
body.pcdm-enable.pcdark-mode .grid-mixed,
body.pcdm-enable.pcdark-mode .penci-post-box-meta,
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button,
body.pcdm-enable.pcdark-mode .widget-social a i,
body.pcdm-enable.pcdark-mode .penci-home-popular-posts,
body.pcdm-enable.pcdark-mode .header-header-1.has-bottom-line,
body.pcdm-enable.pcdark-mode .header-header-4.has-bottom-line,
body.pcdm-enable.pcdark-mode .header-header-7.has-bottom-line,
body.pcdm-enable.pcdark-mode .container-single .post-entry .post-tags a,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-top,
body.pcdm-enable.pcdark-mode .tags-share-box,
body.pcdm-enable.pcdark-mode .post-author,
body.pcdm-enable.pcdark-mode .post-pagination,
body.pcdm-enable.pcdark-mode .post-related,
body.pcdm-enable.pcdark-mode .post-comments .post-title-box,
body.pcdm-enable.pcdark-mode .comments .comment,
body.pcdm-enable.pcdark-mode #respond textarea,
body.pcdm-enable.pcdark-mode .wpcf7 textarea,
body.pcdm-enable.pcdark-mode #respond input,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=date],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=datetime],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=datetime-local],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=email],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=month],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=number],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=password],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=range],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=search],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=tel],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=text],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=time],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=url],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=week],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form select,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form textarea,
body.pcdm-enable.pcdark-mode .wpcf7 input,
body.pcdm-enable.pcdark-mode .widget_wysija input,
body.pcdm-enable.pcdark-mode #respond h3,
body.pcdm-enable.pcdark-mode .post-password-form input[type="text"],
body.pcdm-enable.pcdark-mode .post-password-form input[type="email"],
body.pcdm-enable.pcdark-mode .post-password-form input[type="password"],
body.pcdm-enable.pcdark-mode .post-password-form input[type="number"],
body.pcdm-enable.pcdark-mode .penci-recipe,
body.pcdm-enable.pcdark-mode .penci-recipe-heading,
body.pcdm-enable.pcdark-mode .penci-recipe-ingredients,
body.pcdm-enable.pcdark-mode .penci-recipe-notes,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li span,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a,
body.pcdm-enable.pcdark-mode #comments_pagination span,
body.pcdm-enable.pcdark-mode #comments_pagination a,
body.pcdm-enable.pcdark-mode.author .post-author,
body.pcdm-enable.pcdark-mode .tags-share-box.hide-tags.page-share,
body.pcdm-enable.pcdark-mode .penci-grid li.list-post,
body.pcdm-enable.pcdark-mode .penci-grid li.list-boxed-post-2 .content-boxed-2,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-post-box,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-2 .mag-post-box.first-post,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-10 .mag-post-box.first-post,
body.pcdm-enable.pcdark-mode .widget select,
body.pcdm-enable.pcdark-mode .widget ul ul,
body.pcdm-enable.pcdark-mode .widget input[type="text"],
body.pcdm-enable.pcdark-mode .widget input[type="email"],
body.pcdm-enable.pcdark-mode .widget input[type="date"],
body.pcdm-enable.pcdark-mode .widget input[type="number"],
body.pcdm-enable.pcdark-mode .widget input[type="search"],
body.pcdm-enable.pcdark-mode .widget .tagcloud a,
body.pcdm-enable.pcdark-mode #wp-calendar tbody td,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] td,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] th,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description td,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description th,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description td,
body.pcdm-enable.pcdark-mode th,
body.pcdm-enable.pcdark-mode.woocommerce ul.cart_list li,
body.pcdm-enable.pcdark-mode.woocommerce ul.product_list_widget li,
body.pcdm-enable.pcdark-mode.woocommerce .widget_shopping_cart .total,
body.pcdm-enable.pcdark-mode.woocommerce.widget_shopping_cart .total,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-product-search input[type="search"],
body.pcdm-enable.pcdark-mode.woocommerce nav.woocommerce-pagination ul li a,
body.pcdm-enable.pcdark-mode.woocommerce nav.woocommerce-pagination ul li span,
body.pcdm-enable.pcdark-mode.woocommerce div.product .product_meta,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs ul.tabs,
body.pcdm-enable.pcdark-mode.woocommerce div.product .related > h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .upsells > h2,
body.pcdm-enable.pcdark-mode.woocommerce #reviews #comments ol.commentlist li .comment-text,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table td,
body.pcdm-enable.pcdark-mode .post-entry td,
body.pcdm-enable.pcdark-mode .post-entry th,
body.pcdm-enable.pcdark-mode #add_payment_method .cart-collaterals .cart_totals tr td,
body.pcdm-enable.pcdark-mode #add_payment_method .cart-collaterals .cart_totals tr th,
body.pcdm-enable.pcdark-mode.woocommerce-cart .cart-collaterals .cart_totals tr td,
body.pcdm-enable.pcdark-mode.woocommerce-cart .cart-collaterals .cart_totals tr th,
body.pcdm-enable.pcdark-mode.woocommerce-checkout .cart-collaterals .cart_totals tr td,
body.pcdm-enable.pcdark-mode.woocommerce-checkout .cart-collaterals .cart_totals tr th,
body.pcdm-enable.pcdark-mode.woocommerce-cart .cart-collaterals .cart_totals table,
body.pcdm-enable.pcdark-mode.woocommerce-cart table.cart td.actions .coupon .input-text,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table a.remove,
body.pcdm-enable.pcdark-mode.woocommerce form .form-row .input-text,
body.pcdm-enable.pcdark-mode.woocommerce-page form .form-row .input-text,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-error,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-info,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-message,
body.pcdm-enable.pcdark-mode.woocommerce form.checkout_coupon,
body.pcdm-enable.pcdark-mode.woocommerce form.login,
body.pcdm-enable.pcdark-mode.woocommerce form.register,
body.pcdm-enable.pcdark-mode.woocommerce form.checkout table.shop_table,
body.pcdm-enable.pcdark-mode.woocommerce-checkout #payment ul.payment_methods,
body.pcdm-enable.pcdark-mode .post-entry table,
body.pcdm-enable.pcdark-mode .wrapper-penci-review,
body.pcdm-enable.pcdark-mode .penci-review-container.penci-review-count,
body.pcdm-enable.pcdark-mode #penci-demobar .style-toggle,
body.pcdm-enable.pcdark-mode #widget-area,
body.pcdm-enable.pcdark-mode .post-entry hr,
body.pcdm-enable.pcdark-mode .wpb_text_column hr,
body.pcdm-enable.pcdark-mode #buddypress .dir-search input[type=search],
body.pcdm-enable.pcdark-mode #buddypress .dir-search input[type=text],
body.pcdm-enable.pcdark-mode #buddypress .groups-members-search input[type=search],
body.pcdm-enable.pcdark-mode #buddypress .groups-members-search input[type=text],
body.pcdm-enable.pcdark-mode #buddypress ul.item-list,
body.pcdm-enable.pcdark-mode #buddypress .profile[role=main],
body.pcdm-enable.pcdark-mode #buddypress select,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links span,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links a,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pag-count,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links a:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.item-list li,
body.pcdm-enable.pcdark-mode #buddypress table.forum tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.messages-notices tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.notifications tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.notifications-settings tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.profile-fields tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.wp-profile-fields tr td.label,
body.pcdm-enable.pcdark-mode #buddypress table.profile-fields:last-child,
body.pcdm-enable.pcdark-mode #buddypress form#whats-new-form textarea,
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=text],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=color],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=date],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=datetime],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=datetime-local],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=email],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=month],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=number],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=range],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=search],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=password],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=tel],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=time],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=url],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=week],
body.pcdm-enable.pcdark-mode .bp-avatar-nav ul,
body.pcdm-enable.pcdark-mode .bp-avatar-nav ul.avatar-nav-items li.current,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-footer,
body.pcdm-enable.pcdark-mode .bbp-pagination-links a,
body.pcdm-enable.pcdark-mode .bbp-pagination-links span.current,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links a:hover,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links span.current,
body.pcdm-enable.pcdark-mode #buddypress .standard-form select,
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=password],
body.pcdm-enable.pcdark-mode #buddypress .activity-list li.load-more a,
body.pcdm-enable.pcdark-mode #buddypress .activity-list li.load-newest a,
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a,
body.pcdm-enable.pcdark-mode #buddypress div.generic-button a,
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link,
body.pcdm-enable.pcdark-mode #bbpress-forums div.bbp-template-notice.info,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp-search-form #bbp_search,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-forums-list,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_topic_title,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_topic_tags,
body.pcdm-enable.pcdark-mode #bbpress-forums .wp-editor-container,
body.pcdm-enable.pcdark-mode .widget_display_stats dd,
body.pcdm-enable.pcdark-mode .widget_display_stats dt,
body.pcdm-enable.pcdark-mode div.bbp-forum-header,
body.pcdm-enable.pcdark-mode div.bbp-topic-header,
body.pcdm-enable.pcdark-mode div.bbp-reply-header,
body.pcdm-enable.pcdark-mode .widget input[type="text"],
body.pcdm-enable.pcdark-mode .widget input[type="email"],
body.pcdm-enable.pcdark-mode .widget input[type="date"],
body.pcdm-enable.pcdark-mode .widget input[type="number"],
body.pcdm-enable.pcdark-mode .widget input[type="search"],
body.pcdm-enable.pcdark-mode .widget input[type="password"],
body.pcdm-enable.pcdark-mode blockquote.wp-block-quote,
body.pcdm-enable.pcdark-mode .post-entry blockquote.wp-block-quote,
body.pcdm-enable.pcdark-mode .wp-block-quote:not(.is-large):not(.is-style-large),
body.pcdm-enable.pcdark-mode .post-entry pre,
body.pcdm-enable.pcdark-mode .wp-block-pullquote:not(.is-style-solid-color),
body.pcdm-enable.pcdark-mode .post-entry hr.wp-block-separator,
body.pcdm-enable.pcdark-mode .wp-block-separator,
body.pcdm-enable.pcdark-mode .wp-block-latest-posts,
body.pcdm-enable.pcdark-mode .wp-block-yoast-how-to-block ol.schema-how-to-steps,
body.pcdm-enable.pcdark-mode .wp-block-yoast-how-to-block ol.schema-how-to-steps li,
body.pcdm-enable.pcdark-mode .wp-block-yoast-faq-block .schema-faq-section,
body.pcdm-enable.pcdark-mode .post-entry .wp-block-quote,
body.pcdm-enable.pcdark-mode .wpb_text_column .wp-block-quote,
body.pcdm-enable.pcdark-mode.woocommerce .page-description .wp-block-quote,
body.pcdm-enable.pcdark-mode .wp-block-search .wp-block-search__input {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-recipe-index-wrap h4.recipe-index-heading > span:before,
body.pcdm-enable.pcdark-mode .penci-recipe-index-wrap h4.recipe-index-heading > span:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box .single-comment-o:after,
body.pcdm-enable.pcdark-mode .post-share a.penci-post-like:after {
    background-color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .list-post.list-boxed-post {
    border-color: var(--pcborder-cl) !important;
}
body.pcdm-enable.pcdark-mode .penci-post-box-meta.penci-post-box-grid:before,
body.pcdm-enable.pcdark-mode .woocommerce .widget_price_filter .ui-slider .ui-slider-range {
    background-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts {
    border-color: var(--pcborder-cl) !important;
    color: #999999 !important;
}
body.pcdm-enable.pcdark-mode .penci-vernav-enable .penci-menu-hbg {
    box-shadow: none;
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
}
body.pcdm-enable.pcdark-mode .penci-vernav-enable.penci-vernav-poleft .penci-menu-hbg {
    border-right: 1px solid var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-vernav-enable.penci-vernav-poright .penci-menu-hbg {
    border-left: 1px solid var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode form.pc-searchform input.search-input {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode.pchds-overlay form.pc-searchform input.search-input {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode,
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-post-share-box a,
body.pcdm-enable.pcdark-mode .penci-pagination a,
body.pcdm-enable.pcdark-mode .penci-pagination .disable-url,
body.pcdm-enable.pcdark-mode .widget-social a i,
body.pcdm-enable.pcdark-mode .post-share a,
body.pcdm-enable.pcdark-mode #respond textarea,
body.pcdm-enable.pcdark-mode .wpcf7 textarea,
body.pcdm-enable.pcdark-mode #respond input,
body.pcdm-enable.pcdark-mode .wpcf7 input,
body.pcdm-enable.pcdark-mode .widget_wysija input,
body.pcdm-enable.pcdark-mode #respond h3 small a,
body.pcdm-enable.pcdark-mode #respond h3 small a:hover,
body.pcdm-enable.pcdark-mode .post-comments span.reply a,
body.pcdm-enable.pcdark-mode .post-comments span.reply a:hover,
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author,
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author a,
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span,
body.pcdm-enable.pcdark-mode .post-box-title,
body.pcdm-enable.pcdark-mode .post-pagination a,
body.pcdm-enable.pcdark-mode .post-pagination span,
body.pcdm-enable.pcdark-mode .author-content .author-social,
body.pcdm-enable.pcdark-mode .author-content h5 a,
body.pcdm-enable.pcdark-mode .error-404 .sub-heading-text-404,
body.pcdm-enable.pcdark-mode form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-mode input,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li span,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a,
body.pcdm-enable.pcdark-mode #comments_pagination span,
body.pcdm-enable.pcdark-mode #comments_pagination a,
body.pcdm-enable.pcdark-mode .item-related h3 a,
body.pcdm-enable.pcdark-mode .archive-box span,
body.pcdm-enable.pcdark-mode .archive-box h1,
body.pcdm-enable.pcdark-mode .header-standard .author-post span a,
body.pcdm-enable.pcdark-mode .post-entry h1,
body.pcdm-enable.pcdark-mode .post-entry h2,
body.pcdm-enable.pcdark-mode .post-entry h3,
body.pcdm-enable.pcdark-mode .post-entry h4,
body.pcdm-enable.pcdark-mode .post-entry h5,
body.pcdm-enable.pcdark-mode .post-entry h6,
body.pcdm-enable.pcdark-mode .wpb_text_column h1,
body.pcdm-enable.pcdark-mode .wpb_text_column h2,
body.pcdm-enable.pcdark-mode .wpb_text_column h3,
body.pcdm-enable.pcdark-mode .wpb_text_column h4,
body.pcdm-enable.pcdark-mode .wpb_text_column h5,
body.pcdm-enable.pcdark-mode .wpb_text_column h6,
body.pcdm-enable.pcdark-mode .tags-share-box.hide-tags.page-share .share-title,
body.pcdm-enable.pcdark-mode .about-widget .about-me-heading,
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-text,
body.pcdm-enable.pcdark-mode .widget select,
body.pcdm-enable.pcdark-mode .widget ul li,
body.pcdm-enable.pcdark-mode .widget .tagcloud a,
body.pcdm-enable.pcdark-mode #wp-calendar caption,
body.pcdm-enable.pcdark-mode.woocommerce .page-title,
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product h3,
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product .woocommerce-loop-product__title,
body.pcdm-enable.pcdark-mode.woocommerce .widget_price_filter .price_label,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-product-search input[type="search"],
body.pcdm-enable.pcdark-mode.woocommerce nav.woocommerce-pagination ul li a,
body.pcdm-enable.pcdark-mode.woocommerce nav.woocommerce-pagination ul li span,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h1,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h3,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h4,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h5,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] h6,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h1,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h3,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h4,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h5,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description h6,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h1,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h2,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h3,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h4,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h5,
body.pcdm-enable.pcdark-mode.woocommerce-product-details__short-description h6,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs .panel > h2:first-child,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs .panel #reviews #comments h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs .panel #respond h3.comment-reply-title,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs .panel #respond .comment-reply-title,
body.pcdm-enable.pcdark-mode.woocommerce div.product .related > h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .upsells > h2,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs ul.tabs li a,
body.pcdm-enable.pcdark-mode.woocommerce .comment-form p.stars a,
body.pcdm-enable.pcdark-mode.woocommerce #reviews #comments ol.commentlist li .comment-text .meta strong,
body.pcdm-enable.pcdark-mode .penci-page-header h1,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table a.remove,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table td.product-name a,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table th,
body.pcdm-enable.pcdark-mode.woocommerce form .form-row .input-text,
body.pcdm-enable.pcdark-mode .woocommerce-page form .form-row .input-text,
body.pcdm-enable.pcdark-mode .demobar-title,
body.pcdm-enable.pcdark-mode .demobar-desc,
body.pcdm-enable.pcdark-mode .container-single .post-share a,
body.pcdm-enable.pcdark-mode .page-share .post-share a,
body.pcdm-enable.pcdark-mode .footer-instagram h4.footer-instagram-title,
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li a,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li a,
body.pcdm-enable.pcdark-mode .widget-social.show-text a span,
body.pcdm-enable.pcdark-mode #buddypress select,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links a:hover,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links span,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links a,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pag-count,
body.pcdm-enable.pcdark-mode #buddypress ul.item-list li div.item-title span,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li > span,
body.pcdm-enable.pcdark-mode #buddypress div#item-header div#item-meta,
body.pcdm-enable.pcdark-mode #buddypress form#whats-new-form textarea,
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=text],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=color],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=date],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=datetime],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=datetime-local],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=email],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=month],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=number],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=range],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=search],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=password],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=tel],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=time],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=url],
body.pcdm-enable.pcdark-mode #buddypress .standard-form input[type=week],
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a,
body.pcdm-enable.pcdark-mode #buddypress div.generic-button a,
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links a,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links a:hover,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links span.current,
body.pcdm-enable.pcdark-mode #buddypress .activity-list li.load-more a,
body.pcdm-enable.pcdark-mode #buddypress .activity-list li.load-newest a,
body.pcdm-enable.pcdark-mode .activity-inner,
body.pcdm-enable.pcdark-mode #buddypress a.activity-time-since,
body.pcdm-enable.pcdark-mode .activity-greeting,
body.pcdm-enable.pcdark-mode div.bbp-template-notice,
body.pcdm-enable.pcdark-mode div.indicator-hint,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-info a,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-title a,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-topic-count,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-reply-count,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-freshness a,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-forum-topic-count,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-voice-count,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-forum-reply-count,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness > a,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-freshness,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-reply-count,
body.pcdm-enable.pcdark-mode div.bbp-template-notice a,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp-search-form #bbp_search,
body.pcdm-enable.pcdark-mode #bbpress-forums .wp-editor-container,
body.pcdm-enable.pcdark-mode #bbpress-forums div.bbp-the-content-wrapper textarea.bbp-the-content,
body.pcdm-enable.pcdark-mode .widget_display_stats dd,
body.pcdm-enable.pcdark-mode #bbpress-forums fieldset.bbp-form legend,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-pagination-count,
body.pcdm-enable.pcdark-mode span.bbp-admin-links a,
body.pcdm-enable.pcdark-mode .bbp-forum-header a.bbp-forum-permalink,
body.pcdm-enable.pcdark-mode .bbp-topic-header a.bbp-topic-permalink,
body.pcdm-enable.pcdark-mode .bbp-reply-header a.bbp-reply-permalink,
body.pcdm-enable.pcdark-mode #bbpress-forums .status-closed,
body.pcdm-enable.pcdark-mode #bbpress-forums .status-closed a,
body.pcdm-enable.pcdark-mode .post-entry blockquote.wp-block-quote p,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote.wp-block-quote p,
body.pcdm-enable.pcdark-mode .post-entry blockquote.wp-block-quote cite,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote.wp-block-quote cite,
body.pcdm-enable.pcdark-mode .post-entry code,
body.pcdm-enable.pcdark-mode .wp-block-video figcaption,
body.pcdm-enable.pcdark-mode .post-entry .wp-block-pullquote blockquote p,
body.pcdm-enable.pcdark-mode .post-entry .wp-block-pullquote blockquote cite,
body.pcdm-enable.pcdark-mode .wp-block-categories .category-item-count {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
body.pcdm-enable.pcdark-mode .header-standard.standard-overlay-meta,
body.pcdm-enable.pcdark-mode .post-entry .wp-block-file a.wp-block-file__button {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider .penci-owl-dot span {
    background-color: var(--pcbg-cl);
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta,
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a,
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-box-meta span,
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-box-meta a,
body.pcdm-enable.pcdark-mode .header-standard .author-post span,
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.date,
body.pcdm-enable.pcdark-mode .item-related span.date,
body.pcdm-enable.pcdark-mode .post-box-meta-single span,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .woocommerce #reviews #comments ol.commentlist li .comment-text .meta,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-info .bbp-forum-content,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic p.bbp-topic-meta,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-breadcrumb a,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-breadcrumb .bbp-breadcrumb-current,
body.pcdm-enable.pcdark-mode .bbp-breadcrumb .bbp-breadcrumb-sep,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-topic-started-by,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-topic-started-in {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-process {
    background-color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-file a.wp-block-file__button {
    color: var(--pctext-cl);
}
.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts {
    color: var(--pctext-cl) !important;
    border-color: var(--pcborder-cl) !important;
}
.pcdark-mode .widget ul.side-newsfeed li .number-post {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button,
body.pcdm-enable.pcdark-mode #respond #submit,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"],
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"],
body.pcdm-enable.pcdark-mode .widget input[type="submit"],
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a,
body.pcdm-enable.pcdark-mode .penci-button,
body.pcdm-enable.pcdark-mode .widget button[type="submit"],
body.pcdm-enable.pcdark-mode .woocommerce #respond input#submit,
body.pcdm-enable.pcdark-mode .woocommerce a.button,
body.pcdm-enable.pcdark-mode .woocommerce button.button,
body.pcdm-enable.pcdark-mode .woocommerce input.button,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_reply_submit,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_topic_submit,
body.pcdm-enable.pcdark-mode #main .bbp-login-form .bbp-submit-wrapper button[type="submit"] {
    background: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce .penci-extra-buttons > .button {
    background: transparent;
}
body.pcdm-enable.pcdark-mode #wp-calendar tbody td,
body.pcdm-enable.pcdark-mode #wp-calendar tbody td:hover {
    background: none;
}
body.pcdm-enable.pcdark-mode .woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode #navigation {
    border-color: var(--pcbg-l-cl);
    background-color: #000;
    transition: none;
}
body.pcdm-enable.pcdark-mode .is-sticky #navigation {
    box-shadow: 0 1px 5px rgba(255, 255, 255, 0.08);
    -webkit-box-shadow: 0 1px 5px rgba(255, 255, 255, 0.08);
    -moz-box-shadow: 0 1px 5px rgba(255, 255, 255, 0.08);
}
body.pcdm-enable.pcdark-mode .navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode #navigation .menu .children,
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode #navigation .menu .children,
body.pcdm-enable.pcdark-mode .penci-dropdown-menu {
    box-shadow: 0 0 6px rgba(255, 255, 255, 0.1);
    -webkit-box-shadow: 0 0 6px rgba(255, 255, 255, 0.1);
    -moz-box-shadow: 0 0 6px rgba(255, 255, 255, 0.1);
}
body.pcdm-enable.pcdark-mode .penci-image-holder:not([style*='background-image']),
body.pcdm-enable.pcdark-mode .penci-lazy[src*="penci-holder"],
body.pcdm-enable.pcdark-mode .penci-holder-load:not([style*='background-image']) {
    background-color: #333333;
    background-image: linear-gradient(to left, #333333 0%, #383838 15%, #333333 40%, #333333 100%);
}
body.pcdm-enable.pcdark-mode #penci-demobar .style-toggle,
body.pcdm-enable.pcdark-mode #penci-demobar {
    box-shadow: -1px 2px 10px 0 rgba(255, 255, 255, .15);
    -webkit-box-shadow: -1px 2px 10px 0 rgba(255, 255, 255, .15);
    -moz-box-shadow: -1px 2px 10px 0 rgba(255, 255, 255, .15);
}
body.pcdm-enable.pcdark-mode .post-entry.blockquote-style-2 blockquote,
body.pcdm-enable.pcdark-mode .wp-block-quote.is-style-large,
body.pcdm-enable.pcdark-mode .wp-block-quote.is-large {
    background: #2b2b2b;
}
body.pcdm-enable.pcdark-mode .post-entry pre,
body.pcdm-enable.pcdark-mode .post-entry code,
body.pcdm-enable.pcdark-mode .wp-block-table.is-style-stripes tr:nth-child(odd),
body.pcdm-enable.pcdark-mode .post-entry pre.wp-block-verse,
body.pcdm-enable.pcdark-mode .post-entry .wp-block-verse pre,
body.pcdm-enable.pcdark-mode .wp-block-pullquote.is-style-solid-color {
    background-color: #333333;
}
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a:hover,
body.pcdm-enable.pcdark-mode #comments_pagination a:hover,
body.pcdm-enable.pcdark-mode .woocommerce nav.woocommerce-pagination ul li a:hover {
    color: #dedede;
    border-color: #777777;
}
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs,
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link,
body.pcdm-enable.pcdark-mode #buddypress .generic-button a,
body.pcdm-enable.pcdark-mode #buddypress .standard-form button,
body.pcdm-enable.pcdark-mode #buddypress a.button,
body.pcdm-enable.pcdark-mode #buddypress input[type=button],
body.pcdm-enable.pcdark-mode #buddypress input[type=reset],
body.pcdm-enable.pcdark-mode #buddypress input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a,
body.pcdm-enable.pcdark-mode a.bp-title-button,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-header,
body.pcdm-enable.pcdark-mode #bbpress-forums div.bbp-forum-header,
body.pcdm-enable.pcdark-mode #bbpress-forums div.bbp-topic-header,
body.pcdm-enable.pcdark-mode #bbpress-forums div.bbp-reply-header {
    background-color: #252525;
}
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link,
body.pcdm-enable.pcdark-mode #buddypress .generic-button a,
body.pcdm-enable.pcdark-mode #buddypress .standard-form button,
body.pcdm-enable.pcdark-mode #buddypress a.button,
body.pcdm-enable.pcdark-mode #buddypress input[type=button],
body.pcdm-enable.pcdark-mode #buddypress input[type=reset],
body.pcdm-enable.pcdark-mode #buddypress input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a,
body.pcdm-enable.pcdark-mode a.bp-title-button {
    border-color: #252525;
}
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li.selected a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li.current a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li a:hover,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li.selected a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li.current a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li a:hover {
    color: #fff;
}
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs:not(#subnav) ul li > span {
    border-color: #313131;
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul ul {
    background-color: rgba(0, 0, 0, 0.9);
}
body.pcdm-enable.pcdark-mode .wp-caption p.wp-caption-text,
body.pcdm-enable.pcdark-mode .penci-featured-caption {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .lines-button:after,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .penci-lines:before,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .penci-lines:after,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s2 .post-share-plike,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-playlist-title,
body.pcdm-enable.pcdark-mode .pencisc-column-2.penci-video_playlist {
    background: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-video-nav .playlist-panel-item,
body.pcdm-enable.pcdark-mode .pencisc-column-1.penci-video_playlist .penci-video-nav .playlist-panel-item,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-thumb,
body.pcdm-enable.pcdark-mode .pencisc-button,
body.pcdm-enable.pcdark-mode .post-entry .pencisc-button,
body.pcdm-enable.pcdark-mode .penci-dropcap-box,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle,
body.pcdm-enable.pcdark-mode .penci-login-register input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .penci-ld .penci-ldin:before,
body.pcdm-enable.pcdark-mode .penci-ldspinner > div {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li a:hover,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li a:hover,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li.active a,
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li.active a,
body.pcdm-enable.pcdark-mode .penci-countdown .countdown-amount,
body.pcdm-enable.pcdark-mode .archive-box h1,
body.pcdm-enable.pcdark-mode .post-entry a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .post-entry blockquote:before,
body.pcdm-enable.pcdark-mode .post-entry blockquote cite,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote:before,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote cite,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote .author,
body.pcdm-enable.pcdark-mode .penci-pagination a:hover,
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu > li a:hover,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul > li a:hover,
body.pcdm-enable.pcdark-mode .penci-recipe-heading a.penci-recipe-print,
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-btnbuy,
body.pcdm-enable.pcdark-mode .main-nav-social a:hover,
body.pcdm-enable.pcdark-mode .widget-social .remove-circle a:hover i,
body.pcdm-enable.pcdark-mode .penci-recipe-index .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-info a:hover,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic li.bbp-topic-title a:hover,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.forum li.bbp-forum-info .bbp-forum-content a,
body.pcdm-enable.pcdark-mode #bbpress-forums li.bbp-body ul.topic p.bbp-topic-meta a,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-forum-freshness a:hover,
body.pcdm-enable.pcdark-mode #bbpress-forums .bbp-topic-freshness a:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.item-list li div.item-title a,
body.pcdm-enable.pcdark-mode #buddypress ul.item-list li h4 a,
body.pcdm-enable.pcdark-mode #buddypress .activity-header a:first-child,
body.pcdm-enable.pcdark-mode #buddypress .comment-meta a:first-child,
body.pcdm-enable.pcdark-mode #buddypress .acomment-meta a:first-child,
body.pcdm-enable.pcdark-mode div.bbp-template-notice a:hover,
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li a .indicator:hover,
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li a:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a:hover,
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rltpopup-meta .rltpopup-title:hover,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title:hover,
body.pcdm-enable.pcdark-mode .penci_list_shortcode li:before,
body.pcdm-enable.pcdark-mode .penci-dropcap-box-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-regular,
body.pcdm-enable.pcdark-mode .penci-dropcap-bold {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-home-popular-post ul.slick-dots li button:hover,
body.pcdm-enable.pcdark-mode .penci-home-popular-post ul.slick-dots li.slick-active button,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author span:after,
body.pcdm-enable.pcdark-mode .error-image:after,
body.pcdm-enable.pcdark-mode .error-404 .go-back-home a:after,
body.pcdm-enable.pcdark-mode .penci-header-signup-form,
body.pcdm-enable.pcdark-mode .woocommerce span.onsale,
body.pcdm-enable.pcdark-mode .woocommerce #respond input#submit:hover,
body.pcdm-enable.pcdark-mode .woocommerce a.button:hover,
body.pcdm-enable.pcdark-mode .woocommerce button.button:hover,
body.pcdm-enable.pcdark-mode .woocommerce input.button:hover,
body.pcdm-enable.pcdark-mode .woocommerce nav.woocommerce-pagination ul li span.current,
body.pcdm-enable.pcdark-mode .woocommerce div.product .entry-summary div[itemprop="description"]:before,
body.pcdm-enable.pcdark-mode .woocommerce div.product .entry-summary div[itemprop="description"] blockquote .author span:after,
body.pcdm-enable.pcdark-mode .woocommerce div.product .woocommerce-tabs #tab-description blockquote .author span:after,
body.pcdm-enable.pcdark-mode .woocommerce #respond input#submit.alt:hover,
body.pcdm-enable.pcdark-mode .woocommerce a.button.alt:hover,
body.pcdm-enable.pcdark-mode .woocommerce button.button.alt:hover,
body.pcdm-enable.pcdark-mode .woocommerce input.button.alt:hover,
body.pcdm-enable.pcdark-mode .pcheader-icon.shoping-cart-icon > a > span,
body.pcdm-enable.pcdark-mode #penci-demobar .buy-button,
body.pcdm-enable.pcdark-mode #penci-demobar .buy-button:hover,
body.pcdm-enable.pcdark-mode .penci-recipe-heading a.penci-recipe-print:hover,
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-btnbuy:hover,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 ul.menu ul.sub-menu:before,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .menu ul ul.sub-menu:before,
body.pcdm-enable.pcdark-mode .penci-go-to-top-floating,
body.pcdm-enable.pcdark-mode .post-entry.blockquote-style-2 blockquote:before,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp-search-form .button,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp-search-form .button:hover,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links span.current,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_reply_submit:hover,
body.pcdm-enable.pcdark-mode #bbpress-forums #bbp_topic_submit:hover,
body.pcdm-enable.pcdark-mode #main .bbp-login-form .bbp-submit-wrapper button[type="submit"]:hover,
body.pcdm-enable.pcdark-mode #buddypress .dir-search input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress .groups-members-search input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress button:hover,
body.pcdm-enable.pcdark-mode #buddypress a.button:hover,
body.pcdm-enable.pcdark-mode #buddypress a.button:focus,
body.pcdm-enable.pcdark-mode #buddypress input[type=button]:hover,
body.pcdm-enable.pcdark-mode #buddypress input[type=reset]:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li.current a,
body.pcdm-enable.pcdark-mode #buddypress div.generic-button a:hover,
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link:hover,
body.pcdm-enable.pcdark-mode #buddypress input[type=submit]:hover,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links .current,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs ul li.selected a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs ul li.current a,
body.pcdm-enable.pcdark-mode #buddypress div.item-list-tabs ul li a:hover,
body.pcdm-enable.pcdark-mode #buddypress table.notifications thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.notifications-settings thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.profile-settings thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.profile-fields thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.wp-profile-fields thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.messages-notices thead tr,
body.pcdm-enable.pcdark-mode #buddypress table.forum thead tr,
body.pcdm-enable.pcdark-mode #buddypress input[type=submit] {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce nav.woocommerce-pagination ul li span.current {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li span.current,
body.pcdm-enable.pcdark-mode #comments_pagination span {
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .footer-instagram h4.footer-instagram-title > span:before,
body.pcdm-enable.pcdark-mode.woocommerce nav.woocommerce-pagination ul li span.current,
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover,
body.pcdm-enable.pcdark-mode .penci-recipe-heading a.penci-recipe-print:hover,
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-btnbuy:hover,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .magcat-padding:before,
body.pcdm-enable.pcdark-mode .wrapper-boxed .bbp-pagination-links span.current,
body.pcdm-enable.pcdark-mode #buddypress .dir-search input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress .groups-members-search input[type=submit],
body.pcdm-enable.pcdark-mode #buddypress button:hover,
body.pcdm-enable.pcdark-mode #buddypress a.button:hover,
body.pcdm-enable.pcdark-mode #buddypress a.button:focus,
body.pcdm-enable.pcdark-mode #buddypress input[type=button]:hover,
body.pcdm-enable.pcdark-mode #buddypress input[type=reset]:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li a:hover,
body.pcdm-enable.pcdark-mode #buddypress ul.button-nav li.current a,
body.pcdm-enable.pcdark-mode #buddypress div.generic-button a:hover,
body.pcdm-enable.pcdark-mode #buddypress .comment-reply-link:hover,
body.pcdm-enable.pcdark-mode #buddypress input[type=submit]:hover,
body.pcdm-enable.pcdark-mode #buddypress div.pagination .pagination-links .current,
body.pcdm-enable.pcdark-mode #buddypress input[type=submit],
body.pcdm-enable.pcdark-mode form.pc-searchform.penci-hbg-search-form input.search-input:hover,
body.pcdm-enable.pcdark-mode form.pc-searchform.penci-hbg-search-form input.search-input:focus,
body.pcdm-enable.pcdark-mode .penci-dropcap-box-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle-outline {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-error,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-info,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-message {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-slider ol.penci-control-nav li a.penci-active,
body.pcdm-enable.pcdark-mode .penci-slider ol.penci-control-nav li a:hover,
body.pcdm-enable.pcdark-mode .penci-related-carousel .penci-owl-dot.active span,
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider .penci-owl-dot.active span {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-message:before,
body.pcdm-enable.pcdark-mode.woocommerce form.checkout table.shop_table .order-total .amount,
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product .price ins,
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product .price,
body.pcdm-enable.pcdark-mode.woocommerce div.product p.price ins,
body.pcdm-enable.pcdark-mode.woocommerce div.product span.price ins,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] blockquote:before,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description blockquote:before,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] blockquote cite,
body.pcdm-enable.pcdark-mode.woocommerce div.product .entry-summary div[itemprop="description"] blockquote .author,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description blockquote cite,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs #tab-description blockquote .author,
body.pcdm-enable.pcdark-mode.woocommerce div.product .product_meta > span a:hover,
body.pcdm-enable.pcdark-mode.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
body.pcdm-enable.pcdark-mode.woocommerce ul.cart_list li .amount,
body.pcdm-enable.pcdark-mode.woocommerce ul.product_list_widget li .amount,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table td.product-name a:hover,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table td.product-price span,
body.pcdm-enable.pcdark-mode.woocommerce table.shop_table td.product-subtotal span,
body.pcdm-enable.pcdark-mode.woocommerce-cart .cart-collaterals .cart_totals table td .amount,
body.pcdm-enable.pcdark-mode.woocommerce .woocommerce-info:before,
body.pcdm-enable.pcdark-mode.woocommerce div.product span.price,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce div.product p.price {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link.penci-more-link-button a.more-link,
body.pcdm-enable.pcdark-mode .penci-readmore-btn.penci-btn-make-button a,
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore.penci-btn-make-button a {
    background-color: var(--pcbg-cl);
    color: #fff;
}
body.pcdm-enable.pcdark-mode .penci-vernav-toggle:before {
    border-top-color: var(--pcborder-cl);
    color: #fff;
}
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination a,
body.pcdm-enable.pcdark-mode .penci-pagination .disable-url,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li span,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a,
body.pcdm-enable.pcdark-mode #comments_pagination span,
body.pcdm-enable.pcdark-mode #comments_pagination a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .archive-box span {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .archive-box h1 {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .summary.entry-summary .woocommerce-accordion.wc-accordion-wrapper,
body.pcdm-enable.pcdark-mode .penci_header_overlap .penci-desktop-bottombar,
body.pcdm-enable.pcdark-mode .penci-desktop-bottombar {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-top-bar,
body.pcdm-enable.pcdark-mode .penci-topbar-trending .penci-owl-carousel .owl-item,
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu ul.sub-menu,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul ul.sub-menu,
body.pcdm-enable.pcdark-mode .pctopbar-login-btn .pclogin-sub,
body.pcdm-enable.pcdark-mode .woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button,
body.pcdm-enable.pcdark-mode .penci-topbar-trending .penci-owl-carousel .owl-item {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .headline-title.nticker-style-3:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .headline-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev,
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next,
body.pcdm-enable.pcdark-mode .penci-trending-nav a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev:hover,
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next:hover,
body.pcdm-enable.pcdark-mode .penci-trending-nav a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode a.penci-topbar-post-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode a.penci-topbar-post-title:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-headline .pctopbar-item {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu > li a,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul > li a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu ul.sub-menu,
div.penci-topbar-menu > ul ul.sub-menu {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu > li a:hover,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul > li a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu ul.sub-menu li a,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul ul.sub-menu li a,
body.pcdm-enable.pcdark-mode ul.penci-topbar-menu > li > ul.sub-menu > li:first-child,
body.pcdm-enable.pcdark-mode div.penci-topbar-menu > ul > li > ul.sub-menu > li:first-child {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-topbar-social a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-topbar-social a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-topbar-social .pctopbar-login-btn a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-topbar-social .pctopbar-login-btn a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-ld .penci-ldin:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup,
body.pcdm-enable.pcdark-mode #penci-login-popup:before,
body.pcdm-enable.pcdark-mode #penci-login-popup.ajax-loading:before {
    background: linear-gradient(135deg, var(--pcbg-cl) 0%, var(--pcbg-cl) 100%);
}
body.pcdm-enable.pcdark-mode .mfp-close-btn-in #penci-login-popup .mfp-close {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-lgpop-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="text"],
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="password"],
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="email"] {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="text"]::-webkit-input-placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="password"]::-webkit-input-placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="email"]::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="text"]::-ms-input-placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="password"]::-ms-input-placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="email"]::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="text"]::placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="password"]::placeholder,
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="email"]::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="submit"] {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup .penci-login input[type="submit"]:hover {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup,
body.pcdm-enable.pcdark-mode #penci-login-popup p:not(.message) {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup a,
#penci-login-popup a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation.header-1,
body.pcdm-enable.pcdark-mode #navigation.header-4,
body.pcdm-enable.pcdark-mode #navigation.header-7 {
    border-bottom-color: rgba(255, 255, 255, 0.1) !important
}
body.pcdm-enable.pcdark-mode .header-header-1.has-bottom-line,
body.pcdm-enable.pcdark-mode .header-header-4.has-bottom-line,
body.pcdm-enable.pcdark-mode .header-header-7.has-bottom-line {
    border-bottom-color: rgba(255, 255, 255, 0.1) !important
}
body.pcdm-enable.pcdark-mode #navigation,
body.pcdm-enable.pcdark-mode #navigation.header-layout-bottom {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu > li > a,
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu > li > a:hover,
body.pcdm-enable.pcdark-mode #navigation .menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li:hover > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li a:hover,
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation .sub-menu li:hover > a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation ul.menu > li > a:before,
body.pcdm-enable.pcdark-mode #navigation .menu > ul > li > a:before {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li > a:hover,
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li:hover > a,
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode #navigation.menu-item-padding .menu > li.current-menu-item > a {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode #navigation .menu .children,
body.pcdm-enable.pcdark-mode #navigation ul.menu > li.megamenu > ul.sub-menu {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode #navigation .menu .children,
body.pcdm-enable.pcdark-mode #navigation ul.menu ul.sub-menu li > a,
body.pcdm-enable.pcdark-mode #navigation .menu ul ul.sub-menu li a,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .menu .sub-menu,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .menu .children {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories a.cat-active {
    border-top-color: var(--pcborder-cl);
    border-bottom-color: var(--pcborder-cl);
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #navigation ul.menu > li.megamenu > ul.sub-menu > li:before,
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropdown-menu {
    border-color: var(--pcborder-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu,
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories a.cat-active,
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.cat-active {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories:after,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a.all-style:before,
body.pcdm-enable.pcdark-mode .menu-style-2 .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
    background: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories a.cat-active,
body.pcdm-enable.pcdark-mode #navigation .menu .penci-megamenu .penci-mega-child-categories a:hover,
body.pcdm-enable.pcdark-mode #navigation .menu .penci-megamenu .penci-mega-latest-posts .penci-mega-post a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .header-slogan .header-slogan-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-slogan .header-slogan-text:before,
body.pcdm-enable.pcdark-mode .header-slogan .header-slogan-text:after {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li a:hover,
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation .sub-menu li:hover > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 ul.menu ul.sub-menu:before,
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .menu ul ul.sub-menu:before {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .top-search-classes a.cart-contents,
body.pcdm-enable.pcdark-mode .pcheader-icon > a,
body.pcdm-enable.pcdark-mode #navigation .button-menu-mobile {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation .button-menu-mobile svg {
    fill: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search form.pc-searchform input.search-input::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search form.pc-searchform input.search-input:-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search form.pc-searchform input.search-input::-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search form.pc-searchform input.search-input {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-search a.close-search {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form,
body.pcdm-enable.pcdark-mode .penci-header-signup-form h4.header-signup-form,
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form-fields > p,
body.pcdm-enable.pcdark-mode .penci-header-signup-form form > p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="text"],
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="email"] {
    border-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="text"]::-webkit-input-placeholder,
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="email"]::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="text"]:-moz-placeholder,
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="email"]:-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="text"]::-moz-placeholder,
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="email"]::-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="text"]:-ms-input-placeholder,
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form input[type="email"]:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .widget input[type="submit"] {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .widget input[type="submit"]:hover {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-social a i,
body.pcdm-enable.pcdark-mode .main-nav-social a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-social a:hover i,
body.pcdm-enable.pcdark-mode .main-nav-social a:hover,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .lines-button:after,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .penci-lines:before,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle:hover .penci-lines:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #close-sidebar-nav {
    background-color: rgba(65, 65, 65, 0.8);
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode #close-sidebar-nav i {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input,
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:focus {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-social.sidebar-nav-social a i,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a .indicator {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a:hover,
body.pcdm-enable.pcdark-mode .header-social.sidebar-nav-social a:hover i,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a .indicator:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu .sub-menu li a .indicator:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav-logo:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li,
body.pcdm-enable.pcdark-mode #sidebar-nav ul.sub-menu,
body.pcdm-enable.pcdark-mode #sidebar-nav #logo + ul {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode h2.penci-heading-video {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode p.penci-sub-heading-video {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .featured-cat a,
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode .featured-style-35 .cat > a.penci-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .cat > a.penci-cat-name:after,
body.pcdm-enable.pcdark-mode .penci-featured-content .cat > a.penci-cat-name:after,
body.pcdm-enable.pcdark-mode .featured-style-35 .cat > a.penci-cat-name:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .featured-cat a:hover,
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .cat > a.penci-cat-name:hover,
body.pcdm-enable.pcdark-mode .featured-style-35 .cat > a.penci-cat-name:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content h3 a,
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text h3 a,
body.pcdm-enable.pcdark-mode .featured-style-35 .feat-text-right h3 a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content h3 a:hover,
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text h3 a:hover,
body.pcdm-enable.pcdark-mode .featured-style-35 .feat-text-right h3 a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .feat-meta span,
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .feat-meta a,
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta span,
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta span a,
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt .feat-meta span,
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt .feat-meta span a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .feat-meta > span:after,
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta > span:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt p,
body.pcdm-enable.pcdark-mode .featured-slider-excerpt p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-29 .penci-featured-content .feat-text h3:before {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-29 .penci-featured-slider-button a,
body.pcdm-enable.pcdark-mode .featured-style-35 .penci-featured-slider-button a,
body.pcdm-enable.pcdark-mode .featured-style-38 .penci-featured-slider-button a {
    border-color: var(--pcborder-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-29 .penci-featured-slider-button a:hover,
body.pcdm-enable.pcdark-mode .featured-style-35 .penci-featured-slider-button a:hover,
body.pcdm-enable.pcdark-mode .featured-style-38 .penci-featured-slider-button a:hover {
    border-color: var(--pcborder-cl);
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat .cat > a.penci-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat .cat:before,
body.pcdm-enable.pcdark-mode .penci-standard-cat .cat:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .header-standard > h2 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-standard > h2 a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-post-share-box a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-post-share-box a:hover,
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-post-share-box a.liked {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-standard .author-post span,
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-box-meta span,
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-box-meta a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .header-standard .author-post span a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .header-standard .post-entry a:hover,
body.pcdm-enable.pcdark-mode .header-standard .author-post span a:hover,
body.pcdm-enable.pcdark-mode .standard-content a,
body.pcdm-enable.pcdark-mode .standard-content .post-entry a,
body.pcdm-enable.pcdark-mode .standard-post-entry a.more-link:hover,
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-box-meta a:hover,
body.pcdm-enable.pcdark-mode .standard-content .post-entry blockquote:before,
body.pcdm-enable.pcdark-mode .post-entry blockquote cite,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author,
body.pcdm-enable.pcdark-mode .standard-content-special .author-quote span,
body.pcdm-enable.pcdark-mode .standard-content-special .format-post-box .post-format-icon i,
body.pcdm-enable.pcdark-mode .standard-content-special .format-post-box .dt-special a:hover,
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link a.more-link,
body.pcdm-enable.pcdark-mode .standard-content .penci-post-box-meta .penci-box-meta a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link.penci-more-link-button a.more-link {
    color: #fff;
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .standard-content-special .author-quote span:before,
body.pcdm-enable.pcdark-mode .standard-content-special .author-quote span:after,
body.pcdm-enable.pcdark-mode .standard-content .post-entry ul li:before,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author span:after,
body.pcdm-enable.pcdark-mode .header-standard:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-more-link a.more-link:before,
body.pcdm-enable.pcdark-mode .penci-more-link a.more-link:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link a.more-link,
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link.penci-more-link-button a.more-link {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link a.more-link:before,
body.pcdm-enable.pcdark-mode .standard-content .penci-more-link a.more-link:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li .item h2 a,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry h2 a,
body.pcdm-enable.pcdark-mode .penci-grid li .item .penci_grid_title a,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry .penci_grid_title a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .cat a.penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-grid .cat a.penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-masonry .cat a.penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-featured-infor .cat a.penci-cat-name {
    color: var(--pcaccent-cl) !important;
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .cat a.penci-cat-name:after,
body.pcdm-enable.pcdark-mode .penci-grid .cat a.penci-cat-name:after,
body.pcdm-enable.pcdark-mode .penci-masonry .cat a.penci-cat-name:after,
body.pcdm-enable.pcdark-mode .penci-featured-infor .cat a.penci-cat-name:after {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-post-share-box a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-post-share-box a.liked,
body.pcdm-enable.pcdark-mode .penci-post-share-box a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .grid-featured .penci-featured-share-box a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .grid-featured .penci-featured-share-box a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-share-box .penci-shareic,
body.pcdm-enable.pcdark-mode .penci-featured-share-box .penci-shareso {
    background-color: var(--pcbg-cl);
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci-entry-title a,
body.pcdm-enable.pcdark-mode .penci-grid li .item h2 a,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry h2 a,
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail h2 a,
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci_grid_title a,
body.pcdm-enable.pcdark-mode .penci-grid li .item .penci_grid_title a,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry .penci_grid_title a,
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail .penci_grid_title a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci-entry-title a:hover,
body.pcdm-enable.pcdark-mode .penci-grid li .item h2 a:hover,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry h2 a:hover,
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail h2 a:hover,
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci_grid_title a:hover,
body.pcdm-enable.pcdark-mode .penci-grid li .item .penci_grid_title a:hover,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry .penci_grid_title a:hover,
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail .penci_grid_title a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a,
body.pcdm-enable.pcdark-mode .grid-mixed .penci-post-box-meta .penci-box-meta a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .standard-content-special .format-post-box .dt-special a:hover,
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a:hover,
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a.comment-link:hover,
body.pcdm-enable.pcdark-mode .penci-grid .standard-content-special .author-quote span,
body.pcdm-enable.pcdark-mode .penci-grid .standard-content-special .format-post-box .post-format-icon i,
body.pcdm-enable.pcdark-mode .grid-mixed .penci-post-box-meta .penci-box-meta a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .standard-content-special .author-quote span:before,
body.pcdm-enable.pcdark-mode .penci-grid .standard-content-special .author-quote span:after,
body.pcdm-enable.pcdark-mode .grid-header-box:after,
body.pcdm-enable.pcdark-mode .list-post .header-list-style:after {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .post-box-meta span:after,
body.pcdm-enable.pcdark-mode .penci-masonry .post-box-meta span:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-readmore-btn.penci-btn-make-button a {
    color: #fff;
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-readmore-btn a,
body.pcdm-enable.pcdark-mode .penci-readmore-btn.penci-btn-make-button a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid .typography-style .main-typography a.penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-grid .typography-style .main-typography a.penci-cat-name:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .typography-style .main-typography a.penci-cat-name:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .item .main-typography h2 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .item .main-typography h2 a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .grid-post-box-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .grid-post-box-meta span:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .grid-post-box-meta span a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.pcsb-boxed-whole,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.pcsb-boxed-widget .widget {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-14 .penci-border-arrow .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow {
    background-color: var(--pcbg-l-cl);
    border-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-2 .penci-border-arrow:after {
    border-top-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content .penci-border-arrow:after {
    background-color: var(--pcbg-l-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content .penci-border-arrow .inner-arrow {
    border-color: var(--pcborder-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-4 .penci-border-arrow .inner-arrow:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-5 .penci-border-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-7 {
    border-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-9 .penci-border-arrow {
    border-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content .penci-border-arrow:before {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-16 .penci-border-arrow:after {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-5 .penci-border-arrow {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12 .penci-border-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-10 .penci-border-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-5 .penci-border-arrow .inner-arrow {
    border-bottom-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-10 .penci-border-arrow {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:before {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow:before {
    border-bottom-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12.pcalign-center .penci-border-arrow .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12.pcalign-right .penci-border-arrow .inner-arrow:after {
    border-bottom-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13.pcalign-left .penci-border-arrow .inner-arrow:after {
    border-right-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13.pcalign-center .penci-border-arrow .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13.pcalign-right .penci-border-arrow .inner-arrow:before {
    border-left-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-15 .penci-border-arrow:before {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-15 .penci-border-arrow:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-18 .penci-border-arrow:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-7 .penci-border-arrow .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-9 .penci-border-arrow .inner-arrow:before {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text h4 a,
body.pcdm-enable.pcdark-mode .widget a,
body.pcdm-enable.pcdark-mode #wp-calendar tbody td a,
body.pcdm-enable.pcdark-mode .widget.widget_categories ul li,
body.pcdm-enable.pcdark-mode .widget.widget_archive ul li,
body.pcdm-enable.pcdark-mode .widget-social a i,
body.pcdm-enable.pcdark-mode .widget-social a span,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title:hover,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text h4 a:hover,
body.pcdm-enable.pcdark-mode .widget a:hover,
body.pcdm-enable.pcdark-mode .penci-sidebar-content .widget-social a:hover span,
body.pcdm-enable.pcdark-mode .widget-social a:hover span,
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .icon-tweets,
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-intents a,
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content {
}
body.pcdm-enable.pcdark-mode .tweet-intents span:after,
body.pcdm-enable.pcdark-mode .widget-social.remove-circle a:hover i,
body.pcdm-enable.pcdark-mode #wp-calendar tbody td a:hover,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title:hover,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget .tagcloud a:hover,
body.pcdm-enable.pcdark-mode .widget-social a:hover i,
body.pcdm-enable.pcdark-mode .widget input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a:hover,
body.pcdm-enable.pcdark-mode .penci-button:hover,
body.pcdm-enable.pcdark-mode .widget button[type="submit"]:hover {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .about-widget .about-me-heading:before {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-intents-inner:before,
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-intents-inner:after,
body.pcdm-enable.pcdark-mode .pencisc-column-1.penci-video_playlist .penci-video-nav .playlist-panel-item,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-thumb,
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-playlist-title {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot.active span,
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot:hover span {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe h4.footer-subscribe-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe .mc4wp-form .mdes {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="email"],
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="text"] {
    border-color: var(--pcborder-cl);
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="email"]:focus,
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="email"]:hover,
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="text"]:focus,
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="text"]:hover {
    border-color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="email"]::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="email"]:-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="email"]::-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="email"]:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="email"]::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="text"]::-webkit-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="text"]:-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="text"]::-moz-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="text"]:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe input[type="text"]::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="submit"] {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-subscribe .widget .mc4wp-form input[type="submit"]:hover {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #widget-area {
    background-color: var(--pcbg-l-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget.widget_categories ul li,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget.widget_archive ul li,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="text"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="email"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="date"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="number"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="search"] {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul li,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul ul,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="text"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="email"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="date"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="number"],
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="search"] {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget .widget-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget .widget-title .inner-arrow {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper a,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul.side-newsfeed li .side-item .side-item-text h4 a,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget a,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social a i,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social a span,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social a:hover i {
    color: #fff;
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-tweets-widget-content .icon-tweets,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-tweets-widget-content .tweet-intents a,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-tweets-widget-content .tweet-intents span:after,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul.side-newsfeed li .side-item {
}
body.pcdm-enable.pcdark-mode .side-item-text h4 a:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget a:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social a:hover span,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper a:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social.remove-circle a:hover i,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget .tagcloud a:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget-social a:hover i,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .mc4wp-form input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-user-logged-in .penci-user-action-links a:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget button[type="submit"]:hover {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .about-widget .about-me-heading:before {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-tweets-widget-content .tweet-intents-inner:before,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-tweets-widget-content .tweet-intents-inner:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot.active span,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .penci-owl-carousel.penci-tweets-slider .penci-owl-dots .penci-owl-dot:hover span {
    border-color: var(--pcborder-cl);
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode ul.footer-socials li a i {
    border-color: var(--pcborder-cl);
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode ul.footer-socials li a:hover i {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode ul.footer-socials li a span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode ul.footer-socials li a:hover span {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .footer-socials-section,
body.pcdm-enable.pcdark-mode .penci-footer-social-moved {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .footer-instagram h4.footer-instagram-title {
    border-color: var(--pcborder-cl);
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode #footer-section,
body.pcdm-enable.pcdark-mode .penci-footer-social-moved {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-footer-social-moved {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .footer-menu li a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .footer-menu li a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #footer-section,
body.pcdm-enable.pcdark-mode #footer-copyright * {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .go-to-top i,
body.pcdm-enable.pcdark-mode #footer-section .go-to-top-parent span {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .go-to-top:hover span,
body.pcdm-enable.pcdark-mode #footer-section .go-to-top:hover i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-go-to-top-floating {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #footer-section a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-instagram h4.footer-instagram-title span {
    border-color: var(--pctext-cl);
    color: inherit;
}
body.pcdm-enable.pcdark-mode .comment-content a,
body.pcdm-enable.pcdark-mode .container-single .post-entry a,
body.pcdm-enable.pcdark-mode .container-single .format-post-box .dt-special a:hover,
body.pcdm-enable.pcdark-mode .container-single .author-quote span,
body.pcdm-enable.pcdark-mode .container-single .author-post span a:hover,
body.pcdm-enable.pcdark-mode .post-entry blockquote:before,
body.pcdm-enable.pcdark-mode .post-entry blockquote cite,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote:before,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote cite,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote .author,
body.pcdm-enable.pcdark-mode .post-pagination a:hover,
body.pcdm-enable.pcdark-mode .author-content h5 a:hover,
body.pcdm-enable.pcdark-mode .author-content .author-social:hover,
body.pcdm-enable.pcdark-mode .item-related h3 a:hover,
body.pcdm-enable.pcdark-mode .container-single .format-post-box .post-format-icon i,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb.single-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb.single-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .penci_list_shortcode li:before,
body.pcdm-enable.pcdark-mode .penci-dropcap-box-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-regular,
body.pcdm-enable.pcdark-mode .penci-dropcap-bold,
body.pcdm-enable.pcdark-mode .header-standard .post-box-meta-single .author-post span a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .container-single .standard-content-special .format-post-box,
body.pcdm-enable.pcdark-mode ul.slick-dots li button:hover,
body.pcdm-enable.pcdark-mode ul.slick-dots li.slick-active button,
body.pcdm-enable.pcdark-mode .penci-dropcap-box-outline,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle-outline {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode ul.slick-dots li button:hover,
body.pcdm-enable.pcdark-mode ul.slick-dots li.slick-active button,
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span:before,
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span:after,
body.pcdm-enable.pcdark-mode .post-box-title:before,
body.pcdm-enable.pcdark-mode .post-box-title:after,
body.pcdm-enable.pcdark-mode .container-single .author-quote span:before,
body.pcdm-enable.pcdark-mode .container-single .author-quote {
}
body.pcdm-enable.pcdark-mode .post-entry blockquote .author span:after,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author span:before,
body.pcdm-enable.pcdark-mode .post-entry ul li:before,
body.pcdm-enable.pcdark-mode #respond #submit:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button:hover,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .post-entry.blockquote-style-2 blockquote:before,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s2 .post-share-plike,
body.pcdm-enable.pcdark-mode .penci-dropcap-box,
body.pcdm-enable.pcdark-mode .penci-dropcap-circle,
body.pcdm-enable.pcdark-mode .penci-ldspinner > div {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .container-single .post-entry .post-tags a:hover {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg,
body.pcdm-enable.pcdark-mode #sidebar-nav {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a,
body.pcdm-enable.pcdark-mode .penci-login-register input[type="submit"],
body.pcdm-enable.pcdark-mode .widget input[type="submit"],
body.pcdm-enable.pcdark-mode .widget button[type="submit"],
body.pcdm-enable.pcdark-mode .contact-form input[type=submit],
body.pcdm-enable.pcdark-mode #respond #submit,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"],
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button,
body.pcdm-enable.pcdark-mode .mc4wp-form input[type=submit] {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
.pcdark-mode .penci-user-logged-in .penci-user-action-links a,
.pcdark-mode .penci-login-register input[type="submit"],
.pcdark-mode .widget input[type="submit"],
.pcdark-mode .widget button[type="submit"],
.pcdark-mode .contact-form input[type=submit],
.pcdark-mode #respond #submit,
.pcdark-mode .wpcf7 input[type="submit"],
.pcdark-mode .widget_wysija input[type="submit"],
.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit],
.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit],
.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button,
.pcdark-mode .mc4wp-form input[type=submit] {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .wp-block-search .wp-block-search__button svg {
    fill: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a:hover,
body.pcdm-enable.pcdark-mode .penci-login-register input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget button[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .mc4wp-form input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .footer-widget-wrapper .widget input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget button[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .contact-form input[type=submit]:hover,
body.pcdm-enable.pcdark-mode #respond #submit:hover,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button:hover,
body.pcdm-enable.pcdark-mode .mc4wp-form input[type=submit]:hover {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .wp-block-search .wp-block-search__button:hover svg {
    fill: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-ldspinner > div {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .container-single .penci-standard-cat .cat > a.penci-cat-name {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .container-single .penci-standard-cat .cat:before,
body.pcdm-enable.pcdark-mode .container-single .penci-standard-cat .cat:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .container-single .header-standard .post-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .container-single .header-standard h2.penci-psub-title,
body.pcdm-enable.pcdark-mode .container-single h2.penci-psub-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .container-single .post-entry .post-tags a {
    border-color: var(--pcborder-cl);
    background-color: var(--pcbg-cl);
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .penci-social-share-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text:after {
    border-color: transparent transparent transparent var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text:before {
    border-left-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share .count-number-like,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share a,
body.pcdm-enable.pcdark-mode .container-single .post-share a,
body.pcdm-enable.pcdark-mode .page-share .post-share a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .container-single .post-share a:hover,
body.pcdm-enable.pcdark-mode .page-share .post-share a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .container-single .post-share a.liked {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share .count-number-like,
body.pcdm-enable.pcdark-mode .post-share .count-number-like {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s3 .post-share .post-share-item {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s3 .post-share .post-share-item:hover {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box .single-comment-o,
body.pcdm-enable.pcdark-mode .post-box-meta-single span,
body.pcdm-enable.pcdark-mode .header-standard .post-box-meta-single .author-post span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb.single-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb.single-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .post-entry,
body.pcdm-enable.pcdark-mode .post-entry p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode.single .post-entry a,
body.pcdm-enable.pcdark-mode .container-single .post-entry a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .pcilrp-heading span {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcilrp-heading span:after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a,
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-list a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a:hover,
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-list a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .pcilrp-meta {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-single-style-9 .penci-post-image-wrapper,
body.pcdm-enable.pcdark-mode .penci-single-style-10 .penci-post-image-wrapper {
    background-color: var(--pcbg-cl);
}
/*more css*/
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rtlpopup-heading {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup .penci-close-rltpopup {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rltpopup-meta .rltpopup-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rltpopup-meta .rltpopup-title:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rltpopup-meta .date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-rlt-popup .rltpopup-item {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode. post-author {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .post-author,
body.pcdm-enable.pcdark-mode .abio-style-3 .author-img img,
body.pcdm-enable.pcdark-mode .abio-style-4 .author-img img {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .author-content h5 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .author-content h5 a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .author-content p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .author-content .author-social {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .author-content .author-social:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span,
.post-box-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span:before,
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span:after,
body.pcdm-enable.pcdark-mode .post-box-title:before,
body.pcdm-enable.pcdark-mode .post-box-title:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .item-related h3 a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .item-related h3 a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .item-related span.date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author,
.thecomment .comment-text span.author a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-comments span.reply a,
body.pcdm-enable.pcdark-mode .post-comments span.reply a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-content,
body.pcdm-enable.pcdark-mode .thecomment .comment-content p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="text"],
body.pcdm-enable.pcdark-mode #respond input[type="email"],
body.pcdm-enable.pcdark-mode #respond textarea {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="text"]::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="text"]:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="text"]::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="email"]::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="email"]:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond input[type="email"]::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond textarea::placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond textarea:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond textarea::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode form#commentform > .comment-form-cookies-consent,
body.pcdm-enable.pcdark-mode form#commentform > div.penci-gdpr-message {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 span span,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 span,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4 {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes li .penci-fea-in:before,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes li .penci-fea-in:after,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 span span:before,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 > span:before,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 > span:after,
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in.boxes-style-2 h4:before {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in h4 span span {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode ul.homepage-featured-boxes .penci-fea-in:hover h4 span {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .home-pupular-posts-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-home-popular-posts {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-home-popular-post .item-related h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-home-popular-post .item-related h3 a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-home-popular-post .item-related span.date {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-14 .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-15 .inner-arrow {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title.style-2:after {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title:after {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-4 .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-4 .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-7,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-9 {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title:before {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-5,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-7 {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-16.penci-border-arrow:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-10,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12,
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title.style-5 .inner-arrow {
    border-bottom-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-5 {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-7 .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-9 .inner-arrow:before {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-10 {
    border-top-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13.pcalign-center .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13.pcalign-right .inner-arrow:before {
    border-left-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13.pcalign-center .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13.pcalign-left .inner-arrow:after {
    border-right-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12 .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12.pcalign-center .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12.pcalign-right .inner-arrow:after {
    border-bottom-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow:before {
    border-top-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-15.penci-border-arrow:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-15.penci-border-arrow:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-18.penci-border-arrow:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title.penci-magazine-title .inner-arrow a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .magcat-detail h3 a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .magcat-detail h3 a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .grid-post-box-meta span {
    color: var(--pcmeta-cl)
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .penci-single-mag-slider .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .penci-single-mag-slider .grid-post-box-meta span a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .mag-meta,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .mag-meta span a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span:after,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .grid-post-box-meta span a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .grid-post-box-meta span a {
    color: var(--pcmeta-cl)
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .grid-post-box-meta span a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .first-post .magcat-detail .mag-header:after {
    background: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-slider ol.penci-control-nav li a.penci-active,
body.pcdm-enable.pcdark-mode .penci-slider ol.penci-control-nav li a:hover {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore a,
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore.penci-btn-make-button a {
    color: var(--pctext-cl)
}
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore.penci-btn-make-button a {
    background-color: var(--pcbg-cl)
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .magcat-detail h3 a,
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .magcat-detail .magcat-titlte a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .first-post .magcat-detail h3 a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .magcat-detail h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .magcat-detail h3 a:hover,
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .magcat-detail .magcat-titlte a:hover,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .first-post .magcat-detail h3 a:hover,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .magcat-detail h3 a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .text-grid-info h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .text-grid-info h3 a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-buttons a {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-item .portfolio-buttons a:hover {
    color: var(--pctext-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-item .portfolio-buttons a.liked > i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .text-grid-cat,
body.pcdm-enable.pcdark-mode .text-grid-cat a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .text-grid-cat a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-portfolio-thumbnail a:after {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .inner-item-portfolio .portfolio-desc h3 {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .inner-item-portfolio .portfolio-desc span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .inner-item-portfolio .portfolio-desc h3:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .inner-item-portfolio .portfolio-desc span:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search {
    background-color: var(--pcbg-cl);
    border-color: var(--pcaccent-cl);
    box-shadow: 0 3px 3px rgba(64, 64, 64, 0.6);
    -mox-box-shadow: 0 3px 3px rgba(64, 64, 64, 0.6);
    -webkit-box-shadow: 0 3px 3px rgba(64, 64, 64, 0.6);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search:before {
    border-color: transparent transparent var(--pcaccent-cl) transparent;
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform input.search-input {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform input.search-input::-ms-input-placeholder {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .sticky-wrapper:not(.is-sticky) .show-search form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-mode .header-search-style-showup .sticky-wrapper.is-sticky .show-search form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform input.search-input {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform .searchsubmit {
    background-color: var(--pcaccent-cl);
    color: white;
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .show-search form.pc-searchform .searchsubmit:hover {
    background-color: var(--pcbg-cl);
    color: var(--pctext-cl);
}
/* Dark Mode Modify*/
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow:before,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow:before {
    border-top-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .post-entry.blockquote-style-2 blockquote {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow .inner-arrow {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #widget-area .penci-border-arrow .inner-arrow {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element > .elementor-widget-container,
body.pcdm-enable.pcdark-mode .elementor .elementor-element.elementor-section:not(.elementor-motion-effects-element-type-background),
body.pcdm-enable.pcdark-mode .elementor .elementor-element.elementor-section > .elementor-motion-effects-container > .elementor-motion-effects-layer {
    background-color: transparent;
    border-color: var(--pcborder-cl);
    transition: none;
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .elementor-button {
    color: var(--pctext-cl);
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .penci-soledad-product:not(.style-6) a {
    color: var(--pcl-cl) !important;
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element div:not(.penci-bgrid-content-on) a:not(.penci-btn-readmore):hover {
    color: var(--pclh-cl) !important;
    border-color: var(--pclh-cl) !important;
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-top,
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li,
body.pcdm-enable.pcdark-mode .elementor-widget:not(.elementor-widget-penci-big-grid) * {
    border-color: var(--pcborder-cl) !important;
    fill: var(--pctext-cl) !important;
    color: var(--pctext-cl) !important;
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .elementor-shape * {
    fill: var(--pcbg-cl) !important;
}
body.pcdm-enable.pcdark-mode .mfp-preloader {
    color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .mfp-preloader a {
    color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .mfp-preloader a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mfp-close {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mfp-close-btn-in .mfp-close {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .mfp-image-holder .mfp-close,
body.pcdm-enable.pcdark-mode .mfp-iframe-holder .mfp-close {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mfp-counter {
    color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .mfp-figure small {
    color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .mfp-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .justified-gallery > a > .caption,
body.pcdm-enable.pcdark-mode .justified-gallery > div > .caption {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .justified-gallery > .spinner > span {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode input {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode body {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu .sub-menu {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination h5 {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination h5 {
    transition: color 0.3s;
}
body.pcdm-enable.pcdark-mode .post-pagination h5:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .penci-topbar-ctext * {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-prev,
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider.penci-headline-posts .penci-owl-nav .owl-next {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-trending-nav a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-enews-ticker .headline-title.nticker-style-3:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-enews-ticker .penci-trending-nav a,
body.pcdm-enable.pcdark-mode .penci-enews-ticker .penci-trending-nav a:hover {
    color: #666;
}
body.pcdm-enable.pcdark-mode #penci-login-popup {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #penci-login-popup:after {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode #navigation .sub-menu li a,
body.pcdm-enable.pcdark-mode #navigation .menu > li > a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode #navigation .menu > li > a:hover,
body.pcdm-enable.pcdark-mode #navigation .menu > li:hover > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current-menu-item > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode #navigation .menu > li.current-menu-item > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #navigation .button-menu-mobile {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories:after {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode #navigation ul.menu > li.menu-item-has-children > a:after,
body.pcdm-enable.pcdark-mode #navigation .menu > ul > li.menu-item-has-children > a:after,
body.pcdm-enable.pcdark-mode #navigation ul.menu > li.penci-mega-menu > a:after,
body.pcdm-enable.pcdark-mode #navigation .menu > ul > li.penci-mega-menu > a:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories:after {
    background-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode #navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode #sidebar-nav::-webkit-scrollbar-thumb {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav::-webkit-scrollbar-corner {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .header-social.sidebar-nav-social a i:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg .header-social.penci-hbg-social-style-2 a:hover i {
    border-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li a,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li a:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu li a .indicator:hover,
body.pcdm-enable.pcdark-mode .penci-menu-hbg .menu .sub-menu li a .indicator:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu li a .indicator:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav .menu .sub-menu li a .indicator:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle .penci-lines:before,
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle .penci-lines:after {
    background-color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-menuhbg-toggle .lines-button:after {
    background-color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg-inner #penci-close-hbg:hover:before,
body.pcdm-enable.pcdark-mode .penci-menu-hbg-inner #penci-close-hbg:hover:after {
    background-color: #111;
}
body.pcdm-enable.pcdark-mode .top-search-classes a.cart-contents,
body.pcdm-enable.pcdark-mode .top-search-classes > a,
body.pcdm-enable.pcdark-mode .pcheader-icon > a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .pcheader-icon.shoping-cart-icon > a > span {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .main-nav-social a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .main-nav-social a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .header-social a:hover i {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .dark-layout-enabled .featured-area.featured-video {
    background-color: #2d2d2d;
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel .penci-owl-nav .owl-prev,
body.pcdm-enable.pcdark-mode .penci-owl-carousel .penci-owl-nav .owl-next {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .featured-cat a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .feat-meta span > time,
body.pcdm-enable.pcdark-mode span.side-item-meta > time,
body.pcdm-enable.pcdark-mode span.date > time {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-content .feat-text .feat-meta > span:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode div:not(.penci-slide-overlay) .penci-mag-featured-content h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .cat > a.penci-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .feat-meta span,
body.pcdm-enable.pcdark-mode .penci-mag-featured-content .feat-meta a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .feat-text-right h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .cat > a.penci-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt .feat-meta span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt .feat-meta > span:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .featured-style-35 .featured-content-excerpt .feat-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .featured-slider-excerpt p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-image-holder:not([style*='background-image']),
body.pcdm-enable.pcdark-mode .penci-lazy[src*="penci-holder"],
body.pcdm-enable.pcdark-mode .penci-lazy[src*="20xmlns='http://www.w3.org/2000/svg'"],
body.pcdm-enable.pcdark-mode .owl-lazy[src*="20xmlns='http://www.w3.org/2000/svg'"],
body.pcdm-enable.pcdark-mode .penci-holder-load:not([style*='background-image']),
body.pcdm-enable.pcdark-mode .penci-lazy:not(.lazyloaded) {
    background: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .pencislider-container .pencislider-content .pencislider-title a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pencislider-container .pencislider-content .pencislider-title span {
    color: inherit;
    background-color: rgba(0, 0, 0, 0.4);
}
body.pcdm-enable.pcdark-mode .pencislider-container .pencislider-content .pencislider-caption span {
    color: inherit;
    background-color: rgba(0, 0, 0, 0.4);
}
body.pcdm-enable.pcdark-mode .pc-builder-menu .navigation {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci-desktop-topbar,
body.pcdm-enable.pcdark-mode .penci-desktop-midbar,
body.pcdm-enable.pcdark-mode .penci-desktop-bottombar,
body.pcdm-enable.pcdark-mode .penci-desktop-topblock,
body.pcdm-enable.pcdark-mode .penci-desktop-bottomblock {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .navigation .sub-menu > li > a,
body.pcdm-enable.pcdark-mode .navigation .menu > li > a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .navigation .menu li > a:hover,
body.pcdm-enable.pcdark-mode .navigation .menu li:hover > a,
body.pcdm-enable.pcdark-mode .navigation .menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode .navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode .navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode .navigation .menu > li.current-menu-item > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .navigation .button-menu-mobile {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-child-categories:after {
    background-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-thumbnail .mega-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .navigation ul.menu > li.menu-item-has-children > a:after,
body.pcdm-enable.pcdark-mode .navigation .menu > ul.sub-menu > li.menu-item-has-children > a:after,
body.pcdm-enable.pcdark-mode .navigation ul.menu > li.penci-mega-menu > a:after,
body.pcdm-enable.pcdark-mode .navigation .menu > ul.sub-menu > li.penci-mega-menu > a:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories:after {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .navigation.menu-style-2 ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode .navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .navigation.menu-style-2 .penci-megamenu .penci-mega-child-categories a span {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li > a:hover,
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li:hover > a,
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li.current-menu-item > a,
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode .navigation.menu-item-padding .menu > li.current-menu-item > a {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-text-logo .site-name {
    color: var(--pchb-logo-title-color);
}
body.pcdm-enable.pcdark-mode #navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a,
body.pcdm-enable.pcdark-mode .navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a {
    border-color: transparent;
}
body.pcdm-enable.pcdark-mode #navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a.cat-active,
body.pcdm-enable.pcdark-mode .navigation ul.sub-menu .penci-megamenu .penci-mega-child-categories a.cat-active {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before,
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-child-categories a.cat-active:before {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-image-logo .site-slogan,
body.pcdm-enable.pcdark-mode .penci-header-text-logo .site-slogan {
    color: var(--pchb-logo-slogan-color);
}
body.pcdm-enable.pcdark-mode .penci_navbar_mobile .penci-header-text-logo .site-name {
    color: var(--pchb-m-logo-title-color);
}
body.pcdm-enable.pcdark-mode .penci_navbar_mobile .site-slogan {
    color: var(--pchb-m-logo-slogan-color);
}
body.pcdm-enable.pcdark-mode .pc-logo-sticky.penci-header-text-logo .site-name {
    color: var(--pchb-logo-s-title-color);
}
body.pcdm-enable.pcdark-mode .pc-logo-sticky.penci-header-image-logo .site-slogan,
body.pcdm-enable.pcdark-mode .pc-logo-sticky.penci-header-text-logo .site-slogan {
    color: var(--pchb-logo-s-slogan-color);
}
body.pcdm-enable.pcdark-mode .pb-logo-sidebar-mobile.penci-header-text-logo .site-name {
    color: var(--pchb-logo-sm-title-color);
}
body.pcdm-enable.pcdark-mode .pb-logo-sidebar-mobile.penci-header-image-logo .site-slogan,
body.pcdm-enable.pcdark-mode .pb-logo-sidebar-mobile.penci-header-text-logo .site-slogan {
    color: var(--pchb-logo-sm-slogan-color);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.header-social a i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.header-social a:hover i {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-vertical-line {
    background-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu ul.sub-menu li a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu > li > a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu li > a:hover,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-main-menu .navigation .menu > li.current-menu-item > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu ul.sub-menu li a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu > li > a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu li > a:hover,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-second-menu .navigation .menu > li.current-menu-item > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu ul.sub-menu li a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu > li > a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu li > a:hover,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu li.current-menu-item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu > li.current_page_item > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu > li.current-menu-ancestor > a,
body.pcdm-enable.pcdark-mode .pc-builder-element.pc-third-menu .navigation .menu > li.current-menu-item > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.penci-topbar-trending a.penci-topbar-post-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci_header.penci_builder_sticky_header_desktop {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .close-mobile-menu-builder {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .close-mobile-menu-builder i {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci_navbar_mobile.mobile-sticky {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input {
    color: var(--pcs-d-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input::placeholder {
    color: var(--pcs-d-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pcs-d-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-desktop form.pc-searchform input.search-input::-ms-input-placeholder {
    color: var(--pcs-d-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input {
    color: var(--pcs-s-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input::placeholder {
    color: var(--pcs-s-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pcs-s-txt-cl);
}
body.pcdm-enable.pcdark-mode .penci-builder-element.pc-search-form-sidebar form.pc-searchform input.search-input::-ms-input-placeholder {
    color: var(--pcs-s-txt-cl);
}
body.pcdm-enable.pcdark-mode .pc-search-form.search-style-icon-button .searchsubmit,
body.pcdm-enable.pcdark-mode .pc-search-form.search-style-text-button .searchsubmit {
    background-color: var(--pcaccent-cl);
    color: white;
}
body.pcdm-enable.pcdark-mode .pc-header-element.penci-topbar-social a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pc-header-element .pctopbar-login-btn .pclogin-sub li a {
    color: white;
}
body.pcdm-enable.pcdark-mode .pc-header-element .pctopbar-login-btn .pclogin-sub li a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input {
    color: var(--pchd-sinput-txt);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input::placeholder {
    color: var(--pchd-sinput-txt);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input:-ms-input-placeholder {
    color: var(--pchd-sinput-txt);
}
body.pcdm-enable.pcdark-mode .header-search-style-showup .pc-wrapbuilder-header .show-search form.pc-searchform input.search-input::-ms-input-placeholder {
    color: var(--pchd-sinput-txt);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .mag-cat a.penci-cat-name {
    border-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .mag-cat a.penci-cat-name:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .mag-cat a.penci-cat-name:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .mag-meta h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .mag-meta-child span {
    color: #ffffff;
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .penci-direction-nav a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-magazine-slider .penci-direction-nav a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag2-carousel .mag2-header h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag2-carousel .cat > a.penci-cat-name {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mag2-carousel .cat > a.penci-cat-name:after {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcbg-content-inner .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode .pcbg-content-inner .cat > a.penci-cat-name:hover {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-bgrid-content-on .pcbg-content-inner .pcbg-title a,
body.pcdm-enable.pcdark-mode .penci-bgrid-content-on .pcbg-content-inner .pcbg-title a:hover {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-bgrid-content-on .pcbg-meta,
body.pcdm-enable.pcdark-mode .penci-bgrid-content-on .pcbg-meta span,
body.pcdm-enable.pcdark-mode .penci-bgrid-content-on .pcbg-meta span a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-bgitem .pcbg-pexcerpt p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-bgrid-based-custom .pcbg-sub-title a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcbg-readmore-sec .pcbg-readmorebtn,
body.pcdm-enable.pcdark-mode .pcsl-readmore .pcsl-readmorebtn {
    background-color: #efefef;
    color: #111;
    border-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci-biggrid-data .pcbg-readmore-sec span {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-biggrid-data .pcbg-readmore-sec i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pcbg-thumb .icon-post-format {
    color: rgba(255, 255, 255, 0.9);
}
body.pcdm-enable.pcdark-mode .pcfooter-navmenu .pcfoot-navmenu li a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcfooter-navmenu .pcfoot-navmenu li.current-menu-item a,
body.pcdm-enable.pcdark-mode .pcfooter-navmenu .pcfoot-navmenu li a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .sl-date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pcsl-inner .pcsl-content .pcsl-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcsl-inner .pcsl-content .pcsl-title a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pcsl-inner .pcsl-content .pcsl-title a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcsl-inner .pcsl-content .cat .penci-product-cats,
body.pcdm-enable.pcdark-mode .pcsl-inner .pcsl-content .cat .penci-product-cats a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow:before {
    border-color: transparent;
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-homepage-title h3 {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-simplelist li a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-simplelist.penci-simplelist-type-ordered li:before {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci-simplelist.penci-simplelist-type-unordered li:before {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode ul.mega-menu-list a:hover,
body.pcdm-enable.pcdark-mode .post-entry ul.mega-menu-list a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list > li.heading-style-style-2 > a:after {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .elementor-icon-list-text,
body.pcdm-enable.pcdark-mode .mega-menu-list li a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label {
    color: var(--pctext-cl);
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label.label-style-1:before,
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label.label-style-2:before {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label.label-style-3 {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label.label-style-3:before {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .mega-menu-list .menu-label.label-style-4:before {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .format-post-box .post-format-icon i {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .format-post-box .dt-special,
body.pcdm-enable.pcdark-mode .format-post-box .dt-special a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .format-post-box .dt-special a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .author-quote span {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .header-standard h2,
body.pcdm-enable.pcdark-mode .header-standard .pc_titlebig_standard,
body.pcdm-enable.pcdark-mode .header-standard .pc_titlebig_standard a,
body.pcdm-enable.pcdark-mode .header-standard .post-title,
body.pcdm-enable.pcdark-mode .header-standard h2 a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcsb-subtt .penci-psub-title,
body.pcdm-enable.pcdark-mode .container-single .header-standard h2.penci-psub-title,
body.pcdm-enable.pcdark-mode .container-single h2.penci-psub-title {
    color: var(--pcmeta-cl);
}
@media only screen and (min-width: 768px) {
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard h2.penci-psub-title,
    body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard h2.penci-psub-title {
        color: var(--pcbg-l-cl);
    }
}
body.pcdm-enable.pcdark-mode .header-standard .pc_titlebig_standard a:hover,
body.pcdm-enable.pcdark-mode .header-standard h2 a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .header-standard .author-post span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .header-standard .author-post span a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .penci-more-link a.more-link {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-more-link.penci-more-link-button a.more-link {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-box-meta span,
body.pcdm-enable.pcdark-mode .penci-post-box-meta .penci-box-meta a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pcsl-thumb .icon-post-format,
body.pcdm-enable.pcdark-mode .penci-grid li .item .thumbnail .icon-post-format,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry > .thumbnail .icon-post-format,
body.pcdm-enable.pcdark-mode .grid-mixed .thumbnail .icon-post-format {
    color: rgba(255, 255, 255, 0.9);
}
body.pcdm-enable.pcdark-mode .penci-grid li .item .cat,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry .cat {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li .item h2 a:hover,
body.pcdm-enable.pcdark-mode .penci-masonry .item-masonry h2 a:hover {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-readmore-btn i,
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-readmore-btn.penci-btn-make-button a,
body.pcdm-enable.pcdark-mode .penci-featured-cat-seemore.penci-btn-make-button a {
    color: #fff;
}
body.pcdm-enable.pcdark-mode .cat > a.penci-cat-name {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail h2 a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .grid-mixed .mixed-detail h2 a:hover {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a.comment-link {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a:hover,
body.pcdm-enable.pcdark-mode .grid-post-box-meta span a.comment-link:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci-entry-title a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-infor .penci-entry-title a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .typography-style .main-typography a.penci-cat-name {
    color: var(--pctext-cl);
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .grid-post-box-meta span a:hover,
body.pcdm-enable.pcdark-mode .penci-grid li.typography-style .item .main-typography h2 a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-photo-2-effect figcaption h2,
body.pcdm-enable.pcdark-mode .penci-photo-2-effect figcaption p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.penci-magazine-title h3 a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .magcat-thumb .icon-post-format,
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a.icon-post-format,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-image a.icon-post-format {
    color: rgba(255, 255, 255, 0.9);
}
body.pcdm-enable.pcdark-mode .penci-magcat-carousel .magcat-thumb .mag-post-thumb i {
    color: rgba(255, 255, 255, 0.9);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .magcat-detail h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content .mag-photo .grid-post-box-meta span:after {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .magcat-detail .magcat-titlte a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .magcat-detail .magcat-titlte a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .penci-single-mag-slider .grid-post-box-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .first-post .magcat-detail h3 a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .first-post .magcat-detail h3 a:hover {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .mag-meta {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .mag-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-14 .mag-meta span a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .magcat-detail h3 a,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-15 .first-post .grid-post-box-meta span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .home-pupular-posts-title a,
body.pcdm-enable.pcdark-mode .home-pupular-posts-title span {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-single-featured-img {
    background-color: #f5f5f5;
}
@media only screen and (min-width: 768px) {
    body.pcdm-enable.pcdark-mode .penci-header-text-white .cat > a.penci-cat-name,
    body.pcdm-enable.pcdark-mode .penci-single-style-5.penci-header-text-white .penci-standard-cat .cat > a.penci-cat-name,
    body.pcdm-enable.pcdark-mode .penci-single-style-6.penci-header-text-white .penci-standard-cat .cat > a.penci-cat-name,
    body.pcdm-enable.pcdark-mode .penci-single-style-8.penci-header-text-white .penci-standard-cat .cat > a.penci-cat-name,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard h2,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard .pc_titlebig_standard,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard .post-title,
    body.pcdm-enable.pcdark-mode .container-single.penci-header-text-white .header-standard .post-title,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard h2 a,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard .pc_titlebig_standard a,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .post-box-meta-single span,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .header-standard .author-post span a,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .container.penci-breadcrumb span,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .container.penci-breadcrumb i,
    body.pcdm-enable.pcdark-mode .penci-header-text-white .container.penci-breadcrumb a {
        color: var(--pctext-cl);
    }
}
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .penci-standard-cat .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard h2,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard .pc_titlebig_standard,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard .pc_titlebig_standard a,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard .post-title,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard h2 a,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .post-box-meta-single span,
body.pcdm-enable.pcdark-mode .penci-single-style-10.penci-header-text-white .header-standard .author-post span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode i.penci-post-countview-number {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-single-style-9 .penci-post-image-wrapper {
    background-color: #111;
}
body.pcdm-enable.pcdark-mode .penci-single-style-10 .penci-post-image-wrapper {
    background-color: #111;
}
body.pcdm-enable.pcdark-mode .post-box-meta-single span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single span strong,
body.pcdm-enable.pcdark-mode .post-box-meta-single span time {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-box-meta-single a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-slick-slider > button.slick-prev,
body.pcdm-enable.pcdark-mode .penci-slick-slider > button.slick-next {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .elementor-widget-text-editor p,
body.pcdm-enable.pcdark-mode .elementor-widget-text-editor p,
body.pcdm-enable.pcdark-mode .elementor-widget-text-editor .widget ul li {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-section:not(.penci-elbg-img) *,
body.pcdm-enable.pcdark-mode .penci-section:not(.penci-elbg-img) a {
    color: var(--pctext-cl) !important;
}
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-subtitle .penci-bgitem:hover .pcbg-sub-title a,
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-meta .penci-bgitem:hover .pcbg-meta-desc,
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-title .penci-bgitem:hover .pcbg-title,
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-subtitle .pcbg-sub-title a,
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-meta .pcbg-meta-desc,
body.pcdm-enable.pcdark-mode .penci-biggrid-wrapper.pcbg-mask-title .pcbg-title {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-section:not(.penci-elbg-img) a:hover {
    color: var(--pcaccent-cl) !important;
}
body.pcdm-enable.pcdark-mode .post-entry h1,
body.pcdm-enable.pcdark-mode .post-entry h2,
body.pcdm-enable.pcdark-mode .post-entry h3,
body.pcdm-enable.pcdark-mode .post-entry h4,
body.pcdm-enable.pcdark-mode .post-entry h5,
body.pcdm-enable.pcdark-mode .post-entry h6,
body.pcdm-enable.pcdark-mode .wpb_text_column h1,
body.pcdm-enable.pcdark-mode .wpb_text_column h2,
body.pcdm-enable.pcdark-mode .wpb_text_column h3,
body.pcdm-enable.pcdark-mode .wpb_text_column h4,
body.pcdm-enable.pcdark-mode .wpb_text_column h5,
body.pcdm-enable.pcdark-mode .wpb_text_column h6,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h1,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h2,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h3,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h4,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h5,
body.pcdm-enable.pcdark-mode.woocommerce .page-description h6 {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .post-password-form input[type="submit"] {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry blockquote,
body.pcdm-enable.pcdark-mode .post-entry blockquote p,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote p,
body.pcdm-enable.pcdark-mode.woocommerce .page-description blockquote,
body.pcdm-enable.pcdark-mode.woocommerce .page-description blockquote p {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-entry blockquote:before,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote:before,
body.pcdm-enable.pcdark-mode .woocommerce .page-description blockquote:before {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product .price,
body.pcdm-enable.pcdark-mode .woocommerce ul.products li.product .price,
body.pcdm-enable.pcdark-mode .post-entry blockquote cite,
body.pcdm-enable.pcdark-mode .post-entry blockquote .author,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote cite,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote .author,
body.pcdm-enable.pcdark-mode.woocommerce .page-description blockquote cite,
body.pcdm-enable.pcdark-mode.woocommerce .page-description blockquote .author {
    color: var(--pcaccent-cl) !important;
}
body.pcdm-enable.pcdark-mode.woocommerce ul.products li.product .price *,
body.pcdm-enable.pcdark-mode .woocommerce ul.products li.product .price * {
    color: inherit !important;
}
body.pcdm-enable.pcdark-mode .penci-single-link-pages a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-entry td,
body.pcdm-enable.pcdark-mode .post-entry th {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .pencisc-button,
body.pcdm-enable.pcdark-mode .post-entry .pencisc-button,
body.pcdm-enable.pcdark-mode .woocommerce-product-details__short-description .pencisc-button {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci_list_shortcode li:before {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlight-black {
    background-color: rgba(0, 0, 0, 0.8);
    color: gray;
}
body.pcdm-enable.pcdark-mode .penci-highlight-black:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-black {
    background-color: rgba(0, 0, 0, 0.8);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-red {
    background-color: red;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-blue {
    background-color: #3f51b5;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-green {
    background-color: green;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-yellow {
    background-color: #ffcb00;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-highlighted-pink {
    background-color: #ffc0cb;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-box {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-box-outline {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-circle {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-circle-outline {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-regular {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropcap-bold {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-ilrelated-posts .pcilrp-item-grid .pcilrp-title a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcilrp-meta span {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .gird-post-share a {
    color: #939393;
}
body.pcdm-enable.pcdark-mode .gird-post-share a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .post-tags {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-tags > span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .nc_socialPanel .nc_tweetContainer a.nc_tweet,
body.pcdm-enable.pcdark-mode .swp_social_panel .nc_tweetContainer a.nc_tweet {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-share .count-number-like {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .post-share a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-share a:hover,
body.pcdm-enable.pcdark-mode .post-share a.liked {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box .single-comment-o {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-share a .dt-share {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .penci-social-share-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share .count-number-like,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3 .post-share-item {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .abio-style-4 .author-img img {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .author-content h5 {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-pagination .arrow {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond h3.comment-reply-title span,
body.pcdm-enable.pcdark-mode .post-box-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-carousel button.slick-prev,
body.pcdm-enable.pcdark-mode .penci-carousel button.slick-next {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel-slider .penci-owl-dot.active span,
body.pcdm-enable.pcdark-mode .penci-related-carousel .penci-owl-dot.active span {
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-post a i,
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .penci-mega-post a i,
body.pcdm-enable.pcdark-mode .item-related > a i,
body.pcdm-enable.pcdark-mode .home-featured-cat-content.style-12 .penci-magcat-carousel .magcat-thumb .mag-post-thumb i,
body.pcdm-enable.pcdark-mode .penci-grid.penci-fea-cat-style-13 li .item .thumbnail .icon-post-format {
    color: rgba(255, 255, 255, 0.9);
}
body.pcdm-enable.pcdark-mode ul.slick-dots li button:hover,
body.pcdm-enable.pcdark-mode ul.slick-dots li.slick-active button {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .under-construction-page .under-title {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown .countdown-amount {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown .countdown-period {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination a,
body.pcdm-enable.pcdark-mode .penci-pagination .disable-url {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination .newer:after {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li span,
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a,
body.pcdm-enable.pcdark-mode #comments_pagination span,
body.pcdm-enable.pcdark-mode #comments_pagination a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination ul.page-numbers li a:hover,
body.pcdm-enable.pcdark-mode #comments_pagination a:hover {
    color: var(--pclh-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button .ajax-more-text {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button.loading-posts span.ajaxdot:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode #footer-section {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #footer-copyright * {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #footer-copyright a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .go-to-top-parent span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #footer-section .go-to-top-parent i {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-go-to-top-floating i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content .widget-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow::after {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-border-arrow.penci-homepage-title.style-2:after,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-2 .penci-border-arrow:after {
    border-color: transparent;
    border-top-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow {
    background-color: var(--pcborder-cl);
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-13 .penci-border-arrow .inner-arrow {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-14 .inner-arrow,
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-14 .penci-border-arrow .inner-arrow {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-11 .inner-arrow a,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-12 .inner-arrow a,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-13 .inner-arrow a,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-14 .inner-arrow a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-sidebar-content.style-18 .penci-border-arrow:after,
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-18.penci-border-arrow:after {
    color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .widget ul li {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-advanced-tax.tax-style-1 ul li,
body.pcdm-enable.pcdark-mode .widget.widget_categories ul li,
body.pcdm-enable.pcdark-mode .widget.widget_archive ul li {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-advanced-tax.tax-style-1 ul li span.category-item-count,
body.pcdm-enable.pcdark-mode .widget.widget_categories ul li span.category-item-count {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode form.pc-searchform i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-mode .penci-sidebar-content .widget form.pc-searchform input.search-input {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .about-widget .about-me-heading {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-advanced-tax.tax-style-2 a,
body.pcdm-enable.pcdark-mode .widget .tagcloud a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-advanced-tax.tax-style-2 a:hover,
body.pcdm-enable.pcdark-mode .widget .tagcloud a:hover {
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode #wp-calendar caption {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-entry #wp-calendar caption {
    color: inherit;
}
body.pcdm-enable.pcdark-mode #wp-calendar tbody {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #wp-calendar tbody td a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-image a span.count-post,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-image a span.count-post {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text h4 a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text h4 a:hover,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text h4 a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .side-item .side-item-text .side-item-meta,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .side-item .side-item-text .side-item-meta a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .order-border-number,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .order-border-number {
    background-color: rgba(255, 255, 255, 0.3);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li .number-post,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li .number-post {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .side-newsfeed.pctlst {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci_post-slider-sc .penci-post-slider-style-1 .penci-widget-slide-detail h4 a,
body.pcdm-enable.pcdark-mode .penci_post-slider-sc .penci-post-slider-style-2 .penci-widget-slide-detail h4 a,
body.pcdm-enable.pcdark-mode .widget .penci-widget-slider .penci-widget-slide-detail h4 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci_post-slider-sc .penci-post-slider-style-3 .penci-widget-slide-detail h4 a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-widget-slide-detail .slide-item-date {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-prev,
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-widget-slider.penci-post-slider-style-1 .penci-owl-nav .owl-next,
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-prev,
body.pcdm-enable.pcdark-mode .penci-owl-carousel.penci-widget-slider.penci-post-slider-style-2 .penci-owl-nav .owl-next {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget .penci-widget-slider.penci-post-slider-style-3 .penci-widget-slide-detail h4 a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-post-slider-style-3 .penci-widget-slide-detail .slide-item-date {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget-social a i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .widget-social a:hover i {
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .widget-social.show-text a:hover span {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .widget-social.remove-circle a:hover i {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .quote-widget > i {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-pinterest-widget-container .pin_link a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-promo-item {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-promo-text h4 {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mc4wp-form input[type="submit"] {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .mc4wp-form input[type="submit"]:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-field-label {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit],
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form input[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form button[type=submit]:hover,
body.pcdm-enable.pcdark-mode div.wpforms-container .wpforms-form.wpforms-form .wpforms-page-button:hover,
body.pcdm-enable.pcdark-mode .mc4wp-form input[type="submit"]:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode .mc4wp-response {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .mc4wp-response p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .footer-instagram h4.footer-instagram-title > span:before {
    color: inherit;
}
body.pcdm-enable.pcdark-mode form#commentform > div.penci-gdpr-message {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author,
body.pcdm-enable.pcdark-mode .thecomment .comment-text span.author a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text > em {
    color: orange;
}
body.pcdm-enable.pcdark-mode .thecomment .comment-text > em i {
    color: #f3bd00;
}
body.pcdm-enable.pcdark-mode .post-comments span.reply a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .post-comments span.reply a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode #respond h3 {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #respond h3 a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #respond h3 small a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #respond h3 small a:hover {
    color: var(--pclh-cl);
}
body.pcdm-enable.pcdark-mode form#commentform p.mc4wp-checkbox label,
body.pcdm-enable.pcdark-mode form#commentform p.comment-subscription-form label {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #respond label,
body.pcdm-enable.pcdark-mode .wpcf7 label {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode #respond .comment-form label {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-login-register textarea,
body.pcdm-enable.pcdark-mode #respond textarea,
body.pcdm-enable.pcdark-mode .wpcf7 textarea {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-login-register input[type="submit"],
body.pcdm-enable.pcdark-mode #respond #submit,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"],
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"] {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-login-register input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode #respond #submit:hover,
body.pcdm-enable.pcdark-mode .wpcf7 input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget_wysija input[type="submit"]:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .contact-form input[type=submit] {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-button,
body.pcdm-enable.pcdark-mode .widget input[type="submit"],
body.pcdm-enable.pcdark-mode .widget button[type="submit"] {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-button,
body.pcdm-enable.pcdark-mode .widget input[type="submit"]:hover,
body.pcdm-enable.pcdark-mode .widget button[type="submit"]:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode form#commentform > .comment-form-cookies-consent {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget_block.widget_search .wp-block-search__no-button .wp-block-search__inside-wrapper:before {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .wp-block-search.wp-block-search__button-inside .wp-block-search__inside-wrapper {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .archive-box span,
body.pcdm-enable.pcdark-mode .archive-box h1 {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .nothing span {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span a:hover,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb a:hover,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb span.separator,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb span.separator,
body.pcdm-enable.pcdark-mode .penci-container-inside.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .container.penci-breadcrumb i {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-featured-caption.penci-fixed-caption.penci-caption-relative a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-entry pre {
    background-color: var(--pcbg-l-cl);
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-entry code {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .gallery .gallery-caption {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-post-gallery-container.single-slider figure p,
body.pcdm-enable.pcdark-mode .post-image .penci-owl-carousel figure p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-post-gallery-container.masonry .item-gallery-masonry .caption {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .icon-tweets {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-text {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-intents a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-widget-content .tweet-intents span:after {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form h4.header-signup-form {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-signup-form .mc4wp-form-fields > p,
body.pcdm-enable.pcdark-mode .penci-header-signup-form form > p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-portfolio-thumbnail .penci-image-placeholder {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li a,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li a:hover,
body.pcdm-enable.pcdark-mode .post-entry .penci-portfolio-filter ul li.active a,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li a:hover,
body.pcdm-enable.pcdark-mode .penci-portfolio-filter ul li.active a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .project-pagination .next-post a:after {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .project-pagination .prev-post a:before {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-pfl-ajaxdot {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-share-box .list-posts-share a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-share-box .list-posts-share a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-2 .list-posts-share a,
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-3 .list-posts-share a,
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-4 .list-posts-share a {
    color: black;
}
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-2 .list-posts-share a:hover,
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-3 .list-posts-share a,
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-3 .list-posts-share a:hover,
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-4 .list-posts-share a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-4 .list-posts-share a {
    background-color: #eee;
    border-color: #eee;
}
body.pcdm-enable.pcdark-mode .portfolio-share-box.style-4 .list-posts-share a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-releated-area .item-related .portfolio-cat a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .portfolio-releated-area .item-related .portfolio-cat a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-meta {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-meta i {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-btnbuy {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-metas .penci-review-btnbuy:hover {
    color: var(--pctext-cl);
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-review-container.penci-review-count h4 span,
body.pcdm-enable.pcdark-mode .penci-review-container.penci-review-count h4 a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-review .penci-review-good ul li:before {
    color: #22b162;
}
body.pcdm-enable.pcdark-mode .penci-review .penci-review-bad ul li:before {
    color: #e03030;
}
body.pcdm-enable.pcdark-mode .penci-review-score-total {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-chart-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .bbp-breadcrumb span,
body.pcdm-enable.pcdark-mode .bbp-breadcrumb a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .bbp-breadcrumb .bbp-breadcrumb-sep {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget_display_stats dd {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .widget_text .textwidget blockquote:before {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-vernav-toggle i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode form.pc-searchform.penci-hbg-search-form input.search-input:hover,
body.pcdm-enable.pcdark-mode form.pc-searchform.penci-hbg-search-form input.search-input:focus {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode form.pc-searchform.penci-hbg-search-form i {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:hover,
body.pcdm-enable.pcdark-mode #sidebar-nav form.pc-searchform.penci-hbg-search-form input.search-input:focus {
    border-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-cover .wp-block-cover-text a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry blockquote.wp-block-quote p,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote.wp-block-quote p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry blockquote.wp-block-quote cite,
body.pcdm-enable.pcdark-mode .wpb_text_column blockquote.wp-block-quote cite {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-file a,
body.pcdm-enable.pcdark-mode .container-single .post-entry .wp-block-file a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-pullquote blockquote p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-pullquote blockquote cite {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .post-entry a.has-white-color,
body.pcdm-enable.pcdark-mode .container-single .post-entry a.has-white-color,
body.pcdm-enable.pcdark-mode .post-entry a.wp-block-button__link,
body.pcdm-enable.pcdark-mode .container-single .post-entry a.wp-block-button__link {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry a.has-black-color,
body.pcdm-enable.pcdark-mode .container-single .post-entry a.has-black-color {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-entry a.has-vivid-purple-color,
body.pcdm-enable.pcdark-mode .container-single .post-entry a.has-vivid-purple-color {
    color: #9b51e0;
}
body.pcdm-enable.pcdark-mode .post-entry .wp-block-social-links:not(.is-style-logos-only) .wp-social-link a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .wp-block-separator.is-style-dots:before {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .wp-block-categories .category-item-count {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-wrap-gprd-law {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-gprd-law {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-gprd-law p {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-gprd-law .penci-gprd-accept,
body.pcdm-enable.pcdark-mode .penci-gprd-law .penci-gprd-more {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-gprd-law .penci-gprd-accept {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-wrap-gprd-law .penci-gdrd-show {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-missing-settings {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-missing-settings span {
    background-color: red;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-fancy-heading.penci-block-vc {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci-fancy-heading .penci-heading-content p {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-fancy-heading .penci-heading-title,
body.pcdm-enable.pcdark-mode .penci-fancy-heading .inner-tit {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-dmcheck > .elementor-widget-wrap {
    position: relative;
}
body.pcdm-enable.pcdark-mode .elementor-element .penci-ctslide-bg:before,
body.pcdm-enable.pcdark-mode .elementor-section.penci-dmcheck.penci-elbg-img:before,
body.pcdm-enable.pcdark-mode .penci-dmcheck.penci-elbg-img.elementor-column > .elementor-widget-wrap:before {
    content: '';
    position: absolute;
    top: 0;
    left: 0;
    bottom: 0;
    right: 0;
    z-index: 1;
    background-color: rgba(55, 55, 55, 0.75);
}
body.pcdm-enable.pcdark-mode .elementor-element .penci-ctslider-content,
body.pcdm-enable.pcdark-mode .elementor-element .penci-ctslider-content *,
body.pcdm-enable.pcdark-mode .penci-dmcheck .elementor-widget-wrap > div:not(.elementor-background-overlay) {
    position: relative;
    z-index: 11;
}
body.pcdm-enable.pcdark-mode .penci-dmcheck.penci-elbg-img .elementor-widget-wrap > div:not(.elementor-widget-penci-big-grid) * {
    color: var(--pctext-cl);
    border-color: var(--pctext-cl) !important;
}
body.pcdm-enable.pcdark-mode .elementor-widget-wrap .pcsl-itemin {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-dmcheck.penci-elbg-img .pcbg-bgoverlaytext.active-overlay,
body.pcdm-enable.pcdark-mode .penci-dmcheck.penci-elbg-img .penci-biggrid .penci-bgitin,
body.pcdm-enable.pcdark-mode .penci-dmcheck.penci-elbg-img .elementor-widget-wrap .pcsl-itemin {
    background-color: transparent !important;
}
body.pcdm-enable.pcdark-mode .penci-separator .penci-sep_line {
    border-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-separator .penci-heading-icon {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-icon {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-icon:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-icon {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-icon a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-framed .penci-icon {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-info-box .penci-ibox-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-info-box .penci-ibox-content {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-info-box .penci-ibox-stit {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-info-box .penci-ibox-readmore a,
body.pcdm-enable.pcdark-mode .penci-media-carousels .penci-media-rmbtn a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-animation-custom-2:hover .penci-ibox-icon,
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-animation-custom-1:hover .penci-ibox-icon {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-animation-custom-5 .penci-ibox-icon:hover,
body.pcdm-enable.pcdark-mode .penci-view-stacked .penci-animation-custom-4 .penci-ibox-icon:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-view-framed .penci-animation-custom-1 .penci-ibox-icon:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown-holding span {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown-amount {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown-period {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown-s2 .penci-span-inner {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-countdown-s3 .penci-span-inner {
    border-color: var(--pcbg-l-cl);
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-cup-number-wrapper {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-image-gallery .caption {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-gallery-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a {
    color: var(--pcl-cl);
}
body.pcdm-enable.pcdark-mode .penci-user-logged-in .penci-user-action-links a:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-mailchimp-block .mc4wp-form input[type="submit"]:not(:hover) {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-working-hours .penci-workingh-lists li {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-working-hours .penci-workingh-lists .penci-workingh-icon,
body.pcdm-enable.pcdark-mode .penci-working-hours .penci-workingh-lists .penci-listitem-title,
body.pcdm-enable.pcdark-mode .penci-working-hours .penci-workingh-lists .penci-listitem-hours {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-progress-bar .penci-probar-items .penci-probar-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-progress-bar .penci-review-process {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-progress-bar .penci-review-process span {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcsoc-wrapper .pcsoc-item {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-team_member_pos {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pcsc-st-filled .penci-social-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcsc-st-bordered .penci-social-item i {
    border-color: var(--pcborder-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s2 .penci-teammb-inner {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s3 .penci-teammb-inner {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-teammb-inner {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-team_member_desc {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-team_member_pos,
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-team_member_name,
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-social-wrap .penci-social-item {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-teammb-s4 .penci-social-wrap .penci-social-item:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s1 .penci-testimonail .penci-testi-blockquote {
    color: var(--pctext-cl);
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s1 .penci-testimonail .penci-testi-bq-icon:before {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-company {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-company .testiname {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s2 .penci-testimonail .penci-testi-blockquote {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s2 .penci-testimonail .penci-testi-bq-icon:before {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s3 .penci-testimonail .penci-testi-bq-icon:before {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s3 .penci-testimonail .penci-testi-blockquote {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s3 .penci-testi-name {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s5 .penci-testi-bq-icon:before,
body.pcdm-enable.pcdark-mode .penci-testi-s4 .penci-testi-bq-icon:before {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-testi-s5 .penci-testi-blockquote:after {
    border-color: #f5f5f5 transparent transparent transparent;
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-playlist-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-playlist-title a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-playlist-title h2 {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-play {
    background-color: #111;
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-thumb {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-custom-scroll::-webkit-scrollbar-corner {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-nav .playlist-panel-item {
    color: #111;
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-play-icon {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-title:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-playlist-item .penci-video-duration {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pencisc-column-2.penci-video_playlist .penci-video-nav .playlist-panel-item,
body.pcdm-enable.pcdark-mode .pencisc-column-1.penci-video_playlist .penci-video-nav .playlist-panel-item {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-media-carousels .penci-image-holder {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci-media-carousels .penci-media-stit {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-media-rmbtn i,
body.pcdm-enable.pcdark-mode .penci-media-rmbtn svg {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-weather-widget {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-weather-degrees-wrap i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-weather-week:before {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-item {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing_featured .penci-pricing-ribbon {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing_featured .penci-pricing-ribbon-text {
    background-color: #ff6618;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-item.penci-pricing-s2 {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-item .penci-pricing-icon i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-pricing-item .penci-pricing-subtitle {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-item .penci-pricing-title,
body.pcdm-enable.pcdark-mode .penci-pricing-item .penci-price-unit {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-item .penci-pricing-btn {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-btn-borders .penci-pricing-btn {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-pricing-btn-borders .penci-pricing-btn:hover {
    border-color: var(--pcaccent-cl);
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcbtn-wrapper a.pcbtn {
    color: var(--pctext-cl) !important;
    background-color: var(--pcaccent-cl) !important;
}
body.pcdm-enable.pcdark-mode .pcbtn-wrapper a.pcbtn .pcbtn-wrapperin {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode .penci-slides-wrap .pencislider-caption,
body.pcdm-enable.pcdark-mode .penci-slides-wrap .pencislider-title {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-slider_btnwrap .pencislider-btn {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-slider_btnwrap .pencislider-btn:hover {
    border-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-page-header-wrap {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-page-header-wrap .penci-page-header-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-page-header-wrap .penci-page-header-title:before {
    color: inherit;
}
@media only screen and (max-width: 960px) {
    body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-nav .playlist-panel-item {
        color: var(--pctext-cl);
    }
}
body.pcdm-enable.pcdark-mode .menu-item-has-label .menu-label {
    color: var(--pctext-cl);
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .menu-item-has-label .menu-label.label-style-1:before,
body.pcdm-enable.pcdark-mode .menu-item-has-label .menu-label.label-style-2:before {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .menu-item-has-label .menu-label.label-style-4:before {
    border-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-dropdown-menu:before {
    background-color: inherit;
}
body.pcdm-enable.pcdark-mode .button-popup-content,
body.pcdm-enable.pcdark-mode .penci-popup-content,
body.pcdm-enable.pcdark-mode .penci-age-verify {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-age-verify .penci-age-verify-buttons .button {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-age-verify .penci-age-verify-buttons .button.penci-age-verify-forbidden {
    color: var(--pctext-cl);
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .mp-link:not(.penci-lazy) {
    background-color: rgba(0, 0, 0, 0.5);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .mp-link:before {
    background-color: var(--obg);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .mp-link:hover:before {
    background-color: var(--ohbg);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mpct:hover ~ .mp-link:before {
    background-color: var(--ohbg);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mc .pc-fho-mt a,
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mc .pc-fho-mm a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mi-i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mi-i a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pc-fho-wrap .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lt a,
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lm span,
body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lm a,
body.pcdm-enable.pcdark-mode .pc-fho-mpct .grid-post-box-meta span,
body.pcdm-enable.pcdark-mode .pc-fho-mpct .grid-post-box-meta a {
    color: var(--pctext-cl);
}
@media only screen and (max-width: 767px) {
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mp:before {
        background-color: var(--obg);
    }
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-mp:hover:before {
        background-color: var(--ohbg);
    }
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lm a {
        color: var(--pctext-cl);
    }
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lm span {
        color: var(--pcmeta-cl);
    }
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-li .cat > a.penci-cat-name {
        color: var(--pcaccent-cl);
    }
    body.pcdm-enable.pcdark-mode .pc-fho-wrap .pc-fho-lt a {
        color: var(--pcheading-cl);
    }
}
body.pcdm-enable.pcdark-mode .elementor-element .pcbg-content-inner .pcbg-title,
body.pcdm-enable.pcdark-mode .elementor-element .pcbg-content-inner .pcbg-title a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .elementor-element .pcbg-content-inner .pcbg-title a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share:not(.penci-icon-full) .post-share-item,
body.pcdm-enable.pcdark-mode .pcnew-share.penci-icon-full .post-share-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share .post-share-plike {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share.border-style .post-share-plike {
    background-color: transparent;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-txt.post-share a .dt-share {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .show-txt.focus-icon .post-share-item i {
    background-color: rgba(0, 0, 0, 0.5);
}
body.pcdm-enable.pcdark-mode .show-txt.focus-icon .post-share-item.post-share-plike i {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .show-txt.txt-below.post-share a .dt-share {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .show-txt.border-style.post-share a .dt-share {
    color: var(--pctext-cl);
    border-color: rgba(0, 0, 0, 0.1);
}
body.pcdm-enable.pcdark-mode .black-ver .post-share-item,
body.pcdm-enable.pcdark-mode .black-ver .post-share-item i {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box-n19.pcnew-share.border-style .post-share-item i,
body.pcdm-enable.pcdark-mode .tags-share-box-n20.pcnew-share.border-style .post-share-item i,
body.pcdm-enable.pcdark-mode .tags-share-box-n20 .post-share-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box-n19.pcnew-share.border-style .post-share-item.post-share-plike i,
body.pcdm-enable.pcdark-mode .tags-share-box-n20.pcnew-share.border-style .post-share-item.post-share-plike i {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .tags-share-box-n20 .post-share-item i:after {
    border-color: transparent transparent transparent transparent;
}
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text:before,
body.pcdm-enable.pcdark-mode .pcnew-share .penci-social-share-text:after {
    border-color: transparent transparent transparent var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box-n19.post-share a.penci-post-like,
body.pcdm-enable.pcdark-mode .tags-share-box-n20.post-share a.penci-post-like {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share.penci-social-colored .post-share-item.post-share-plike {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .post-share.tags-share-box-n14 .count-number-like,
body.pcdm-enable.pcdark-mode .pcnew-share.penci-social-colored .post-share-item.post-share-plike .count-number-like {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pcnew-share.border-style .post-share-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s1 .pcmt-icon {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s2 .pcmt-icon {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s3 .pcmt-icon {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s3 .pcmt-icon:after {
    border-color: transparent transparent transparent var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s4 .pcmt-icon:before {
    border-color: transparent transparent transparent #fff;
}
body.pcdm-enable.pcdark-mode .post-box-meta-single.style-s4 .pcmt-icon:after {
    border-color: transparent transparent transparent var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .pctmp-term-list.label-style-s1 .term-labels,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s1 .pctmp-term-item {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pctmp-term-list.label-style-s2 .term-labels,
body.pcdm-enable.pcdark-mode .pctmp-term-list.label-style-s3 .term-labels,
body.pcdm-enable.pcdark-mode .pctmp-term-list.label-style-s4 .term-labels,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s2 .pctmp-term-item,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s3 .pctmp-term-item,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s4 .pctmp-term-item {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pctmp-term-list.label-style-s4 .term-labels,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s4 .pctmp-term-item {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .pctmp-term-list .pctmp-term-item:hover,
body.pcdm-enable.pcdark-mode .pctmp-term-list .pctmp-term-item.current-item,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s4 .pctmp-term-item.current-item,
body.pcdm-enable.pcdark-mode .pctmp-term-list.term-style-s4 .pctmp-term-item:hover {
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
    color: white;
}
body.pcdm-enable.pcdark-mode .penci-social-colored .post-share-item.post-share-expand i,
body.pcdm-enable.pcdark-mode .pcnew-share.size-large.penci-icon-full .post-share-item.post-share-expand i,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s2 .post-share-item.post-share-expand {
    background-color: var(--pcbg-cl);
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s2 .post-share-item.post-share-plike .count-number-like,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-s2 .post-share-item.post-share-plike a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat.s1 .cat > .penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-standard-cat.s2 .cat > .penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-standard-cat.s3 .cat > .penci-cat-name,
body.pcdm-enable.pcdark-mode .penci-standard-cat.s4 .cat > .penci-cat-name {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat.s2 .cat > .penci-cat-name {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat.s3 .cat > .penci-cat-name {
    background-color: var(--pctext-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat.s4 .cat > .penci-cat-name {
    background-color: transparent;
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-standard-cat.s4 .cat > .penci-cat-name:hover {
    border-color: var(--pcaccent-cl);
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc-wrapper {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc-wrapper.s2 {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc-wrapper .penci-toc-title-toggle {
    background-color: var(--pcmeta-cl);
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc-wrapper.s2 .penci-toc-title-toggle {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc ul a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc ul li.active > a,
body.pcdm-enable.pcdark-mode .penci-toc ul a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-toc-wrapper.s3 {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .pcsb-ft-o .penci-container-inside.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .container.penci-breadcrumb i,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .cat > a.penci-cat-name,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .post-box-meta-single a,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard h2,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard .pc_titlebig_standard,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard .pc_titlebig_standard a,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard .post-title,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard h2 a,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .post-box-meta-single span,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .post-box-meta-single span i,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard .author-post span,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .header-standard .author-post span a,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .penci-container-inside.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .penci-container-inside.penci-breadcrumb span a,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .container.penci-breadcrumb span,
body.pcdm-enable.pcdark-mode .pcsb-ft-o .container.penci-breadcrumb span a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-share.pcnew-share .count-number-like,
body.pcdm-enable.pcdark-mode .post-share.tags-share-box-2_3.post-share .count-number-like,
body.pcdm-enable.pcdark-mode .tags-share-box.tags-share-box-2_3.post-share .post-share-item .penci-post-like {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .post-share.pcnew-share.border-style .count-number-like {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul li {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul li a {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul li i {
    color: inherit;
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul li > a.clactive,
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul li:hover > a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pcnav-lgroup ul ul li a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-homepage-title.style-4 .pcnav-lgroup {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-loading-animation-1 .penci-loading-animation,
body.pcdm-enable.pcdark-mode .penci-loading-animation-1 .penci-loading-animation:before,
body.pcdm-enable.pcdark-mode .penci-loading-animation-1 .penci-loading-animation:after,
body.pcdm-enable.pcdark-mode .penci-loading-animation-5 .penci-loading-animation,
body.pcdm-enable.pcdark-mode .penci-loading-animation-6 .penci-loading-animation:before,
body.pcdm-enable.pcdark-mode .penci-loading-animation-7 .penci-loading-animation,
body.pcdm-enable.pcdark-mode .penci-loading-animation-8 .penci-loading-animation,
body.pcdm-enable.pcdark-mode .penci-loading-animation-9 .penci-loading-circle-inner:before {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-three-bounce .one,
body.pcdm-enable.pcdark-mode .penci-three-bounce .two,
body.pcdm-enable.pcdark-mode .penci-three-bounce .three {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-loading-animation-1 > div {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-user-lists .count {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci_posts_tabs_widget .tabs ul > li.active a {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci_posts_tabs_widget .author-info {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .penci_snapchat_widget .pc-snapchat-avatar {
    background-color: transparent;
}
body.pcdm-enable.pcdark-mode .penci_snapchat_widget .pc-snapchat-wrapper a:hover {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-tiktok-verified {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-tweets-lists .tweet-intents-inner > span a {
    color: var(--pcmeta-cl);
}
body.pcdm-enable.pcdark-mode .pc-widget-advanced-tax.tax-style-1.hlmark .category-item-count {
    background-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-wstories-wrapper .pc-webstory-thumb-wrapper {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .pc-wstories-wrapper .pc-webstory-item.seen .pc-webstory-thumb-wrapper {
    background-color: gray;
}
body.pcdm-enable.pcdark-mode .pc-wstories-popup-wrapper {
    background-color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .pc-wstories-popup-wrapper .pc-ws-btn {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .penci-social-wrap .penci-social-item,
body.pcdm-enable.pcdark-mode .elementor .elementor-element .penci-social-wrap .penci-social-item i {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci_recent-posts-sc ul.side-newsfeed li.featured-news2 .side-item .side-item-text,
body.pcdm-enable.pcdark-mode .widget ul.side-newsfeed li.featured-news2 .side-item .side-item-text {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .penci-biggrid .penci-bgitin {
    background-color: transparent !important;
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element .pcbg-bgoverlaytext.active-overlay {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .elementor .elementor-element:not(.elementor-motion-effects-element-type-background) > .elementor-widget-wrap,
body.pcdm-enable.pcdark-mode .elementor .elementor-element > .elementor-widget-wrap > .elementor-motion-effects-container > .elementor-motion-effects-layer {
    background-color: transparent !important;
}
body.pcdm-enable.pcdark-mode .navigation .penci-megamenu .penci-mega-child-categories,
body.pcdm-enable.pcdark-mode .navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode .navigation .menu .children {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .cat > a.penci-cat-name {
    color: var(--pcaccent-cl) !important;
}
body.pcdm-enable.pcdark-mode .navigation .menu .sub-menu,
body.pcdm-enable.pcdark-mode .navigation .menu .children,
body.pcdm-enable.pcdark-mode .navigation ul.menu ul.sub-menu li a {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode #navigation .penci-megamenu .post-mega-title a,
body.pcdm-enable.pcdark-mode .pc-builder-element .navigation .penci-megamenu .penci-content-megamenu .penci-mega-latest-posts .penci-mega-post .post-mega-title a {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .elementor-element .penci-pagination.penci-ajax-more a.penci-ajax-more-button {
    color: #fff;
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .penci-recipe-tagged .prt-icon span,
body.pcdm-enable.pcdark-mode .penci-recipe-action-buttons .penci-recipe-button:hover,
body.pcdm-enable.pcdark-mode .elementor-element .penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover {
    color: #fff;
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover .ajaxdot,
body.pcdm-enable.pcdark-mode .penci-pagination.penci-ajax-more a.penci-ajax-more-button:hover i {
    color: #fff;
}
body.pcdm-enable.pcdark-mode .penci-woo-before-main-content .penci-products-per-page span,
body.pcdm-enable.pcdark-mode .single-product-share a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sticky-cart,
body.pcdm-enable.pcdark-mode .single-product-share a {
    background-color: var(--pcbg-l-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .jq-toast-single a {
    border-color: transparent;
}
/* Switcher */
.pc_dm_switch {
    position: relative;
    display: block;
    width: 45px;
    height: 25px
}
.pc_dm_switch input {
    opacity: 0;
    width: 0;
    height: 0
}
.pc_dm_switch .slider {
    position: absolute;
    cursor: pointer;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    background-color: var(--pcdm_btnbg);
    transition: .4s
}
.pc_dm_switch .slider:before {
    color: var(--pcdm_btnd);
    background-color: var(--pcdm_btndbg);
    font-family: "penciicon";
    font-size: 14px !important;
    position: absolute;
    content: "\f117";
    height: 19px;
    line-height: 20px;
    width: 19px;
    text-align: center;
    left: 3px;
    bottom: 3px;
    box-shadow: 0 1px 3px rgba(0, 0, 0, .3);
    transition: .25s;
}
body.pcdark-mode .pc_dm_switch .slider {
    background-color: hsla(0, 0%, 100%, .3)
}
body.pcdark-mode .pc_dm_switch .slider:before {
    content: "\f116";
    transform: translateX(19px);
    color: var(--pcdm_btnn);
    background: var(--pcdm_btnnbg);
}
.pc_dm_switch .slider.round {
    border-radius: 25px
}
.pc_dm_switch .slider.round:before {
    border-radius: 50%
}
.penci-top-bar .pc_dm_mode,
#navigation .pc_dm_mode {
    float: right;
    margin-left: 12px;
    height: 58px;
    display: flex;
    align-items: center;
    transition: .3s;
}
body.rtl #navigation .pc_dm_mode {
    margin-left: 0;
    margin-right: 12px;
    float: left;
}
body.rtl #navigation.header-4 .pc_dm_mode,
body.rtl #navigation.header-5 .pc_dm_mode,
#navigation.header-4 .pc_dm_mode,
#navigation.header-5 .pc_dm_mode {
    float: none;
    display: inline-flex;
}
@media only screen and (min-width: 961px) {
    #navigation.header-6 .pc_dm_mode,
    #navigation.header-10 .pc_dm_mode,
    #navigation.header-11 .pc_dm_mode {
        height: 80px;
    }
}
.is-sticky #navigation.header-6 .pc_dm_mode,
.is-sticky #navigation.header-10 .pc_dm_mode,
.is-sticky #navigation.header-11 .pc_dm_mode {
    height: 58px;
}
.penci-top-bar .pc_dm_mode {
    height: 32px;
}
@media only screen and (max-width: 960px) {
    #navigation .pc_dm_mode {
        height: 58px;
        line-height: 58px;
    }
}
.penci-top-bar .pc_dm_mode .pc_dm_switch .slider {
    background-color: rgba(255, 255, 255, 0.1);
}
body.pclight-mode .penci-show-onlight,
body.pcdark-mode .penci-show-ondark {
    display: block;
}
body.pclight-mode .penci-show-ondark,
body.pcdark-mode .penci-show-onlight {
    display: none;
}
.pc_dm_mode.style_2 .pc_dm_switch:before,
.pc_dm_mode.style_2 .pc_dm_switch:after {
    content: "\f116";
    font-family: "penciicon";
    font-size: 14px !important;
    position: absolute;
    left: -18px;
    top: 50%;
    transform: translateY(-50%);
    color: var(--pcdm_btnd);
}
.pc_dm_mode.style_2 .pc_dm_switch:after {
    content: "\f117";
    left: auto;
    right: -18px;
    color: var(--pcdm_btnn);
}
.pc_dm_mode.style_2 .pc_dm_switch .slider:before {
    content: '';
}
.pc_dm_mode.style_2 {
    padding-left: 18px;
    padding-right: 18px;
}
.pc_dm_mode.style_3 .pc_dm_switch {
    width: 25px;
}
.pc_dm_mode.style_3 .pc_dm_switch .slider.round:before,
.pc_dm_mode.style_3 .pc_dm_switch .slider.round:after,
.pc_dm_mode.style_3 .pc_dm_switch .slider.round {
    border-radius: 50%;
}
body.pcdark-mode .pc_dm_mode.style_3 .pc_dm_switch .slider:before {
    transform: none;
}
.pc_dm_mode.style_4 .pc_dm_switch {
    width: 25px;
}
.pc_dm_mode.style_4 .pc_dm_switch .slider.round:before,
.pc_dm_mode.style_4 .pc_dm_switch .slider.round:after,
.pc_dm_mode.style_4 .pc_dm_switch .slider.round {
    border-radius: 0;
    box-shadow: unset;
    background-color: transparent;
}
.pc_dm_mode.style_4 .pc_dm_switch .slider {
    box-shadow: none;
}
body.pcdark-mode .pc_dm_mode.style_4 .pc_dm_switch .slider:before {
    transform: none;
    box-shadow: none;
    background: var(--pcdm_btnnbg);
}
body.pcdark-mode .pc_dm_mode.style_4 .pc_dm_switch .slider {
    color: var(--pcdm_btnn);
    background: var(--pcdm_btnnbg);
}
body.pcdark-mode .pc_dm_mode.style_4 .pc_dm_switch .slider,
.penci-top-bar .pc_dm_mode.style_4 .pc_dm_switch .slider {
    background: transparent;
}
body.pcdark-mode .pcbtn-wrapper a.pcbtn,
body.pcdark-mode .penci-dmcheck:not(.penci-elbg-img) .pcbtn-wrapper a.pcbtn {
    background: var(--pcaccent-cl);
    border-color: var(--pcaccent-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode #navigation.header-11 > .container {
    background: var(--pcbg-cl) !important;
}
/* WooCommerce*/
body.pcdm-enable.pcdark-mode .quick-shop-shown .quick-shop-wrapper {
    background-color: rgba(55, 55, 55, 0.95);
}
body.pcdm-enable.pcdark-mode .variations select,
body.pcdm-enable.pcdark-mode .woocommerce-ordering select,
body.pcdm-enable.pcdark-mode .penci-widget-layered-nav-dropdown-form select {
    border-color: rgba(0, 0, 0, 0.9);
    background-color: transparent;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-header-cart-detail .woocommerce-mini-cart__buttons.buttons,
body.pcdm-enable.pcdark-mode .penci-header-cart-detail .woocommerce-mini-cart__total.total,
body.pcdm-enable.pcdark-mode .penci-header-cart-detail {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce-ordering select option,
body.pcdm-enable.pcdark-mode .penci-widget-layered-nav-dropdown-form select option,
body.pcdm-enable.pcdark-mode .variations select option {
    background-color: transparent;
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode div.quantity input[type="number"],
body.pcdm-enable.pcdark-mode div.quantity input[type="button"] {
    background: transparent;
}
body.pcdm-enable.pcdark-mode .penci-top-relate-post ul li.item-shop-link svg {
    fill: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-filter .sidefilter-heading,
body.pcdm-enable.pcdark-mode .penci-sidebar-cart .sidecart-heading {
    background-color: var(--pcbg-cl);
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .penci-sidebar-filter,
body.pcdm-enable.pcdark-mode .penci-sidebar-cart,
body.pcdm-enable.pcdark-mode .penci-sidebar-cart .penci-woo-cart-buttons-group,
body.pcdm-enable.pcdark-mode .penci-sidebar-cart .penci-woo-cart-total-group {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce table.shop_table td.product-name a,
body.pcdm-enable.pcdark-mode .woocommerce table.shop_table th {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .select2-dropdown,
body.pcdm-enable.pcdark-mode .select2-container--default .select2-selection--single,
body.pcdm-enable.pcdark-mode .woocommerce-checkout #payment ul.payment_methods,
body.pcdm-enable.pcdark-mode .woocommerce .woocommerce-error,
body.pcdm-enable.pcdark-mode .woocommerce .woocommerce-info,
body.pcdm-enable.pcdark-mode .woocommerce .woocommerce-message,
body.pcdm-enable.pcdark-mode.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner table,
body.pcdm-enable.pcdark-mode.woocommerce-checkout form.checkout.woocommerce-checkout .woocommerce-checkout-review-order-inner .woocommerce-checkout-payment {
    background-color: var(--pcbg-l-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce table.shop_table a.remove,
body.pcdm-enable.pcdark-mode .woocommerce table.shop_table a.remove:before {
    color: var(--pctext-cl) !important;
}
body.pcdm-enable.pcdark-mode.woocommerce-cart table.cart td.actions .coupon .input-text,
body.pcdm-enable.pcdark-mode .woocommerce .input-text,
body.pcdm-enable.pcdark-mode .woocommerce form .form-row .input-text,
body.pcdm-enable.pcdark-mode .woocommerce form .form-row .input-text {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce button.button {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .select2-container--default .select2-results__option[aria-selected="true"],
body.pcdm-enable.pcdark-mode .select2-container--default .select2-results__option[data-selected="true"] {
    background-color: var(--pcbg-d-cl);
}
body.pcdm-enable.pcdark-mode .penci-products-tabs .products-tabs-title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .products.product-list .penci-soledad-product .penci-product-loop-inner-content,
body.pcdm-enable.pcdark-mode .penci-sidebar-cart .penci-woo-cart-total-group {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce-product-gallery .penci-thumbnail-slider .penci-custom-thumbnail-nav button {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce div.product div.images .woocommerce-product-gallery__trigger {
    background-color: var(--pcbg-d-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce div.product div.images .woocommerce-product-gallery__trigger:hover {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce-accordion-item .penci-review-style-default #comments .woocommerce-Reviews-title,
body.pcdm-enable.pcdark-mode .product .woocommerce-accordion-item #respond .comment-reply-title,
body.pcdm-enable.pcdark-mode .woocommerce div.product .product_title,
body.pcdm-enable.pcdark-mode.woocommerce div.product .product_title {
    color: var(--pcheading-cl);
}
body.pcdm-enable.pcdark-mode .penci-content-quickview {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce-product-gallery.thumbnail-bottom .penci-thumbnail-slider .penci-custom-thumbnail-nav button:hover {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-top-relate-post .inner-content {
    background-color: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .woocommerce div.product form.cart .button,
body.pcdm-enable.pcdark-mode.woocommerce div.product form.cart .button {
    background-color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-mode .hotspot-content {
    background-color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .variations select,
body.pcdm-enable.pcdark-mode .woocommerce-ordering select,
body.pcdm-enable.pcdark-mode .penci-widget-layered-nav-dropdown-form select {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode.woocommerce .widget_layered_nav_filters ul li a:before {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-mode .penci-woo-before-main-content .penci-products-per-page a.current-variation {
    color: var(--pcaccent-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode #navigation,
body.pcdm-enable.pcdark-df.pclight-mode .show-search {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode #navigation,
body.pcdm-enable.pcdark-df.pclight-mode #navigation.header-layout-bottom {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .top-search-classes a.cart-contents,
body.pcdm-enable.pcdark-df.pclight-mode .pcheader-icon > a, #navigation .button-menu-mobile,
body.pcdm-enable.pcdark-df.pclight-mode .header-social a i,
body.pcdm-enable.pcdark-df.pclight-mode .main-nav-social a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .penci-sidebar-content .widget-title {
    background: var(--pcbg-cl);
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .about-widget .about-me-heading,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget select,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget select option,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .menu li a,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget ul.side-newsfeed li .side-item .side-item-text h4 a,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg #wp-calendar tbody td a,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget.widget_categories ul li,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget.widget_archive ul li,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget-social a i,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget-social a span,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget-social.show-text a span,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget a {
    color: var(--pctext-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget ul li,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .menu li,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget-social a i,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .penci-home-popular-posts,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg #respond textarea,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .wpcf7 textarea,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg #respond input,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="date"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="datetime"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="datetime-local"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="email"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="month"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="number"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="password"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="range"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="search"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="tel"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="text"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="time"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="url"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form input[type="week"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form select,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg div.wpforms-container .wpforms-form.wpforms-form textarea,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .wpcf7 input,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget_wysija input,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget select,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget ul ul,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget .tagcloud a,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg #wp-calendar tbody td,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg #wp-calendar thead th,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget input[type="text"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget input[type="email"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget input[type="date"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget input[type="number"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg .widget input[type="search"],
body.pcdm-enable.pcdark-df.pclight-mode .widget input[type="password"],
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg form.pc-searchform input.search-input,
body.pcdm-enable.pcdark-df.pclight-mode .penci-vernav-enable.penci-vernav-poleft .penci-menu-hbg,
body.pcdm-enable.pcdark-df.pclight-mode .penci-vernav-enable.penci-vernav-poright .penci-menu-hbg,
body.pcdm-enable.pcdark-df.pclight-mode .penci-menu-hbg ul.sub-menu {
    border-color: var(--pcborder-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-11 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-12 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-14 .penci-border-arrow .inner-arrow:before,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-13 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow {
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow,
body.pcdm-enable.pcdark-df.pclight-mode .penci-sidebar-content.style-15 .penci-border-arrow .inner-arrow {
    color: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-df.pclight-mode .header-standard > h2 a {
    color: var(--pcheading-cl);
}
.penci-ver-dm-switcher .pc_dm_mode {
    display: flex;
    justify-content: center;
    margin: -5px 0 30px;
}
body.pcdm-enable.pcdark-mode .penci-menu-hbg-overlay,
body.pcdm-enable.pcdark-mode #close-sidebar-nav {
    background: rgba(24, 24, 24, 0.5);
}
@media only screen and (min-width: 960px) {
    body.pcdm-enable.pclight-mode #navigation.header-11 > .container {
        background: var(--pcbg-cl);
    }
}
body.pcdm-enable.pcdark-mode .show-search,
body.pcdm-enable.pcdark-mode .penci-enews-ticker.penci-topbar-trending, body.pcdm-enable.pcdark-mode .grid-overlay-meta .grid-header-box {
    background: var(--pcbg-cl);
}
body.pcdm-enable.pcdark-mode .penci-video_playlist .penci-video-nav {
    background: var(--pcbg-l-cl);
}
body.pcdm-enable.pcdark-mode .widget.penci_search_box_widget .penci-opened .penci-search-results-wrapper,
body.pcdm-enable.pcdark-mode .search-results-wrapper .penci-dropdown-results.penci-opened {
    -moz-box-shadow: 0 2px 3px rgba(255, 255, 255, 0.15);
    -webkit-box-shadow: 0 2px 3px rgba(255, 255, 255, 0.15);
    box-shadow: 0 2px 3px rgba(255, 255, 255, 0.15);
}
body.pcdm-enable.pcdark-mode .penci-patreon-badge-wrap svg [data-color="2"] {
    fill: #000;
}
body.pcdm-enable.pcdark-mode .widget .penci-buymeacoffee-badge-wrap svg path:last-child {
    fill: #fff;
}